import {
  LOAD_USER, LOAD_USER_SUCCESS, LOAD_USER_FAILED,
  SAVE_USER, SAVE_USER_SUCCESS, SAVE_USER_FAILED,
  SAVE_PASSWORD, SAVE_PASSWORD_SUCCESS, SAVE_PASSWORD_FAILED,
  SAVE_PROFILE_PICTURE_SUCCESS,
  GET_ACCOUNTS, GET_ACCOUNTS_SUCCESS, GET_ACCOUNTS_FAILURE
} from "./AccountActionCreator"
import ReduxStatus from '../Common/Constants/ReduxStatus'

const initialState = {
  userData: {
    status: ReduxStatus.empty,
    user: {},
    message: "",
  },
  passwordData: {
    status: ReduxStatus.empty,
    message: "",
  },
  accountList: {
    status: ReduxStatus.empty,
    activePage: 1,
    totalPage: 1,
    totalRecord: 0,
    data: [],
    message: "",
    filter: {},
  }
};

const actionsMap = {
  // Async action
  [LOAD_USER]: state => {
    return {
      ...state,
      userData: {
        user: {
          ...state.userData.user,
        },
        status: ReduxStatus.loading,
        message: "",
      }
    };
  },
  [LOAD_USER_SUCCESS]: (state, payload) => {
    return {
      ...state,
      userData: {
        user: {
          ...payload,
        },
        status: ReduxStatus.loaded,
        message: "",
      }
    };
  },
  [LOAD_USER_FAILED]: (state, payload) => {
    return {
      ...state,
      userData: {
        user: {},
        status: ReduxStatus.loadFailed,
        message: payload.message,
      }
    };
  },
  [SAVE_USER]: state => {
    return {
      ...state,
      userData: {
        user: {
          ...state.userData.user,
        },
        status: ReduxStatus.saving,
        message: "",
      }
    };
  },
  [SAVE_USER_SUCCESS]: (state, payload) => {
    return {
      ...state,
      userData: {
        user: {
          ...state.userData.user,
          ...payload,
        },
        status: ReduxStatus.saved,
      }
    };
  },
  [SAVE_USER_FAILED]: (state, payload) => {
    return {
      ...state,
      userData: {
        user: {
          ...state.userData.user,
        },
        status: ReduxStatus.saveFailed,
        message: payload.message,
      }
    };
  },
  [SAVE_PROFILE_PICTURE_SUCCESS]: (state, payload) => {
    return {
      ...state,
      userData: {
        ...state.userData,
        user: {
          ...payload,
        },
      }
    };
  },

  [SAVE_PASSWORD]: state => {
    return {
      ...state,
      passwordData: {
        status: ReduxStatus.saving,
        message: "",
      }
    };
  },
  [SAVE_PASSWORD_SUCCESS]: (state) => {
    return {
      ...state,
      passwordData: {
        status: ReduxStatus.saved,
        message: "",
      }
    };
  },
  [SAVE_PASSWORD_FAILED]: (state, payload) => {
    return {
      ...state,
      passwordData: {
        status: ReduxStatus.saveFailed,
        message: payload.message,
      }
    };
  },

  [GET_ACCOUNTS]: (state, payload) => {
    return {
      ...state,
      accountList: {
        ...state.accountList,
        status: ReduxStatus.loading,
        message: payload.message
      }
    };
  },
  [GET_ACCOUNTS_SUCCESS]: (state, { activePage, totalPage, totalRecord, data, filter }) => {
    return {
      ...state,
      accountList: {
        ...state.accountList,
        activePage,
        totalPage,
        totalRecord,
        data,
        status: ReduxStatus.loaded,
        message: "",
        filter,
      }
    };
  },
  [GET_ACCOUNTS_FAILURE]: (state, payload) => {
    return {
      ...state,
      accountList: {
        ...state.accountList,
        status: ReduxStatus.loadFailed,
        message: payload.message,
      }
    };
  },
};

export default function reducer(state = initialState, action = {}) {
  const fn = actionsMap[action.type];
  return fn ? fn(state, action.payload) : state;
}
