import React from 'react';
import injectSheet from "react-jss";
import style from '../style';
import AccountActionCreator from "../../AccountActionCreator";
import AppContext from "../../../Common/Constants/AppContext";

const FILE_TYPE_SIZE = {
  image: 5,
};

class AccountAvatar extends React.Component {
  static contextType = AppContext;
  constructor() {
    super();
    this.handleUploadImage = this.handleUploadImage.bind(this);
    this.removeImage = this.removeImage.bind(this);
  }

  validateUploadFileType(file, type) {
    if (file.type.indexOf(type) > -1) {
      const fileSize = file.size / 1024 / 1024;
      if (fileSize > FILE_TYPE_SIZE[type]) {
        return false;
      }
    } else {
      return false;
    }
    return true;
  }

  handleUploadImage(e) {
    if (e.target.files.length > 0) {
      const { user } = this.props;
      const {dispatch} = this.context;
      const file = e.target.files[0];

      // Check the file type.
      if (!file.type.match('image.*')) {
        return;
      }

      const reader = new FileReader();

      (function () {
        reader.onload = function (event) {
          dispatch(AccountActionCreator.saveProfilePicture({
            ...user,
            profile_picture: event.target.result,
          }));
        };
      }());
      reader.readAsDataURL(file);
    }
  }

  removeImage() {
    const { user } = this.props;
    const {dispatch} = this.context;
    dispatch(AccountActionCreator.saveProfilePicture({
      ...user,
      profile_picture: "",
    }));
  }

  render() {
    const { classes, user } = this.props;
    const { intl: { messages } } = this.context;
    return (
      <div className={classes.accountAvatarSection}>
        <div className={classes.avatarImage}>
          {user.profile_picture && user.profile_picture.original ?
            <img className='profile-image' src={user.profile_picture.original} alt="" />
            : <img className='profile-image' src={require("../../../Assets/avatar.png")} alt='' />
          }
        </div>
        <div className={classes.accountAvatarAction}>
          <div className="upload-image-container">
            <div className="upload-image-text">
              {messages.uploadImage}
            </div>
            <input
              className="input-upload-file"
              type="file" onChange={this.handleUploadImage}
              accept=".png,.jpg,.jpeg,.gif"
            />
          </div>
          <div className="remove-image"
               onClick={this.removeImage}>{messages.removeCurrentImage}</div>
        </div>
      </div>
    )
  }
}

export default injectSheet(style)(AccountAvatar);
