import React from 'react';
import PropTypes from 'prop-types';
import { Form, Button, Header, Message } from 'semantic-ui-react';
import injectSheet from "react-jss";
import isequal from 'lodash.isequal';

import style from '../style';
import ReduxStatus from "../../../Common/Constants/ReduxStatus";
import AccountActionCreator from "../../AccountActionCreator";
import AppContext from "../../../Common/Constants/AppContext";


class AccountBasicDetail extends React.Component {
  static contextType = AppContext;
  static getDerivedStateFromProps(props, state) {
    if (!state.userInfo._id && props.userData.user._id) {
      return {
        userInfo: {
          ...props.userData.user,
        }
      };
    } else if (props.userData.user._id !== state.userInfo._id) {
      return {
        userInfo: {
          ...props.userData.user,
        }
      };
    }
    return null;
  }

  constructor() {
    super();
    this.state = {
      isHitSave: false,
      userInfo: {},
    }
    this.handleChange = this.handleChange.bind(this);
    this.isFieldError = this.isFieldError.bind(this);
    this.handleSubmit = this.handleSubmit.bind(this);
  }

  handleChange({ target: { name, value } }) {
    this.setState({
      userInfo: {
        ...this.state.userInfo,
        [name]: value,
      }
    })
  }

  isFieldError(name) {
    if (!this.state.isHitSave) {
      return false;
    }
    if (!this.state.userInfo[name]) {
      return true;
    }
    return false;
  }

  handleSubmit() {
    if (!this.state.isHitSave) {
      this.setState({
        isHitSave: true,
      });
    }
    if (this.state.userInfo.first_name && this.state.userInfo.last_name) {
      const {dispatch} = this.context;
      dispatch(AccountActionCreator.saveUser(this.state.userInfo));
    }
  }

  render() {
    const { classes, userData } = this.props;
    const { status, message } = userData;
    const { intl: { messages } } = this.context;
    const { userInfo } = this.state;
    return (
      <Form
        loading={status === ReduxStatus.loading}
        error={status === ReduxStatus.saveFailed || status === ReduxStatus.loadFailed }
        onSubmit={this.handleSubmit}
      >
        <Header size='medium'>{messages.basicDetails}</Header>
        <Message
          error
          header={messages.failed}
          content={message}
        />
        <Form.Field required error={this.isFieldError('first_name')}>
          <label>{messages.firstName}</label>
          <input
            placeholder={messages.firstName}
            name='first_name'
            value={userInfo.first_name}
            onChange={this.handleChange}
          />
          {
            this.isFieldError('first_name') &&
            <div className={classes.helpText}>{messages.pleaseEnter} {messages.firstName}</div>
          }
        </Form.Field>
        <Form.Field required error={this.isFieldError('last_name')}>
          <label>{messages.lastName}</label>
          <input
            placeholder={messages.lastName}
            name='last_name'
            value={userInfo.last_name}
            onChange={this.handleChange}
          />
          {
            this.isFieldError('last_name') &&
            <div className={classes.helpText}>{messages.pleaseEnter} {messages.lastName}</div>
          }
        </Form.Field>
        <Form.Field>
          <label>{messages.phone}</label>
          <input
            placeholder={`${messages.phone} (${messages.optional})`}
            name='phone'
            value={userInfo.phone}
            onChange={this.handleChange}
          />
        </Form.Field>
        <Form.Field className={classes.actionGroup}>
          {
            status === ReduxStatus.saved &&
            <div className="text-status">{messages.savedChange}</div>
          }
          <Button
            type='submit'
            color='green'
            loading={status === ReduxStatus.saving}
            disabled={isequal(userInfo, userData.user)}
          >
            {messages.save}
          </Button>
        </Form.Field>
      </Form>
    )
  }
}

AccountBasicDetail.propTypes = {
  userData: PropTypes.shape({}),
};

AccountBasicDetail.defaultProps = {
  userData: {
    user: {
      _id: '',
    },
    status: ReduxStatus.empty,
  },
}

export default injectSheet(style)(AccountBasicDetail);