import React from 'react';
import { Form, Button, Header, Message } from 'semantic-ui-react';
import injectSheet from "react-jss";

import style from '../style';
import ReduxStatus from "../../../Common/Constants/ReduxStatus";

import AccountActionCreator from "../../AccountActionCreator";
import AppContext from "../../../Common/Constants/AppContext";

class AccountPassword extends React.Component {
  static contextType = AppContext;
  constructor() {
    super();
    this.state = {
      isHitSave: false,
      passwordInfo: {
        currentPassword: '',
        newPassword: '',
        confirmedPassword: ''
      },
    }
    this.handleChange = this.handleChange.bind(this);
    this.isFieldError = this.isFieldError.bind(this);
    this.isFormError = this.isFormError.bind(this);
    this.handleSubmit = this.handleSubmit.bind(this);
  }

  handleChange({ target: { name, value } }) {
    this.setState({
      passwordInfo: {
        ...this.state.passwordInfo,
        [name]: value,
      }
    })
  }

  isFieldError(name) {
    const { intl: { messages } } = this.context;
    if (!this.state.passwordInfo[name]) {
      return `${messages.pleaseEnter} ${messages[name]}`;
    }
    if (name === 'confirmedPassword') {
      if (this.state.passwordInfo.newPassword !== this.state.passwordInfo.confirmedPassword) {
        return `${messages.passwordNotMatch}`;
      }
    }
    return '';
  }

  isFormError() {
    return Object.keys(this.state.passwordInfo).some(item => {
      return this.isFieldError(item);
    });
  }

  handleSubmit() {
    if (!this.state.isHitSave) {
      this.setState({
        isHitSave: true,
      });
    }
    if (!this.isFormError()) {
      const {dispatch} = this.context;
      dispatch(AccountActionCreator.savePassword(this.state.passwordInfo));
    }
  }

  render() {
    const { classes, passwordData: { status, message } } = this.props;
    const { intl: { messages } } = this.context;
    const { passwordInfo } = this.state;
    const disabled = !passwordInfo.currentPassword &&
      !passwordInfo.newPassword && !passwordInfo.confirmedPassword;
    return (
      <Form
        error={status === ReduxStatus.saveFailed || status === ReduxStatus.loadFailed}
        onSubmit={this.handleSubmit}
      >
        <Header size='medium'>{messages.changePassword}</Header>
        <Message
          error
          header={messages.failed}
          content={message}
        />
        <Form.Field
          required
          error={this.state.isHitSave && this.isFieldError('currentPassword')}
        >
          <label>{messages.currentPassword}</label>
          <input
            type='password'
            placeholder={messages.currentPassword}
            name='currentPassword'
            value={passwordInfo.currentPassword}
            onChange={this.handleChange}
          />
          {
            this.state.isHitSave && this.isFieldError('currentPassword') &&
            <div className={classes.helpText}>{this.isFieldError('currentPassword')}</div>
          }
        </Form.Field>
        <Form.Field
          required
          error={this.state.isHitSave && this.isFieldError('newPassword')}
        >
          <label>{messages.newPassword}</label>
          <input
            type='password'
            placeholder={messages.newPassword}
            name='newPassword'
            value={passwordInfo.newPassword}
            onChange={this.handleChange}
          />
          {
            this.state.isHitSave && this.isFieldError('newPassword') &&
            <div className={classes.helpText}>{this.isFieldError('newPassword')}</div>
          }
        </Form.Field>
        <Form.Field
          required
          error={this.state.isHitSave && this.isFieldError('confirmedPassword')}
        >
          <label>{messages.confirmedPassword}</label>
          <input
            type='password'
            placeholder={messages.reEnterPassword}
            name='confirmedPassword'
            value={passwordInfo.confirmedPassword}
            onChange={this.handleChange}
          />
          {
            this.state.isHitSave && this.isFieldError('confirmedPassword') &&
            <div className={classes.helpText}>{this.isFieldError('confirmedPassword')}</div>
          }
        </Form.Field>
        <Form.Field className={classes.actionGroup}>
          {
            status === ReduxStatus.saved &&
            <div className="text-status">{messages.savedChange}</div>
          }
          <Button
            type='submit'
            color='green'
            loading={status === ReduxStatus.saving}
            disabled={disabled}
          >
            {messages.save}
          </Button>
        </Form.Field>
      </Form>
    )
  }
}

export default injectSheet(style)(AccountPassword);