import React from 'react';
import PropTypes from 'prop-types';
import injectSheet from "react-jss";
import { Divider } from 'semantic-ui-react'

import AccountAvatar from './AccountAvatar/AccountAvatar';
import AccountBasicDetail from './AccountBasicDetail/AccountBasicDetail';
import AccountPassword from './AccountPassword/AccountPassword';

const style = {
  myAccountInfo: {
    width: 500,
    maxWidth: '100%',
    margin: 'auto',
    padding: '1.3rem 1rem',
  }
}

const MyAccount = ({ classes, account }) => {
  const userData = {
    ...account.userData,
    user: {
      _id: account.userData.user._id,
      first_name: account.userData.user.first_name,
      last_name: account.userData.user.last_name,
      phone: account.userData.user.phone,
      firebase_uid: account.userData.user.firebase_uid,
    }
  }
  return (
    <div className={classes.myAccountInfo}>
      <AccountAvatar
        user={{
          _id: account.userData.user._id,
          firebase_uid: account.userData.user.firebase_uid,
          profile_picture: account.userData.user.profile_picture,
        }}
      />
      <Divider section />
      <AccountBasicDetail
        userData={userData}
      />
      <Divider section />
      <AccountPassword
        passwordData={account.passwordData}
      />
    </div>
  )
}

MyAccount.propTypes = {
  account: PropTypes.shape({}),
};

MyAccount.defaultProps = {
  account: {
    userData: {
      user: {},
    },
    passwordData: {},
  },
};

export default injectSheet(style)(MyAccount);