import React, {
  Component,
} from 'react';
import PropTypes from 'prop-types';
import isempty from 'lodash.isempty';
import { connect } from "react-redux";
import { Loader } from "semantic-ui-react";
import { Firebase } from './Firebase';
import { auth } from './Firebase/Firebase';
import LoginComponent from "./Containers/Login/Login";
import AccountActionCreator from "../Account/AccountActionCreator";
import FileUploadList from "../Common/Components/FileUploadList";
import AppContext from './Constants/AppContext';
import * as Auth from "./Firebase/Auth";
import Utils, { firebaseToken, firebaseTokenTimer } from "./Utils/Utils";

class AppContextProvider extends Component {
  constructor() {
    super();
    this.state = {
      currentUser: null,
      wait: true,
      userRole: null,
    };
    this.signInWithEmailLink = false;
    this.checkSignInWithEmailLink = this.checkSignInWithEmailLink.bind(this);
  }

  componentDidMount() {
    const { dispatch } = this.props;
    Firebase.auth.onAuthStateChanged(user => {
      if (!this.signInWithEmailLink && auth.isSignInWithEmailLink(window.location.href)) {
        if (user) {
          Utils.setCookie(firebaseToken, "", 0);
          Utils.setCookie(firebaseTokenTimer, "", 0);
        }
        this.checkSignInWithEmailLink(user);
      } else {
        dispatch(AccountActionCreator.checkToken(user));
        if (user && user.emailVerified) {
          dispatch(AccountActionCreator.loadUser(user.uid));
          user.getIdTokenResult()
            .then((idTokenResult) => {
              const { claims: { group, permissions } } = idTokenResult;
              this.setState({
                currentUser: user,
                wait: false,
                userRole: {
                  role: group,
                  permissions,
                }
              })
            });
        } else {
          this.setState({
            currentUser: user && user.emailVerified ? user : null,
            wait: false
          });
        }
      }
    });
  }

  checkSignInWithEmailLink() {
    this.signInWithEmailLink = true;
    const email = window.prompt('Please provide your email for confirmation');
    Auth.signInWithEmailLink(email).catch((error) => {
      // Some error occurred, you can inspect the code: error.code
      // Common errors could be invalid email and invalid or expired OTPs.
      alert(error.message);
      if (error.message.includes("badly formatted")) {
        this.checkSignInWithEmailLink();
      } else {
        const { dispatch } = this.props;
        dispatch(AccountActionCreator.logout());
        window.location.replace(window.location.origin);
      }
    });
  }

  render() {
    const { dispatch, intl, user } = this.props;
    return (
      !this.state.wait &&
      <AppContext.Provider
        value={{
          dispatch: dispatch,
          currentUser: user,
          intl: intl,
          userRole: this.state.userRole,
        }}
      >
        {
          !this.state.currentUser ? <LoginComponent /> :
            (
              isempty(user) ? <Loader active /> : this.props.children
            )
        }
        <FileUploadList />
      </AppContext.Provider>
    )
  }
}

AppContextProvider.propTypes = {
  dispatch: PropTypes.func.isRequired,
  user: PropTypes.shape({}),
  intl: PropTypes.shape({}),
}

AppContextProvider.defaultProps = {
  user: null,
};

const mapStateToProps = ({ intl, account: { userData: { user } } }) => ({
  intl,
  user,
})

export default connect(mapStateToProps)(AppContextProvider);