import React, { Component } from 'react'
import { Search, Grid } from 'semantic-ui-react';
import PropTypes from 'prop-types';
import PlacesAutocomplete, {
  geocodeByAddress,
  getLatLng,
} from 'react-places-autocomplete';
import Utils from "../../Utils/Utils";

class SearchAddress extends Component {
  constructor(props) {
    super(props);
    const address = Utils.combineAddress(props.address)
    this.state = {
      address,
    }

    this.handleChange = this.handleChange.bind(this);
  }

  handleChange(address) {
    this.setState({ address });
  };
  handleResultSelect = (e, { result }) => {
    const { onSelect } = this.props;
    this.setState({ address: result.title });
    const selectedAddressInfo = {};
    geocodeByAddress(result.title)
      .then(results => {
        const componentForm = {
          subpremise: 'short_name',
          street_number: 'short_name',
          route: 'long_name',
          locality: 'long_name',
          colloquial_area: 'long_name',
          administrative_area_level_1: 'short_name',
          postal_code: 'short_name',
          country: 'long_name',
        };
        const mapDataForm = {
          subpremise: 'line1',
          street_number: 'line1',
          route: 'line2',
          locality: 'city',
          colloquial_area: 'city',
          administrative_area_level_1: 'state',
          postal_code: 'postal_code',
          country: 'country',
        };
        for (let i = 0; i < results.length; i++) {
          for (let j = 0; j < results[i].address_components.length; j++) {
            const addressInfo = results[i].address_components[j];
            const addressType = addressInfo.types[0];
            if (componentForm[addressType]) {
              if(addressType === 'street_number') {
                if(selectedAddressInfo[mapDataForm[addressType]]) {
                  selectedAddressInfo[mapDataForm[addressType]] += '/' + addressInfo[componentForm[addressType]];
                } else {
                  selectedAddressInfo[mapDataForm[addressType]] = addressInfo[componentForm[addressType]];
                }
              } else {
                selectedAddressInfo[mapDataForm[addressType]] = addressInfo[componentForm[addressType]];
              }
            }
          }
        }
        return getLatLng(results[0]);
      })
      .then(latLng => {
        selectedAddressInfo.location = {
          type: 'Point',
          coordinates: [latLng.lng, latLng.lat],
        };
        if (onSelect) {
          onSelect(selectedAddressInfo);
        }
      })
      .catch(error => console.error('Error', error));
  }

  render() {
    return (
      <Grid>
        <Grid.Column width={16}>
          <PlacesAutocomplete
            value={this.state.address}
            onChange={this.handleChange}
            inputProps={
              {
                value: this.state.address,
                placeholder: "Enter a location"
              }
            }
          >
            {
              ({ getInputProps, suggestions, getSuggestionItemProps, loading }) => {
                const { onChange, value } = getInputProps();
                const results = suggestions.map(item => ({ title: item.description }));
                return <Search
                  value={value}
                  input={{ icon: 'search', iconPosition: 'left' }}
                  loading={loading}
                  onResultSelect={this.handleResultSelect}
                  onSearchChange={onChange}
                  results={results}
                  fluid
                />
              }
            }
          </PlacesAutocomplete>
        </Grid.Column>
      </Grid>
    )
  }
}

SearchAddress.propTypes = {
  onSelect: PropTypes.func.isRequired,
  address: PropTypes.shape({}),
};

SearchAddress.defaultProps = {
  address: {},
}

export default SearchAddress;