import React from 'react';
import PropTypes from 'prop-types';
import debounce from 'lodash.debounce';
import { Icon, Input, Popup, Visibility, Loader } from "semantic-ui-react";
import AppContext from "../../Constants/AppContext";
import ElectorateActionCreator from "./ElectorateActionCreator";
import injectSheet from "react-jss";
import stylesheet from "./stylesheet";

class ElectorateComponent extends React.Component {

  constructor(props) {
    super(props);
    this.state = {
      defaultSelected: props.defaultSelected,
      data: [],
      currentSearchText: '',
      currentSelected: props.defaultSelected,

      activePage: 1,
      isLoadMore: false,
    }
    this.onSearchChange = this.onSearchChange.bind(this);
    this.groupSearchResultData = this.groupSearchResultData.bind(this);
    this.handleSelectElectorate = this.handleSelectElectorate.bind(this);
    this.handleUpdate = this.handleUpdate.bind(this);
    this.handleLoadMore = debounce(this.handleLoadMore.bind(this), 300);
  }

  componentDidMount() {
    const { dispatch } = this.context;
    const { getDefault, onSelect, locationState, defaultSelected } = this.props;
    const callback = (data, totalPage) => {
      if (getDefault && !defaultSelected._id && data && data.length > 0) {
        onSelect(data[0]);
        this.setState({
          data: this.groupSearchResultData(data),
          defaultSelected: data[0],
          currentSelected: data[0],
          isLoadMore: this.state.activePage < totalPage,
        })
      } else {
        this.setState({
          data: this.groupSearchResultData(data),
          isLoadMore: this.state.activePage < totalPage,
        });
      }
    }
    const filter = {};
    if (locationState) {
      filter.state = locationState;
    }
    dispatch(ElectorateActionCreator.getElectorate(callback, filter, 1));
  }

  onSearchChange(e, { value }) {
    this.setState({
      currentSearchText: value,
      activePage: 1,
    });
    const callback = (data, totalPage) => {
      this.setState({
        data: this.groupSearchResultData(data),
        isLoadMore: this.state.activePage < totalPage,
      });
    }
    const { dispatch } = this.context;
    const { locationState } = this.props;
    const filter = {};
    if (value) {
      filter.name = { "$regex": value, "$options": "i" };
    }
    if (locationState) {
      filter.state = locationState;
    }
    dispatch(ElectorateActionCreator.getElectorate(callback, filter, 1));
  }

  groupSearchResultData(data) {
    const result = {};
    data.forEach(item => {
      if (result[item.type]) {
        result[item.type].electorates.push(item);
      } else {
        result[item.type] = {
          name: item.type,
          electorates: [item],
        }
      }
    })
    return result;
  }

  handleSelectElectorate(item) {
    const { onSelect } = this.props;
    if (this.state.currentSelected._id !== item._id) {
      this.setState({
        currentSelected: item,
      });
      onSelect(item);
    }
    document.getElementsByTagName('body')[0].click();
  }

  handleClearData(e) {
    e.stopPropagation();
    const { defaultSelected } = this.state;
    this.handleSelectElectorate(defaultSelected);
  }

  handleUpdate(e, { calculations }) {
    const { bottomVisible } = calculations;
    if (bottomVisible && this.state.isLoadMore) {
      this.handleLoadMore();
    }
  }

  handleLoadMore() {
    const callback = (data, totalPage) => {
      const currentData = {
        ...this.state.data,
      }
      const groupData = this.groupSearchResultData(data, totalPage);
      Object.keys(currentData).forEach(key => {
        if (groupData[key]) {
          currentData[key].electorates = currentData[key].electorates.concat(groupData[key].electorates);
        }
      })
      this.setState({
        data: currentData,
        activePage: this.state.activePage + 1,
        isLoadMore: (this.state.activePage + 1) < totalPage,
      });
    }
    const { dispatch } = this.context;
    const { locationState } = this.props;
    const filter = {};
    if (this.state.currentSearchText) {
      filter.name = { "$regex": this.state.currentSearchText, "$options": "i" };
    }
    if (locationState) {
      filter.state = locationState;
    }
    dispatch(ElectorateActionCreator.getElectorate(callback, filter, this.state.activePage + 1));
  }

  render() {
    const { classes, allowClear, allowAll } = this.props;
    const { intl: { messages } } = this.context;
    const { currentSearchText, currentSelected } = this.state;

    return (
      <Popup
        className={classes.electoratePopup}
        trigger={(
          <div className={classes.electorateBox}>
            <div className='name'>
              <span>{currentSelected.name}</span>
              {
                allowClear &&
                <Icon name='close' onClick={(e) => this.handleClearData(e)} />
              }
            </div>
            <Icon name='angle down' />
          </div>
        )}
        content={(
          <div className={classes.electorateOptionsContainer}>
            <div className='search-container'>
              <Input
                icon='search'
                iconPosition='left'
                value={currentSearchText}
                onChange={this.onSearchChange}
              />
            </div>
            <div className='electorate-options-box'>
              <Visibility onUpdate={this.handleUpdate}>
                {
                  allowAll && <div
                    style={{ cursor: 'pointer' }}
                    className='electorate-group-item'
                    onClick={() => this.handleSelectElectorate({ name: 'All' })}
                  >
                    All
                  </div>
                }

                {
                  Object.values(this.state.data).map((item, index) => (
                    <div key={`${item._id}_${index}`} className='electorate-group-item'>
                      <div className='group-header'>
                        {messages[item.name] || item.name}
                      </div>
                      {
                        item.electorates.map(el => (
                          <div key={el._id} className='electorate-item' onClick={() => this.handleSelectElectorate(el)}>
                            {el.name}
                          </div>
                        ))
                      }
                    </div>
                  ))
                }
                {
                  this.state.isLoadMore && <Loader active inline />
                }
              </Visibility>
            </div>
          </div>
        )}
        on='click'
        position='bottom center'
      />
    )
  }
}

ElectorateComponent.contextType = AppContext;

ElectorateComponent.propTypes = {
  getDefault: PropTypes.bool,
  onSelect: PropTypes.func.isRequired,
  locationState: PropTypes.string,
  defaultSelected: PropTypes.shape({}),
  allowClear: PropTypes.bool,
  allowAll: PropTypes.bool,
};

ElectorateComponent.defaultProps = {
  getDefault: false,
  locationState: '',
  defaultSelected: {
    name: 'All',
  },
  allowClear: false,
  allowAll: false,
}


export default injectSheet(stylesheet)(({ forwardedRef, ...props }) => (
  <ElectorateComponent ref={forwardedRef} {...props} />
));
