import React from "react";
import PropTypes from "prop-types";
import { v4 as uuid } from "uuid";
import { useDispatch } from "react-redux";

import uploadAction from "./FileUploadCreator";
import { STORAGE_PATH, uploadFileToCloud } from "../../Firebase/Storage";

const FileUpload = (props) => {
  const {
    children,
    onUploadSuccess,
  } = props;

  const dispatch = useDispatch();

  const _onUploadStart = ({ fileId, fileName, task }) => {
    dispatch(uploadAction.uploadFileStart({ fileId, fileName, task }));
  };

  const _onUploadSuccess = ({ fileId, fileUrl, fileName }) => {
    if (typeof onUploadSuccess === "function")
      onUploadSuccess({ fileId, fileUrl, fileName });
    dispatch(uploadAction.uploadFileSuccess({ fileId }));
  };

  const _onUploadFailure = ({ fileId }) => {
    dispatch(uploadAction.uploadFileFailure({ fileId }));
  };

  const _onUploadStateChange = ({ fileId, progress }) => {
    dispatch(uploadAction.uploadFileStateChange({ fileId, progress }));
  };

  const onUploadFiles = (files) => {
    const uploadEvent = {
      onUploadStart: _onUploadStart,
      onUploadSuccess: _onUploadSuccess,
      onUploadFailure: _onUploadFailure,
      onUploadStateChange: _onUploadStateChange,
    };

    [...files].forEach((file) => {
      uploadFileToCloud({
        fileId: uuid(),
        file,
        uploadEvent,
        path: STORAGE_PATH.ELECTORAL_ROLL,
      });
    });
  };

  return <>{children({ onUploadFiles })}</>;
};

FileUpload.propTypes = {
  children: PropTypes.func.isRequired,
};

export default FileUpload;
