import React from 'react';
import PropTypes from 'prop-types';
import injectSheet from 'react-jss';
import { connect, useDispatch } from 'react-redux';
import { Card, Progress, Icon, Grid, Item } from 'semantic-ui-react';

import styles from './styles'
import Enum from '../../Constants/Enum';
import actionTypes from '../../Components/FileUpload/FileUploadCreator'

const FileUploadList = props => {
  const { classes, fileUploads: list } = props
  const ref = React.useRef();
  const dispatch = useDispatch();

  const [fileUploads, setFileUploads] = React.useState([]);
  const [isVisible, setVisible] = React.useState(false);
  const [collapse, setCollapse] = React.useState(true);

  React.useEffect(() => {
    const newList = Object.values(list);
    setVisible(newList.length !== 0)
    setFileUploads(newList);
    ref.current = newList;
  }, [list])

  const isProcessCompleted = fileUploads.filter(file => file.status !== Enum.FileUploadStatus.Success).length === 0

  const isFileUploadCompleted = status =>
    [
      Enum.FileUploadStatus.Failure,
      Enum.FileUploadStatus.Success,
    ].includes(status)

  const uploadingCount = fileUploads.filter(file =>
    file.status === Enum.FileUploadStatus.Uploading
  ).length;

  const getTitle = () => {
    if (uploadingCount) return `Uploading ${uploadingCount} items`
    return 'Upload Completed';
  }

  const onResetFiles = () => {
    dispatch(actionTypes.resetFiles())
  }

  if (!isVisible) return null;

  return (
    <div className={classes.wrapperFileUploadList}>
      <Card>
        <Card.Content>
          <Grid columns={2}>
            <Grid.Row>
              <Grid.Column verticalAlign="middle">{getTitle()}</Grid.Column>
              <Grid.Column textAlign="right">
                <Icon className={classes.icon}
                  name={`angle ${collapse ? 'down' : 'up'}`}
                  onClick={() => setCollapse(visible => !visible)}
                />
                {isProcessCompleted &&
                  <Icon name="times" onClick={onResetFiles} className={classes.icon} />
                }
              </Grid.Column>
            </Grid.Row>
          </Grid>
        </Card.Content>
        <div className={classes.list}>
          <Card>
            {collapse && fileUploads.map(file => (
              <Card.Content className={classes.content} key={file.fileId}>
                <Item.Group>
                  <Item>
                    <Icon size="large" name="file alternate" color="blue" />
                    <Item.Content>
                      <Grid columns={isFileUploadCompleted(file.status) ? 2 : 1}>
                        <Grid.Row>
                          <Grid.Column verticalAlign="middle" className={classes.fileName}>
                            {file.fileName}
                          </Grid.Column>
                          <Grid.Column verticalAlign="middle" textAlign="right">
                            {
                              isFileUploadCompleted(file.status)
                                ? <Icon
                                  size="large"
                                  name={`${file.status === Enum.FileUploadStatus.Failure ? 'times' : 'check'} circle`}
                                  color={`${file.status === Enum.FileUploadStatus.Failure ? 'red' : 'green'}`}
                                />
                                : <Progress
                                  active
                                  size="tiny"
                                  color="olive"
                                  percent={file.progress}
                                  className={classes.progress}
                                />
                            }
                          </Grid.Column>
                        </Grid.Row>
                      </Grid>
                    </Item.Content>
                  </Item>
                </Item.Group>
              </Card.Content>
            ))}
          </Card>
        </div>
      </Card>
    </div>
  );
}

FileUploadList.propTypes = {
  fileUploads: PropTypes.object
}

const mapStateToProps = ({ fileUploads }) => ({
  fileUploads
})

export default connect(mapStateToProps)(injectSheet(styles)(FileUploadList))
