import React from 'react'
import PropTypes from 'prop-types'
import { Button, Form, Modal, Loader, Dimmer, Checkbox } from 'semantic-ui-react'
import injectSheet from "react-jss"
import AppContext from "../../../Common/Constants/AppContext"
import { ModalStyleSheet } from "../../../Common/GlobalStyle"
import colors from '../../../Common/Constants/color'
import Dropzone from 'react-dropzone';
import ReduxStatus from "../../../Common/Constants/ReduxStatus"

const style = {
  groupOfType: {
    justifyContent: 'center',
  },
  toggleContactType: {
    display: 'flex',
    alignItems: 'center',
    '& .ui.toggle.checkbox .box:before, .ui.toggle.checkbox label:before': {
      backgroundColor: '#0d71bb!important',
    }
  },
  helpText: {
    extend: ModalStyleSheet.helpText,
  },
  actionGroup: {
    extend: ModalStyleSheet.actionGroup,
  },
  header: {
    extend: ModalStyleSheet.header,
  },
  dropzoneContainer: {
    '& .dropzone': {
      margin: '1em 0 1em 0',
      padding: '4em 0em',
      borderRadius: '.3em',
      backgroundColor: `${colors.primaryGray4} !important`,
      color: `${colors.primaryBlue} !important`,
      fontWeight: 'bold',
      fontSize: '9pt',
      textAlign: 'center',
      cursor: 'pointer'
    }
  }
}

class ImportModal extends React.Component {
  constructor(props) {
    super(props);
    this.state = {}
  }

  render() {
    const { classes, isOpen, onClose, onUpload, onGoToImportList, uploadContactListStatus: { status, filename }, labelCheckBox, onChangeCheckBox, isRemoveAllVoter } = this.props
    const { intl: { messages } } = this.context
    return (
      <Modal
        open={isOpen}
        onClose={onClose}
        size="mini"
      >
        <Modal.Header className={classes.header}>
          Upload CSV
        </Modal.Header>
        <Modal.Content>
          {
            status === ReduxStatus.loading && <Dimmer active inverted><Loader size='medium'>Uploading</Loader></Dimmer>
          }
          {/* <Form> */}
            <Dropzone accept= '.csv' multiple={false} onDrop={onUpload}>
              {({getRootProps, getInputProps}) => (
                <section className={classes.dropzoneContainer}>
                  <div {...getRootProps({className: 'dropzone'})}>
                    <input {...getInputProps()} />
                    <p>Drag & drop some files here, or click to select files</p>
                  </div>
                </section>
              )}
            </Dropzone>
            {filename && <p>{filename} was uploaded</p>}
            <Form.Field className={classes.actionGroup}>
              {
                status === ReduxStatus.loaded && <Button color='green' onClick={onGoToImportList}>
                  {messages['contact.list.uploadCSV.goToImportHistory']}
                </Button>
              }
              { labelCheckBox && status !== ReduxStatus.loaded && <Checkbox checked={isRemoveAllVoter} label={<label>{labelCheckBox}</label>} onChange={onChangeCheckBox} />}
              <Button onClick={onClose}>
                {messages.close}
              </Button>
            </Form.Field>
          {/* </Form> */}
        </Modal.Content>
      </Modal>
    )
  }
}

ImportModal.propTypes = {
  isOpen: PropTypes.bool.isRequired,
  onClose: PropTypes.func.isRequired,
  onUpload: PropTypes.func.isRequired
};

ImportModal.contextType = AppContext;

export default injectSheet(style)(ImportModal);
