import React from "react";
import PropTypes from "prop-types";
import {Icon, Dropdown} from "semantic-ui-react";
import AppContext from "../../../Common/Constants/AppContext";
import colors from "../../../Common/Constants/color";
import Enum from "../../../Common/Constants/Enum";
import injectSheet from "react-jss";
import style from "./stylesheet";
import _ from "lodash";

class InlineEditAdditionDropdownComponent extends React.Component {
  static getDerivedStateFromProps(props, state) {
    if (!state.isBind) {
      if (props.value) {
        return {
          value: props.value,
          isBind: true,
        };
      }
    }
    return null;
  }

  constructor(props) {
    super(props);
    this.state = {
      isEdit: false,
      isBind: false,
      value: null,
      isHitSave: false,
      sources: Object.values(Enum.Interests).map(item => ({
        key: item,
        text: item,
        value: item
      }))
    }
    this.handleSaveInfo = this.handleSaveInfo.bind(this);
    this.handleChange = this.handleChange.bind(this);
    this.getErrorMessage = this.getErrorMessage.bind(this);
    this.onCancel = this.onCancel.bind(this);
  }

  getErrorMessage() {
    const { validators } = this.props;
    const { intl: { messages } } = this.context;
    if (validators.includes('required') && !this.state.value) {
      return messages.requiredField;
    }
    return '';
  }

  handleSaveInfo() {
    if (!this.state.isHitSave) {
      this.setState({
        isHitSave: true,
      });
    }
    if (!this.getErrorMessage()) {
      const { onUpdate } = this.props;
      if(this.state.value === this.props.value) {
        this.onCancel();
        return;
      }
      onUpdate(this.state.value)
      this.setState({
        isEdit: false,
      })
    }
  }

  handleAddition = (e, { value }) => {
    this.setState((prevState) => ({
      sources: [{ text: value, value }, ...prevState.sources],
    }))
  }

  handleChange(e, { value }) {
    this.setState({
      value
    })
  }

  onCancel() {
    const { value } = this.props;
    this.setState({
      value,
      isEdit: false,
    })
  }

  render() {
    const { name, value, placeholder, classes } = this.props;
    const sourceOptions = _.union(this.state.sources, value ? value.map(item => ({
      key: item,
      text: item,
      value: item
    })): [])
    return (
      <div className={classes.container}>
        {
          !this.state.isEdit &&
          <div className={classes.displayText} onClick={() => this.setState({ isEdit: true })}>
            <span>{ value ? value.join(', ') : ''}</span>
            <Icon name='edit' color='blue' />
          </div>
        }
        {
          !this.state.isEdit && (!value || value.length ===0) &&
          <Icon name='edit' color='blue' onClick={() => this.setState({ isEdit: true })} />
        }
        {
          this.state.isEdit &&
          <div className={classes.editInterests}>
            <Dropdown
              name={name}
              options={sourceOptions}
              placeholder={placeholder}
              search
              selection
              fluid
              multiple
              allowAdditions
              value={this.state.value}
              onAddItem={this.handleAddition}
              onChange={this.handleChange} 
            />
            <Icon name='check' color='blue' onClick={this.handleSaveInfo} />
            <Icon name='close' color='blue' onClick={this.onCancel} />
          </div>
        }
        {
          this.state.isEdit && this.state.isHitSave &&
          <div style={{ fontSize: '0.9rem', color: colors.primaryRed1 }}>{this.getErrorMessage()}</div>
        }
      </div>
    );
  }
}

InlineEditAdditionDropdownComponent.propTypes = {
  name: PropTypes.string.isRequired,
  value: PropTypes.array.isRequired,
  validators: PropTypes.arrayOf(PropTypes.string),
};

InlineEditAdditionDropdownComponent.defaultProps = {
  validators: [],
};

InlineEditAdditionDropdownComponent.contextType = AppContext;

export default injectSheet(style)(InlineEditAdditionDropdownComponent);
