import React from 'react';
import PropTypes from 'prop-types';
import { Icon } from 'semantic-ui-react';
import AppContext from "../../../Common/Constants/AppContext";
import colors from "../../../Common/Constants/color";
import injectSheet from "react-jss";
import style from './stylesheet';

class InlineEditTextComponent extends React.Component {
  static getDerivedStateFromProps(props, state) {
    if (!state.isBind) {
      if (props.value) {
        return {
          value: props.value,
          isBind: true,
        };
      }
    }
    return null;
  }

  constructor(props) {
    super(props);
    this.state = {
      isEdit: false,
      isBind: false,
      value: null,
      isHitSave: false,
    }
    this.handleSaveInfo = this.handleSaveInfo.bind(this);
    this.handleChange = this.handleChange.bind(this);
    this.getErrorMessage = this.getErrorMessage.bind(this);
    this.onCancel = this.onCancel.bind(this);
  }

  getErrorMessage() {
    const { validators } = this.props;
    const { intl: { messages } } = this.context;
    if (validators.includes('required') && !this.state.value) {
      return messages.requiredField;
    }
    return '';
  }

  handleSaveInfo() {
    if (!this.state.isHitSave) {
      this.setState({
        isHitSave: true,
      });
    }
    if (!this.getErrorMessage()) {
      const { onUpdate } = this.props;

      if(this.state.value === this.props.value) {
        this.onCancel();
        return;
      }
      onUpdate(this.state.value)
      this.setState({
        isEdit: false,
      })
    }
  }

  handleChange({ target: { value } }) {
    this.setState({
      value,
    })
  }

  onCancel() {
    const { value } = this.props;
    this.setState({
      value,
      isEdit: false,
    })
  }

  render() {
    const { name, value, placeholder, classes } = this.props;

    return (
      <div className={classes.container}>
        {
          !this.state.isEdit &&
          <div className={classes.displayText} onClick={() => this.setState({ isEdit: true })}>
            <span>{value}</span>
            <Icon name='edit' color='blue' />
          </div>
        }
        {
          !this.state.isEdit && !value &&
          <Icon name='edit' color='blue' onClick={() => this.setState({ isEdit: true })} />
        }
        {
          this.state.isEdit &&
          <div className={classes.editInput}>
            <input
              placeholder={placeholder}
              name={name}
              value={this.state.value}
              onChange={this.handleChange}
            />
            <Icon name='check' color='blue' onClick={this.handleSaveInfo} />
            <Icon name='close icon' color='blue' onClick={this.onCancel} />
          </div>
        }
        {
          this.state.isEdit && this.state.isHitSave &&
          <div style={{ fontSize: '0.9rem', color: colors.primaryRed1 }}>{this.getErrorMessage()}</div>
        }
      </div>
    );
  }
}

InlineEditTextComponent.propTypes = {
  name: PropTypes.string.isRequired,
  value: PropTypes.string.isRequired,
  validators: PropTypes.arrayOf(PropTypes.string),
};

InlineEditTextComponent.defaultProps = {
  validators: [],
};

InlineEditTextComponent.contextType = AppContext;

export default injectSheet(style)(InlineEditTextComponent);
