import React from 'react';
import PropTypes from 'prop-types';
import { Button, Modal } from 'semantic-ui-react';
import injectSheet from "react-jss";
import colors from "../../Constants/color";

const style = {
  header: {
    '&.header': {
      textAlign: 'center',
      backgroundColor: '#db2828 !important',
      color: `${colors.primaryWhite} !important`,
    }
  },
  textContent: {
    margin: [20, 0],
    '& .main-text': {
      color: '#db2828',
      fontWeight: 'bold',
    },
    '& .description-text': {

    }
  }
}
const ConfirmModal = (
  { classes, isOpen, title, onClose, size, onConfirm, content, cancelText, confirmText }
) => {
  return (
    <Modal
      open={isOpen}
      onClose={onClose}
      size={size}
    >
      <Modal.Header className={classes.header}>{title}</Modal.Header>
      <Modal.Content>
        <div className={classes.textContent}>
          <p className='main-text'>{content.mainText}</p>
          <p className='description-text'>{content.description}</p>
        </div>
      </Modal.Content>
      <Modal.Actions>
        <Button onClick={onClose}>
          {cancelText}
        </Button>
        <Button
          onClick={onConfirm}
          color={"red"}
        >
          {confirmText}
        </Button>
      </Modal.Actions>
    </Modal>
  )
}

ConfirmModal.propTypes = {
  isOpen: PropTypes.bool.isRequired,
  onClose: PropTypes.func.isRequired,
  onConfirm: PropTypes.func.isRequired,
  size: PropTypes.string,
  title: PropTypes.string,
  content: PropTypes.shape({
    mainText: PropTypes.string,
    description: PropTypes.string,
  }),
  cancelText: PropTypes.string,
  confirmText: PropTypes.string,
};

ConfirmModal.defaultProps = {
  size: 'tiny',
  title: '',
  content: {
    mainText: '',
    description: '',
  },
  cancelText: 'Cancel',
  confirmText: 'Confirm',
};

export default injectSheet(style)(ConfirmModal);