import React from 'react';
import PropTypes from 'prop-types';
import { Button, Modal } from 'semantic-ui-react';
import injectSheet from "react-jss";
import colors from "../../Constants/color";

const style = {
  header: {
    '&.header': {
      textAlign: 'center',
      backgroundColor: '#EDB505 !important',
      color: `${colors.primaryWhite} !important`,
    }
  },
  textContent: {
    margin: [20, 0],
    '& .main-text': {
      color: colors.primaryBlack,
      fontWeight: 'bold',
      fontSize: '1.2rem',
    },
  }
}
const NotificationModal = (
  { classes, isOpen, title, onClose, size, textContent, cancelText }
) => {
  return (
    <Modal
      open={isOpen}
      onClose={onClose}
      size={size}
    >
      <Modal.Header className={classes.header}>{title}</Modal.Header>
      <Modal.Content>
        <div className={classes.textContent}>
          <p className='main-text'>{textContent}</p>
        </div>
      </Modal.Content>
      <Modal.Actions>
        <Button onClick={onClose}>
          Close
        </Button>
      </Modal.Actions>
    </Modal>
  )
}

NotificationModal.propTypes = {
  isOpen: PropTypes.bool.isRequired,
  onClose: PropTypes.func.isRequired,
  size: PropTypes.string,
  title: PropTypes.string,
  textContent: PropTypes.string,
};

NotificationModal.defaultProps = {
  size: 'tiny',
  title: 'Warning',
  content: '',
};

export default injectSheet(style)(NotificationModal);