import React from 'react';
import PropTypes from 'prop-types';
import injectSheet from "react-jss";
import stylesheet from './stylesheet';
import isempty from "lodash.isempty";
import moment from 'moment';
import { Image, Popup } from "semantic-ui-react";
import { Link } from "react-router-dom";
import Utils from "../../Utils/Utils";
import AppContext from "../../Constants/AppContext";

const hours = [
  "12am",
  '1am',
  '2am',
  '3am',
  '4am',
  '5am',
  '6am',
  '7am',
  '8am',
  '9am',
  '10am',
  '11am',
  '12pm',
  '1pm',
  '2pm',
  '3pm',
  '4pm',
  '5pm',
  '6pm',
  '7pm',
  '8pm',
  '9pm',
  '10pm',
  '11pm',
]

class Scheduler extends React.Component {
  constructor() {
    super();
    this.renderHourRange = this.renderHourRange.bind(this);
  }

  renderHourRange(item) {
    let spaceStart = 0;
    let spaceEnd = 0;
    if (item.start_time) {
      const start = new Date(item.start_time);
      const end = new Date(item.end_time);
      const date = new Date(start.getFullYear(), start.getMonth(), start.getDate(), 0, 0, 0);

      const mStart = moment(start);
      const mEnd = moment(end);
      const mDate = moment(date);
      let diffStart = mStart.diff(mDate, 'minutes');
      spaceStart = (diffStart / 60) * 100;
      let diffEnd = mEnd.diff(mDate, 'minutes');
      spaceEnd = (diffEnd / 60) * 100;
    }
    const width = spaceEnd - spaceStart;
    const style = {
      width: `${width}px`,
      minWidth: `${width}px`,
      marginLeft: `${spaceStart}px`,
    }
    return (
      <div style={style} className='hour-range'>
        {moment(new Date(item.start_time)).format('h:mma')} to {moment(new Date(item.end_time)).format('h:mma')}
      </div>
    )
  }

  componentDidMount() {
    const hourContainer = document.getElementById("hourContainer");
    hourContainer.scrollLeft = 600;
  }

  render() {
    const { intl: { messages } } = this.context;
    const { classes, scheduleData, editResource, deleteResource } = this.props;
    return (
      <div className={classes.schedulerContainer}>
        <div className='scheduler-row'>
          <div className='resource'>
            <div className='resource-header'>
              VOLUNTEERS
            </div>
            {
              scheduleData.map(item => (
                <div className='resource-container'>
                  {
                    (item.volunteer && !isempty(item.volunteer.profile_picture)) ?
                      <Image avatar src={item.volunteer.profile_picture['thumb@64_64']} /> :
                      <Image avatar src={require("../../../Assets/avatar.png")} />
                  }
                  <div className='resource-name'>
                    <Link to={`/contact-detail/${item.volunteer._id}/overview`}>
                      {Utils.combineName(item.volunteer, messages)}
                    </Link>
                  </div>
                  <Popup
                    trigger={(
                      <div className='action'>
                        <div>. . .</div>
                      </div>
                    )}
                    content={(
                      <div className={classes.resourceAction}>
                        <div
                          className='action'
                          onClick={(e) => {
                            e.stopPropagation();
                            editResource(item);
                            document.getElementsByTagName('body')[0].click();
                          }}
                        >
                          {messages.edit}
                        </div>
                        <div
                          className='action'
                          onClick={(e) => {
                            e.stopPropagation();
                            deleteResource(item);
                            document.getElementsByTagName('body')[0].click();
                          }}
                        >
                          {messages.delete}
                        </div>
                      </div>
                    )}
                    on='click'
                    position='bottom center'
                  />
                </div>
              ))
            }
          </div>
          <div className='hour-container' id='hourContainer'>
            <div className='hour-header'>
              {
                hours.map(item => (
                  <div className='hour-space'>
                    <span className='hour-label'>{item}</span>
                  </div>
                ))
              }
            </div>
            {
              scheduleData.map(item => (
                <div className='hour-value'>
                  {
                    hours.map(() => (
                      <div className='hour-space'>
                        <div className='middle-time'>&nbsp;</div>
                      </div>
                    ))
                  }
                  {
                    item.time_slots.map(timeSlot => (
                      this.renderHourRange(timeSlot)
                    ))
                  }
                </div>
              ))
            }
          </div>
        </div>
      </div>
    );
  }
}

Scheduler.propType = {
  scheduleData: PropTypes.shape([]).isRequired,
  editResource: PropTypes.func,
  deleteResource: PropTypes.func,
};

Scheduler.defaultProps = {
  editResource: () => {
  },
  deleteResource: () => {
  },
}

Scheduler.contextType = AppContext;

export default injectSheet(stylesheet)(Scheduler);