import React from 'react';
import PropTypes from 'prop-types';
import { Search } from "semantic-ui-react";
import AppContext from "../../Constants/AppContext";
import EventActionCreator from "../../../Events/Actions/EventActionCreator";

class SearchEvent extends React.Component {

  constructor(props) {
    super(props);
    this.state = {
      value: props.value || ' ',
      options: [],
      loading: false,
      selectedEvent: props.initEvent,
      localOptions: [],
    };
    this.handleChange = this.handleChange.bind(this);
    this.handleResultSelect = this.handleResultSelect.bind(this);
    this.handleBlur = this.handleBlur.bind(this);
    this.handleSearchResult = this.handleSearchResult.bind(this);
  }

  componentDidMount() {
    const { dispatch } = this.context;
    const { getDefault } = this.props;
    const handleSearchResult = (data) => {
      if(data && data.length > 0) {
        const firstEvent = data[0];
        const shouldSetDefault = getDefault && !this.state.selectedEvent._id;
        this.setState({
          options: data,
          localOptions: data,
          loading: false,
          selectedEvent: shouldSetDefault ? firstEvent : this.state.selectedEvent,
          value: shouldSetDefault ? firstEvent.name : this.state.value,
        });
        const { onSelect } = this.props;
        if (shouldSetDefault && onSelect) {
          onSelect(firstEvent);
        }
      } else {
        this.setState({
          loading: false,
        })
      }
    };
    dispatch(EventActionCreator.searchEvent('', handleSearchResult.bind(this)));
  }

  handleSearchResult(data) {
    this.setState({
      options: data,
      loading: false,
    })
  };

  handleResultSelect = (e, { result }) => {
    this.setState({
      value: result.name,
      selectedEvent: result,
    });
    const { onSelect } = this.props;
    if (onSelect) {
      onSelect(result);
    }
  }

  handleChange({ target: { name, value } }) {
    const { dispatch } = this.context;
    const { resetWhenClear } = this.props;
    if (!value.trim()) {
      if(this.state.value !== ' ') {
        this.setState({
          value: ' ',
          options: this.state.localOptions,
          selectedEvent: resetWhenClear ? {} : this.state.selectedEvent,
        });
        const { onSelect } = this.props;
        if (resetWhenClear && onSelect) {
          onSelect({});
        }
      }
    } else {
      this.setState({
        value,
        loading: true,
      });
      dispatch(EventActionCreator.searchEvent(value.trim(), this.handleSearchResult));
    }
  }

  handleBlur() {
    this.setState({
      value: this.state.selectedEvent.name || '',
    });
  }

  render() {
    const { loading, options } = this.state;

    const results = options.map(item => ({
      ...item,
      title: item.name,
    }));
    return (
      <Search
        value={this.state.value}
        input={{ icon: 'search', iconPosition: 'left' }}
        loading={loading}
        onBlur={this.handleBlur}
        onResultSelect={this.handleResultSelect}
        onSearchChange={this.handleChange}
        results={results}
        fluid
        placeholder='Select Event'
      />
    )
  }
}

SearchEvent.contextType = AppContext;

SearchEvent.propTypes = {
  onSelect: PropTypes.func,
  initEvent: PropTypes.shape({}),
  getDefault: PropTypes.bool,
  resetWhenClear: PropTypes.bool,
};

SearchEvent.defaultProps = {
  onSelect: null,
  initEvent: {},
  getDefault: false,
  resetWhenClear: false,
}

export default SearchEvent;