import React from 'react';
import PropTypes from 'prop-types';
import { Search } from "semantic-ui-react";
import LocationActionCreator from "../../../Events/Actions/LocationActionCreator";
import AppContext from "../../Constants/AppContext";
import isequal from "lodash.isequal";

class SearchLocationDropDown extends React.Component {

  constructor(props) {
    super(props);
    this.state = {
      value: props.value || ' ',
      options: [],
      loading: false,
      selectedLocation: props.initLocation,
      localOptions: [],
    };
    this.handleChange = this.handleChange.bind(this);
    this.handleResultSelect = this.handleResultSelect.bind(this);
    this.handleBlur = this.handleBlur.bind(this);
    this.handleSearchResult = this.handleSearchResult.bind(this);
  }

  componentDidMount() {
    const { dispatch } = this.context;
    const { eventId, getDefault, voting_district } = this.props;
    const handleSearchResult = (data) => {
      if (data && data.length > 0) {
        const firstLocation = data[0];
        const shouldSetDefault = getDefault && !this.state.selectedLocation._id;
        this.setState({
          options: data,
          localOptions: data,
          loading: false,
          selectedLocation: shouldSetDefault ? firstLocation : this.state.selectedLocation,
          value: shouldSetDefault ? firstLocation.name : this.state.value,
        });
        const { onSelect } = this.props;
        if (shouldSetDefault && onSelect) {
          onSelect(firstLocation);
        }
      } else {
        this.setState({
          loading: false,
        })
      }
    };
    dispatch(LocationActionCreator.searchLocations(eventId, '', voting_district, handleSearchResult.bind(this)));
  }

  handleSearchResult(data) {
    this.setState({
      options: data.slice(0),
      loading: false,
    })
  };

  handleResultSelect = (e, { result }) => {
    this.setState({
      value: result.name,
      selectedLocation: result,
    });
    const { onSelect } = this.props;
    if (onSelect) {
      onSelect(result);
    }
  }

  handleChange({ target: { name, value } }) {
    const { dispatch } = this.context;
    const { eventId, resetWhenClear, voting_district } = this.props;
    if (!value.trim()) {
      if (this.state.value !== ' ') {
        this.setState({
          value: ' ',
          options: this.state.localOptions,
          selectedLocation: resetWhenClear ? {} : this.state.selectedLocation,
        });
        const { onSelect } = this.props;
        if (resetWhenClear && onSelect) {
          onSelect({});
        }
      }
    } else {
      this.setState({
        value,
        loading: true,
      });
      dispatch(LocationActionCreator.searchLocations(eventId, value.trim(), voting_district, this.handleSearchResult));
    }
  }

  handleBlur() {
    this.setState({
      value: this.state.selectedLocation.name || '',
    });
  }

  getSnapshotBeforeUpdate(prevProps, prevState) {
    if (!isequal(prevProps.voting_district, this.props.voting_district)) {
      return true;
    }
    return null;
  }
  componentDidUpdate(prevProps, prevState, snapshot) {
    if (snapshot !== null) {
      const { dispatch } = this.context;
      const { eventId, getDefault, voting_district } = this.props;
      const handleSearchResult = (data) => {
        if (data && data.length > 0) {
          const firstLocation = data[0];
          this.setState({
            options: data,
            localOptions: data,
            loading: false,
            selectedLocation: getDefault ? firstLocation :{},
            value: getDefault ? firstLocation.name : '',
          });
          const { onSelect } = this.props;
          if (getDefault && onSelect) {
            onSelect(firstLocation);
          }
        } else {
          this.setState({
            loading: false,
          })
        }
      };
      dispatch(LocationActionCreator.searchLocations(eventId, '', voting_district, handleSearchResult.bind(this)));
    }
  }

  render() {
    const { loading, options } = this.state;

    const results = options.map(item => ({
      ...item,
      key: item._id,
      title: item.name,
    }));
    return (
      <Search
        value={this.state.value}
        icon={false}
        loading={loading}
        onBlur={this.handleBlur}
        onResultSelect={this.handleResultSelect}
        onSearchChange={this.handleChange}
        results={results}
        fluid
        placeholder='Select Location'
      />
    )
  }
}

SearchLocationDropDown.contextType = AppContext;

SearchLocationDropDown.propTypes = {
  onSelect: PropTypes.func,
  eventId: PropTypes.string.isRequired,
  initLocation: PropTypes.shape({}),
  getDefault: PropTypes.bool,
  resetWhenClear: PropTypes.bool,
  voting_district: PropTypes.string,
};

SearchLocationDropDown.defaultProps = {
  onSelect: null,
  initLocation: {},
  getDefault: false,
  resetWhenClear: false,
  voting_district: '',
}

export default SearchLocationDropDown;