import React from 'react';
import PropTypes from 'prop-types';
import { Search } from "semantic-ui-react";
import Utils from "../../Utils/Utils";
import ContactActionCreator from "../../../Contact/Actions/ContactActionCreator";
import AppContext from "../../Constants/AppContext";

class SearchVolunteer extends React.Component {

  constructor(props) {
    super(props);
    this.state = {
      value: '',
      options: [],
      loading: false,
      selectedVolunteer: {},
    };
    this.handleChange = this.handleChange.bind(this);
    this.handleResultSelect = this.handleResultSelect.bind(this);
    this.handleBlur = this.handleBlur.bind(this);
  }

  handleResultSelect = (e, { result }) => {
    const { intl: { messages } } = this.context;
    this.setState({
      value: Utils.combineName(result, messages),
      selectedVolunteer: result,
    });
    const { onSelect } = this.props;
    if (onSelect) {
      onSelect(result);
    }
  }

  handleChange({ target: { name, value } }) {
    const { dispatch } = this.context;
    this.setState({
      value,
      loading: true,
    });
    const handleSearchResult = (data) => {
      this.setState({
        options: data,
        loading: false,
      })
    };
    dispatch(ContactActionCreator.searchVolunteer(value.trim(), handleSearchResult));
  }

  handleBlur() {
    const { intl: { messages } } = this.context;
    this.setState({
      value: Utils.combineName(this.state.selectedVolunteer, messages),
    });
  }

  render() {
    const { intl: { messages } } = this.context;
    const { loading, options } = this.state;

    const results = options.map(item => ({
      ...item,
      title: Utils.combineName(item, messages),
    }));
    return (
      <Search
        value={this.state.value}
        input={{ icon: 'search', iconPosition: 'left' }}
        loading={loading}
        onBlur={this.handleBlur}
        onResultSelect={this.handleResultSelect}
        onSearchChange={this.handleChange}
        results={results}
        fluid
        placeholder='Select Volunteer'
  />
  )
  }
}

SearchVolunteer.contextType = AppContext;

SearchVolunteer.propTypes = {
  onSelect: PropTypes.func,
};

SearchVolunteer.defaultProps = {
  onSelect: null,
}

export default SearchVolunteer;