import React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';
import { IoMdPerson, IoMdContact, IoMdSettings, IoMdLogOut, IoLogoUsd, IoIosSpeedometer } from 'react-icons/io';
import { GoTools } from 'react-icons/go';
import { Dropdown, Popup, Menu } from 'semantic-ui-react';
import injectSheet from "react-jss";
import { Link, NavLink, withRouter } from 'react-router-dom';

import colors from '../../Constants/color';
import Logo from '../../../Assets/SFFP_Logo.png';
import { FaCalendar } from 'react-icons/fa'
import AppContext from "../../Constants/AppContext";
import AccountActionCreator from "../../../Account/AccountActionCreator";
import stylesheet from './stylesheet';
import Enum from "../../Constants/Enum";


class SidebarComponent extends React.Component {

  constructor(props) {
    super(props);
    this.state = {
      activeSection: '',
    };
    this.setCurrentActiveSection = this.setCurrentActiveSection.bind(this);
    this.handleLogout = this.handleLogout.bind(this);
  }

  setCurrentActiveSection() {
    let activeSection = 'dashboard';
    if (window.location.pathname.includes('/dashboard')) {
      activeSection = 'dashboard';
    } else if (window.location.pathname.includes('/contact')) {
      activeSection = 'contact';
    } else if (window.location.pathname.includes('/finance')) {
      activeSection = 'finance';
    } else if (window.location.pathname.includes('/events') || window.location.pathname.includes('/event-detail')) {
      activeSection = 'events';
    } else if (window.location.pathname.includes('/tools')) {
      activeSection = 'tools';
    }
    this.setState({
      activeSection,
    });
  }

  componentDidMount() {
    this.setCurrentActiveSection();
    this.unlisten = this.props.history.listen(() => {
      this.setCurrentActiveSection();
    });
  }

  componentWillUnmount() {
    this.unlisten();
  }

  handleLogout() {
    const { dispatch } = this.context;
    dispatch(AccountActionCreator.logout());
  }

  render() {
    const { classes, userData: { user } } = this.props;
    const { intl: { messages }, userRole: { role } } = this.context;
    return (
      <div className={`${classes.sidebarMenu} no-print`}>
        <div className={classes.logoSection}>
          <NavLink to="/">
            <img src={Logo} alt="Logo" />
          </NavLink>
        </div>
        <div className={classNames(classes.menuSection, { active: this.state.activeSection === 'dashboard' })}>
          <div className="main-section">
            <Link to="/dashboard">
              <IoIosSpeedometer color={colors.primaryWhite} size={24} />
              <span>{messages.dashboard}</span>
            </Link>
          </div>
        </div>
        <div className={classNames(classes.menuSection, { active: this.state.activeSection === 'contact' })}>
          <div className="main-section">
            <Link to="/contacts/all">
              <IoMdPerson color={colors.primaryWhite} size={24} />
              <span>{messages.contacts}</span>
            </Link>
          </div>
          <div className="sub-section">
            <NavLink to="/contacts/all" activeClassName='active'>{messages.all}</NavLink>
            <NavLink to="/contacts/donors" activeClassName='active'>{messages.donors}</NavLink>
            <NavLink to="/contacts/members" activeClassName='active'>{messages.members}</NavLink>
            <NavLink to="/contacts/volunteers" activeClassName='active'>{messages.volunteers}</NavLink>
            <NavLink to="/contacts/advanced-filter" activeClassName='active'>{messages.segments}</NavLink>
          </div>
        </div>
        <div className={classNames(classes.menuSection, { active: this.state.activeSection === 'finance' })}>
          <div className="main-section">
            <Link to="/finance/allPayments">
              <IoLogoUsd size={24} />
              <span>{messages.finance}</span>
            </Link>
          </div>
          <div className="sub-section">
            <NavLink to="/finance/allPayments" activeClassName='active'>{messages.allPayment}</NavLink>
            <NavLink to="/finance/donations" activeClassName='active'>{messages.donations}</NavLink>
            <NavLink to="/finance/memberships" activeClassName='active'>{messages.memberships}</NavLink>
            <NavLink to="/finance/campaigns" activeClassName='active'>{messages.campaigns}</NavLink>
            <NavLink to="/finance/advanced-filter" activeClassName='active'>{messages.segments}</NavLink>
          </div>
        </div>
        <div className={classNames(classes.menuSection, { active: this.state.activeSection === 'events' })}>
          <div className="main-section">
            <Link to="/events/upcoming">
              <FaCalendar size={24} />
              <span>{messages.events}</span>
            </Link>
          </div>
          <div className="sub-section">
            <NavLink to="/events/upcoming" activeClassName='active'>{messages.upcoming}</NavLink>
            <NavLink to="/events/past" activeClassName='active'>{messages.past}</NavLink>
          </div>
        </div>
        <div
          className={classNames(classes.menuSection, { active: this.state.activeSection === 'tools' })}
        >
          <div className="main-section">
            <Link to="/tools/printing">
              <GoTools size={24} />
              <span>{messages.tools}</span>
            </Link>
          </div>
          <div className="sub-section">
            <NavLink to="/tools/printing" activeClassName='active'>{messages.printing}</NavLink>
            <NavLink to="/tools/electoralRoll" activeClassName='active'>{messages.electoralRoll}</NavLink>
            <NavLink to="/tools/importHistory" activeClassName='active'>{messages['tools.menu.import_history']}</NavLink>
          </div>
        </div>
        <Popup
          className={classes.myAccountPopover}
          onClose={() => {
            this.setState({ activeSection: '' })
          }}
          trigger={(
            <div
              className={classNames(classes.userSection, { active: this.state.activeSection === 'account' })}
              onClick={() => this.setState({ activeSection: 'account' })}
            >
              <IoMdContact color={colors.primaryWhite} size={24} />
              <span className="user-name">{user.first_name} {user.last_name}</span>
            </div>
          )}
          content={(
            <Menu
              vertical
              className={classes.myAccountPopover}
            >
              {
                (role === Enum.UserRole.owner || role === Enum.UserRole.admin) &&
                <Dropdown.Item>
                  <IoMdSettings size={24} />
                  <NavLink to='/settings/team'>Settings</NavLink>
                </Dropdown.Item>
              }
              <Dropdown.Item>
                <IoMdPerson size={24} />
                <NavLink to='/account'>My Account</NavLink>
              </Dropdown.Item>
              <Dropdown.Item
                onClick={this.handleLogout}
              >
                <IoMdLogOut size={24} />
                <NavLink to='/'>Logout</NavLink>
              </Dropdown.Item>
            </Menu>
          )}
          on='click'
          open={this.state.activeSection === 'account'}
          position='top center'
        />
      </div>
    )
  }
}

SidebarComponent.propTypes = {
  userData: PropTypes.shape({}),
};

SidebarComponent.contextType = AppContext;


export default withRouter(injectSheet(stylesheet)(SidebarComponent));