import React from 'react';
import { Button, Form, Header, Message } from "semantic-ui-react";
import injectSheet from "react-jss";
import * as Auth from "../../Firebase/Auth";
import colors from "../../Constants/color";
import AppContext from "../../Constants/AppContext";

const style = {
  helpText: {
    textAlign: 'right',
    color: colors.primaryRed1,
  },
  forgotPasswordToggle: {
    textAlign: 'center',
    cursor: 'pointer',
    fontSize: '1rem',
    marginTop: '1.2rem',
    color: colors.primaryGray3,
  },
}

class FormResetPassword extends React.Component {
  static contextType = AppContext;
  constructor(props) {
    super(props);

    this.state = {
      email: '',
      errorMessage: '',
      emailSent: false,
    };
    this.handleChange = this.handleChange.bind(this);
    this.isFieldError = this.isFieldError.bind(this);
    this.handleSubmit = this.handleSubmit.bind(this);
  }

  handleChange({ target: { value } }) {
    this.setState({
      email: value,
    })
  }

  isFieldError(name) {
    const { intl: { messages } } = this.context;
    if (!this.state[name]) {
      return `${messages.pleaseEnter} ${messages.email}`;
    }
    return '';
  }

  handleSubmit() {
    if (!this.state.isHitSave) {
      this.setState({
        isHitSave: true,
      });
    }
    if (!this.isFieldError('email')) {
      const { email} = this.state;
      const {changeForm} = this.props;
      Auth.resetPassword(email)
        .then(() => {
          changeForm('emailSent');
          this.setState({
            errorMessage: ''
          });
        }).catch(e => {
        this.setState({
          errorMessage: e.message,
        });
      });
    }
  }

  render() {
    const { classes, changeForm } = this.props;
    const { intl: { messages } } = this.context;
    const { errorMessage, email } = this.state;
    return (
      <div className={classes.loginForm}>
        <Form
          onSubmit={this.handleSubmit}
          error={errorMessage}
        >
          <Header as='h1' textAlign='center'>{messages.resetPassword}</Header>
          <Message
            error
            header={messages.somethingWrong}
            content={errorMessage}
          />
          <Form.Field
            required
            error={this.state.isHitSave && this.isFieldError('email')}
          >
            <label>{messages.email}</label>
            <input
              placeholder={messages.email}
              name='email'
              value={email}
              onChange={this.handleChange}
            />
            {
              this.state.isHitSave && this.isFieldError('email') &&
              <div className={classes.helpText}>{this.isFieldError('email')}</div>
            }
          </Form.Field>
          <Button
            type='submit'
            color='blue'
            fluid
            disabled={!email}
          >
            {messages.reset}
          </Button>
          <div
            className={classes.forgotPasswordToggle}
            onClick={() => changeForm('login')}
          >
            {messages.returnToSignIn}
          </div>
        </Form>
      </div>
    )
  }
}

export default injectSheet(style)(FormResetPassword);
