import React from 'react';
import injectSheet from "react-jss";

import colors from '../../Constants/color';
import Logo from '../../../Assets/SFFP_Logo.png';
import FormLogin from './FormLogin';
import FormResetPassword from "./FormResetPassword";
import FormEmailSent from "./FormEmailSent";

const style = {
  loginPage: {
    width: '100vw',
    height: '100vh',
    display: 'flex',
  },
  loginSection: {
    width: 400,
    minWidth: 400,
    display: 'flex',
    flexDirection: 'column',
    backgroundColor: colors.primaryWhite,
    padding: [0, 20],
    fontSize: '1rem',
  },
  logoSection: {
    height: 170,
    position: 'relative',
    display: 'flex',
    alignItems: 'center',
    justifyContent: 'center',
  },
  backgroundSection: {
    flexGrow: 1,
    transition: 'background-image 1s ease-in-out',
    backgroundSize: 'cover',
    position: 'relative',
    '& .image': {
      position: 'absolute',
      height: '100%',
      width: '100%',
      left: 0,
      top: 0,
      opacity: 0,
      transition: 'opacity 1s linear',
      objectFit: 'cover',
      objectPosition: 'center',
      '&.active': {
        opacity: 1,
      }
    }
  },
}

const FORM = {
  login: 'login',
  forgotPassword: 'forgotPassword',
  emailSent: 'emailSent',
}

const allBackgroundImage = [
  require(`../../../Assets/background/bg1.jpg`),
  require(`../../../Assets/background/bg2.jpg`),
  require(`../../../Assets/background/bg3.jpg`),
  require(`../../../Assets/background/bg4.jpg`),
  require(`../../../Assets/background/bg5.jpg`),
  require(`../../../Assets/background/bg6.jpg`),
  require(`../../../Assets/background/bg7.jpg`),
  require(`../../../Assets/background/bg8.jpg`),
  require(`../../../Assets/background/bg9.jpg`),
  require(`../../../Assets/background/bg10.jpg`),
  require(`../../../Assets/background/bg11.jpg`),
  require(`../../../Assets/background/bg12.jpg`),
]

class LoginComponent extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      currentIndex: this.getRandomIndex(),
      currentForm: FORM.login,
    };
    this.changeForm = this.changeForm.bind(this);
    this.interval = setInterval(() => {
      this.setState({
        currentIndex: this.getRandomIndex()
      })
    }, 6000);
  }

  getRandomIndex() {
    return Math.floor(Math.random() * 12);
  }

  changeForm(value) {
    this.setState({
      currentForm: value,
    });
  }

  componentWillUnmount() {
    clearInterval(this.interval);
  }

  render() {
    const { classes } = this.props;
    return (
      <div className={classes.loginPage}>
        <div className={classes.loginSection}>
          <div className={classes.logoSection}>
            <img src={Logo} alt="Logo" />
          </div>
          {
            this.state.currentForm === FORM.login &&
            <FormLogin changeForm={this.changeForm} />
          }
          {
            this.state.currentForm === FORM.forgotPassword &&
            <FormResetPassword changeForm={this.changeForm} />
          }
          {
            this.state.currentForm === FORM.emailSent &&
            <FormEmailSent changeForm={this.changeForm} />
          }
        </div>
        <div className={classes.backgroundSection}>
          {
            allBackgroundImage.map((item, index) => (
              <img alt='' src={item} className={`image ${index === this.state.currentIndex ? 'active' : ''}`} />
            ))
          }
        </div>
      </div>
    )
  }
}

export default injectSheet(style)(LoginComponent);