import { storage } from "./Firebase";

export const STORAGE_PATH = {
  ELECTORAL_ROLL: "Electoral Roll",
};

export const uploadFileToCloud = (params) => {
  const { fileId, file, path, uploadEvent = {} } = params;
  const {
    onUploadStart,
    onUploadSuccess,
    onUploadFailure,
    onUploadStateChange,
  } = uploadEvent;

  const fileName = file.name;

  const task = storage.ref(path).child(fileName).put(file);

  onUploadStart({ fileId, fileName, task });

  task.on(
    "state_changed",
    (snapshot) => {
      const { bytesTransferred, totalBytes } = snapshot;
      const progress = (bytesTransferred / totalBytes) * 100;

      onUploadStateChange({ fileId, progress });
    },
    (error) => {
      console.log(error);
      onUploadFailure({ fileId });
    },
    () => {
      storage
        .ref(path)
        .child(fileName)
        .getDownloadURL()
        .then((fileUrl) => {
          onUploadSuccess({ fileId, fileUrl, fileName });
        })
        .catch(() => onUploadFailure({ fileId }));
    }
  );
};
