import { takeEvery, call, select, put } from "redux-saga/effects";
import { get, post } from '../Utils/AxiosClient';
import { toast } from 'react-toastify';

import { SEND_SMS } from "./SMSActionCreator";
import EventActionCreator from "../../Events/Actions/EventActionCreator";
import Utils from "../Utils/Utils";

const getVolunteerSchedule = (contactId, locationId) => {
  const url = `/locations/${locationId}/schedules`;
  const params = {
    filter: { volunteer: contactId },
    limit: 1,
  };
  return get(url, params);
};

function* sendMessage(volunteer, message) {
  if (!volunteer.location._id) {
    // Notification goes here
    toast.warn(`You have to set location for volunteer: ${volunteer.fullName}`);
  } else if (volunteer.mobile_number) {
    try {
      const resSchedule = yield call(getVolunteerSchedule, volunteer.contact_id, volunteer.location._id);
      const time = Utils.getScheduleInfo(resSchedule.data.data[0]);
      let phone = volunteer.mobile_number;
      if (phone.startsWith("0")) {
        phone = phone.replace("0", "+61");
      } else if (phone.startsWith("61")) {
        phone = phone.replace("61", "+61");
      } else if (!phone.startsWith("+")) {
        phone = "+61" + phone;
      }
      phone = phone.trim().replace(/ /g, '');
      const url = `/send-sms/${phone}`;
      var sendMessage = message.replace(/<First Name>/g, volunteer.name);
      sendMessage = sendMessage.replace(/<Elecorate>/g, volunteer.location.voting_district.name);
      sendMessage = sendMessage.replace(/<Time>/g, time);
      sendMessage = sendMessage.replace(/<LocationName>/g, volunteer.location.name);
      if (volunteer.location.address) {
        sendMessage = sendMessage.replace(/<Line 1>/g, volunteer.location.address.line1 || '');
        sendMessage = sendMessage.replace(/<Line 2>/g, volunteer.location.address.line2 || '');
        sendMessage = sendMessage.replace(/<City>/g, volunteer.location.address.city || '');
        sendMessage = sendMessage.replace(/<PostalCode>/g, volunteer.location.address.postal_code || '');
      }
      yield call(post, url, { message: sendMessage, contact_id: volunteer.contact_id });
      toast.success(`Send SMS to ${volunteer.fullName} successful`);
    } catch (e) {
      toast.error(`Send SMS to ${volunteer.fullName} failed`);
    }
  } else {
    toast.warn(`Send SMS to ${volunteer.fullName} failed, missing phone number`);
  }
}

function* watchSendSms({ payload: { eventId, volunteers, message } }) {
  try {
    for (let i = 0; i < volunteers.length; i++) {
      yield call(sendMessage, volunteers[i], message);
    }
    let eventVolunteers = yield select(state => state.events.eventVolunteers);
    yield put(EventActionCreator.getEventVolunteers(eventId, eventVolunteers.activePage, eventVolunteers.filter));
  } catch (e) {
  }
}

function* SmsSagas() {
  yield takeEvery(SEND_SMS, watchSendSms);
}

export default SmsSagas;
