import axios from 'axios';
import Utils, { firebaseToken } from '../Utils/Utils';
import store from '../store';
import AccountActionCreator from "../../Account/AccountActionCreator";
import { config } from '../../configuration';

const baseURL = config.REACT_APP_API_ENDPOINT;

const AxiosClient = axios.create({
  baseURL,
  headers: {
    "Accept": "application/json",
    'Content-Type': 'application/json',
  },
});

AxiosClient.interceptors.request.use(async (config) => {
  try {
    // Add some other config here
    config.headers['Authorization'] = `bearer ${Utils.getCookie(firebaseToken)}`
    return config;
  } catch (error) {
    return Promise.reject(error);
  }
});

AxiosClient.interceptors.response.use(response => response, (error) => {
  if (error && error.response && error.response.status === 401) {
    const { dispatch } = store;
    dispatch(AccountActionCreator.logout());
  }
  return Promise.reject(error);
});

export const get = (url, params = {}, config = {}) => {
  return AxiosClient.get(url, { params, ...config });
}

export const post = (url, data, config = {}) => { 
  return AxiosClient.post(url, data, { ...config });
}

export const put = (url, data) => {
  return AxiosClient.put(url, data);
}

export const patch = (url, data) => {
  return AxiosClient.patch(url, data);
}

export const deleteClient = (url) => {
  return AxiosClient.delete(url);
}

export default AxiosClient;
