import Enum from "../../Common/Constants/Enum";

export const GET_CONTACTS = "GET_CONTACTS";
export const GET_CONTACTS_SUCCESS = "GET_CONTACTS_SUCCESS";
export const GET_CONTACTS_FAILED = "GET_CONTACTS_FAILED";

export const GET_VOLUNTEER_CONTACTS = 'GET_VOLUNTEER_CONTACTS';
export const GET_VOLUNTEER_CONTACTS_SUCCESS = "GET_VOLUNTEER_CONTACTS_SUCCESS";
export const GET_VOLUNTEER_CONTACTS_FAILED = "GET_VOLUNTEER_CONTACTS_FAILED";

export const GET_CONTACT_FILTER_SEGMENT = 'GET_CONTACT_FILTER_SEGMENT';
export const GET_CONTACT_FILTER_SEGMENT_SUCCESS = "GET_CONTACT_FILTER_SEGMENT_SUCCESS";
export const GET_CONTACT_FILTER_SEGMENT_FAILED = "GET_CONTACT_FILTER_SEGMENT_FAILED";

export const GET_CONTACT_BY_ID = 'GET_CONTACT_BY_ID';
export const GET_CONTACT_BY_ID_SUCCESS = 'GET_CONTACT_BY_ID_SUCCESS';
export const GET_CONTACT_BY_ID_FAILED = 'GET_CONTACT_BY_ID_FAILED';

export const CLEAR_SELECTED_CONTACT = 'CLEAR_SELECTED_CONTACT';

export const CREATE_CONTACT = "CREATE_CONTACT";

export const SAVE_CONTACT = "SAVE_CONTACT";
export const SAVE_CONTACT_FAILED = "SAVE_CONTACT_FAILED";

export const DELETE_CONTACT = 'DELETE_CONTACT';
export const DELETE_MULTIPLE_CONTACTS = 'DELETE_MULTIPLE_CONTACTS';

export const GET_PAYMENT_BY_CONTACT = 'GET_PAYMENT_BY_CONTACT';
export const GET_PAYMENT_BY_CONTACT_SUCCESS = 'GET_PAYMENT_BY_CONTACT_SUCCESS';
export const GET_PAYMENT_BY_CONTACT_FAILED = 'GET_PAYMENT_BY_CONTACT_FAILED';

export const GET_PAYMENT_DONATION_BY_CONTACT = 'GET_PAYMENT_DONATION_BY_CONTACT';
export const GET_PAYMENT_DONATION_BY_CONTACT_SUCCESS = 'GET_PAYMENT_DONATION_BY_CONTACT_SUCCESS';
export const GET_PAYMENT_DONATION_BY_CONTACT_FAILED = 'GET_PAYMENT_DONATION_BY_CONTACT_FAILED';

export const GET_PAYMENT_MEMBERSHIPS_BY_CONTACT = 'GET_PAYMENT_MEMBERSHIPS_BY_CONTACT';
export const GET_PAYMENT_MEMBERSHIPS_BY_CONTACT_SUCCESS = 'GET_PAYMENT_MEMBERSHIPS_BY_CONTACT_SUCCESS';
export const GET_PAYMENT_MEMBERSHIPS_BY_CONTACT_FAILED = 'GET_PAYMENT_MEMBERSHIPS_BY_CONTACT_FAILED';

export const SEARCH_VOLUNTEER = 'SEARCH_VOLUNTEER';
export const SEARCH_VOLUNTEER_ON_MAP = 'SEARCH_VOLUNTEER_ON_MAP';
export const SEARCH_VOLUNTEER_ON_MAP_SUCCESS = 'SEARCH_VOLUNTEER_ON_MAP_SUCCESS';

export const EXPORT_CONTACTS = 'EXPORT_CONTACTS';

export const ADD_PAYMENT_SOURCE = "ADD_PAYMENT_SOURCE";

export const SET_DEFAULT_PAYMENT_SOURCE = 'SET_DEFAULT_PAYMENT_SOURCE';

export const REMOVE_PAYMENT_SOURCE = 'REMOVE_PAYMENT_SOURCE';

export const SET_DONATION_TAB_INDEX = 'SET_DONATION_TAB_INDEX';

export const UPLOAD_CONTACT_LIST = 'UPLOAD_CONTACT_LIST';
export const UPLOAD_CONTACT_LIST_SUCCESS = 'UPLOAD_CONTACT_LIST_SUCCESS';
export const UPLOAD_CONTACT_LIST_FAILED = 'UPLOAD_CONTACT_LIST_FAILED';
export const RESET_UPLOAD_CONTACT_LIST = 'RESET_UPLOAD_CONTACT_LIST'
export const GET_CONTACT_TEMPLATE = 'GET_CONTACT_TEMPLATE'

export default {
  getContacts: (activePage = 1, filter = {}, type) => ({
    type: GET_CONTACTS,
    payload: {
      activePage,
      filter,
      type,
      opts: {}
    }
  }),
  getVolunteerContacts: (activePage = 1, filter = {}, type) => ({
    type: GET_VOLUNTEER_CONTACTS,
    payload: {
      activePage,
      filter,
      type,
      opts: {
        successAction: GET_VOLUNTEER_CONTACTS_SUCCESS,
        failureAction: GET_VOLUNTEER_CONTACTS_FAILED,
      }
    }
  }),
  getContactsFilterSegment: (activePage = 1, filter = {}) => ({
    type: GET_CONTACT_FILTER_SEGMENT,
    payload: {
      activePage,
      filter,
    }
  }),
  getContactById: (id) => ({
    type: GET_CONTACT_BY_ID,
    payload: {
      id,
    }
  }),
  clearSelectedContact: (id) => ({
    type: CLEAR_SELECTED_CONTACT,
  }),
  createContact: (contact, history) => ({
    type: CREATE_CONTACT,
    payload: {
      contact,
      history,
    }
  }),
  saveContact: (contact, reloadList = true) => ({
    type: SAVE_CONTACT,
    payload: {
      contact,
      reloadList,
    }
  }),
  deleteContact: (id, opts = {}) => ({
    type: DELETE_CONTACT,
    payload: {
      id,
      opts,
    }
  }),
  deleteMultipleContacts: (ids = [], opts = {}) => ({
    type: DELETE_MULTIPLE_CONTACTS,
    payload: {
      ids,
      opts,
    }
  }),
  getPaymentByContact: (id, activePage = 1, paymentType = '') => {
    let type = GET_PAYMENT_BY_CONTACT;
    if (paymentType === Enum.PaymentEnum.donationPayment) {
      type = GET_PAYMENT_DONATION_BY_CONTACT;
    } else if (paymentType === Enum.PaymentEnum.membershipPayment) {
      type = GET_PAYMENT_MEMBERSHIPS_BY_CONTACT
    }
    return {
      type,
      payload: {
        id,
        activePage,
      }
    }
  },

  searchVolunteer: (searchText, handleSearchResult, status = Object.values(Enum.VolunteerStatus)) => ({
    type: SEARCH_VOLUNTEER,
    payload: {
      searchText,
      status,
      handleSearchResult,
    }
  }),

  searchVolunteerOnMap: (geoInfo, status = Object.values(Enum.VolunteerStatus)) => ({
    type: SEARCH_VOLUNTEER_ON_MAP,
    payload: {
      geoInfo,
      status,
    }
  }),

  exportContactsToCSV: (filter = {}, opts = {}, type) => ({
    type: EXPORT_CONTACTS,
    payload: {
      filter,
      opts,
      type
    }
  }),

  addPaymentSource: (contact_id, source_id) => ({
    type: ADD_PAYMENT_SOURCE,
    payload: {
      contact_id,
      source_id,
    }
  }),

  removePaymentSource: (contact_id, source_id) => ({
    type: REMOVE_PAYMENT_SOURCE,
    payload: {
      contact_id,
      source_id,
    }
  }),

  setDefaultPaymentSource: (contact_id, source_id) => ({
    type: SET_DEFAULT_PAYMENT_SOURCE,
    payload: {
      contact_id,
      source_id,
    }
  }),

  setDonationTabIndex: (index) => ({
    type: SET_DONATION_TAB_INDEX,
    payload: {
      index,
    }
  }),

  uploadFileContactList: (file) => ({
    type: UPLOAD_CONTACT_LIST,
    payload: {
      file,
    }
  }),

  resetFileContactListStatus: () => ({
    type: RESET_UPLOAD_CONTACT_LIST
  }),

  getContactTemplate: () => ({
    type: GET_CONTACT_TEMPLATE
  })
};
