import React from 'react';
import PropTypes from "prop-types";
import { List, Radio } from "semantic-ui-react";
import injectSheet from "react-jss";
import { ModalStyleSheet } from "../../../Common/GlobalStyle";
import AppContext from "../../../Common/Constants/AppContext";

const stylesheet = {
  ...ModalStyleSheet,
  modalContent: {
    padding: '2em 2em, 3em 2em !important',
  },
  sourceList: {
    marginTop: '2em !important',
    '& .item': {
      padding: '1.5em 2em !important',
      textAlign: 'left'
    }
  },
  actionPopup: {
    padding: '25px 35px 25px 30px'
  },
  cardElement: {
    border: '1px solid rgba(34,36,38,.15)',
    borderRadius: '3px',
    padding: '10px'
  },
  newSourceCheckBox: {
    marginLeft: '2em',
    marginBottom: '1em'
  }
}

class PaymentSourceSelector extends React.PureComponent {

  

  handleChangeDefaultSource = async (e, { value }) => {
    this.props.onSelectSource(value)
  }

  render() {
    const { classes, contact, currentSource } = this.props;
    let sources = []
    if(contact.stripe_customer && contact.stripe_customer.sources) {
      sources = contact.stripe_customer.sources.data
    }
    return (
      <div>
        <List celled className={classes.sourceList}>
          {
            sources.map((source, idx) => (
              <List.Item key={idx}>
                <List.Content floated='left' verticalAlign='middle'>
                  <Radio
                    name='defaultSource'
                    value={source.id}
                    checked={currentSource === source.id}
                    onChange={this.handleChangeDefaultSource}
                  />
                </List.Content>
                <List.Content>
                  <List.Description><b>{source.name}</b>    **** **** **** {source.last4}</List.Description>
                </List.Content>
              </List.Item>
            ))
          }
        </List>
        <Radio
          className={classes.newSourceCheckBox}
          label='Add a new card'
          name='defaultSource'
          value='new_source'
          checked={currentSource === 'new_source'}
          onChange={this.handleChangeDefaultSource}
        />
      </div>
    );
  }
}

PaymentSourceSelector.propTypes = {
  onSelectSource: PropTypes.func.isRequired,
  contact: PropTypes.object.isRequired,
  currentSource: PropTypes.string.isRequired
};
PaymentSourceSelector.defaultProps = {
  currentSource: 'new_source'
}

PaymentSourceSelector.contextType = AppContext;

export default injectSheet(stylesheet)(PaymentSourceSelector);
