import React from 'react';
import { Table, Label, Pagination, Loader } from 'semantic-ui-react';
import moment from "moment/moment";
import injectSheet from "react-jss";
import AppContext from "../../../Common/Constants/AppContext";
import ContactActionCreator from "../../Actions/ContactActionCreator";
import Enum from "../../../Common/Constants/Enum";
import ReduxStatus from "../../../Common/Constants/ReduxStatus";
import { config } from '../../../configuration';

const style = {
  membershipsTab: {
    padding: [20, 0],
    '& .ui.basic.table': {
      border: 'none',
    },
    '& .ui.table thead th': {
      textTransform: 'uppercase'
    },
    '& .ui.pagination.menu': {
      marginLeft: '50%',
      transform: 'translateX(-50%)',
      maxWidth: '100%',
    },
  }
};

class FinanceMemberships extends React.Component {
  constructor() {
    super();
    this.handlePaginationChange = this.handlePaginationChange.bind(this);
  }

  componentDidMount() {
    const { dispatch } = this.context;
    const { match: { params: { id } } } = this.props;
    dispatch(ContactActionCreator.getPaymentByContact(id, 1, Enum.PaymentEnum.membershipPayment));
  }

  handlePaginationChange(e, { activePage }) {
    const { dispatch } = this.context;
    const { match: { params: { id } } } = this.props;
    dispatch(ContactActionCreator.getPaymentByContact(id, activePage, Enum.PaymentEnum.membershipPayment));

  }

  render() {
    const { classes, contactPaymentsMemberships: { data, status, activePage, totalPage } } = this.props;
    const { intl: { messages } } = this.context;
    return (
      <div className={classes.membershipsTab}>
        <Table singleLine selectable basic>
          <Table.Header>
            <Table.Row>
              <Table.HeaderCell>{messages.amount}</Table.HeaderCell>
              <Table.HeaderCell>{messages.class}</Table.HeaderCell>
              <Table.HeaderCell>{messages.startDate}</Table.HeaderCell>
              <Table.HeaderCell>{messages.expiryDate}</Table.HeaderCell>
              <Table.HeaderCell>{messages.membershipId}</Table.HeaderCell>
              <Table.HeaderCell>{messages.status}</Table.HeaderCell>
            </Table.Row>
          </Table.Header>
          <Table.Body>
            {
              data.map(item => (
                <Table.Row>
                  <Table.Cell>${item.amount}</Table.Cell>
                  <Table.Cell>{item.membership_class}</Table.Cell>
                  <Table.Cell>
                    {item.start_date && moment(new Date(item.start_date)).format(config.DATE_FORMAT)}
                  </Table.Cell>
                  <Table.Cell>
                    {item.expiry && moment(new Date(item.expiry)).format(config.DATE_FORMAT)}
                  </Table.Cell>
                  <Table.Cell>{item.membershipId}</Table.Cell>
                  <Table.Cell>
                    {
                      item.status === 'active' &&
                      <Label circular color='green'>
                        {item.status}
                      </Label>
                    }
                    {
                      item.status === 'inactive' &&
                      <Label circular color='red'>
                        {item.status}
                      </Label>
                    }
                  </Table.Cell>
                </Table.Row>
              ))
            }
          </Table.Body>
        </Table>
        {
          data.length > 0 &&
          <Pagination
            activePage={activePage}
            totalPages={totalPage}
            onPageChange={this.handlePaginationChange}
          />
        }
        {
          status === ReduxStatus.loading && <Loader active />
        }
      </div>
    );
  }
}

FinanceMemberships.contextType = AppContext;

export default injectSheet(style)(FinanceMemberships);