import React from 'react';
import { Table, Label, Pagination, Loader } from 'semantic-ui-react';
import injectSheet from "react-jss";
import AppContext from "../../../Common/Constants/AppContext";
import ContactActionCreator from "../../Actions/ContactActionCreator";
import ReduxStatus from "../../../Common/Constants/ReduxStatus";
import moment from "moment/moment";
import { config } from '../../../configuration';

const style = {
  paymentTab: {
    padding: [20, 0],
    '& .ui.basic.table': {
      border: 'none',
    },
    '& .ui.table thead th': {
      textTransform: 'uppercase'
    },
    '& .ui.pagination.menu': {
      marginLeft: '50%',
      transform: 'translateX(-50%)',
      maxWidth: '100%',
    },
  }
};

class FinancePayment extends React.Component {
  constructor() {
    super();
    this.handlePaginationChange = this.handlePaginationChange.bind(this);
  }

  componentDidMount() {
    const { dispatch } = this.context;
    const { match: { params: { id } } } = this.props;
    dispatch(ContactActionCreator.getPaymentByContact(id, 1));
  }

  handlePaginationChange(e, { activePage }) {
    const { dispatch } = this.context;
    const { match: { params: { id } } } = this.props;
    dispatch(ContactActionCreator.getPaymentByContact(id, activePage));

  }

  render() {
    const { classes, contactPayments: { data, status, activePage, totalPage } } = this.props;
    const { intl: { messages } } = this.context;
    return (
      <div className={classes.paymentTab}>
        <Table singleLine selectable basic>
          <Table.Header>
            <Table.Row>
              <Table.HeaderCell>{messages.amount}</Table.HeaderCell>
              <Table.HeaderCell>{messages.type}</Table.HeaderCell>
              <Table.HeaderCell>{messages.status}</Table.HeaderCell>
              <Table.HeaderCell>{messages.dateReceived}</Table.HeaderCell>
              <Table.HeaderCell>{messages.paymentId}</Table.HeaderCell>
              <Table.HeaderCell>{messages.paymentMethod}</Table.HeaderCell>
            </Table.Row>
          </Table.Header>
          <Table.Body>
            {
              data.map(item => (
                <Table.Row>
                  <Table.Cell>${item.amount}</Table.Cell>
                  <Table.Cell>{item.type}</Table.Cell>
                  <Table.Cell>
                    {
                      item.status === 'paid' &&
                      <Label circular color='green'>
                        {item.status}
                      </Label>
                    }
                    {
                      item.status === 'rejected' &&
                      <Label circular color='red'>
                        {item.status}
                      </Label>
                    }

                    {
                      item.status === 'pending' &&
                      <Label circular color='yellow'>
                        {item.status}
                      </Label>
                    }
                  </Table.Cell>
                  <Table.Cell>{item.created_at && moment(new Date(item.created_at)).format(config.DATE_FORMAT)}</Table.Cell>
                  <Table.Cell>{item.paymentId}</Table.Cell>
                  <Table.Cell>{item.payment_method}</Table.Cell>
                </Table.Row>
              ))
            }
          </Table.Body>
        </Table>
        {
          data.length > 0 &&
          <Pagination
            activePage={activePage}
            totalPages={totalPage}
            onPageChange={this.handlePaginationChange}
          />
        }
        {
          status === ReduxStatus.loading && <Loader active />
        }
      </div>
    );
  }
}

FinancePayment.contextType = AppContext;

export default injectSheet(style)(FinancePayment);