import React from 'react'
import PropTypes from "prop-types"
import { Button, Modal, Form } from "semantic-ui-react"
import injectSheet from "react-jss"
import { ModalStyleSheet } from "../../../../Common/GlobalStyle"
import AppContext from "../../../../Common/Constants/AppContext"
import { toast } from "react-toastify"
import { injectStripe, CardNumberElement, CardExpiryElement } from 'react-stripe-elements'

const stylesheet = {
  ...ModalStyleSheet,
  modalContent: {
    padding: '2em 2em, 3em 2em !important',
  },
  sourceList: {
    marginTop: '2em !important',
    '& .item': {
      padding: '1.5em 2em !important',
      textAlign: 'left'
    }
  },
  actionPopup: {
    padding: '25px 35px 25px 30px'
  },
  cardElement: {
    border: '1px solid rgba(34,36,38,.15)',
    borderRadius: '3px',
    padding: '10px'
  }
}

class AddCardModal extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      error: ''
    }
  }

  handleSubmit = async () => {
    const { first_name, last_name } = this.props.contact
    const {token, error} = await this.props.stripe.createToken({name: first_name + ' ' + last_name});
    if (error) {
      toast.error(error.message)
      return
    }
    if (!token) {
      return
    }
    this.props.onAddSource(token.id)
  }

  render() {
    const { classes, isOpen, onClose } = this.props;
    const { intl: { messages } } = this.context;
    
    return (
      <Modal
        open={isOpen}
        onClose={() => onClose()}
        size="tiny"
      >
        <Modal.Header className={classes.header}>
          {messages['contact.details.add_card']}
        </Modal.Header>
        <Modal.Content className={classes.modalContent}>
          <Form>
            <Form.Group>
              <Form.Field width={12}>
                <label>Credit or debit card</label>
                <div className={classes.cardElement}><CardNumberElement /></div>
              </Form.Field>
              <Form.Field width={4}>
                <label>Expiry</label>
                <div className={classes.cardElement}><CardExpiryElement /></div>
              </Form.Field>
            </Form.Group>
            <p>{this.state.error}</p>
          </Form>
        </Modal.Content>
        <Modal.Actions>
          <Button onClick={() => onClose()}>
            {messages['common.cancel']}
          </Button>
          <Button
            onClick={this.handleSubmit}
            color='green'>
            {messages['common.add']}
          </Button>
        </Modal.Actions>
      </Modal>
    );
  }
}

AddCardModal.propTypes = {
  isOpen: PropTypes.bool.isRequired,
  onClose: PropTypes.func.isRequired,
  onAddSource: PropTypes.func.isRequired
};

AddCardModal.contextType = AppContext

export default injectSheet(stylesheet)(injectStripe(AddCardModal))
