import React from 'react'
import { Card, Icon, Form, Popup, Checkbox } from 'semantic-ui-react'
import { Link } from "react-router-dom"
import injectSheet from "react-jss"
import isequal from 'lodash.isequal'
import ReduxStatus from "../../../Common/Constants/ReduxStatus"
import Utils from '../../../Common/Utils/Utils'
import colors, { getBoxShadow } from "../../../Common/Constants/color"
import moment from "moment/moment"
import Enum from "../../../Common/Constants/Enum"
import ContactActionCreator from "../../Actions/ContactActionCreator"
import AppContext from "../../../Common/Constants/AppContext"
import ContactStatus from "../Common/ContactStatus"
import PaymentSourceModal from "./PaymentSource/PaymentSourceModal"
import ConfirmDeleteModal from '../ContactList/ConfirmDeleteModal'

const style = {
  profileCard: {
    '&.ui.card': {
      marginTop: 70,
      position: 'relative',
      boxShadow: getBoxShadow(colors.primaryGray7),
      '& .profile-image': {
        position: 'absolute',
        left: '50%',
        transform: 'translate(-50%, -50%)',
        width: 120,
        height: 120,
        borderRadius: '50%',
        backgroundColor: colors.primaryWhite,
        '& img': {
          width: 120,
          height: 120,
          borderRadius: '50%',
          objectFit: 'cover',
          boxShadow: getBoxShadow(colors.primaryGray7, 7, 1),
        },
        '& .contact-status': {
          position: 'absolute',
          left: '50%',
          transform: 'translateX(-50%)',
          bottom: -20,
          display: 'table',
        }
      },
      '& .profile-content': {
        marginTop: 80,
        borderTop: 0,
        textAlign: 'center',
        color: colors.primaryGray8,
        '& .nationBuilder': {
          marginTop: '1.5rem',
          fontSize: '0.8rem',
        },
        '& .action-container': {
          border: '1px solid #B4BEC7',
          borderRadius: 4,
          height: 38,
          width: 'fit-content',
          minWidth: 'fit-content',
          color: colors.primaryGray2,
          textTransform: 'capitalize',
          lineHeight: '34px',
          padding: [0, 15],
          cursor: 'pointer',
          marginLeft: '50%',
          transform: 'translateX(-50%)',
          marginTop: 10,
          fontWeight: 700,
        },
      }
    },
  },
  rowBlock: {
    marginTop: '1.5rem',
    '& .address': {
      color: colors.mainBlue,
    },
  },
  contactFlag: {
    marginTop: '1.5em',
    marginLeft: '2em',
    display: 'flex',
    justifyContent: 'flex-start',
    '& .icon': {
      width: '30%',
      minWidth: '30%',
      display: 'flex',
      justifyContent: 'flex-end',
      '& i': {
        fontSize: '1.5rem !important',
        opacity: '0.4 !important',
      },
      '& i.circular.icon': {
        fontSize: '1rem !important',
        width: '1.5rem !important',
        height: '1.5rem !important',
        padding: '0 !important',
        paddingTop: '0.25rem !important',
        position: 'relative',
        '&:before': {
          position: 'absolute',
          left: '50%',
          transform: 'translateX(-50%)',
        }
      },
      '& i.paper.icon': {
        marginRight: 7
      }
    },
    '& span': {
      marginLeft: 10,
    }
  },
  profileAction: {
    display: 'flex',
    flexDirection: 'column',
    width: 150,
    '& .checkbox-status': {
      '& .checkbox': {
        margin: [15, 0],
      },
      paddingBottom: 10,
    },
    '& .btn-delete': {
      padding: [20, 10, 10, 0],
      borderTop: `1px solid #d4d4d5`,
      cursor: 'pointer',
    },
  },
}

class ContactDetailProfile extends React.Component {
  constructor(props) {
    super(props);
    const { selectedContactDetail: { selectedContact } } = props;
    this.state = {
      toggleDeleteContact: false,
      do_not_contact: selectedContact.do_not_contact,
      is_deceased: selectedContact.is_deceased,
      isShowPaymentSourceModal: false
    }
    this.handleDeleteContact = this.handleDeleteContact.bind(this);
    this.handleSaveContact = this.handleSaveContact.bind(this);
  }

  handleDeleteContact(reason) {
    const { dispatch } = this.context;
    const { selectedContactDetail, history } = this.props;
    const { selectedContact } = selectedContactDetail;
    dispatch(ContactActionCreator.deleteContact(selectedContact._id, {reason}));
    this.setState({
      toggleDeleteContact: false,
    });
    history.push('/contacts/all');
  }

  getSnapshotBeforeUpdate(prevProps, prevState) {
    const { selectedContactDetail: { selectedContact } } = this.props;
    const { selectedContactDetail: { selectedContact: prevSelectedContact } } = prevProps;
    if (!isequal(selectedContact, prevSelectedContact)) {
      return true;
    }
    return null;
  }

  componentDidUpdate(prevProps, prevState, snapshot) {
    if (snapshot) {
      const { selectedContactDetail: { selectedContact } } = this.props;
      this.setState({
        do_not_contact: selectedContact.do_not_contact,
        is_deceased: selectedContact.is_deceased,
      })
    }
  }

  handleSaveContact() {
    const { selectedContactDetail: { selectedContact } } = this.props;
    if (selectedContact.do_not_contact !== this.state.do_not_contact ||
      selectedContact.is_deceased !== this.state.is_deceased) {
      const { dispatch } = this.context;
      dispatch(ContactActionCreator.saveContact({
          _id: selectedContact._id,
          do_not_contact: this.state.do_not_contact,
          is_deceased: this.state.is_deceased,
        },
        false
      ));
    }
  }

  render() {
    const { intl: { messages } } = this.context;
    const { classes, selectedContactDetail } = this.props;
    const { selectedContact, status } = selectedContactDetail;
    return (
      <Form
        loading={status === ReduxStatus.loading}
        error={status === ReduxStatus.saveFailed || status === ReduxStatus.loadFailed}
      >
        {
          this.state.toggleDeleteContact &&
          <ConfirmDeleteModal
            isOpen={true}
            onClose={() => this.setState({ toggleDeleteContact: false })}
            onConfirm={this.handleDeleteContact}
            title={messages.deleteContact}
            cancelText={messages.cancelText}
            confirmText={messages.delete}
          />
        }
        <Card className={classes.profileCard}>
          <div className='profile-image'>
            {
              status !== ReduxStatus.loading && (selectedContact.profile_picture && selectedContact.profile_picture['thumb@128_128'] ?
                <img
                  src={selectedContact.profile_picture['thumb@128_128']}
                  alt=''
                /> :
                <img src={require("../../../Assets/avatar.png")} alt='' />)
            }
            <ContactStatus contactDetail={selectedContact} />
          </div>
          <Card.Content className='profile-content'>
            {
              selectedContact.type === Enum.ContactTypeEnum.person &&
              [
                <Card.Header key='card-header'>{selectedContact.first_name} {selectedContact.last_name}</Card.Header>,
                <Popup
                  key='popup'
                  trigger={(
                    <div className='action-container'>
                      <span>{messages.actions}</span> <Icon name='ellipsis horizontal' />
                    </div>
                  )}
                  content={(
                    <div className={classes.profileAction}>
                      <div className='checkbox-status'>
                        <Checkbox
                          label='Do Not Contact'
                          onChange={() => this.setState({ do_not_contact: !this.state.do_not_contact })}
                          checked={this.state.do_not_contact}
                        />
                        <Checkbox
                          label='Deceased'
                          onChange={() => this.setState({ is_deceased: !this.state.is_deceased })}
                          checked={this.state.is_deceased}
                        />
                      </div>
                      <div
                        className='btn-delete'
                        onClick={(e) => {
                          e.stopPropagation();
                          this.setState({ toggleDeleteContact: true })
                          document.getElementsByTagName('body')[0].click();
                        }}
                      >
                        Delete
                      </div>
                    </div>
                  )}
                  position='bottom center'
                  on='click'
                  onClose={this.handleSaveContact}
                />
              ]
            }
            {
              selectedContact.type === Enum.ContactTypeEnum.organisation &&
              [
                <Card.Header>{selectedContact.organisation_name}</Card.Header>,
                <span>Organisation</span>
              ]
            }
            <div className='nationBuilder'>
              NB ID: {selectedContact.nationbuilder_id}
            </div>
            {
              selectedContact.type === Enum.ContactTypeEnum.person && selectedContact.day_of_birth &&
              <Card.Description
                className={classes.rowBlock}>Age {new Date().getFullYear() - new Date(selectedContact.day_of_birth).getFullYear()} (Born {moment(new Date(selectedContact.day_of_birth)).format('MMMM YYYY')})</Card.Description>
            }
            {
              selectedContact.type === Enum.ContactTypeEnum.person && selectedContact.title &&
              <Card.Description>{selectedContact.title}</Card.Description>
            }
            {
              selectedContact.type === Enum.ContactTypeEnum.person && selectedContact.home_address &&
              <Card.Description className={classes.rowBlock}>
                <Icon name='map marker alternate' color='blue' />
                <span className='address'>{Utils.combineShortAddress(selectedContact.home_address)}</span>
              </Card.Description>
            }
            {
              selectedContact.type === Enum.ContactTypeEnum.organisation &&
              <Card.Description className={classes.rowBlock}>ABN: {selectedContact.abn}</Card.Description>
            }
            {
              selectedContact.type === Enum.ContactTypeEnum.organisation &&
              <Card.Description className={classes.rowBlock}>
                <Icon name='map marker alternate' color='blue' />
                <span className='address'>{Utils.combineShortAddress(selectedContact.postal_address)}</span>
              </Card.Description>
            }
            {
              selectedContact.flags && selectedContact.flags.indexOf(Enum.ContactFlag.member) > -1 &&
              <Card.Description className={classes.contactFlag}>
              <div className='icon'>
                <Icon
                  name='address card'
                  color='black'
                />
              </div>
              <span>Member</span>
            </Card.Description>
            }
            {
              selectedContact.flags && selectedContact.flags.indexOf(Enum.ContactFlag.donor) > -1 &&
              <Card.Description className={classes.contactFlag}>
              <div className='icon'>
                <Icon
                  name='dollar'
                  circular
                  inverted
                />
              </div>
              <span>Donor</span>
            </Card.Description>
            }
            {
              selectedContact.flags && selectedContact.flags.indexOf(Enum.ContactFlag.volunteer) > -1 &&
              <Card.Description className={classes.contactFlag}>
              <div className='icon'>
                <Icon
                  name='hand paper'
                />
              </div>
              <span>Volunteer</span>
            </Card.Description>
            }
            <Card.Description className={classes.rowBlock}>
              Payment: <a href="javascript:void(0)" onClick={() => this.setState({isShowPaymentSourceModal: true})}>Sources</a>&nbsp;/&nbsp;
              <Link to={`/finance/allPayments?payeeId=${selectedContact._id}`}>
                 History
              </Link>
              <PaymentSourceModal 
                isOpen={this.state.isShowPaymentSourceModal} 
                onClose={() => this.setState({isShowPaymentSourceModal: false})}
                contact={selectedContact} />
            </Card.Description>
          </Card.Content>
        </Card>
      </Form>
    )
  }
}

ContactDetailProfile.contextType = AppContext;

export default injectSheet(style)(ContactDetailProfile);
