import React from 'react'
import { Form, Grid } from 'semantic-ui-react'
import AppContext from "../../../../Common/Constants/AppContext"
import ReduxStatus from "../../../../Common/Constants/ReduxStatus"
import ContactEditComponent from "./ContactEditComponent"
import ContactEditDateComponent from "./ContactEditDateComponent"
import ContactEditNameComponent from "./ContactEditNameComponent"
import ContactEditRadioComponent from "./ContactEditRadioComponent"
import Enum from "../../../../Common/Constants/Enum"
import moment from "moment/moment"

class BasicDetail extends React.Component {
  render() {
    const { intl: { messages } } = this.context;
    const { selectedContactDetail } = this.props;
    const { selectedContact, status } = selectedContactDetail;
    const professionalTitleOptions = Enum.ProfessionalTitleOptions.map(item => ({
      key: item,
      text: item,
      value: item
    }));
    const emptyFilter = {
      key: 'Select',
      text: 'Select',
      value: '',
    };
    professionalTitleOptions.unshift(emptyFilter);

    return (
      <Form
        loading={status === ReduxStatus.loading || status === ReduxStatus.saving}
        error={status === ReduxStatus.saveFailed || status === ReduxStatus.loadFailed}
      >
        {
          selectedContact._id &&
          <Grid>
            <Grid.Row>
              <Grid.Column mobile={16} tablet={6} computer={6} className='text-info'>
                {messages.nationbuilder_id}
              </Grid.Column>
              <Grid.Column mobile={16} tablet={10} computer={10} className='value-info'>
                <ContactEditComponent
                  name='nationbuilder_id'
                  value={selectedContact.nationbuilder_id}
                  placeholder={messages.nationbuilder_id}
                  id={selectedContact._id}
                />
              </Grid.Column>
            </Grid.Row>
            <Grid.Row>
              <Grid.Column mobile={16} tablet={6} computer={6} className='text-info'>
                {messages.type}
              </Grid.Column>
              <Grid.Column mobile={16} tablet={10} computer={10} className='value-info'>
                <ContactEditRadioComponent
                  name='type'
                  value={selectedContact.type}
                  id={selectedContact._id}
                />
              </Grid.Column>
            </Grid.Row>
            {
              selectedContact.type === Enum.ContactTypeEnum.person &&
                [
                  <Grid.Row>
                    <Grid.Column mobile={16} tablet={6} computer={6} className='text-info'>
                      {messages.name}
                    </Grid.Column>
                    <Grid.Column mobile={16} tablet={10} computer={10} className='value-info'>
                      <ContactEditNameComponent
                        prefix_name={selectedContact.prefix_name}
                        first_name={selectedContact.first_name}
                        middle_name={selectedContact.middle_name}
                        nickname={selectedContact.nickname}
                        last_name={selectedContact.last_name}
                        id={selectedContact._id}
                      />
                    </Grid.Column>
                  </Grid.Row>,
                  <Grid.Row>
                    <Grid.Column mobile={16} tablet={6} computer={6} className='text-info'>
                      {messages.dateOfBirth}
                    </Grid.Column>
                    <Grid.Column mobile={16} tablet={10} computer={10} className='value-info'>
                      <ContactEditDateComponent
                        name='day_of_birth'
                        value={selectedContact.day_of_birth}
                        id={selectedContact._id}
                        key='day_of_birth'
                      />
                    </Grid.Column>
                  </Grid.Row>,
                  <Grid.Row>
                    <Grid.Column mobile={16} tablet={6} computer={6} className='text-info'>
                      {messages.professional_title}
                    </Grid.Column>
                    <Grid.Column mobile={16} tablet={10} computer={10} className='value-info'>
                      <ContactEditComponent
                        name='professional_title'
                        value={selectedContact.professional_title}
                        placeholder={messages.professional_title}
                        id={selectedContact._id}
                        type='dropdown'
                        options={professionalTitleOptions}
                      />
                    </Grid.Column>
                  </Grid.Row>,
                  <Grid.Row>
                    <Grid.Column mobile={16} tablet={6} computer={6} className='text-info'>
                      {messages.organisation}
                    </Grid.Column>
                    <Grid.Column mobile={16} tablet={10} computer={10} className='value-info'>
                      <ContactEditComponent
                        name='related_organisation'
                        value={selectedContact.related_organisation}
                        placeholder={messages.organisation}
                        id={selectedContact._id}
                      />
                    </Grid.Column>
                  </Grid.Row>
                ]
            }
            {
              selectedContact.type === Enum.ContactTypeEnum.organisation &&
              [
                <Grid.Row>
                  <Grid.Column mobile={16} tablet={6} computer={6} className='text-info'>
                    {messages.organisationName}
                  </Grid.Column>
                  <Grid.Column mobile={16} tablet={10} computer={10} className='value-info'>
                    <ContactEditComponent
                      name='organisation_name'
                      value={selectedContact.organisation_name}
                      placeholder={messages.organisationName}
                      id={selectedContact._id}
                    />
                  </Grid.Column>
                </Grid.Row>,
                <Grid.Row>
                  <Grid.Column mobile={16} tablet={6} computer={6} className='text-info'>
                    {messages.abn}
                  </Grid.Column>
                  <Grid.Column mobile={16} tablet={10} computer={10} className='value-info'>
                    <ContactEditComponent
                      name='abn'
                      value={selectedContact.abn}
                      placeholder={messages.abn}
                      id={selectedContact._id}
                    />
                  </Grid.Column>
                </Grid.Row>,
              ]
            }
            <Grid.Row>
              <Grid.Column mobile={16} tablet={6} computer={6} className='text-info'>
                {messages.dateAdded}
              </Grid.Column>
              <Grid.Column mobile={16} tablet={10} computer={10} className='value-info'>
                {selectedContact.created_at && moment(new Date(selectedContact.created_at)).format('DD MMM YYYY')}
              </Grid.Column>
            </Grid.Row> 
            <Grid.Row>
              <Grid.Column mobile={16} tablet={6} computer={6} className='text-info'>
                {messages['contact.details.member_since']}
              </Grid.Column>
              <Grid.Column mobile={16} tablet={10} computer={10} className='value-info'>
                <ContactEditDateComponent
                  name='member_since'
                  value={selectedContact.member_since}
                  id={selectedContact._id}
                  key='member_since'
                />
                {/* {selectedContact.member_since ? moment(new Date(selectedContact.member_since)).format('DD MMM YYYY') : '-'} */}
              </Grid.Column>
            </Grid.Row>
          </Grid>
        }
      </Form>
    );
  }
}

BasicDetail.contextType = AppContext;

export default BasicDetail;
