import React from 'react';
import { Form, Grid } from 'semantic-ui-react';
import AppContext from "../../../../Common/Constants/AppContext";
import ReduxStatus from "../../../../Common/Constants/ReduxStatus";
import ContactEditComponent from './ContactEditComponent';
import BranchState from './ContactEditBranchState';
import ContactAddressEditComponent from "./ContactEditAddressComponent";
import ContactEditEmailComponent from "./ContactEditEmailComponent";
import Enum from "../../../../Common/Constants/Enum";

class ContactDetail extends React.Component {
  render() {
    const { selectedContactDetail: { selectedContact, status } } = this.props;
    const { intl: { messages } } = this.context;

    const stateBranchesOptions = Enum.StateBranches.map(item => ({
      key: item,
      text: item,
      value: item
    }));
    const emptyFilter = {
      key: 'Select',
      text: 'Select',
      value: '',
    };
    stateBranchesOptions.unshift(emptyFilter);

    return (
      <Form
        loading={status === ReduxStatus.loading}
        error={status === ReduxStatus.saveFailed || status === ReduxStatus.loadFailed}
      >
        {
          selectedContact._id &&
          <Grid>
            <Grid.Row>
              <Grid.Column mobile={16} tablet={6} computer={6} className='text-info'>
                {messages.mobile}
              </Grid.Column>
              <Grid.Column mobile={16} tablet={10} computer={10} className='value-info'>
                <ContactEditComponent
                  name='mobile_number'
                  value={selectedContact.mobile_number}
                  placeholder={messages.mobile}
                  id={selectedContact._id}
                />
              </Grid.Column>
            </Grid.Row>
            <Grid.Row>
              <Grid.Column mobile={16} tablet={6} computer={6} className='text-info'>
                {messages.home}
              </Grid.Column>
              <Grid.Column mobile={16} tablet={10} computer={10} className='value-info'>
                <ContactEditComponent
                  name='home_number'
                  value={selectedContact.home_number}
                  placeholder={messages.home}
                  id={selectedContact._id}
                />
              </Grid.Column>
            </Grid.Row>
            {
              selectedContact.emails && selectedContact.emails.length > 0 &&
              selectedContact.emails.map((item, index) => (
                <Grid.Row key={item._id}>
                  <Grid.Column mobile={16} tablet={6} computer={6} className='text-info'>
                    {
                      item.primary ? messages.email1Primary : (messages.email + (index + 1))
                    }
                  </Grid.Column>
                  <Grid.Column mobile={16} tablet={10} computer={10} className='value-info'>
                    <ContactEditEmailComponent
                      name='emails'
                      value={selectedContact.emails}
                      placeholder={messages.email}
                      id={selectedContact._id}
                      validators={['required']}
                      emailIndex={index}
                    />
                  </Grid.Column>
                </Grid.Row>
              ))
            }
            {
              selectedContact.emails && selectedContact.emails.length > 0 &&
              <Grid.Row>
                <Grid.Column mobile={16} tablet={6} computer={6} className='text-info'>
                  {
                    `${messages.email} ${selectedContact.emails.length + 1}`
                  }
                </Grid.Column>
                <Grid.Column mobile={16} tablet={10} computer={10} className='value-info'>
                  <ContactEditEmailComponent
                    name='emails'
                    value={selectedContact.emails}
                    id={selectedContact._id}
                    emailIndex={selectedContact.emails.length}
                    validators={['required']}
                  />
                </Grid.Column>
              </Grid.Row>
            }
            {
              (!selectedContact.emails || selectedContact.emails.length === 0) &&
              <Grid.Row>
                <Grid.Column mobile={16} tablet={6} computer={6} className='text-info'>
                  {
                    messages.email1Primary
                  }
                </Grid.Column>
                <Grid.Column mobile={16} tablet={10} computer={10} className='value-info'>
                  <ContactEditEmailComponent
                    name='emails'
                    value={[]}
                    id={selectedContact._id}
                    emailIndex={0}
                    validators={['required']}
                  />
                </Grid.Column>
              </Grid.Row>
            }
            {
              selectedContact.type === Enum.ContactTypeEnum.person &&
              <Grid.Row>
                <Grid.Column mobile={16} tablet={6} computer={6} className='text-info'>
                  {messages.homeAddress}
                </Grid.Column>
                <Grid.Column mobile={16} tablet={10} computer={10} className='value-info'>
                  <ContactAddressEditComponent
                    name='home_address'
                    address={selectedContact.home_address}
                    id={selectedContact._id}
                  />
                </Grid.Column>
              </Grid.Row>
            }
            <Grid.Row>
              <Grid.Column mobile={16} tablet={6} computer={6} className='text-info'>
                {messages.postalAddress}
              </Grid.Column>
              <Grid.Column mobile={16} tablet={10} computer={10} className='value-info'>
                <ContactAddressEditComponent
                  name='postal_address'
                  address={selectedContact.postal_address}
                  id={selectedContact._id}
                />
              </Grid.Column>
            </Grid.Row>
            <Grid.Row>
              <Grid.Column mobile={16} tablet={6} computer={6} className='text-info'>
                {messages.workAddress}
              </Grid.Column>
              <Grid.Column mobile={16} tablet={10} computer={10} className='value-info'>
                <ContactAddressEditComponent
                  name='work_address'
                  address={selectedContact.work_address}
                  id={selectedContact._id}
                />
              </Grid.Column>
            </Grid.Row>
            <Grid.Row>
              <Grid.Column mobile={16} tablet={6} computer={6} className='text-info'>
                {messages.branchState}
              </Grid.Column>
              <Grid.Column mobile={16} tablet={10} computer={10} className='value-info'>
                <BranchState
                  name='state_branch'
                  value={selectedContact.state_branch?.state}
                  address={selectedContact.home_address}
                  id={selectedContact._id}
                  type='dropdown'
                  options={stateBranchesOptions}
                  placeholder={messages.state_branch}
                />
              </Grid.Column>
            </Grid.Row>
          </Grid>
        }
      </Form>
    );
  }
}

ContactDetail.contextType = AppContext;

export default ContactDetail;
