import React from 'react';
import PropTypes from 'prop-types';
import { Icon, Form } from 'semantic-ui-react';
import AppContext from "../../../../Common/Constants/AppContext";
import Utils from "../../../../Common/Utils/Utils";
import ContactActionCreator from "../../../Actions/ContactActionCreator";
import injectSheet from "react-jss";
import style from "./stylesheet";
import SearchAddress from "../../../../Common/Components/AutocompleteSearchAddress/SearchAddress";

class ContactEditAddressComponent extends React.Component {

  static getDerivedStateFromProps(props, state) {
    if (!state.isBind) {
      if (props.address) {
        return {
          address: props.address,
          isBind: true,
        };
      }
    }
    return null;
  }

  constructor(props) {
    super(props);
    this.state = {
      isEdit: false,
      isBind: false,
      address: {},
      isHitSave: false,
    }
    this.handleSaveInfo = this.handleSaveInfo.bind(this);
    this.handleChange = this.handleChange.bind(this);
    this.onCancel = this.onCancel.bind(this);
  }

  handleSaveInfo() {
    if (!this.state.isHitSave) {
      this.setState({
        isHitSave: true,
      });
    }
    const { dispatch } = this.context;
    const { id, name } = this.props;
    dispatch(ContactActionCreator.saveContact({
        _id: id,
        [name]: this.state.address,
      },
      false
    ));
    this.setState({
      isEdit: false,
    })
  }

  handleChange({ target: { name, value } }) {
    this.setState({
      address: {
        ...this.state.address,
        [name]: value,
      }
    })
  }

  onCancel() {
    const { value } = this.props;
    this.setState({
      value,
      isEdit: false,
    })
  }

  handleDeleteAddress = () => {
    const { dispatch } = this.context;
    const { id, name } = this.props;
    dispatch(ContactActionCreator.saveContact({
        _id: id,
        [name]: {},
      },
      false
    ));
  }

  render() {
    const { classes } = this.props;
    const { intl: { messages } } = this.context;
    const { address } = this.state;
    if (!this.state.isEdit) {
      if (Utils.combineAddress(address)) {
        return (
          <div className={classes.displayText}>
            <span onClick={() => this.setState({ isEdit: true })}>{Utils.combineAddress(address)}</span>
            <Icon name='edit' color='blue' onClick={() => this.setState({ isEdit: true })} />
            <Icon name='trash alternate' onClick={this.handleDeleteAddress} color='red' />
          </div>
        )
      }
      return (
        <Icon name='edit' color='blue' onClick={() => this.setState({ isEdit: true })} />
      )
    }
    return (
      <Form className={classes.addressInput}>
        <Form.Field className='search-location'>
          <SearchAddress
            address={address}
            onSelect={(addressInfo) => this.setState({ address: addressInfo })}
          />
        </Form.Field>
        <Form.Field>
          <input
            placeholder={messages.line1}
            name='line1'
            value={this.state.address.line1 || ''}
            onChange={this.handleChange}
          />
        </Form.Field>
        <Form.Field>
          <input
            placeholder={messages.line2}
            name='line2'
            value={this.state.address.line2 || ''}
            onChange={this.handleChange}
          />
        </Form.Field>
        <Form.Field>
          <input
            placeholder={messages.line3}
            name='line3'
            value={this.state.address.line3 || ''}
            onChange={this.handleChange}
          />
        </Form.Field>
        <Form.Field>
          <input
            placeholder={messages.city}
            name='city'
            value={this.state.address.city || ''}
            onChange={this.handleChange}
          />
        </Form.Field>
        <Form.Field>
          <input
            placeholder={messages.postal_code}
            name='postal_code'
            value={this.state.address.postal_code || ''}
            onChange={this.handleChange}
          />
        </Form.Field>
        <Form.Field>
          <input
            placeholder={messages.state}
            name='state'
            value={this.state.address.state || ''}
            onChange={this.handleChange}
            disabled
          />
        </Form.Field>
        <Form.Field>
          <input
            placeholder={messages.country}
            name='country'
            value={this.state.address.country || ''}
            onChange={this.handleChange}
            disabled
          />
        </Form.Field>
        <Form.Field>
          <div className='action-icon'>
            <Icon name='check' color='blue' onClick={this.handleSaveInfo} />
            <Icon name='close' color='blue' onClick={this.onCancel} />
          </div>
        </Form.Field>
      </Form>
    );
  }
}

ContactEditAddressComponent.propTypes = {
  name: PropTypes.string.isRequired,
  address: PropTypes.shape({}).isRequired,
  id: PropTypes.string.isRequired,
  validators: PropTypes.arrayOf(PropTypes.string),
};

ContactEditAddressComponent.defaultProps = {
  validators: [],
};

ContactEditAddressComponent.contextType = AppContext;

export default injectSheet(style)(ContactEditAddressComponent);