import React from 'react';
import PropTypes from 'prop-types';
import { Icon, Form } from 'semantic-ui-react';
import AppContext from "../../../../Common/Constants/AppContext";
import colors from "../../../../Common/Constants/color";
import ContactActionCreator from "../../../Actions/ContactActionCreator";
import injectSheet from "react-jss";
import style from './stylesheet';

class BranchState extends React.Component {
  static getDerivedStateFromProps(props, state) {
    if (!state.isBind) {
      if (props.id) {
        return {
          value: props.value,
          isBind: true,
        };
      }
    }
    return null;
  }

  constructor(props) {
    super(props);
    this.state = {
      isEdit: false,
      isBind: false,
      value: null,
      isHitSave: false,
    }
    this.handleSaveInfo = this.handleSaveInfo.bind(this);
    this.handleChange = this.handleChange.bind(this);
    this.onDateChange = this.onDateChange.bind(this);
    this.getErrorMessage = this.getErrorMessage.bind(this);
    this.onCancel = this.onCancel.bind(this);
  }

  getErrorMessage() {
    const { validators } = this.props;
    const { intl: { messages } } = this.context;
    if (validators.includes('required') && !this.state.value) {
      return messages.requiredField;
    }
    return '';
  }

  handleSaveInfo() {
    if (!this.state.isHitSave) {
      this.setState({
        isHitSave: true,
      });
    }
    if (!this.getErrorMessage()) {
      const { dispatch } = this.context;
      const { id, home_address } = this.props;

      if(this.state.value === this.props.value) {
        this.onCancel();
        return;
      }
      dispatch(ContactActionCreator.saveContact({
          _id: id,
          state_branch: {
            state: this.state.value,
            is_manual_change: home_address?.state !== this.state.value
          },
        },
        false
      ));
      this.setState({
        isEdit: false,
      })
    }
  }

  handleChange({ target: { value } }) {
    this.setState({
      value,
    })
  }

  onDateChange(event, { name, value }) {
    this.setState({
      value,
    })
  }

  onCancel() {
    const { value } = this.props;
    this.setState({
      value,
      isEdit: false,
    })
  }

  render() {
    const { name, type, value, options, placeholder, classes } = this.props;
    const { intl: { messages } } = this.context;

    return (
      <div>
        {
          !this.state.isEdit && type === 'text' &&
          <div className={classes.displayText} onClick={() => this.setState({ isEdit: true })}>
            <span>{value}</span>
            <Icon name='edit' color='blue' />
          </div>
        }
        {
          !this.state.isEdit && type === 'dropdown' &&
          <div className={classes.displayText} onClick={() => this.setState({ isEdit: true })}>
            <span>{messages[value] || value}</span>
            <Icon name='edit' onClick={() => this.setState({ isEdit: true })} color='blue' />
          </div>
        }
        {
          !this.state.isEdit && !value &&
          <Icon name='edit' color='blue' onClick={() => this.setState({ isEdit: true })} />
        }
        {
          this.state.isEdit && type === 'text' &&
          <div className={classes.editInput}>
            <input
              placeholder={placeholder}
              name={name}
              value={this.state.value}
              onChange={this.handleChange}
            />
            <Icon name='check' color='blue' onClick={this.handleSaveInfo} />
            <Icon name='close' color='blue' onClick={this.onCancel} />
          </div>
        }
        {
          this.state.isEdit && type === 'dropdown' &&
          <div className={classes.editInput}>
            <Form.Select
              placeholder={placeholder}
              options={options}
              name={name}
              value={this.state.value}
              onChange={(e, target) => this.handleChange({ target: target })}
            />
            <Icon name='check' color='blue' onClick={this.handleSaveInfo} />
            <Icon name='close' color='blue' onClick={this.onCancel} />
          </div>
        }
        {
          this.state.isEdit && this.state.isHitSave &&
          <div style={{ fontSize: '0.9rem', color: colors.primaryRed1 }}>{this.getErrorMessage()}</div>
        }
      </div>
    );
  }Anderson
}

BranchState.propTypes = {
  name: PropTypes.string.isRequired,
  value: PropTypes.string.isRequired,
  id: PropTypes.string.isRequired,
  type: PropTypes.string,
  validators: PropTypes.arrayOf(PropTypes.string),
};

BranchState.defaultProps = {
  type: 'text',
  validators: [],
};

BranchState.contextType = AppContext;

export default injectSheet(style)(BranchState);
