import React from 'react';
import PropTypes from 'prop-types';
import moment from 'moment';
import { Icon } from 'semantic-ui-react';
import DatePicker from 'react-datepicker/es';
import AppContext from "../../../../Common/Constants/AppContext";
import colors from "../../../../Common/Constants/color";
import ContactActionCreator from "../../../Actions/ContactActionCreator";
import injectSheet from "react-jss";
import style from './stylesheet';
import { config } from '../../../../configuration';

class ContactEditDateComponent extends React.Component {
  static getDerivedStateFromProps(props, state) {
    if (!state.isBind) {
      if (!state.value && props.value) {
        return {
          value: props.value,
          isBind: true,
        };
      }
    }
    return null;
  }

  constructor(props) {
    super(props);
    this.state = {
      isEdit: false,
      isBind: false,
      value: null,
      isHitSave: false,
    }
    this.handleSaveInfo = this.handleSaveInfo.bind(this);
    this.onDateChange = this.onDateChange.bind(this);
    this.getErrorMessage = this.getErrorMessage.bind(this);
    this.onCancel = this.onCancel.bind(this);
  }

  getErrorMessage() {
    const { validators } = this.props;
    const { intl: { messages } } = this.context;
    if (validators.includes('required') && !this.state.value) {
      return messages.requiredField;
    }
    return '';
  }

  handleSaveInfo() {
    if (!this.state.isHitSave) {
      this.setState({
        isHitSave: true,
      });
    }
    if (!this.getErrorMessage()) {
      const { dispatch } = this.context;
      const { id, name } = this.props;
      dispatch(ContactActionCreator.saveContact({
          _id: id,
          [name]: this.state.value ? moment(this.state.value).startOf('D').format('YYYY-MM-DD HH:mm:ss') : this.state.value,
        },
        false
      ));
      this.setState({
        isEdit: false,
      })
    }
  }

  onDateChange(date) {
    this.setState({
      value: date || null,
    })
  }

  onCancel() {
    const { value } = this.props;
    this.setState({
      value,
      isEdit: false,
    })
  }

  render() {
    const { name, placeholder, classes } = this.props;
    return (
      <div>
        {
          !this.state.isEdit && this.state.value &&
          <div className={classes.displayText} onClick={() => this.setState({ isEdit: true })}>
            <span>{moment(new Date(this.state.value)).format('DD MMMM YYYY')}</span>
            <Icon name='edit' color='blue' />
          </div>
        }
        {
          !this.state.isEdit && !this.state.value &&
          <Icon name='edit' color='blue' onClick={() => this.setState({ isEdit: true })} />
        }
        {
          this.state.isEdit &&
          <div className={classes.editInput}>
            <DatePicker
              name={name}
              placeholder={placeholder}
              selected={this.state.value ? new Date(this.state.value) : null}
              onChange={this.onDateChange}
              showYearDropdown={true}
              dateFormat={'dd/MM/yyyy'}
              placeholderText={config.DATE_FORMAT}
            />
            <Icon name='check' color='blue' onClick={this.handleSaveInfo} />
            <Icon name='close' color='blue' onClick={this.onCancel} />
          </div>
        }
        {
          this.state.isEdit && this.state.isHitSave &&
          <div style={{ fontSize: '0.9rem', color: colors.primaryRed1 }}>{this.getErrorMessage()}</div>
        }
      </div>
    );
  }
}

ContactEditDateComponent.propTypes = {
  name: PropTypes.string.isRequired,
  // value: PropTypes.string.isRequired,
  id: PropTypes.string.isRequired,
  type: PropTypes.string,
  validators: PropTypes.arrayOf(PropTypes.string),
};

ContactEditDateComponent.defaultProps = {
  type: 'text',
  validators: [],
};

ContactEditDateComponent.contextType = AppContext;

export default injectSheet(style)(ContactEditDateComponent);
