import React from 'react';
import PropTypes from 'prop-types';
import { Icon } from 'semantic-ui-react';
import AppContext from "../../../../Common/Constants/AppContext";
import Utils from "../../../../Common/Utils/Utils";
import colors from "../../../../Common/Constants/color";
import ContactActionCreator from "../../../Actions/ContactActionCreator";
import injectSheet from "react-jss";
import style from './stylesheet';

class ContactEditEmailComponent extends React.Component {

  static getEmailValue(emails, emailIndex) {
    if (!emails[emailIndex]) {
      return '';
    } else {
      return emails[emailIndex].email;
    }
  }

  static getDerivedStateFromProps(props, state) {
    if (!state.isBind) {
      if (!state.value && props.value) {
        const value = ContactEditEmailComponent.getEmailValue(props.value, props.emailIndex);
        return {
          value,
          isBind: true,
        }
      }
    }
    return null;
  }

  constructor(props) {
    super(props);
    this.state = {
      isEdit: false,
      isBind: false,
      value: null,
      isHitSave: false,
    }
    this.handleSaveInfo = this.handleSaveInfo.bind(this);
    this.handleChange = this.handleChange.bind(this);
    this.getErrorMessage = this.getErrorMessage.bind(this);
    this.onCancel = this.onCancel.bind(this);
    this.handleDeleteEmail = this.handleDeleteEmail.bind(this);
  }

  getErrorMessage() {
    const { validators } = this.props;
    const { intl: { messages } } = this.context;
    if (validators.includes('required') && !this.state.value) {
      return messages.requiredField;
    }
    if (this.state.value && !Utils.validateEmail(this.state.value)) {
      return messages.inputValidEmail;
    }
    return '';
  }

  handleSaveInfo() {
    if (!this.state.isHitSave) {
      this.setState({
        isHitSave: true,
      });
    }
    if (!this.getErrorMessage()) {
      const { dispatch } = this.context;
      const { id, name } = this.props;
      const { emailIndex } = this.props;
      const emails = [...this.props.value];
      if (!emails[emailIndex]) {
        emails[emailIndex] = {
          email: this.state.value,
          primary: emails.length > 0 ? false : true,
        }
      } else {
        emails[emailIndex].email = this.state.value;
      }
      dispatch(ContactActionCreator.saveContact({
          _id: id,
          [name]: emails,
        },
        false
      ));
      this.setState({
        isEdit: false,
      })
    }
  }

  handleChange({ target: { value } }) {
    this.setState({
      value,
    })
  }

  handleDeleteEmail() {
    const { dispatch } = this.context;
    const { id, name } = this.props;
    const { emailIndex } = this.props;
    const emails = [...this.props.value];
    if (emails[emailIndex]) {
      emails.splice(emailIndex, 1);
      dispatch(ContactActionCreator.saveContact({
          _id: id,
          [name]: emails,
        },
        false
      ));
    }
  }

  onCancel() {
    const { value, emailIndex } = this.props;
    let initValue = ContactEditEmailComponent.getEmailValue(value, emailIndex);
    this.setState({
      value: initValue,
      isEdit: false,
    })
  }

  render() {
    const { name, value, emailIndex, placeholder, classes } = this.props;
    let currentEmail = {};
    if (value && value[emailIndex]) {
      currentEmail = value[emailIndex];
    }

    return (
      <div>
        {
          !this.state.isEdit && value &&
          <div className={classes.displayText}>
                <span onClick={() => this.setState({ isEdit: true })}>
                  {ContactEditEmailComponent.getEmailValue(value, emailIndex)}
                </span>
            {
              currentEmail.email &&
              [
                <Icon name='edit' onClick={() => this.setState({ isEdit: true })} color='blue' />,
                <Icon name='trash alternate' onClick={this.handleDeleteEmail} color='red' />
              ]
            }
          </div>
        }
        {
          !this.state.isEdit && !currentEmail.email &&
          <Icon name='add' onClick={() => this.setState({ isEdit: true })} color='blue' />
        }
        {
          this.state.isEdit &&
          <div className={classes.editInput}>
            <input
              placeholder={placeholder}
              name={name}
              value={this.state.value}
              onChange={this.handleChange}
            />
            <Icon name='check' color='blue' onClick={this.handleSaveInfo} />
            <Icon name='close icon' color='blue' onClick={this.onCancel} />
          </div>
        }
        {
          this.state.isEdit && this.state.isHitSave &&
          <div style={{ fontSize: '0.9rem', color: colors.primaryRed1 }}>{this.getErrorMessage()}</div>
        }
      </div>
    );
  }
}

ContactEditEmailComponent.propTypes = {
  name: PropTypes.string.isRequired,
  value: PropTypes.arrayOf(PropTypes.shape({})).isRequired,
  id: PropTypes.string.isRequired,
  emailIndex: PropTypes.number.isRequired,
  validators: PropTypes.arrayOf(PropTypes.string),
};

ContactEditEmailComponent.defaultProps = {
  validators: [],
};

ContactEditEmailComponent.contextType = AppContext;

export default injectSheet(style)(ContactEditEmailComponent);