import React from 'react';
import PropTypes from 'prop-types';
import { Icon, Form, Dropdown } from 'semantic-ui-react';
import AppContext from "../../../../Common/Constants/AppContext";
import colors from "../../../../Common/Constants/color";
import Enum from "../../../../Common/Constants/Enum";
import ContactActionCreator from "../../../Actions/ContactActionCreator";
import injectSheet from "react-jss";
import style from './stylesheet';
import _ from 'lodash';

class ContactEditInterestsComponent extends React.Component {
  static getDerivedStateFromProps(props, state) {
    if (!state.isBind) {
      if (props.id) {
        return {
          value: props.value,
          isBind: true,
        };
      }
    }
    return null;
  }

  constructor(props) {
    super(props);
    this.state = {
      isEdit: false,
      isBind: false,
      value: null,
      isHitSave: false,
      interests: Object.values(Enum.Interests).map(item => ({
        key: item,
        text: item,
        value: item
      }))
    }
    this.handleSaveInfo = this.handleSaveInfo.bind(this);
    this.handleChange = this.handleChange.bind(this);
    this.onDateChange = this.onDateChange.bind(this);
    this.getErrorMessage = this.getErrorMessage.bind(this);
    this.onCancel = this.onCancel.bind(this);
  }

  getErrorMessage() {
    const { validators } = this.props;
    const { intl: { messages } } = this.context;
    if (validators.includes('required') && !this.state.value) {
      return messages.requiredField;
    }
    return '';
  }

  handleSaveInfo() {
    if (!this.state.isHitSave) {
      this.setState({
        isHitSave: true,
      });
    }
    if (!this.getErrorMessage()) {
      const { dispatch } = this.context;
      const { id, name } = this.props;

      if(this.state.value === this.props.value) {
        this.onCancel();
        return;
      }
      dispatch(ContactActionCreator.saveContact({
          _id: id,
          [name]: this.state.value,
        },
        false
      ));
      this.setState({
        isEdit: false,
      })
    }
  }

  handleAddition = (e, { value }) => {
    this.setState((prevState) => ({
      interests: [{ text: value, value }, ...prevState.interests],
    }))
  }

  handleChange(e, { value }) {
    this.setState({
      value
    })
  }

  onDateChange(event, { name, value }) {
    this.setState({
      value,
    })
  }

  onCancel() {
    const { value } = this.props;
    this.setState({
      value,
      isEdit: false,
    })
  }

  render() {
    const { name, type, value, options, placeholder, classes } = this.props;
    const { intl: { messages } } = this.context;
    const interestOptions = _.union(this.state.interests, value ? value.map(item => ({
      key: item,
      text: item,
      value: item
    })): [])
    return (
      <div>
        {
          !this.state.isEdit && type === 'text' &&
          <div className={classes.displayText} onClick={() => this.setState({ isEdit: true })}>
            <span>{ value ? value.join(', ') : ''}</span>
            <Icon name='edit' color='blue' />
          </div>
        }
        {
          !this.state.isEdit && type === 'dropdown' &&
          <div className={classes.displayText} onClick={() => this.setState({ isEdit: true })}>
            <span>{messages[value] || value}</span>
            <Icon name='edit' onClick={() => this.setState({ isEdit: true })} color='blue' />
          </div>
        }
        {
          !this.state.isEdit && (!value || value.length ===0) &&
          <Icon name='edit' color='blue' onClick={() => this.setState({ isEdit: true })} />
        }
        {
          this.state.isEdit && type === 'text' &&
          <div className={classes.editInterests}>
            <Dropdown
              options={interestOptions}
              placeholder={placeholder}
              search
              selection
              fluid
              multiple
              allowAdditions
              value={this.state.value}
              onAddItem={this.handleAddition}
              onChange={this.handleChange} 
            />
            <Icon name='check' color='blue' onClick={this.handleSaveInfo} />
            <Icon name='close' color='blue' onClick={this.onCancel} />
          </div>
        }
        {
          this.state.isEdit && type === 'dropdown' &&
          <div className={classes.editInput}>
            <Form.Select
              placeholder={placeholder}
              options={options}
              name={name}
              value={this.state.value}
              onChange={(e, target) => this.handleChange({ target: target })}
            />
            <Icon name='check' color='blue' onClick={this.handleSaveInfo} />
            <Icon name='close' color='blue' onClick={this.onCancel} />
          </div>
        }
        {
          this.state.isEdit && this.state.isHitSave &&
          <div style={{ fontSize: '0.9rem', color: colors.primaryRed1 }}>{this.getErrorMessage()}</div>
        }
      </div>
    );
  }
}

ContactEditInterestsComponent.propTypes = {
  name: PropTypes.string.isRequired,
  value: PropTypes.string.isRequired,
  id: PropTypes.string.isRequired,
  type: PropTypes.string,
  validators: PropTypes.arrayOf(PropTypes.string),
};

ContactEditInterestsComponent.defaultProps = {
  type: 'text',
  validators: [],
};

ContactEditInterestsComponent.contextType = AppContext;

export default injectSheet(style)(ContactEditInterestsComponent);