import React from 'react';
import PropTypes from 'prop-types';
import { Icon, Form } from 'semantic-ui-react';
import AppContext from "../../../../Common/Constants/AppContext";
import Utils from "../../../../Common/Utils/Utils";
import ContactActionCreator from "../../../Actions/ContactActionCreator";
import injectSheet from "react-jss";
import style from "./stylesheet";
import {compose} from 'redux';
import {connect} from 'react-redux';

class ContactEditNameComponent extends React.Component {

  static getDerivedStateFromProps(props, state) {
    if (!state.isBind) {
      if (props.id) {
        const { prefix_name, first_name, middle_name, last_name, nickname } = props;
        return {
          prefix_name,
          first_name,
          middle_name,
          last_name,
          nickname,
          isBind: true,
        };
      }
    }
    return null;
  }

  constructor(props) {
    super(props);
    this.state = {
      isEdit: false,
      isBind: false,
      isHitSave: false,
      prefix_name: '',
      first_name: '',
      middle_name: '',
      last_name: '',
      nickname: '',
      type: 'person'
    }
    this.isFieldError = this.isFieldError.bind(this);
    this.handleSaveInfo = this.handleSaveInfo.bind(this);
    this.handleChange = this.handleChange.bind(this);
    this.onCancel = this.onCancel.bind(this);
  }

  isFieldError(name) {
    const { intl: { messages } } = this.context;
    if (!this.state[name]) {
      return messages.requiredField;
    }
    return '';
  }

  handleSaveInfo() {
    if (!this.state.isHitSave) {
      this.setState({
        isHitSave: true,
      });
    }
    if (!this.isFieldError('first_name') &&
      !this.isFieldError('last_name')
    ) {
      const { dispatch } = this.context;
      const { id } = this.props;
      const { prefix_name, first_name, middle_name, last_name, nickname } = this.state;
      dispatch(ContactActionCreator.saveContact({
          _id: id,
          prefix_name,
          first_name,
          middle_name,
          last_name,
          nickname
        },
        false
      ));
      this.setState({
        isEdit: false,
      })
    }
  }

  handleChange({ target: { name, value } }) {
    this.setState({
      [name]: value,
    })
  }

  onCancel() {
    const { prefix_name, first_name, middle_name, last_name, nickname } = this.props;
    this.setState({
      prefix_name,
      first_name,
      middle_name,
      last_name,
      nickname,
      isEdit: false
    })
  }

  render() {
    const { classes, contactTitles } = this.props;
    const { intl: { messages } } = this.context;
    if (!this.state.isEdit) {
      if (Utils.combineName(this.state, messages)) {
        return (
          <div className={classes.displayText} onClick={() => this.setState({ isEdit: true })}>
            <span>{Utils.combineName(this.state, messages, true)}</span>
            <Icon name='edit' color='blue' />
          </div>
        )
      }
      return (
        <Icon name='edit' color='blue' onClick={() => this.setState({ isEdit: true })} />
      )
    }
    const prefix = contactTitles.map(item => ({
      key: item._id,
      value: item.title,
      text: item.title
    }));
    return (
      <Form className={classes.nameInput}>
        <Form.Field>
          <Form.Select
            options={prefix}
            placeholder={messages.prefixName}
            name='prefix_name'
            value={this.state.prefix_name}
            onChange={(e, target) => this.handleChange({ target: target })}
          />
        </Form.Field>
        <Form.Field required error={this.state.isHitSave && this.isFieldError('first_name')}>
          <input
            placeholder={messages.firstName}
            name='first_name'
            value={this.state.first_name}
            onChange={this.handleChange}
          />
          {
            this.state.isHitSave && this.isFieldError('first_name') &&
            <div className={classes.helpText}>{this.isFieldError('first_name')}</div>
          }
        </Form.Field>
        <Form.Field required error={this.state.isHitSave && this.isFieldError('nickname')}>
          <input
            placeholder={messages['contact.details.nickname']}
            name='nickname'
            value={this.state.nickname}
            onChange={this.handleChange}
          />
          {
            this.state.isHitSave && this.isFieldError('nickname') &&
            <div className={classes.helpText}>{this.isFieldError('nickname')}</div>
          }
        </Form.Field>
        <Form.Field>
          <input
            placeholder={messages.middleName}
            name='middle_name'
            value={this.state.middle_name}
            onChange={this.handleChange}
          />
        </Form.Field>
        <Form.Field required error={this.state.isHitSave && this.isFieldError('last_name')}>
          <input
            placeholder={messages.lastName}
            name='last_name'
            value={this.state.last_name}
            onChange={this.handleChange}
          />
          {
            this.state.isHitSave && this.isFieldError('last_name') &&
            <div className={classes.helpText}>{this.isFieldError('last_name')}</div>
          }
        </Form.Field>
        <Form.Field>
          <div className='action-icon'>
            <Icon name='check' color='blue' onClick={this.handleSaveInfo} />
            <Icon name='close icon' color='blue' onClick={this.onCancel} />
          </div>
        </Form.Field>
      </Form>
    );
  }
}

ContactEditNameComponent.propTypes = {
  prefix_name: PropTypes.string,
  first_name: PropTypes.string.isRequired,
  middle_name: PropTypes.string.isRequired,
  last_name: PropTypes.string.isRequired,
  nickname: PropTypes.string.isRequired,
  id: PropTypes.string.isRequired,
  contactTitles: PropTypes.array.isRequired
};

ContactEditNameComponent.defaultProps = {
  prefix_name: '',
}

ContactEditNameComponent.contextType = AppContext;

const mapStateToProps = ({settings}) => ({
  contactTitles: settings.contactTitles
})

export default compose(
  injectSheet(style),
  connect(mapStateToProps)
)(ContactEditNameComponent);

