import React from 'react';
import PropTypes from 'prop-types';
import { Icon, Form, Checkbox } from 'semantic-ui-react';
import AppContext from "../../../../Common/Constants/AppContext";
import ContactActionCreator from "../../../Actions/ContactActionCreator";
import injectSheet from "react-jss";
import style from './stylesheet';
import Enum from "../../../../Common/Constants/Enum";

class ContactEditRadioComponent extends React.Component {
  static getDerivedStateFromProps(props, state) {
    if (!state.isBind) {
      if (props.id) {
        return {
          value: props.value,
          isBind: true,
        };
      }
    }
    return null;
  }

  constructor(props) {
    super(props);
    this.state = {
      isEdit: false,
      isBind: false,
      value: Enum.ContactTypeEnum.person,
      isHitSave: false,
    }
    this.handleSaveInfo = this.handleSaveInfo.bind(this);
    this.handleChangeRadio = this.handleChangeRadio.bind(this);
    this.onCancel = this.onCancel.bind(this);
  }

  handleSaveInfo() {
    if (!this.state.isHitSave) {
      this.setState({
        isHitSave: true,
      });
    }
    const { dispatch } = this.context;
    const { id, name } = this.props;

    if(this.state.value === this.props.value) {
      this.onCancel();
      return;
    }
    dispatch(ContactActionCreator.saveContact({
        _id: id,
        [name]: this.state.value,
      },
      false
    ));
    this.setState({
      isEdit: false,
    })
  }

  handleChangeRadio() {
    this.setState({
      value: this.state.value === Enum.ContactTypeEnum.organisation ?
        Enum.ContactTypeEnum.person : Enum.ContactTypeEnum.organisation,
    })
  }

  onCancel() {
    const { value } = this.props;
    this.setState({
      value,
      isEdit: false,
    })
  }

  render() {
    const { name, value, classes } = this.props;
    const { intl: { messages } } = this.context;

    return (
      <div>
        {
          !this.state.isEdit &&
          <div className={classes.displayText} onClick={() => this.setState({ isEdit: true })}>
            <span>{messages[value]}</span>
            <Icon name='edit' color='blue' />
          </div>
        }
        {
          !this.state.isEdit && !value &&
          <Icon name='edit' color='blue' onClick={() => this.setState({ isEdit: true })} />
        }
        {
          this.state.isEdit &&
          <Form
            onSubmit={this.handleSubmit}
          >
            <Form.Group inline className={classes.groupOfType}>
              <Form.Field label={messages.person}></Form.Field>
              <Form.Field
                className={classes.toggleContactType}
                control={Checkbox}
                toggle
                name={name}
                checked={this.state.value !== Enum.ContactTypeEnum.person}
                onChange={this.handleChangeRadio}
              />
              <Form.Field label={messages.organisation}></Form.Field>
              <Icon name='check' color='blue' onClick={this.handleSaveInfo} />
              <Icon name='close icon' color='blue' onClick={this.onCancel} />
            </Form.Group>
          </Form>
        }
      </div>
    );
  }
}

ContactEditRadioComponent.propTypes = {
  name: PropTypes.string.isRequired,
  value: PropTypes.string.isRequired,
  id: PropTypes.string.isRequired,
};

ContactEditRadioComponent.defaultProps = {
};

ContactEditRadioComponent.contextType = AppContext;

export default injectSheet(style)(ContactEditRadioComponent);