import React from 'react';
import { Grid, Accordion, Icon } from 'semantic-ui-react';
import injectSheet from "react-jss";

import BasicDetail from './BasicDetail';
import ContactDetail from './ContactDetail';
import VotingDetail from './VotingDetail';
import colors from "../../../../Common/Constants/color";
import Enum from "../../../../Common/Constants/Enum";

const style = {
  profileInformation: {
    '& .ui.accordion .title .dropdown.icon': {
      transform: 'rotate(180deg)',
      float: 'right',
      position: 'relative',
      top: 15,
    },
    '& .ui.accordion .active.title .dropdown.icon': {
      transform: 'rotate(90deg)',
      float: 'right',
    },
    '& .ui.grid>.row': {
      alignItems: 'center',
    },
    '& .accordion .title .label': {
      textTransform: 'uppercase',
      fontWeight: 'bold',
      width: '100%',
      fontSize: '1rem',
      backgroundColor: '#F5F5F5',
      padding: [0, 11],
      height: 40,
      lineHeight: '40px'
    },
    '& .information-content': {
      padding: [20, 40],
      '& .text-info': {
        color: colors.primaryGray,
        fontWeight: 'bold',
      },
      '& .value-info': {
        color: colors.primaryGray2,
        '& i': {
          cursor: 'pointer',
          fontSize: '0.9rem',
        }
      },
    }
  },
  sectionTitle: {
    fontSize: '1.1rem',
    marginBottom: 34,
  }
}

const getPanels = (selectedContactDetail) => {
  const result = [
    {
      key: 'basic_detail',
      title: <Accordion.Title index={0}>
        <div className="ui label">
          <Icon name='dropdown' />
          Basic Details
        </div>
      </Accordion.Title>,
      content: <Accordion.Content>
        <div className='information-content'>
          <BasicDetail selectedContactDetail={selectedContactDetail} />
        </div>
      </Accordion.Content>,
    },
    {
      key: 'contact_detail',
      title: <Accordion.Title index={1}>
        <div className="ui label">
          <Icon name='dropdown' />
          Contact Details
        </div>
      </Accordion.Title>,
      content: <Accordion.Content>
        <div className='information-content'>
          <ContactDetail selectedContactDetail={selectedContactDetail} />
        </div>
      </Accordion.Content>
    },
  ];
  if (selectedContactDetail.selectedContact.type === Enum.ContactTypeEnum.person) {
    result.push({
      key: 'voting_status',
      title: <Accordion.Title index={2}>
        <div className="ui label">
          <Icon name='dropdown' />
          Voting Details
        </div>
      </Accordion.Title>,
      content: <Accordion.Content>
        <div className='information-content'>
          <VotingDetail selectedContactDetail={selectedContactDetail} />
        </div>
      </Accordion.Content>
    });
  }
  return result;
}

const ProfileInformation = ({ classes, selectedContactDetail }) => (
  <Grid className={classes.profileInformation}>
    <Grid.Row>
      <Accordion defaultActiveIndex={[0, 1, 2]} panels={getPanels(selectedContactDetail)} exclusive={false} fluid />
    </Grid.Row>
  </Grid>
);

export default injectSheet(style)(ProfileInformation);