import React from 'react';
import injectSheet from "react-jss";
import { Grid, Icon, Accordion } from 'semantic-ui-react';

import ProfileCard from '../ContactDetailProfile/ProfileCard';
import stylesheet from './stylesheet';
import AppContext from "../../../Common/Constants/AppContext";
import ContactVolunteerGeneral from "./ContactVolunteerGeneral";
import ContactVolunteerSpecialisations from "./ContactVolunteerSpecialisations/ContactVolunteerSpecialisations";
import ContactVolunteerSchedule from "./ContactVolunteerSchedule/ContactVolunteerSchedule";



class ContactDetailVolunteer extends React.Component {
  constructor() {
    super();
    this.state = {
      volunteer: {
        status: '',
        shirt_size: '',
        specialisations: [],
        roles: [],
      },
    }
  }

  getPanels = () => {
    const { selectedContactDetail, contactSchedule, history } = this.props;
    const {selectedContact} = selectedContactDetail;
    const result = [
      {
        key: 'general',
        title: <Accordion.Title index={0}>
          <div className="ui label">
            <Icon name='dropdown' />
            General
          </div>
        </Accordion.Title>,
        content: <Accordion.Content>
          <div className='information-content'>
            <ContactVolunteerGeneral selectedContactDetail={selectedContactDetail} />
          </div>
        </Accordion.Content>,
      },
      {
        key: 'specialisations',
        title: <Accordion.Title index={1}>
          <div className="ui label">
            <Icon name='dropdown' />
            Specialisations
          </div>
        </Accordion.Title>,
        content: <Accordion.Content>
          <div className='information-content'>
            <ContactVolunteerSpecialisations selectedContactDetail={selectedContactDetail} />
          </div>
        </Accordion.Content>,
      },
      {
        key: 'contactSchedule',
        title: <Accordion.Title index={2}>
          <div className="ui label">
            <Icon name='dropdown' />
            EVENT SCHEDULE
          </div>
        </Accordion.Title>,
        content: <Accordion.Content>
          {
            selectedContact._id &&
            <div className='information-content'>
              <ContactVolunteerSchedule selectedContactDetail={selectedContactDetail} contactSchedule={contactSchedule} history={history}/>
            </div>
          }
        </Accordion.Content>,
      },
    ];
    return result;
  }

  render() {
    const { classes, selectedContactDetail, history } = this.props;

    return (
      <div className={classes.contactDetailVolunteerPage}>
        <Grid>
          <Grid.Row>
            <Grid.Column computer={5}>
              <ProfileCard selectedContactDetail={selectedContactDetail} history={history} />
            </Grid.Column>
            <Grid.Column computer={11}>
              <Grid>
                <Grid.Row>
                  <Accordion defaultActiveIndex={[0, 1, 2]} panels={this.getPanels()} exclusive={false}
                             fluid />
                </Grid.Row>
              </Grid>
            </Grid.Column>
          </Grid.Row>
        </Grid>
      </div>
    );
  }
}

ContactDetailVolunteer.contextType = AppContext;

export default injectSheet(stylesheet)(ContactDetailVolunteer);