import React from 'react';
import PropTypes from 'prop-types';
import { Icon, Form, Checkbox } from 'semantic-ui-react';
import injectSheet from "react-jss";

import AppContext from "../../../Common/Constants/AppContext";
import ContactActionCreator from "../../Actions/ContactActionCreator";
import style from './stylesheet';

class ContactVolunteerEditCheckboxComponent extends React.Component {
  static getDerivedStateFromProps(props, state) {
    if (!state.isBind) {
      if (props.id) {
        return {
          value: props.value,
          isBind: true,
        };
      }
    }
    return null;
  }

  constructor(props) {
    super(props);
    this.state = {
      isEdit: false,
      isBind: false,
      value: null,
      isHitSave: false,
    }
    this.handleSaveInfo = this.handleSaveInfo.bind(this);
    this.onCancel = this.onCancel.bind(this);
    this.handleCheckboxChange = this.handleCheckboxChange.bind(this);
  }

  handleSaveInfo() {
    if (!this.state.isHitSave) {
      this.setState({
        isHitSave: true,
      });
    }
    const { dispatch } = this.context;
    const { id, name, volunteer } = this.props;

    if (this.state.value === this.props.value) {
      this.onCancel();
      return;
    }
    dispatch(ContactActionCreator.saveContact({
        _id: id,
        volunteer: {
          ...volunteer,
          [name]: this.state.value,
        }
      },
      false
    ));
    this.setState({
      isEdit: false,
    })
  }

  handleCheckboxChange(event, { name, value }) {
    const newValues = [...this.state.value];
    if(newValues.includes(value)) {
      newValues.splice(newValues.indexOf(value), 1);
    } else {
      newValues.push(value);
    }
    this.setState({
      value: newValues,
    })
  }

  onCancel() {
    const { value } = this.props;
    this.setState({
      value,
      isEdit: false,
    })
  }

  render() {
    const { value, options, classes } = this.props;
    const { intl: { messages } } = this.context;

    return (
      <div>
        {
          !this.state.isEdit && value.length > 0 &&
          <div className={classes.displayText} onClick={() => this.setState({ isEdit: true })}>
            <span>{value.join(', ')}</span>
            <Icon name='edit' onClick={() => this.setState({ isEdit: true })} color='blue' />
          </div>
        }
        {
          !this.state.isEdit && value.length === 0 &&
          <Icon name='edit' color='blue' onClick={() => this.setState({ isEdit: true })} />
        }
        {
          this.state.isEdit &&
          <Form>
            {
              options.map(item => (
                <Form.Field
                  control={Checkbox}
                  value={item.value}
                  checked={this.state.value.includes(item.value)}
                  onChange={this.handleCheckboxChange}
                  label={messages[item.value] || item.value}
                />
              ))
            }
            <Form.Field>
              <div className='action-icon'>
                <Icon name='check' color='blue' onClick={this.handleSaveInfo} />
                <Icon name='close icon' color='blue' onClick={this.onCancel} />
              </div>
            </Form.Field>
          </Form>
        }
      </div>
    );
  }
}

ContactVolunteerEditCheckboxComponent.propTypes = {
  name: PropTypes.string.isRequired,
  value: PropTypes.shape([]),
  volunteer: PropTypes.shape({}).isRequired,
  id: PropTypes.string.isRequired,
};

ContactVolunteerEditCheckboxComponent.contextType = AppContext;

export default injectSheet(style)(ContactVolunteerEditCheckboxComponent);