import React from 'react';
import PropTypes from 'prop-types';
import { Icon, Form } from 'semantic-ui-react';
import injectSheet from "react-jss";

import AppContext from "../../../Common/Constants/AppContext";
import colors from "../../../Common/Constants/color";
import ContactActionCreator from "../../Actions/ContactActionCreator";
import style from './stylesheet';

class ContactVolunteerEditComponent extends React.Component {
  static getDerivedStateFromProps(props, state) {
    if (!state.isBind) {
      if (props.id) {
        return {
          value: props.value,
          isBind: true,
        };
      }
    }
    return null;
  }

  constructor(props) {
    super(props);
    this.state = {
      isEdit: false,
      isBind: false,
      value: null,
      isHitSave: false,
    }
    this.handleSaveInfo = this.handleSaveInfo.bind(this);
    this.handleChange = this.handleChange.bind(this);
    this.onCancel = this.onCancel.bind(this);
  }

  handleSaveInfo() {
    if (!this.state.isHitSave) {
      this.setState({
        isHitSave: true,
      });
    }
    const { dispatch } = this.context;
    const { id, name, volunteer } = this.props;

    if(this.state.value === this.props.value) {
      this.onCancel();
      return;
    }
    dispatch(ContactActionCreator.saveContact({
        _id: id,
        volunteer: {
          ...volunteer,
          [name]: this.state.value,
        }
      },
      false
    ));
    this.setState({
      isEdit: false,
    })
  }

  handleChange({ target: { value } }) {
    this.setState({
      value,
    })
  }

  onCancel() {
    const { value } = this.props;
    this.setState({
      value,
      isEdit: false,
    })
  }

  render(){
    const { name, value, options, placeholder, classes } = this.props;
    const { intl: { messages } } = this.context;

    return (
      <div>
        {
          !this.state.isEdit && value &&
          <div className={classes.displayText} onClick={() => this.setState({ isEdit: true })}>
            <span>{messages[value] || value}</span>
            <Icon name='edit' onClick={() => this.setState({ isEdit: true })} color='blue' />
          </div>
        }
        {
          !this.state.isEdit && !value &&
          <Icon name='edit' color='blue' onClick={() => this.setState({ isEdit: true })} />
        }
        {
          this.state.isEdit &&
          <div className={classes.editInput}>
            <Form.Select
              placeholder={placeholder}
              options={options}
              name={name}
              value={this.state.value}
              onChange={(e, target) => this.handleChange({ target: target })}
            />
            <Icon name='check' color='blue' onClick={this.handleSaveInfo} />
            <Icon name='close icon' color='blue' onClick={this.onCancel} />
          </div>
        }
        {
          this.state.isEdit && this.state.isHitSave &&
          <div style={{ fontSize: '0.9rem', color: colors.primaryRed1 }}>{this.getErrorMessage()}</div>
        }
      </div>
    );
  }
}

ContactVolunteerEditComponent.propTypes = {
  name: PropTypes.string.isRequired,
  value: PropTypes.string.isRequired,
  volunteer: PropTypes.shape({}).isRequired,
  id: PropTypes.string.isRequired,
};

ContactVolunteerEditComponent.contextType = AppContext;

export default injectSheet(style)(ContactVolunteerEditComponent);