import React from 'react';
import { Form, Grid } from "semantic-ui-react";
import injectSheet from "react-jss";
import ReduxStatus from "../../../Common/Constants/ReduxStatus";
import ContactVolunteerEditComponent from "./ContactVolunteerEditComponent";
import ContactVolunteerEditCheckboxComponent from "./ContactVolunteerEditCheckboxComponent";
import stylesheet from "./stylesheet";
import AppContext from "../../../Common/Constants/AppContext";
import Enum from "../../../Common/Constants/Enum";

class ContactVolunteerGeneral extends React.Component {
  render() {
    const { selectedContactDetail } = this.props;
    const { selectedContact, status } = selectedContactDetail;
    const { intl: { messages } } = this.context;

    const volunteer = selectedContact.volunteer || {};

    const emptyFilter = {
      key: 'Select',
      text: 'Select',
      value: '',
    };
    const volunteerStatus = Object.values(Enum.VolunteerStatus).map(item => ({
      key: item,
      text: messages[item],
      value: item
    }));
    volunteerStatus.unshift(emptyFilter);

    const shirtSizes = ['XS', 'S', 'M', 'L', 'XL', 'XXL'].map(item => ({
      key: item,
      text: item,
      value: item
    }));

    const roles = Enum.VolunteerRoles.map(item => ({
      value: item
    }));

    return (
      <Form
        loading={status === ReduxStatus.loading}
        error={status === ReduxStatus.saveFailed || status === ReduxStatus.loadFailed}
      >
        {
          selectedContact._id &&
          <Grid>
            <Grid.Row>
              <Grid.Column mobile={16} tablet={6} computer={6} className='text-info'>
                {messages.volunteerStatus}
              </Grid.Column>
              <Grid.Column mobile={16} tablet={10} computer={10} className='value-info'>
                <ContactVolunteerEditComponent
                  id={selectedContact._id}
                  name='status'
                  value={volunteer.status}
                  volunteer={volunteer}
                  options={volunteerStatus}
                  placeholder={messages.volunteerStatus}
                />
              </Grid.Column>
            </Grid.Row>
            <Grid.Row>
              <Grid.Column mobile={16} tablet={6} computer={6} className='text-info'>
                {messages.shirtSize}
              </Grid.Column>
              <Grid.Column mobile={16} tablet={10} computer={10} className='value-info'>
                <ContactVolunteerEditComponent
                  id={selectedContact._id}
                  name='shirt_size'
                  value={volunteer.shirt_size}
                  volunteer={volunteer}
                  options={shirtSizes}
                />
              </Grid.Column>
            </Grid.Row>
            <Grid.Row>
              <Grid.Column mobile={16} tablet={6} computer={6} className='text-info'>
                {messages.roles}
              </Grid.Column>
              <Grid.Column mobile={16} tablet={10} computer={10} className='value-info'>
                <ContactVolunteerEditCheckboxComponent
                  id={selectedContact._id}
                  name='roles'
                  value={volunteer.roles || []}
                  volunteer={volunteer}
                  options={roles}
                />
              </Grid.Column>
            </Grid.Row>
          </Grid>
        }
      </Form>
    )
  }
}

ContactVolunteerGeneral.contextType = AppContext;

export default injectSheet(stylesheet)(ContactVolunteerGeneral);