import React from 'react';
import { Table } from "semantic-ui-react";
import { Link } from 'react-router-dom';
import injectSheet from "react-jss";
import moment from "moment";
import stylesheet from "../stylesheet";
import AppContext from "../../../../Common/Constants/AppContext";
import ContactScheduleActionCreator from "../../../Actions/ContactScheduleActionCreator";
import Utils from "../../../../Common/Utils/Utils";
import { eventVotingDistrictLocation } from "../../../../Common/Constants/AppKey";

class ContactVolunteerSchedule extends React.Component {
  componentDidMount() {
    const { dispatch } = this.context;
    const { selectedContactDetail } = this.props;
    const { selectedContact } = selectedContactDetail;
    dispatch(ContactScheduleActionCreator.getContactSchedules(1, { volunteer: selectedContact._id }))
  }

  handleLinkToSchedule(item, e) {
    e.preventDefault();
    const eventId = item.location.event._id;
    const preSelectedData = Utils.getLocalStorage(eventVotingDistrictLocation) || {
      [eventId]: {
        location: {},
        votingDistrict: {}
      }
    };
    if (preSelectedData[eventId]) {
      preSelectedData[eventId].location = item.location;
      preSelectedData[eventId].votingDistrict = item.location.voting_district;
    } else {
      preSelectedData[eventId] = {
        location: item.location,
        votingDistrict: item.location.voting_district,
      }
    }
    Utils.setLocalStorage(eventVotingDistrictLocation, preSelectedData);
    const { history } = this.props;
    history.push(`/event-detail/${item.location.event._id}/schedule`);
  }

  render() {
    const { intl: { messages } } = this.context;
    const { classes, contactSchedule: { data } } = this.props;
    return (
      <div className={classes.specialisationContainer}>
        <Table selectable basic>
          <Table.Header>
            <Table.Row>
              <Table.HeaderCell>{messages.event}</Table.HeaderCell>
              <Table.HeaderCell>{messages.date}</Table.HeaderCell>
              <Table.HeaderCell>{messages.location}</Table.HeaderCell>
              <Table.HeaderCell>{messages.time}</Table.HeaderCell>
            </Table.Row>
          </Table.Header>
          <Table.Body>
            {data.map(item => (
              <Table.Row key={item._id} className="specialisation-row">
                <Table.Cell>
                  <Link onClick={(e) => this.handleLinkToSchedule(item, e)}
                        to={`/event-detail/${item.location.event._id}/schedule`}>
                    {item.location.event.name}
                  </Link>
                </Table.Cell>
                <Table.Cell>{moment(new Date(item.location.event.start_time)).format('D MMM YYYY')}</Table.Cell>
                <Table.Cell>{item.location.name}</Table.Cell>
                <Table.Cell>
                  {
                    Utils.getScheduleInfo(item)
                  }
                </Table.Cell>
              </Table.Row>
            ))}
          </Table.Body>
        </Table>
      </div>
    )
  }
}

ContactVolunteerSchedule.contextType = AppContext;

export default injectSheet(stylesheet)(ContactVolunteerSchedule);