import React from 'react';
import { Table, Loader, Button, Icon } from "semantic-ui-react";
import injectSheet from "react-jss";
import moment from "moment";
import uuid from 'uuid/v4';
import ReduxStatus from "../../../../Common/Constants/ReduxStatus";
import stylesheet from "../stylesheet";
import ConfirmModal from "../../../../Common/Components/Modal/ConfirmModal";
import SpecialisationInfoModal from "./SpecialisationInfoModal";
import AppContext from "../../../../Common/Constants/AppContext";
import ContactActionCreator from "../../../Actions/ContactActionCreator";
import { config } from '../../../../configuration';

class ContactVolunteerSpecialisations extends React.Component {
  constructor() {
    super();
    this.state = {
      toggleSave: false,
      specialisationInfo: {},

      toggleRemove: false,
      selectedDeleteSpecialisation: null,
    }
    this.handleSave = this.handleSave.bind(this);
    this.handleRemove = this.handleRemove.bind(this);
  }

  handleSave(specialisationInfo) {
    const { dispatch } = this.context;
    const { selectedContactDetail } = this.props;
    const { selectedContact } = selectedContactDetail;
    const volunteer = selectedContact.volunteer || {};
    const specialisations = volunteer.specialisations ? [...volunteer.specialisations] :  [];
    if(specialisationInfo.id) {
      specialisations.forEach(item => {
        if(item.id === specialisationInfo.id) {
          item.name = specialisationInfo.name;
          item.state = specialisationInfo.state;
          item.expiry_date = specialisationInfo.expiry_date;
        }
      })
    } else {
      specialisations.push({
        ...specialisationInfo,
        id: uuid(),
      });
    }
    dispatch(ContactActionCreator.saveContact({
        _id: selectedContact._id,
        volunteer: {
          ...volunteer,
          specialisations,
        }
      },
      false
    ));
    this.setState({
      toggleSave: false,
    })
  }

  handleRemove() {
    const { dispatch } = this.context;
    const { selectedContactDetail } = this.props;
    const { selectedContact } = selectedContactDetail;
    const volunteer = selectedContact.volunteer || {};
    const specialisations = volunteer.specialisations.filter(item => item.id !== this.state.selectedDeleteSpecialisation.id)
    dispatch(ContactActionCreator.saveContact({
        _id: selectedContact._id,
        volunteer: {
          ...volunteer,
          specialisations,
        }
      },
      false
    ));
    this.setState({
      toggleRemove: false,
    });
  }

  render() {
    const { intl: { messages }, currentUser } = this.context;
    const { classes, selectedContactDetail } = this.props;
    const { selectedContact, status } = selectedContactDetail;
    const volunteer = selectedContact.volunteer || {};
    const specialisations = volunteer.specialisations || [];

    return (
      <div className={classes.specialisationContainer}>
        {
          status === ReduxStatus.loading && <Loader active />
        }
        {
          this.state.toggleSave &&
          <SpecialisationInfoModal
            isOpen={this.state.toggleSave}
            onClose={() => this.setState({ toggleSave: false })}
            onOk={this.handleSave}
            specialisationInfo={this.state.specialisationInfo}
          />
        }
        {
          this.state.toggleRemove &&
          <ConfirmModal
            isOpen={true}
            onClose={() => this.setState({ toggleRemove: false })}
            onConfirm={this.handleRemove}
            content={{
              mainText: messages.deleteText.replace('{item}', this.state.selectedDeleteSpecialisation.name),
              description: messages.messageConfirm.replace('{name}',
                `${currentUser.first_name}`)
            }}
            title={messages.removeVolunteer}
            cancelText={messages.keepThis}
            confirmText={messages.delete}
          />
        }
        <Table selectable basic>
          <Table.Header>
            <Table.Row>
              <Table.HeaderCell width={4}>{messages.name}</Table.HeaderCell>
              <Table.HeaderCell>{messages.state}</Table.HeaderCell>
              <Table.HeaderCell>{messages.expiry}</Table.HeaderCell>
              <Table.HeaderCell width={3}>
                <Button
                  icon
                  labelPosition='right'
                  color='green'
                  className='add-specialisation-button'
                  onClick={() => this.setState({
                    toggleSave: true,
                    specialisationInfo: {},
                  })}
                >
                  {messages.add}
                  <Icon name='right add' circular inverted />
                </Button>
              </Table.HeaderCell>
            </Table.Row>
          </Table.Header>
          <Table.Body>
            {specialisations.map(item => (
              <Table.Row key={item._id} className="specialisation-row">
                <Table.Cell>
                  {item.name}
                </Table.Cell>
                <Table.Cell>{item.state}</Table.Cell>
                <Table.Cell>
                  {moment(new Date(item.expiry_date)).format(config.DATE_FORMAT)}
                </Table.Cell>
                <Table.Cell>
                  <div className="user-action">
                    <div onClick={() => this.setState({
                      toggleRemove: true,
                      selectedDeleteSpecialisation: item,
                    })}>
                      {messages.delete}
                    </div>
                    <div onClick={() => this.setState({
                      toggleSave: true,
                      specialisationInfo: item,
                    })}>
                      {messages.edit}
                    </div>
                  </div>
                </Table.Cell>
              </Table.Row>
            ))}
          </Table.Body>
        </Table>
      </div>
    )
  }
}

ContactVolunteerSpecialisations.contextType = AppContext;

export default injectSheet(stylesheet)(ContactVolunteerSpecialisations);