import React from 'react';
import injectSheet from 'react-jss';

import stylesheet from './stylesheet';
import { Table, Loader } from 'semantic-ui-react';
import { Link } from 'react-router-dom';
import moment from 'moment';
import AppContext from '../../../../Common/Constants/AppContext';
import ContactOrderCreator from '../../../Actions/ContactOrderActionCreator';
import ReduxStatus from '../../../../Common/Constants/ReduxStatus';
import _ from 'lodash';
import { config } from '../../../../configuration';

class ContactDonationsOnceOff extends React.Component {

  componentDidMount() {
    const { dispatch } = this.context;
    const onceOffFilter = {
      contact: this.props.selectedContact._id,
      type: "donation",
      "donation.donation_type": "once-off-donation"
    }
    dispatch(ContactOrderCreator.getContactOnceOffDonationOrders(1, onceOffFilter));
  }

  render() {
    const { classes, contactOnceOffDonationOrders: { data, status }, contactDonationPayments } = this.props;
    const { intl: { messages } } = this.context;
    const onceOffDonationPayments = contactDonationPayments.data.filter(p => p.payment_type === 'once-off-donation')
  
    return (
      <div className={classes.contactDonationOnceOffPage}>
        <Table selectable basic>
          <Table.Header>
            <Table.Row>
              <Table.HeaderCell>{messages.paymentId}</Table.HeaderCell>
              <Table.HeaderCell>{messages.date}</Table.HeaderCell>
              <Table.HeaderCell>{messages.amount}</Table.HeaderCell>
              <Table.HeaderCell>{messages.campaign_id}</Table.HeaderCell>
            </Table.Row>
          </Table.Header>
          <Table.Body>
            {data.map(item => (
              <Table.Row key={item._id}>
                <Table.Cell>
                  {
                    item.payment ? <Link to={`/finance-detail/${item.payment._id}`}>
                      {_.padStart(item.payment_id, 5, 0)}
                    </Link> :
                    'Pending'
                  }
                </Table.Cell>
                <Table.Cell>
                  {item.donation && item.donation.received_date && moment(new Date(item.donation.received_date)).format(config.DATE_FORMAT)}
                </Table.Cell>
                <Table.Cell>
                  ${item.donation && item.donation.amount}
                </Table.Cell>
                <Table.Cell>
                  {item.campaign_id}
                </Table.Cell>
              </Table.Row>
            ))}
            { 
              status !== ReduxStatus.loading && onceOffDonationPayments.map(item => (
                <Table.Row key={item._id}>
                  <Table.Cell>
                    <Link to={`/finance-detail/${item._id}`}>
                      {item.payment_id}
                    </Link>
                  </Table.Cell>
                  <Table.Cell>
                    {item.processed_date && moment(new Date(item.processed_date)).format(config.DATE_FORMAT)}
                  </Table.Cell>
                  <Table.Cell>
                    ${item.amount}
                  </Table.Cell>
                  <Table.Cell>
                    {item.campaign_id}
                  </Table.Cell>
                </Table.Row>
              ))
            }
          </Table.Body>
        </Table>
        {
          status === ReduxStatus.loading && <Loader active />
        }
      </div>
    )
  }
}

ContactDonationsOnceOff.contextType = AppContext;

export default injectSheet(stylesheet)(ContactDonationsOnceOff);