import React from 'react'
import injectSheet from "react-jss"

import stylesheet from './stylesheet'
import { Table, Loader, Icon, Grid, List, Popup } from "semantic-ui-react"
import { Link } from 'react-router-dom'
import moment from "moment"
import AppContext from "../../../../Common/Constants/AppContext"
import ContactOrderCreator from '../../../Actions/ContactOrderActionCreator'
import ConfirmModal from "../../../../Common/Components/Modal/ConfirmModal"
import ReduxStatus from '../../../../Common/Constants/ReduxStatus'
import _ from 'lodash'
import { config } from '../../../../configuration'
import { Elements, StripeProvider } from 'react-stripe-elements'
import PaymentSourceModal from '../../Common/PaymentSourceModal'

class ContactDonationsRecurring extends React.Component {

  constructor() {
    super();
    this.state = {
      togglecancelOrder: false,
      isShowUpdateSourceModal: false,
      selectedDonation: {}
    };
  }

  componentDidMount() {
    const { dispatch } = this.context;
    const recurringFilter = {
      contact: this.props.selectedContact._id,
      type: "donation",
      "donation.donation_type": "recurring-donation"
    }
    dispatch(ContactOrderCreator.getContactRecurringDonationOrders(1, recurringFilter));
  }

  handlecancelOrder = () => {
    const orderId = this.state.selectedOrderId
    if(orderId) {
      const { dispatch } = this.context
      dispatch(ContactOrderCreator.cancelOrder(orderId, 'donation'))
    }
    this.setState({togglecancelOrder: false, selectedOrderId: ''})
  }

  handleUpdatePaymentSource = (orderId, source) => {
    const { dispatch } = this.context
    dispatch(ContactOrderCreator.updatePaymentSource(orderId, source))
  }
  
  render() {
    const { classes, contactRecurringDonationOrders: { data, status }, contactDonationPayments, selectedContact } = this.props;
    const { intl: { messages } } = this.context;

    const recurringDonationPayments = contactDonationPayments.data.filter(p => p.payment_type === 'recurring-donation')
    
    return (
      <div className={classes.contactDonationOnceOffPage}>
        {
          this.state.togglecancelOrder &&
          <ConfirmModal
            isOpen={true}
            onClose={() => this.setState({ togglecancelOrder: false, selectedOrderId: '' })}
            onConfirm={this.handlecancelOrder}
            content={{
              mainText: messages.cancelRecurringDonationText
            }}
            title={messages.cancelRecurringDonation}
            cancelText={messages.keep}
            confirmText={messages.ok}
          />
        }
        <Grid>
          <Grid.Row>
            <Grid.Column>
              <Table selectable basic>
                <Table.Header>
                  <Table.Row>
                    <Table.HeaderCell>{messages.reference}</Table.HeaderCell>
                    <Table.HeaderCell>{messages.startDate}</Table.HeaderCell>
                    <Table.HeaderCell>{messages.amount}</Table.HeaderCell>
                    <Table.HeaderCell>{messages.total}</Table.HeaderCell>
                    <Table.HeaderCell>{messages.frequency}</Table.HeaderCell>
                    <Table.HeaderCell>{messages.status}</Table.HeaderCell>
                    <Table.HeaderCell></Table.HeaderCell>
                  </Table.Row>
                </Table.Header>
                <Table.Body>
                  {data.map(item => (
                    <Table.Row className='payment-row' key={item._id}>
                      <Table.Cell>
                        {
                          item.order_id ?
                            <Link to={`/finance/allPayments?reference=${_.padStart(item.order_id, 5, 0)}`}>
                              {_.padStart(item.order_id, 5, 0)}
                            </Link> :
                            '-'
                        }
                      </Table.Cell>
                      <Table.Cell>
                        {item.donation && item.donation.start_date && moment(new Date(item.donation.start_date)).format(config.DATE_FORMAT)}
                      </Table.Cell>
                      <Table.Cell>
                        ${item.donation.amount}
                      </Table.Cell>
                      <Table.Cell>
                        {item.total ? '$' + item.total : '-'}
                      </Table.Cell>
                      <Table.Cell>
                        {item.donation.period}
                      </Table.Cell>
                      <Table.Cell>
                        <div className={`status ${item.status}`}>
                          {messages[item.status] || '-'}
                        </div>
                      </Table.Cell>
                      <Table.Cell>
                        <div className='user-action'>
                          {/* <a onClick={() => {this.setState({togglecancelOrder: true, selectedOrderId: item._id})}}>{messages.cancel}</a> */}
                          {
                            item.stripe_subscription_id ? 
                            <Popup style={{padding: '20px 30px 20px 20px'}} position='bottom right' hoverable on='click' trigger={<Icon link name='ellipsis horizontal' />}>
                              <List link>
                                <List.Item style={{marginBottom: 5}} as='a' onClick={() => this.setState({isShowUpdateSourceModal: true, selectedDonation : item})}>{messages['contact.details.update_card']}</List.Item>
                                <List.Item as='a' onClick={() => {this.setState({togglecancelOrder: true, selectedOrderId: item._id})}}>{messages.cancel}</List.Item>
                              </List>
                            </Popup> : 
                            <Icon name="lock" />
                          }
                          
                        </div>
                      </Table.Cell>
                    </Table.Row>
                  ))}
                  {
                    status !== ReduxStatus.loading && recurringDonationPayments.map(item => (
                      <Table.Row className='payment-row' key={item._id}>
                        <Table.Cell>{item.reference || messages.donationNationbuilder + ' - ID: ' + item.nb_donation_id}</Table.Cell>
                        <Table.Cell>
                          {item.start_date ? moment(new Date(item.start_date)).format(config.DATE_FORMAT) 
                          : (item.processed_date && moment(new Date(item.processed_date)).format(config.DATE_FORMAT))}
                        </Table.Cell>
                        <Table.Cell>
                          ${item.amount}
                        </Table.Cell>
                        <Table.Cell>
                          ${item.amount}
                        </Table.Cell>
                        <Table.Cell>
                          monthly
                        </Table.Cell>
                        <Table.Cell>
                          <div className={`status ${item.canceled_at ? 'cancelled' : 'active'}`}>
                            {messages[item.canceled_at ? 'cancelled' : 'active']}
                          </div>
                        </Table.Cell>
                        <Table.Cell>
                          <div className='user-action'>
                            <Icon name="lock" />
                          </div>
                        </Table.Cell>
                      </Table.Row>
                    ))
                  }
                </Table.Body>
              </Table>
              {
                status === ReduxStatus.loading && <Loader active />
              }
            </Grid.Column>
          </Grid.Row>
        </Grid> 
        <StripeProvider apiKey={config.REACT_APP_STRIPE_KEY}>
          <Elements>
            <PaymentSourceModal 
              isOpen={this.state.isShowUpdateSourceModal} 
              onClose={() => this.setState({isShowUpdateSourceModal: false})}
              order={this.state.selectedDonation}
              contact={selectedContact}
              onUpdateSource={this.handleUpdatePaymentSource} />
          </Elements>
        </StripeProvider>
      </div>
    )
  }
}

ContactDonationsRecurring.contextType = AppContext;

export default injectSheet(stylesheet)(ContactDonationsRecurring);
