import React from 'react';
import injectSheet from "react-jss";
import AppContext from "../../../../Common/Constants/AppContext";

import { Loader } from 'semantic-ui-react'
import ReduxStatus from '../../../../Common/Constants/ReduxStatus'
import stylesheet from './stylesheet';
import ContactOrderCreator from '../../../Actions/ContactOrderActionCreator';

class ContactDonationsSummary extends React.Component {

  componentDidMount() {
    const { dispatch } = this.context;
    const { selectedContact } = this.props;
    dispatch(ContactOrderCreator.getContactDonationSummary(selectedContact._id));
  }

  render() {
    const { donationSummaryDetail: { donationSummary: { total, total_amount, recurring_donations, financial_YTD, last_donation }, status } } = this.props
    const { classes } = this.props;
    const recurringAmount =  Math.ceil((total_amount!==0 && recurring_donations/total_amount) * 100)
    return (
      <div className={classes.contactDonationSummaryPage}>
        <div className='field-content extra-section'>
          <div className='field-label'>Donations made</div>
          {total && <div className='field-value'>{total}</div>}
        </div>
        <div className='field-content extra-section'>
          <div className='field-label'>Total amount donated</div>
          { total_amount && <div className='field-value'>{`$${total_amount} (${recurringAmount}% Recurring / ${100 - recurringAmount}% Once-off)`}</div> }
        </div>
        <div className='field-content extra-section'>
          <div className='field-label'>Financial YTD</div>
          { financial_YTD && <div className='field-value'>{`$${financial_YTD}`}</div> }
        </div>
        <div className='field-content extra-section'>
          <div className='field-label'>Last donation</div>
          { last_donation && <div className='field-value'>{`$${last_donation}`}</div> }
        </div>
        {
          status === ReduxStatus.loading && <Loader active />
        }
      </div>
    )
  }
}

ContactDonationsSummary.contextType = AppContext;

export default injectSheet(stylesheet)(ContactDonationsSummary);