import React from 'react';
import ReduxStatus from "../../../Common/Constants/ReduxStatus";
import { Icon, Loader, Popup, Table, Pagination, Checkbox } from "semantic-ui-react";
import { Link } from 'react-router-dom';
import isempty from "lodash.isempty";
import injectSheet from "react-jss";
import PropTypes from "prop-types";
import AppContext from "../../../Common/Constants/AppContext";
import ContactInfoModal from "./ContactInfoModal";
import ImportModal from "./ImportModal";
import ContactActionCreator from "../../Actions/ContactActionCreator";
import ContactFilter from "./ContactFilter/ContactFilter";
import Enum from "../../../Common/Constants/Enum";
import stylesheet from './stylesheet';
import Utils from "../../../Common/Utils/Utils";
import AddButton from '../../../Common/Components/Base/AddButton';
import ImportButton from '../../../Common/Components/Base/ImportButton';
import AssignToEventModal from "./AssignToEventModal";
import EventActionCreator from "../../../Events/Actions/EventActionCreator";
import ContactStatus from "../Common/ContactStatus";
import ConfirmDeleteModal from './ConfirmDeleteModal';

class AllContact extends React.Component {
  constructor() {
    super();
    this.state = {
      toggleDeleteContact: false,
      selectedDeleteContact: null,
      toggleContactModal: false,
      toggleImportModal: false,
      contactInfo: {},
      currentCheckList: [],
      toggleAssignToEvent: false,
      toggleDeleteMultiplesContact: false,
      filter: {}
    };
    this.handleSaveContact = this.handleSaveContact.bind(this);
    this.handleDeleteContact = this.handleDeleteContact.bind(this);
    this.handlePaginationChange = this.handlePaginationChange.bind(this);
    this.onSearchFilterChange = this.onSearchFilterChange.bind(this);
    this.addOrRemoveCheck = this.addOrRemoveCheck.bind(this);
    this.handleCheckAll = this.handleCheckAll.bind(this);
    this.handleAssignContactToEvent = this.handleAssignContactToEvent.bind(this);
    this.handleDeleteMultipleContacts = this.handleDeleteMultipleContacts.bind(this);
    this.handleExportToCSV = this.handleExportToCSV.bind(this);
  }

  componentDidMount() {
    const { dispatch } = this.context;
    const { type } = this.props;
    dispatch(ContactActionCreator.getContacts(1, {}, type));
  }

  handleCheckAll() {
    const { contacts: { data } } = this.props;
    if (this.state.currentCheckList.length !== data.length) {
      const currentCheckList = data.map(item => item._id);
      this.setState({
        currentCheckList,
      })
    } else {
      this.setState({
        currentCheckList: [],
      })
    }
  }

  addOrRemoveCheck(id) {
    const currentCheckList = [...this.state.currentCheckList];
    if (currentCheckList.includes(id)) {
      const index = currentCheckList.indexOf(id);
      currentCheckList.splice(index, 1);
    } else {
      currentCheckList.push(id);
    }
    this.setState({
      currentCheckList,
    });
  }

  handleAssignContactToEvent(selectedEvent) {
    const { dispatch } = this.context;
    dispatch(EventActionCreator.addVolunteerToEvent(selectedEvent._id, this.state.currentCheckList));
    this.setState({
      toggleAssignToEvent: false,
      currentCheckList: [],
    });
  }

  handlePaginationChange(e, { activePage }) {
    const { dispatch } = this.context;
    const { contacts: { filter }, type } = this.props;
    dispatch(ContactActionCreator.getContacts(activePage, filter, type));
  }

  handleSaveContact(contactInfo) {
    const { dispatch } = this.context;
    const { history } = this.props;
    if (contactInfo._id) {
      dispatch(ContactActionCreator.saveContact(contactInfo));
    } else {
      dispatch(ContactActionCreator.createContact(contactInfo, history));
    }
    this.setState({
      toggleContactModal: false,
      contactInfo: {},
    });
  }

  handleDeleteContact(reason) {
    const { dispatch } = this.context;
    dispatch(ContactActionCreator.deleteContact(this.state.selectedDeleteContact._id, {reason}));
    this.setState({
      toggleDeleteContact: false,
      selectedDeleteContact: null,
    })
  }

  handleDeleteMultipleContacts(reason) {
    const { dispatch } = this.context;
    dispatch(ContactActionCreator.deleteMultipleContacts(this.state.currentCheckList, {reason}));
    this.setState({
      toggleDeleteMultiplesContact: false,
      currentCheckList: [],
    })
  }

  onSearchFilterChange(filter) {
    const { dispatch } = this.context;
    const { type } = this.props;
    this.setState({ filter })
    dispatch(ContactActionCreator.getContacts(1, filter, type));
  }

  handleToggleContacted(contact) {
    contact.contacted_for_next_election = !contact.contacted_for_next_election;
    const { dispatch } = this.context;
    const { _id, contacted_for_next_election } = contact;
    dispatch(ContactActionCreator.saveContact({ _id, contacted_for_next_election }));
  }

  handleExportToCSV() {
    const { dispatch } = this.context;
    if (this.state.currentCheckList.length > 0) {
      const filter = { "_id": { "$in": this.state.currentCheckList } };
      dispatch(ContactActionCreator.exportContactsToCSV(filter));
    } else {
      const { type } = this.props;
      const { filter } = this.state;
      dispatch(ContactActionCreator.exportContactsToCSV(filter, {}, type));
    }
  }

  handleUploadCSV = (files) => {
    const { dispatch } = this.context
    const [file] = files
    if(!file) return
    dispatch(ContactActionCreator.uploadFileContactList(file))
  }

  handleCloseImportModal = () => {
    const { dispatch } = this.context
    this.setState({ toggleImportModal: false })
    dispatch(ContactActionCreator.resetFileContactListStatus())
  }

  handleOnGoToImportList = () => {
    const { history } = this.props
    history.push(`/tools/importHistory`)
  }

  render() {
    const { classes, contacts: { data, status, activePage, totalPage, totalRecord, filter }, type, uploadContactList } = this.props;
    const { intl: { messages } } = this.context;
    return (
      <div className={classes.contactPage}>
        {
          status === ReduxStatus.loading && <Loader active />
        }
        {
          this.state.toggleDeleteContact &&
          <ConfirmDeleteModal
            isOpen={true}
            onClose={() => this.setState({ toggleDeleteContact: false })}
            onConfirm={this.handleDeleteContact}
            title={messages.deleteContact}
            cancelText={messages.cancelText}
            confirmText={messages.delete}
          />
        }
        {
          this.state.toggleDeleteMultiplesContact &&
          <ConfirmDeleteModal
            isOpen={true}
            onClose={() => this.setState({ toggleDeleteMultiplesContact: false })}
            onConfirm={this.handleDeleteMultipleContacts}
            
            title={messages.deleteContact}
            cancelText={messages.cancelText}
            confirmText={messages.delete}
          />
        }
        {
          this.state.toggleContactModal &&
          <ContactInfoModal
            isOpen={this.state.toggleContactModal}
            onClose={() => this.setState({ toggleContactModal: false })}
            onOk={this.handleSaveContact}
            contactInfo={this.state.contactInfo}
            contactData={data}
          />
        }
        {
          this.state.toggleImportModal &&
          <ImportModal
            isOpen={this.state.toggleImportModal}
            onClose={this.handleCloseImportModal}
            onUpload={this.handleUploadCSV}
            onGoToImportList={this.handleOnGoToImportList}
            uploadContactListStatus={uploadContactList}
          />
        }
        {
          this.state.toggleAssignToEvent &&
          <AssignToEventModal
            isOpen={this.state.toggleAssignToEvent}
            onClose={() => this.setState({ toggleAssignToEvent: false })}
            onOk={this.handleAssignContactToEvent}
          />
        }
        { 
          type === 'all' &&
          <ImportButton
            onClick={() => this.setState({
              toggleImportModal: true
            })}
            content='Import'
          />
        }
        <AddButton
          onClick={() => this.setState({
            toggleContactModal: true,
            contactInfo: {},
          })}
          content={messages.addContact}
        />
        <ContactFilter
          onSearchFilterChange={this.onSearchFilterChange}
          showNumber={data.length}
          total={totalRecord}
          initFilter={filter}
          contactPaymentType={type}
        />
        <Table singleLine selectable basic>
          <Table.Header>
            <Table.Row className="contact-header">
              <Table.HeaderCell>
                <Checkbox checked={this.state.currentCheckList.length === data.length} onChange={this.handleCheckAll} />
              </Table.HeaderCell>
              <Table.HeaderCell></Table.HeaderCell>
              <Table.HeaderCell>{messages.name}</Table.HeaderCell>
              <Table.HeaderCell>{messages.mobile}</Table.HeaderCell>
              <Table.HeaderCell>{messages.email}</Table.HeaderCell>
              <Table.HeaderCell>{messages.flags}</Table.HeaderCell>
              <Table.HeaderCell>{messages.contacted}</Table.HeaderCell>
              <Table.HeaderCell>
                <Popup
                  trigger={(
                    <div className='action-container'>
                      <span>{messages.actions}</span> <Icon name='ellipsis horizontal' />
                    </div>
                  )}
                  content={(
                    <div className={classes.headerAction}>
                      <div
                        className='action'
                        onClick={(e) => {
                          e.stopPropagation();
                          this.setState({
                            toggleAssignToEvent: true,
                          })
                          document.getElementsByTagName('body')[0].click();
                        }}
                      >
                        Assign to event
                      </div>
                      <div
                        className='action'
                        onClick={(e) => {
                          e.stopPropagation();
                          this.setState({
                            toggleDeleteMultiplesContact: true,
                          })
                          document.getElementsByTagName('body')[0].click();
                        }}
                      >
                        {messages.delete}
                      </div>
                      <div
                        className='action'
                        onClick={(e) => {
                          e.stopPropagation()
                          this.handleExportToCSV()
                          document.getElementsByTagName('body')[0].click()
                        }}
                      >
                        {messages.exportToCSV}
                      </div>
                    </div>
                  )}
                  position='bottom right'
                  on='click'
                />
              </Table.HeaderCell>
            </Table.Row>
          </Table.Header>
          <Table.Body>
            {data.map(item => (
              <Table.Row key={item._id} className="contact-row">
                <Table.Cell collapsing>
                  <Checkbox
                    onChange={() => this.addOrRemoveCheck(item._id)}
                    checked={this.state.currentCheckList.includes(item._id)}
                  />
                </Table.Cell>
                <Table.Cell collapsing>
                  {
                    !isempty(item.profile_picture) ?
                      <img className={classes.profileImage} src={item.profile_picture['thumb@64_64']} alt='' /> :
                      <img className={classes.profileImage} src={require("../../../Assets/avatar.png")} alt='' />
                  }
                </Table.Cell>
                <Table.Cell>
                  <Link to={`/contact-detail/${item._id}/overview`}>
                    {item.type === 'person' ? Utils.combineName(item, messages): item.organisation_name}
                  </Link>
                  <div className='volunteer-city'>
                    {item.home_address && item.home_address.city}
                  </div>
                </Table.Cell>
                <Table.Cell>{item.mobile_number}</Table.Cell>
                <Table.Cell>
                  <a href={`mailto: ${Utils.getContactEmail(item.emails)}`}
                     target="_top">{Utils.getContactEmail(item.emails)}</a>
                </Table.Cell>
                <Table.Cell className={classes.flagIcon}>
                  <Popup
                    trigger={
                      <Icon
                        disabled={!item.flags.includes(Enum.ContactFlag.member)}
                        name='address card'
                        size='large'
                      />
                    }
                    inverted
                    content={messages.member}
                  />
                  <Popup
                    trigger={
                      <Icon
                        disabled={!item.flags.includes(Enum.ContactFlag.donor)}
                        name='dollar'
                        circular
                        inverted
                      />
                    }
                    inverted
                    content={messages.donor}
                  />
                  <Popup
                    trigger={
                      <Icon
                        disabled={!item.flags.includes(Enum.ContactFlag.volunteer)}
                        name='hand paper'
                        size='large'
                      />
                    }
                    inverted
                    content={messages.volunteer}
                  />
                  <ContactStatus contactDetail={item} />
                </Table.Cell>
                <Table.Cell>
                  <Checkbox
                    toggle checked={item.contacted_for_next_election}
                    onChange={() => this.handleToggleContacted(item)}
                  />
                </Table.Cell>
                <Table.Cell>
                  <div className="user-action">
                    <div onClick={() => this.setState({
                      toggleDeleteContact: true,
                      selectedDeleteContact: item,
                    })}>
                      {messages.delete}
                    </div>
                    <div onClick={() => this.setState({
                      toggleContactModal: true,
                      contactInfo: item,
                    })}>
                      {messages.edit}
                    </div>
                  </div>
                </Table.Cell>
              </Table.Row>
            ))}
          </Table.Body>
        </Table>
        {
          data.length > 0 &&
          <Pagination
            activePage={activePage}
            totalPages={totalPage}
            onPageChange={this.handlePaginationChange}
          />
        }
      </div>
    )
  }
}

AllContact.propTypes = {
  contacts: PropTypes.shape({}).isRequired,
};

AllContact.contextType = AppContext;

export default injectSheet(stylesheet)(AllContact);
