import React from 'react';
import PropTypes from 'prop-types';
import { Button, Form, Modal } from 'semantic-ui-react';
import injectSheet from "react-jss";
import SearchEvent from "../../../Common/Components/Search/SearchEvent";
import { ModalStyleSheet } from "../../../Common/GlobalStyle";
import AppContext from "../../../Common/Constants/AppContext";

class AssignToEventModal extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      selectedEvent: {},
    };
    this.handleSubmit = this.handleSubmit.bind(this);
    this.handleSelect = this.handleSelect.bind(this);
  }

  handleSelect = (selectedEvent) => {
    this.setState({
      selectedEvent,
    });
  }

  handleSubmit() {
    const { onOk } = this.props;
    onOk(this.state.selectedEvent);
  }

  render() {
    const { classes, isOpen, onClose } = this.props;
    const { intl: { messages } } = this.context;
    const { selectedEvent } = this.state;

    return (
      <Modal
        open={isOpen}
        onClose={onClose}
        size="tiny"
      >
        <Modal.Header className={classes.header}>
          Assign to event
        </Modal.Header>
        <Modal.Content>
          <Form
            onSubmit={this.handleSubmit}
          >
            <Form.Field>
              <SearchEvent
                onSelect={this.handleSelect}
                resetWhenClear={true}
              />
            </Form.Field>
            <Form.Field className={classes.actionGroup}>
              <Button onClick={onClose}>
                {messages.cancel}
              </Button>
              <Button
                type='submit'
                color='green'
                disabled={!selectedEvent._id}
              >
                Set
              </Button>
            </Form.Field>
          </Form>
        </Modal.Content>
      </Modal>
    )
  }
}

AssignToEventModal.propTypes = {
  isOpen: PropTypes.bool.isRequired,
  onClose: PropTypes.func.isRequired,
  onOk: PropTypes.func.isRequired,
};

AssignToEventModal.contextType = AppContext;

export default injectSheet(ModalStyleSheet)(AssignToEventModal);