import React, { useState } from 'react';
import PropTypes from 'prop-types';
import { Button, Modal, Select } from 'semantic-ui-react';
import injectSheet from "react-jss";
import colors from "../../../Common/Constants/color";
import Enum from '../../../Common/Constants/Enum';

const style = {
  header: {
    '&.header': {
      textAlign: 'center',
      backgroundColor: '#db2828 !important',
      color: `${colors.primaryWhite} !important`,
    }
  },
  textContent: {
    margin: [10, 0],
    '& .label': {
      marginBottom: 8
    }
  }
}
const ConfirmModal = (
  { classes, isOpen, title, onClose, size, onConfirm, content, cancelText, confirmText }
) => {
  const [reason, setReason] = useState()

  const onConfirmDelete = () => {
    onConfirm(reason)
  }
  
  return (
    <Modal
      open={isOpen}
      onClose={onClose}
      size="mini"
    >
      <Modal.Header className={classes.header}>{title}</Modal.Header>
      <Modal.Content>
        <div className={classes.textContent}>
          <div className="label">Reason</div>
          <Select
            style={{width: '100%'}}
            value={reason}
            options={Object.keys(Enum.DeleteContactReason).map(key => ({
              value: key,
              text: Enum.DeleteContactReasonText[key]
            }))}
            onChange={(e, {value}) => setReason(value)}
            placeholder="Select reason..."
          />
        </div>
      </Modal.Content>
      <Modal.Actions>
        <Button onClick={onClose}>
          {cancelText}
        </Button>
        <Button
          disabled={!reason}
          onClick={onConfirmDelete}
          color={"red"}
        >
          {confirmText}
        </Button>
      </Modal.Actions>
    </Modal>
  )
}

ConfirmModal.propTypes = {
  isOpen: PropTypes.bool.isRequired,
  onClose: PropTypes.func.isRequired,
  onConfirm: PropTypes.func.isRequired,
  size: PropTypes.string,
  title: PropTypes.string,
  content: PropTypes.shape({
    mainText: PropTypes.string,
    description: PropTypes.string,
  }),
  cancelText: PropTypes.string,
  confirmText: PropTypes.string,
};

ConfirmModal.defaultProps = {
  title: '',
  content: {
    mainText: '',
    description: '',
  },
  cancelText: 'Cancel',
  confirmText: 'Confirm',
};

export default injectSheet(style)(ConfirmModal);