import React from 'react';
import injectSheet from 'react-jss';
import isequal from 'lodash.isequal';
import debounce from 'lodash.debounce';
import clonedeep from 'lodash.clonedeep';
import stylesheet from './stylesheet';
import AppContext from "../../../../../../Common/Constants/AppContext";
import SegmentFilterActionCreator from "../../../../../Actions/CriteriaActionCreator";
import AccountActionCreator from '../../../../../../Account/AccountActionCreator'
import CriteriaInfoModal from "./CriteriaInfoModal";
import { Input, Loader, Pagination, Menu, Dropdown, Icon } from "semantic-ui-react";
import ContactActionCreator from "../../../../../Actions/ContactActionCreator";
import ReduxStatus from "../../../../../../Common/Constants/ReduxStatus";
import Confirmation from "../../../../../../Common/Components/Modal/ConfirmModal";
import CriteriaActionCreator from "../../../../../Actions/CriteriaActionCreator";
import CriteriaNameModal from "./CriteriaNameModal";

const defaultCriteria = {
  _id: "",
  name: "None",
  type: "contact",
  criteria: {
    operator: 'and',
    segmentFilter: {},
  }
}

class CriteriaList extends React.Component {
  constructor() {
    super();
    this.state = {
      toggleEdit: false,
      criteriaInfo: { ...defaultCriteria },

      temporaryCriteriaInfo: { ...defaultCriteria },

      toggleDelete: false,

      toggleEditName: false,
      isSaveAs: false,
    }
    this.onSearchFilterChange = debounce(this.onSearchFilterChange, 300);
    this.handlePaginationChange = this.handlePaginationChange.bind(this);
  }

  componentDidMount() {
    const { dispatch, currentUser } = this.context;
    dispatch(SegmentFilterActionCreator.getCriteriaList(currentUser._id, 1, {type: 'contact'}));
    dispatch(AccountActionCreator.getAccounts(1))
    this.handleSelectCriteria(defaultCriteria);
  }

  handlePaginationChange(e, { activePage }) {
    const { dispatch, currentUser } = this.context;
    const { criteriaList: { filter } } = this.props;
    dispatch(SegmentFilterActionCreator.getCriteriaList(currentUser._id, activePage, filter));
  }

  onSearchFilterChange = (e, { value }) => {
    const { dispatch, currentUser } = this.context;
    const { criteriaList } = this.props;
    const newFilter = { ...criteriaList.filter };
    if (value) {
      newFilter.name = { "$regex": value, "$options": "i" };
    } else {
      newFilter.name = null;
    }
    dispatch(SegmentFilterActionCreator.getCriteriaList(currentUser._id, 1, newFilter));
  }

  handleSelectCriteria = (item) => {
    const { criteria } = item;
    if (this.state.criteriaInfo._id === item._id) {
      return;
    }
    this.setState({
      criteriaInfo: item,
      temporaryCriteriaInfo: clonedeep(item),
    });
    const { dispatch } = this.context;
    dispatch(ContactActionCreator.getContactsFilterSegment(1, criteria));
  }

  handleSaveCriteria = () => {
    const { temporaryCriteriaInfo } = this.state
    this.handleSave(temporaryCriteriaInfo)
  };

  handleSave = (criteriaInfo) => {
    const { dispatch, currentUser } = this.context;
    const saveCriteria = clonedeep(criteriaInfo);
    saveCriteria.criteria = JSON.stringify(saveCriteria.criteria);
    if (!saveCriteria._id) {
      const opts = {
        callback: (saveData) => {
          this.setState({
            criteriaInfo: {
              ...clonedeep(criteriaInfo),
              _id: saveData._id,
            },
            temporaryCriteriaInfo: {
              ...clonedeep(criteriaInfo),
              _id: saveData._id,
            },
            toggleEdit: false,
            toggleEditName: false,
          });
        },
      };
      dispatch(CriteriaActionCreator.createCriteria(currentUser._id, saveCriteria, opts));
    } else {
      const opts = {
        callback: () => {
          this.setState({
            toggleEdit: false,
            toggleEditName: false,
            criteriaInfo: clonedeep(criteriaInfo),
            temporaryCriteriaInfo: clonedeep(criteriaInfo),
          });
        },
      };
      dispatch(CriteriaActionCreator.saveCriteria(currentUser._id, saveCriteria, opts));
    }
  }

  handleApplyFilter = (temporaryCriteriaInfo) => {
    const { dispatch } = this.context;
    const { operator, segmentFilter } = temporaryCriteriaInfo.criteria;
    this.setState({
      toggleEdit: false,
      temporaryCriteriaInfo
    });
    dispatch(ContactActionCreator.getContactsFilterSegment(1, {
      operator,
      segmentFilter,
    }));

  }

  handleDeleteCriteria = () => {
    const { dispatch, currentUser } = this.context;
    const { criteriaInfo } = this.state;
    dispatch(SegmentFilterActionCreator.deleteCriteria(currentUser._id, criteriaInfo._id));

    dispatch(ContactActionCreator.getContactsFilterSegment(1, {}));
    this.setState({
      toggleDelete: false,

      criteriaInfo: { ...defaultCriteria },
      temporaryCriteriaInfo: { ...defaultCriteria },
    });
  }

  handleCloseCriteria = () => {
    this.setState({
      toggleEdit: false,
    })
  }

  render() {
    const { intl: { messages }, currentUser } = this.context;
    const { classes, criteriaList: { data, activePage, totalPage, status }, accountList } = this.props;

    const { criteriaInfo, temporaryCriteriaInfo } = this.state;
    
    return (
      <div className={classes.criteriaList}>
        {
          status === ReduxStatus.loading && <Loader active />
        }
        {
          this.state.toggleEditName &&
          <CriteriaNameModal
            isOpen={this.state.toggleEditName}
            isSaveAs={this.state.isSaveAs}
            onClose={() => this.setState({ toggleEditName: false })}
            onSave={this.handleSave}
            criteriaInfo={
              this.state.isSaveAs ? {
                  ...clonedeep(temporaryCriteriaInfo),
                  _id: null,
                  name: `${temporaryCriteriaInfo.name} 2`,
                } :
                clonedeep(temporaryCriteriaInfo)
            }
          />
        }
        {
          this.state.toggleEdit &&
          <CriteriaInfoModal
            isOpen={this.state.toggleEdit}
            onClose={this.handleCloseCriteria}
            onApplyFilter={this.handleApplyFilter}
            criteriaInfo={clonedeep(temporaryCriteriaInfo)}
            accountList={accountList}
          />
        }
        {
          this.state.toggleDelete &&
          <Confirmation
            isOpen={true}
            onClose={() => this.setState({ toggleDelete: false })}
            onConfirm={this.handleDeleteCriteria}
            content={{
              mainText: messages.deleteText.replace('{item}', criteriaInfo.name),
              description: messages.messageConfirm.replace('{name}',
                `${currentUser.first_name}`)
            }}
            title={messages.deleteSegment}
            cancelText={messages.keepThisSegment}
            confirmText={messages.delete}
          />
        }
        <div className='selected-criteria-info'>
          <div className='criteria-name'>{criteriaInfo.name}</div>
        </div>
        <div className='criteria-action'>
          <div className='edit-filter-text' onClick={() => this.setState({
            toggleEdit: true,
          })}>
            Edit Filter
          </div>
          {
            !isequal(criteriaInfo, temporaryCriteriaInfo) &&
            <div className='saved-change-text'>Unsaved changes</div>
          }
          <Menu className='segment-filter-menu'>
            {
              criteriaInfo._id &&
              <Menu.Item
                disabled={isequal(temporaryCriteriaInfo, criteriaInfo)}
                onClick={this.handleSaveCriteria}
              >
                Save
              </Menu.Item>
            }
            <Dropdown text='Actions' className='link item'>
              <Dropdown.Menu>
                <Dropdown.Item
                  onClick={() => this.setState({
                    toggleEditName: true,
                    isSaveAs: true,
                  })}
                >
                  Save As
                </Dropdown.Item>
                {
                  criteriaInfo._id &&
                  [
                    <Dropdown.Item
                      key='edit'
                      onClick={() => this.setState({
                        toggleEditName: true,
                        isSaveAs: false,
                      })}
                    >
                      Edit Name
                    </Dropdown.Item>,
                    <Dropdown.Item
                      key='delete'
                      onClick={() => this.setState({
                        toggleDelete: true,
                      })}
                    >
                      Delete
                    </Dropdown.Item>
                  ]
                }
              </Dropdown.Menu>
            </Dropdown>
          </Menu>
        </div>

        <Input
          fluid
          icon='search'
          iconPosition='left'
          placeholder='Search segment...'
          onChange={this.onSearchFilterChange}
        />
        <div className='criteria-list'>
          <div
            className={`criteria-item ${!criteriaInfo._id ? 'active' : ''}`}
            onClick={() => this.handleSelectCriteria(defaultCriteria)}
          >
            <div className='criteria-name'>
              None
            </div>
          </div>
          {
            data.map(item => (
              <div
                className={`criteria-item ${criteriaInfo._id === item._id ? 'active' : ''}`}
                key={item._id}
                onClick={() => this.handleSelectCriteria(item)}>
                <div className='criteria-name'>
                  {item.name}
                </div>
                {item.is_public && <Icon name='users'/>}
              </div>
            ))
          }
        </div>
        {
          data.length > 0 && totalPage > 1 &&
          <Pagination
            activePage={activePage}
            totalPages={totalPage}
            onPageChange={this.handlePaginationChange}
          />
        }
      </div>
    );
  }
}

CriteriaList.contextType = AppContext;

export default injectSheet(stylesheet)(CriteriaList);