import Enum from "../../../../../../../Common/Constants/Enum";

export const ContactFields = {
  type: {
    type: 'dropdown',
  },
  abn: {
    type: 'string',
  },
  first_name: {
    type: 'string',
  },
  middle_name: {
    type: 'string',
  },
  last_name: {
    type: 'string',
  },
  day_of_birth: {
    type: 'date'
  },
  state: {
    type: 'dropdown'
  },
  postal_code: {
    type: 'number'
  },
  related_organisation: {
    type: 'string',
  },
  nationbuilder_id: {
    type: 'string',
  },
  professional_title: {
    type: 'string',
  },
  'volunteer.status': {
    type: 'dropdown',
  },
  interests: {
    type: 'dropdown'
  },
  deleted: {
    type: 'boolean'
  },
  membership_status: {
    type: 'dropdown'
  },
  'payments.membership_started_at': {
    type: 'date'
  },
  'payments.membership_expires_at': {
    type: 'date'
  },
  'payments.membership_class': {
    type: 'string',
  },
  'payments.donation_started_at': {
    type: 'date'
  },
  total_donation_amount: {
    type: 'number'
  },
  is_on_electoral_roll: {
    type: 'boolean'
  }
}

export const OperatorOptions = {
  'string': [
    {
      key: 'is',
      text: 'is',
      value: 'is',
    },
    {
      key: 'is_not',
      text: 'is not',
      value: 'is_not',
    },
    {
      key: 'contains',
      text: 'contains',
      value: 'contains',
    },
    {
      key: 'not_contains',
      text: 'not contains',
      value: 'not_contains',
    },
  ],
  'dropdown': [
    {
      key: 'is',
      text: 'is',
      value: 'is',
    },
    {
      key: 'is_not',
      text: 'is not',
      value: 'is_not',
    },
  ],
  'date': [
    {
      key: 'is',
      text: 'is',
      value: 'is',
    },
    {
      key: 'is_not',
      text: 'is not',
      value: 'is_not',
    },
    {
      key: 'before',
      text: 'Before',
      value: 'before',
    },
    {
      key: 'after',
      text: 'After',
      value: 'after',
    }
  ],
  'boolean': [
    {
      key: 'is',
      text: 'is',
      value: 'is',
    }
  ],
  'number': [
    {
      key: 'is',
      text: 'is',
      value: 'is',
    },
    {
      key: 'is_not',
      text: 'is not',
      value: 'is_not',
    },
    {
      key: 'greater_than',
      text: 'greater than',
      value: 'greater_than',
    },
    {
      key: 'lower_than',
      text: 'less than',
      value: 'lower_than',
    },
  ]
}

export const ValueDataOption = (field, messages) => {
  switch (field) {
    case 'type':
      return Object.values(Enum.ContactTypeEnum).map(item => ({
        key: item,
        text: messages[item],
        value: item
      }))
    case 'volunteer.status':
      return Object.values(Enum.VolunteerStatus).map(item => ({
        key: item,
        text: messages[item],
        value: item
      }))
    case 'interests':
      return Object.values(Enum.Interests).map(item => ({
        key: item,
        text: item,
        value: item
      }))
    case 'deleted':
      return [true].map(item => ({
        key: item,
        text: 'True',
        value: item
      }))  
    case 'membership_status':
      return Object.values(Enum.MembershipStatus).map(item => ({
        key: item,
        text: messages[item],
        value: item
      }))
    case 'state':
      return Object.keys(Enum.StateAustralia).map(item => ({
        key: item,
        text: Enum.StateAustralia[item],
        value: item
      }))  
    case 'is_on_electoral_roll':
      return [true, false].map(item => ({
        key: item,
        text: item ? 'Yes' : 'No',
        value: item
      }))  
    default:
      return null
  }
}
