import React from 'react';
import ReduxStatus from "../../../../Common/Constants/ReduxStatus";
import { Icon, Loader, Popup, Table, Pagination, Checkbox } from "semantic-ui-react";
import { Link } from 'react-router-dom';
import isempty from "lodash.isempty";
import injectSheet from "react-jss";
import PropTypes from "prop-types";
import AppContext from "../../../../Common/Constants/AppContext";
import ContactActionCreator from "../../../Actions/ContactActionCreator";
import Enum from "../../../../Common/Constants/Enum";
import stylesheet from './stylesheet';
import Utils from "../../../../Common/Utils/Utils";
import EventActionCreator from "../../../../Events/Actions/EventActionCreator";
import ContactStatus from "../../Common/ContactStatus";
import AdvanceFilterSegment from "./AdvanceFilterSegment/AdvanceFilterSegment";

class ContactAdvancedFilter extends React.Component {
  constructor() {
    super();
    this.state = {
      currentCheckList: [],
      toggleAssignToEvent: false,
      toggleDeleteMultiplesContact: false,
      filter: {}
    };
    this.handlePaginationChange = this.handlePaginationChange.bind(this);
    this.addOrRemoveCheck = this.addOrRemoveCheck.bind(this);
    this.handleCheckAll = this.handleCheckAll.bind(this);
    this.handleAssignContactToEvent = this.handleAssignContactToEvent.bind(this);
    this.handleDeleteMultipleContacts = this.handleDeleteMultipleContacts.bind(this);
    this.handleExportToCSV = this.handleExportToCSV.bind(this);
  }

  componentDidMount() {
    const { dispatch } = this.context;
    const { contacts: { activePage, filter } } = this.props;
    dispatch(ContactActionCreator.getContactsFilterSegment(activePage, filter));
  }

  handleCheckAll() {
    const { contacts: { data } } = this.props;
    if (this.state.currentCheckList.length !== data.length) {
      const currentCheckList = data.map(item => item._id);
      this.setState({
        currentCheckList,
      })
    } else {
      this.setState({
        currentCheckList: [],
      })
    }
  }

  addOrRemoveCheck(id) {
    const currentCheckList = [...this.state.currentCheckList];
    if (currentCheckList.includes(id)) {
      const index = currentCheckList.indexOf(id);
      currentCheckList.splice(index, 1);
    } else {
      currentCheckList.push(id);
    }
    this.setState({
      currentCheckList,
    });
  }

  handleAssignContactToEvent(selectedEvent) {
    const { dispatch } = this.context;
    dispatch(EventActionCreator.addVolunteerToEvent(selectedEvent._id, this.state.currentCheckList));
    this.setState({
      toggleAssignToEvent: false,
      currentCheckList: [],
    });
  }

  handlePaginationChange(e, { activePage }) {
    const { dispatch } = this.context;
    const { contacts: { filter } } = this.props;
    dispatch(ContactActionCreator.getContacts(activePage, filter));
  }

  handleDeleteMultipleContacts() {
    const { dispatch } = this.context;
    dispatch(ContactActionCreator.deleteMultipleContacts(this.state.currentCheckList));
    this.setState({
      toggleDeleteMultiplesContact: false,
      currentCheckList: [],
    })
  }

  handleToggleContacted(contact) {
    contact.contacted_for_next_election = !contact.contacted_for_next_election;
    const { dispatch } = this.context;
    const { _id, contacted_for_next_election } = contact;
    dispatch(ContactActionCreator.saveContact({ _id, contacted_for_next_election }));
  }

  handleExportToCSV() {
    const { dispatch } = this.context;
    if (this.state.currentCheckList.length > 0) {
      const filter = { "_id": { "$in": this.state.currentCheckList } };
      dispatch(ContactActionCreator.exportContactsToCSV(filter));
    } else {
      const { contacts: { filter } } = this.props;
      dispatch(ContactActionCreator.exportContactsToCSV(Utils.buildAdvancedQueryString(filter), {}, 'advanced-filter'));
    }
  }

  render() {
    const { classes, contacts: { data, status, activePage, totalPage, totalRecord }, criteriaList, accountList } = this.props;
    const { intl: { messages } } = this.context;
    return (
      <div className={classes.contactAdvancedFilterSegment}>
        {
          status === ReduxStatus.loading && <Loader active />
        }
        <div className='contact-advanced-list'>
          <div className='contact-information'>
            <div className='display-contact-number'>
              Showing <b>{data.length}</b> of <b>{totalRecord}</b> contacts
            </div>
            <Popup
              trigger={(
                <div className='action-container'>
                  <span>{messages.actions}</span> <Icon name='ellipsis horizontal' />
                </div>
              )}
              content={(
                <div className={classes.contactActions}>
                  <div
                    className='action'
                    onClick={(e) => {
                      e.stopPropagation();
                      this.setState({
                        toggleAssignToEvent: true,
                      })
                      document.getElementsByTagName('body')[0].click();
                    }}
                  >
                    Assign to event
                  </div>
                  <div
                    className='action'
                    onClick={(e) => {
                      e.stopPropagation();
                      this.setState({
                        toggleDeleteMultiplesContact: true,
                      })
                      document.getElementsByTagName('body')[0].click();
                    }}
                  >
                    {messages.delete}
                  </div>
                  <div
                    className='action'
                    onClick={(e) => {
                      e.stopPropagation()
                      this.handleExportToCSV()
                      document.getElementsByTagName('body')[0].click()
                    }}
                  >
                    {messages.exportToCSV}
                  </div>
                </div>
              )}
              position='bottom right'
              on='click'
            />
          </div>
          <Table selectable basic>
            <Table.Header>
              <Table.Row className="contact-header">
                <Table.HeaderCell>
                  <Checkbox checked={this.state.currentCheckList.length === data.length}
                            onChange={this.handleCheckAll} />
                </Table.HeaderCell>
                <Table.HeaderCell></Table.HeaderCell>
                <Table.HeaderCell>{messages.name}</Table.HeaderCell>
                <Table.HeaderCell>{messages.flags}</Table.HeaderCell>
                <Table.HeaderCell></Table.HeaderCell>
                <Table.HeaderCell></Table.HeaderCell>
              </Table.Row>
            </Table.Header>
            <Table.Body>
              {data.map(item => (
                <Table.Row key={item._id} className="contact-row">
                  <Table.Cell collapsing>
                    <Checkbox
                      onChange={() => this.addOrRemoveCheck(item._id)}
                      checked={this.state.currentCheckList.includes(item._id)}
                    />
                  </Table.Cell>
                  <Table.Cell collapsing>
                    {
                      !isempty(item.profile_picture) ?
                        <img className='profile-image' src={item.profile_picture['thumb@64_64']} alt='' /> :
                        <img className='profile-image' src={require("../../../../Assets/avatar.png")} alt='' />
                    }
                  </Table.Cell>
                  <Table.Cell collapsing>
                    <Link to={`/contact-detail/${item._id}/overview`}>
                      {Utils.combineName(item, messages)}
                    </Link>
                    <div className='volunteer-city'>
                      {item.home_address && item.home_address.city}
                    </div>
                    <div>
                      {item.mobile_number}
                    </div>
                    <div style={{ maxWidth: 150, textOverflow: 'ellipsis', overflow: 'hidden'}}>
                      <a href={`mailto: ${Utils.getContactEmail(item.emails)}`}
                         target="_top">{Utils.getContactEmail(item.emails)}</a>
                    </div>
                  </Table.Cell>
                  <Table.Cell singleLine className={classes.flagIcon}>
                    <Popup
                      trigger={
                        <Icon
                          disabled={!item.flags.includes(Enum.ContactFlag.member)}
                          name='address card'
                          size='large'
                        />
                      }
                      inverted
                      content={messages.member}
                    />
                    <Popup
                      trigger={
                        <Icon
                          disabled={!item.flags.includes(Enum.ContactFlag.donor)}
                          name='dollar'
                          circular
                          inverted
                        />
                      }
                      inverted
                      content={messages.donor}
                    />
                    <Popup
                      trigger={
                        <Icon
                          disabled={!item.flags.includes(Enum.ContactFlag.volunteer)}
                          name='hand paper'
                          size='large'
                        />
                      }
                      inverted
                      content={messages.volunteer}
                    />
                  </Table.Cell>
                  <Table.Cell>
                    <Link to={`/finance/allPayments?payeeId=${item._id}`}>
                      {messages['common.payments_history']}
                    </Link>
                    {/* <Checkbox
                      toggle checked={item.contacted_for_next_election}
                      onChange={() => this.handleToggleContacted(item)}
                    /> */}
                  </Table.Cell>
                  <Table.Cell>
                    <ContactStatus contactDetail={item} />
                  </Table.Cell>
                </Table.Row>
              ))}
            </Table.Body>
          </Table>
          {
            data.length > 0 && totalPage > 1 &&
            <Pagination
              activePage={activePage}
              totalPages={totalPage}
              onPageChange={this.handlePaginationChange}
            />
          }
        </div>
        <div className='advanced-filter-segment'>
          <AdvanceFilterSegment criteriaList={criteriaList} accountList={accountList} />
        </div>
      </div>
    )
  }
}

ContactAdvancedFilter.propTypes = {
  contacts: PropTypes.shape({}).isRequired,
  criteriaList: PropTypes.shape({}).isRequired,
};

ContactAdvancedFilter.contextType = AppContext;

export default injectSheet(stylesheet)(ContactAdvancedFilter);
