import React from "react";
import { connect } from "react-redux";
import { compose } from "redux";
import PropTypes from "prop-types";
import {
  Button,
  Form,
  Modal,
  Loader,
  Dimmer,
  List,
  Icon,
} from "semantic-ui-react";
import injectSheet from "react-jss";
import AppContext from "../../../Common/Constants/AppContext";
import { ModalStyleSheet } from "../../../Common/GlobalStyle";
import colors from "../../../Common/Constants/color";
import Dropzone from "react-dropzone";
import ReduxStatus from "../../../Common/Constants/ReduxStatus";
import ContactActionCreator from "../../Actions/ContactActionCreator";

const style = {
  groupOfType: {
    justifyContent: "center",
  },
  toggleContactType: {
    display: "flex",
    alignItems: "center",
    "& .ui.toggle.checkbox .box:before, .ui.toggle.checkbox label:before": {
      backgroundColor: "#0d71bb!important",
    },
  },
  helpText: {
    extend: ModalStyleSheet.helpText,
  },
  actionGroup: {
    extend: ModalStyleSheet.actionGroup,
  },
  header: {
    extend: ModalStyleSheet.header,
  },
  dropzoneContainer: {
    "& .dropzone": {
      margin: "1em 0 1em 0",
      padding: "4em 0em",
      borderRadius: ".3em",
      backgroundColor: `${colors.primaryGray4} !important`,
      color: `${colors.primaryBlue} !important`,
      fontWeight: "bold",
      fontSize: "9pt",
      textAlign: "center",
      cursor: "pointer",
    },
  },
  downloadText: {
    color: colors.primaryBlue,
    textDecoration: "underline",
    fontSize: 13,
    cursor: "pointer",
  },
  note: {
    marginTop: 10,
    "& .title": {
      display: "flex",
      justifyContent: "space-between",
      alignItems: "center",
      cursor: "pointer",
    },
  },
};

class ImportModal extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      expand: false,
    };
  }

  downloadTemplate = () => {
    const { dispatch } = this.props;
    dispatch(ContactActionCreator.getContactTemplate());
    };

  render() {
    const {
      classes,
      isOpen,
      onClose,
      onUpload,
      onGoToImportList,
      uploadContactListStatus: { status, filename },
    } = this.props;
    const {
      intl: { messages },
    } = this.context;
    const { expand } = this.state;
    return (
      <Modal open={isOpen} onClose={onClose} size="tiny">
        <Modal.Header className={classes.header}>Upload CSV</Modal.Header>
        <Modal.Content>
          {status === ReduxStatus.loading && (
            <Dimmer active inverted>
              <Loader size="medium">Uploading</Loader>
            </Dimmer>
          )}
          {/* <Form> */}
          <Dropzone accept=".csv" multiple={false} onDrop={onUpload}>
            {({ getRootProps, getInputProps }) => (
              <section className={classes.dropzoneContainer}>
                <div {...getRootProps({ className: "dropzone" })}>
                  <input {...getInputProps()} />
                  <p>Drag & drop some files here, or click to select files</p>
                </div>
              </section>
            )}
          </Dropzone>
          {filename && <p>{filename} was uploaded</p>}
          <Form.Field className={classes.actionGroup}>
            {status === ReduxStatus.loaded && (
              <Button color="green" onClick={onGoToImportList}>
                {messages["contact.list.uploadCSV.goToImportHistory"]}
              </Button>
            )}
            <Button onClick={onClose}>{messages.close}</Button>
          </Form.Field>
          <div className={classes.downloadText} onClick={this.downloadTemplate}>
            Download import template
          </div>
          <div className={classes.note}>
            <div
              className="title"
              onClick={() =>
                this.setState((prev) => ({ expand: !prev.expand }))
              }
            >
              <span>Notes for the special fields</span>
              <Icon name={`chevron ${expand ? "down" : "up"}`} />
            </div>
            {expand ? (
              <List>
                {[
                  {
                    field: "type",
                    description: "Possible values: ['person','organisation']",
                  },
                  {
                    field: "day_of_birth",
                    description: "A date in format DD/MM/YYYY",
                  },
                  {
                    field: "volunteer_status",
                    description:
                      "Possible values: ['active,'inactive','retired']",
                  },
                  {
                    field: "volunteer_roles",
                    description:
                      "String separated by semicolon, eg: Hand out on polling day;Displaying a corflute poster",
                  },
                  {
                    field: "interests",
                    description:
                      "String separated by semicolon. eg: Listening music;Reading book",
                  },
                  {
                    field: "date_first_joined",
                    description: "A date in format DD/MM/YYYY",
                  },
                  {
                    field: "abn",
                    description: "A unique 11 digit identifier",
                  },
                  {
                    field: "other field",
                    description: "Free text",
                  },
                ].map((item) => (
                  <List.Item>
                    <List.Header>{item.field}</List.Header>
                    <List.Description>{item.description}</List.Description>
                  </List.Item>
                ))}
              </List>
            ) : null}
          </div>
        </Modal.Content>
      </Modal>
    );
  }
}

ImportModal.propTypes = {
  isOpen: PropTypes.bool.isRequired,
  onClose: PropTypes.func.isRequired,
  onUpload: PropTypes.func.isRequired,
  // contactInfo: PropTypes.shape({}).isRequired,
  // contactData: PropTypes.shape([]).isRequired,
};

ImportModal.contextType = AppContext;

export default compose(injectSheet(style), connect())(ImportModal);
