import React from 'react'
import { Button, Grid, Icon, Table, Form, Popup, List } from "semantic-ui-react"
import { Link } from 'react-router-dom'
import injectSheet from "react-jss"
import { Elements, StripeProvider } from 'react-stripe-elements'
import isequal from 'lodash.isequal'
import _ from 'lodash'
import ReduxStatus from '../../../Common/Constants/ReduxStatus'
import PaymentSourceModal from '../Common/PaymentSourceModal'

import ProfileCard from "../ContactDetailProfile/ProfileCard"
import stylesheet from "./stylesheet"
import { config } from "../../../configuration"
import moment from "moment"
import AppContext from "../../../Common/Constants/AppContext"
import AssignMembershipModal from "./AssignMembershipModal"
import RenewMembershipModal from "./RenewMembershipModal"
import ConfirmModal from "../../../Common/Components/Modal/ConfirmModal"
import InlineEditText from '../../../Common/Components/InlineEditText/InlineEditText'
import InlineEditAdditionDropdown from '../../../Common/Components/InlineEditAdditionDropdown/InlineEditAdditionDropdown'
import Utils from "../../../Common/Utils/Utils"

import ContactOrderCreator from "../../Actions/ContactOrderActionCreator";
import ContactActionCreator from "../../Actions/ContactActionCreator";

class ContactMembership extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      assignMembershipToggle: false,
      toggleCancelMembership: false,
      toggleRenewMembership: false,
      isShowPaymentSourceModal: false,
      selectedMembership: {}
    }
  }

  getSnapshotBeforeUpdate(prevProps, prevState) {
    const { selectedContactDetail: { selectedContact } } = this.props;
    const { selectedContactDetail: { selectedContact: prevSelectedContact } } = prevProps;
    if (!isequal(selectedContact, prevSelectedContact)) {
      return true;
    }
    return null;
  }

  componentDidUpdate(prevProps, prevState, snapshot) {
    if (snapshot) {
      const { dispatch } = this.context;
      const {selectedContactDetail: {selectedContact}} = this.props;
      const filterMembershipOrder = {
        contact: selectedContact._id,
        type: "membership"
      }
      dispatch(ContactOrderCreator.getContactMembershipOrders(1, filterMembershipOrder));
      // const filterMembershipPayment = {
      //   linked_profile: selectedContact._id,
      //   payment_type: "membership",
      //   nb_donation_id: { $exists: true }
      // }
      // dispatch(ContactOrderCreator.getContactMembershipPayments(1, filterMembershipPayment));
    }
  }

  componentDidMount() {
    const { dispatch } = this.context;
    dispatch(ContactOrderCreator.getMemberships(1,{archived: {$ne: true}}));
    const {selectedContactDetail: {selectedContact}} = this.props;
    const filterMembershipOrder = {
      contact: selectedContact._id,
      type: "membership"
    }
    dispatch(ContactOrderCreator.getContactMembershipOrders(1, filterMembershipOrder));
  }

  handleCancelMembership = () => {
    const orderId = this.state.selectedOrderId
    if(orderId) {
      const { dispatch } = this.context
      dispatch(ContactOrderCreator.cancelOrder(orderId, 'membership'))
    }
    this.setState({toggleCancelMembership: false, selectedOrderId: ''})
  }

  handleRenewMembership = ({start_date, expiry_date}) => {
    const orderId = this.state.selectedOrderId
    if(orderId) {
      const { dispatch } = this.context
      dispatch(ContactOrderCreator.renewOrder(orderId, start_date, expiry_date, 'membership'))
    }
    this.setState({toggleRenewMembership: false, selectedOrderId: ''})
  }

  onAssignMembership = (membershipOrder) => {
    const { membership_id, price, campaign_id, stripe_token_id, tender, auto_renew, start_date, expiry_date } = membershipOrder;
    const { selectedContactDetail: {selectedContact} } = this.props;
    const { dispatch } = this.context;
    const order = {
      contact: selectedContact._id,
      type: "membership",
      membership: membership_id,
      campaign_id: campaign_id,
      stripe_token_id,
      tender,
      auto_renew,
      start_date,
      expiry_date,
      price
    }
    dispatch(ContactOrderCreator.createContactMembershipOrder(order));
    this.setState({assignMembershipToggle: false});
  }

  handlePatchContact = ({_id, name, value}) => {
    const {dispatch} = this.context;
    dispatch(ContactActionCreator.saveContact({
      _id,
      [name]: value
    }, false));
  }

  onClosePaymentSourceModal = () => {
    this.setState({isShowPaymentSourceModal: false})
  }

  onOpenPaymentSourceModal (membership) {
    this.setState({isShowPaymentSourceModal: true, selectedMembership : membership})
  }

  handleUpdatePaymentSource = (orderId, source) => {
    const { dispatch } = this.context
    dispatch(ContactOrderCreator.updatePaymentSource(orderId, source))
  }

  render() {
    const { classes,
      selectedContactDetail, 
      history,
      contactMembershipOrders: { data, status },
      contactMemberships } = this.props;
    const { intl: { messages } } = this.context;
    const { selectedContact } = selectedContactDetail
    return ( 
      <div className={classes.contactMembershipPage}>
        {
          this.state.toggleCancelMembership &&
          <ConfirmModal
            isOpen={true}
            onClose={() => this.setState({ toggleCancelMembership: false, selectedOrderId: '' })}
            onConfirm={this.handleCancelMembership}
            content={{
              mainText: messages.cancelRenewalMembershipText
            }}
            title={messages.cancelRenewalMembership}
            cancelText={messages.keep}
            confirmText={messages.ok}
          />
        }
        {
          this.state.toggleRenewMembership &&
          <RenewMembershipModal
            isOpen={this.state.toggleRenewMembership}
            selectedOrder={this.state.selectedOrder}
            onClose={() => this.setState({ toggleRenewMembership: false })}
            onRenew={this.handleRenewMembership}
          />
          // <ConfirmModal
          //   isOpen={true}
          //   onClose={() => this.setState({ toggleRenewMembership: false, selectedOrderId: '' })}
          //   onConfirm={this.handleRenewMembership}
          //   content={{
          //     mainText: messages.renewMembershipText
          //   }}
          //   title={messages.renewMembership}
          //   cancelText={messages.keep}
          //   confirmText={messages.ok}
          // />
        }
        <Grid>
          <Grid.Row>
            <Grid.Column computer={5}>
              <ProfileCard selectedContactDetail={selectedContactDetail} history={history} />
            </Grid.Column>
            <Grid.Column computer={11}>
              <div className='membership-list-container'>
                <div className='action-row'>
                  {
                    this.state.assignMembershipToggle &&
                    <StripeProvider apiKey={config.REACT_APP_STRIPE_KEY}>
                      <Elements>
                        <AssignMembershipModal
                          isOpen={this.state.assignMembershipToggle}
                          onClose={() => this.setState({assignMembershipToggle: false})}
                          onAssign={this.onAssignMembership}
                          memberships={contactMemberships ? contactMemberships.data : []}
                          membershipOrders = {data ? data : []}
                          contactDetail={selectedContactDetail.selectedContact}
                        />
                      </Elements>
                    </StripeProvider>  
                  }
                  <Button
                    icon
                    labelPosition='right'
                    color='green'
                    className='add-membership-button'
                    onClick={() => this.setState({assignMembershipToggle: true})}
                  >
                    {messages.membership}
                    <Icon name='add' circular inverted />
                  </Button>
                </div>
                <Table selectable basic>
                  <Table.Header>
                    <Table.Row>
                      <Table.HeaderCell>{messages.membershipName}</Table.HeaderCell>
                      <Table.HeaderCell>{messages.fee}</Table.HeaderCell>
                      <Table.HeaderCell>{messages.period}</Table.HeaderCell>
                      <Table.HeaderCell>{messages['contact.memberships.membership_number']}</Table.HeaderCell>
                      <Table.HeaderCell>{messages.reference}</Table.HeaderCell>
                      <Table.HeaderCell>{messages.status}</Table.HeaderCell>
                      <Table.HeaderCell></Table.HeaderCell>
                    </Table.Row>
                  </Table.Header>
                  <Table.Body>
                    {data.map(item => (
                      <Table.Row key={item._id} className='membership-row'>
                        <Table.Cell>{item.membership && `${item.membership.membership_class} ${item.membership.state}`}</Table.Cell>
                        <Table.Cell>${item.membership && item.membership.price + ' / ' + Utils.getMembershipPeriodText(item.membership.period)} {item.auto_renew && <Icon name='refresh' size='small'/>}</Table.Cell>
                        <Table.Cell>
                          {item.membership_period && item.membership_period.start_date && moment(new Date(item.membership_period.start_date)).format(config.DATE_FORMAT)} to {item.membership_period.end_date && moment(new Date(item.membership_period.end_date)).format(config.DATE_FORMAT)}
                        </Table.Cell>
                        <Table.Cell>
                          {selectedContact.membership_number}
                        </Table.Cell>
                        <Table.Cell>
                          {
                            item.order_id ?
                              <Link to={`/finance/allPayments?reference=${_.padStart(item.order_id, 5, 0)}`}>
                                {_.padStart(item.order_id, 5, 0)}
                              </Link> :
                              '-'
                          }
                        </Table.Cell>
                        <Table.Cell>
                          <div className={`status ${item.status}`}>
                            {messages[item.status]}
                          </div>
                        </Table.Cell>
                        <Table.Cell>
                          {
                            item.status !== 'cancelled' && item.status !== 'expired' &&
                            <div className='user-action'>
                              <Popup style={{padding: '20px 30px 20px 20px'}} position = 'bottom right' hoverable on='click' trigger={<Icon link name='ellipsis horizontal' />}>
                                <List link>
                                  {item.auto_renew && <List.Item style={{marginBottom: 10}} as='a' onClick={() => this.onOpenPaymentSourceModal(item)}>{messages['contact.details.update_card']}</List.Item>}
                                  <List.Item as='a' onClick={() => {this.setState({ toggleCancelMembership: true, selectedOrderId: item._id })}}>{messages.cancel}</List.Item>
                                  {/* <List.Item as='a' onClick={() => {this.setState({ toggleRenewMembership: true, selectedOrder: item, selectedOrderId: item._id })}}>{messages['common.renew']}</List.Item> */}
                                </List>
                              </Popup>
                            </div>
                          }
                        </Table.Cell>
                      </Table.Row>
                    ))}
                    {/* {
                      status !== ReduxStatus.loading && contactMembershipPayments.data.map(item => (
                        <Table.Row key={item._id}>
                          <Table.Cell>{item.membership_class || messages.membershipNationbuilder}</Table.Cell>
                          <Table.Cell>${item.amount && item.amount}</Table.Cell>
                          <Table.Cell>
                            {
                              item.membership_started_at && item.membership_expires_at ? 
                                moment(new Date(item.membership_started_at)).format(config.DATE_FORMAT) + ' to '+ moment(new Date(item.membership_expires_at)).format(config.DATE_FORMAT) :
                                '-'
                            }
                          </Table.Cell>
                          <Table.Cell>
                            {                            
                              <Link to={`/finance-detail/${item._id}`}>
                                {_.padStart(item.payment_id, 5, 0)}
                              </Link>
                            }
                          </Table.Cell>
                          <Table.Cell>
                          {
                            item.membership_expires_at ? 
                            (new Date(item.membership_expires_at) > new Date() ? 
                            <div className={`status active`}>
                              {messages['active']}
                            </div> : 
                            <div className={`status expired`}>
                              {messages['expired']}
                            </div> ) :
                            '-'
                          }
                          </Table.Cell>
                          <Table.Cell>
                            <div className='user-action'>
                              <Icon name="lock"/>
                            </div>
                          </Table.Cell>
                        </Table.Row>
                      ))
                    } */}
                  </Table.Body>
                </Table>
                {/* {
                  data.length === 0 && contactMembershipPayments.data.length === 0 &&
                  <div className='empty-list-message'>
                    <Icon name='address card outline' size='big' className='icon-membership' />
                    <p>{messages['contact.details.membership.empty_membership']}</p>
                  </div>
                }
                {
                  status === ReduxStatus.loading && <Loader active />
                } */}
                <StripeProvider apiKey={config.REACT_APP_STRIPE_KEY}>
                  <Elements>
                    <PaymentSourceModal
                      isOpen={this.state.isShowPaymentSourceModal}
                      onClose={this.onClosePaymentSourceModal}
                      order={this.state.selectedMembership}
                      contact={selectedContactDetail.selectedContact}
                      onUpdateSource={this.handleUpdatePaymentSource} />
                  </Elements>
                </StripeProvider>
              </div>
              <div className='related-member-details'>
                <div className='title'>Related Member Details</div>
                <Form
                  loading={status === ReduxStatus.loading}
                  error={status === ReduxStatus.saveFailed || status === ReduxStatus.loadFailed}
                >
                  <Grid>
                    <Grid.Row>
                      <Grid.Column mobile={16} tablet={6} computer={6} className='text-info'>
                        {messages.otherMembershipsOrClub}
                      </Grid.Column>
                      <Grid.Column mobile={16} tablet={10} computer={10} className='value-info'>
                        <InlineEditText
                          name='other_membership_club_name'
                          value={selectedContactDetail.selectedContact.other_membership_club_name}
                          onUpdate={(value) => this.handlePatchContact({
                            _id: selectedContactDetail.selectedContact._id,
                            name: 'other_membership_club_name',
                            value
                          })} />
                      </Grid.Column>
                    </Grid.Row>
                    <Grid.Row>
                      <Grid.Column mobile={16} tablet={6} computer={6} className='text-info'>
                        {messages.interests}
                      </Grid.Column>
                      <Grid.Column mobile={16} tablet={10} computer={10} className='value-info'>
                        <InlineEditAdditionDropdown
                          name='interests' 
                          value = {selectedContactDetail.selectedContact.interests}
                          onUpdate= {(value) => this.handlePatchContact({
                            _id: selectedContactDetail.selectedContact._id,
                            name: 'interests',
                            value
                          })} />
                      </Grid.Column>
                    </Grid.Row>
                  </Grid>
                </Form>
              </div>
            </Grid.Column>
          </Grid.Row>
        </Grid>
      </div>
    );
  }
}

ContactMembership.contextType = AppContext;

export default injectSheet(stylesheet)(ContactMembership);
