import React from 'react';
import { Loader, List, Pagination } from 'semantic-ui-react';
import injectSheet from "react-jss";

import ReduxStatus from "../../../../Common/Constants/ReduxStatus";
import stylesheet from "./stylesheet";
import AppContext from "../../../../Common/Constants/AppContext";
import moment from "moment/moment";
import ContactActivitiesActionCreator from "../../../Actions/ContactActivitiesActionCreator";
import Utils from "../../../../Common/Utils/Utils";
import Enum from '../../../../Common/Constants/Enum';

class Activities extends React.Component {
  constructor() {
    super();
    this.handlePaginationChange = this.handlePaginationChange.bind(this);
  }

  componentDidMount() {
    const { dispatch } = this.context;
    const { selectedContact } = this.props;
    const filter = {
      ref: selectedContact._id,
      group: 'contact'
    };
    dispatch(ContactActivitiesActionCreator.getContactActivities(1, filter));
  }

  handlePaginationChange(e, { activePage }) {
    const { dispatch } = this.context;
    const { contactActivities: { filter } } = this.props;
    dispatch(ContactActivitiesActionCreator.getContactActivities(activePage, filter))
  }

  render() {
    const { classes, selectedContact, contactActivities: { data, status, activePage, totalPage } } = this.props;
    return (
      <div className={classes.contactOverviewActivities}>
        <List celled>
          {data.map((log) => (
            <List.Item key={log._id}>
              <List.Content>
                <div className="actor">
                  <div className="created-date">
                    {moment().diff(log.created_at, "days") <= 2
                      ? moment(new Date(log.created_at)).fromNow()
                      : moment(new Date(log.created_at)).format("DD MMM YYYY")}
                  </div>
                </div>
                {log.action === "deleted" ? (
                  <div className="activity-content">
                    <span className="author">
                      {Utils.combinePersonName(log.actor)}
                    </span>{" "}
                    <span className="action">deleted</span>{" "}
                    {Utils.combinePersonName(selectedContact)} for the reason{" "}
                    <span className="action">
                      {Enum.DeleteContactReasonText[selectedContact.reason]}
                    </span>
                  </div>
                ) : (
                  <div className="activity-content">
                    <span className="action">
                      {log.object} {log.action}
                    </span> {' '} by
                    {
                      <span className="author">
                        {" "}
                        {log.type === "user"
                          ? log.actor.first_name + " " + log.actor.last_name
                          : "System"}
                      </span>
                    }
                  </div>
                )}
              </List.Content>
            </List.Item>
          ))}
        </List>
        {data.length > 0 && totalPage > 1 && (
          <Pagination
            activePage={activePage}
            totalPages={totalPage}
            onPageChange={this.handlePaginationChange}
          />
        )}
        {status === ReduxStatus.loading && <Loader active />}
      </div>
    );
  }
}

Activities.contextType = AppContext;

export default injectSheet(stylesheet)(Activities);