import React from 'react';
import { Grid, Tab } from "semantic-ui-react";
import injectSheet from "react-jss";

import ProfileCard from "../ContactDetailProfile/ProfileCard";
import Notes from './Notes/Notes';
import Activities from './Activities/Activities';
import stylesheet from "./stylesheet";
import Tasks from "./Tasks/Tasks";

class ContactOverview extends React.Component {

  getPanels = () => {
    const { selectedContactDetail: { selectedContact }, contactNotes, contactTasks, contactActivities } = this.props;
    return [
      {
        menuItem: "Activity",
        render: () => (
          <Activities
            contactActivities={contactActivities}
            selectedContact={selectedContact}
          />
        )
      },
      {
        menuItem: "Tasks",
        render: () => (
          <div>
            <Tasks
              selectedContact={selectedContact}
              contactTasks={contactTasks}
            />
          </div>
        )
      },
      {
        menuItem: "Notes",
        render: () => (
          <div>
            <Notes
              selectedContact={selectedContact}
              contactNotes={contactNotes}
            />
          </div>
        )
      },
    ];
  }

  render() {
    const { classes, selectedContactDetail, history } = this.props;
    const { selectedContact } = selectedContactDetail;

    return (
      <div className={classes.contactDetailOverview}>
        <Grid>
          <Grid.Row>
            <Grid.Column computer={5}>
              <ProfileCard selectedContactDetail={selectedContactDetail} history={history} />
            </Grid.Column>
            <Grid.Column computer={11}>
              {
                selectedContact._id &&
                <Tab menu={{ secondary: true, pointing: true }} panes={this.getPanels()} />
              }
            </Grid.Column>
          </Grid.Row>
        </Grid>
      </div>
    );
  }
}

export default injectSheet(stylesheet)(ContactOverview);