import React from 'react';
import PropTypes from 'prop-types';
import isequal from "lodash.isequal";
import { Button, Form, Modal } from 'semantic-ui-react';
import injectSheet from "react-jss";
import { ModalStyleSheet } from "../../../../Common/GlobalStyle";
import AppContext from "../../../../Common/Constants/AppContext";
import ContactNoteActionCreator from "../../../Actions/ContactNoteActionCreator";
import Enum from "../../../../Common/Constants/Enum";

class NoteInfoModal extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      noteInfo: {
        ...props.noteInfo,
      },
    };
    this.isFieldError = this.isFieldError.bind(this);
    this.handleChange = this.handleChange.bind(this);
    this.handleSubmit = this.handleSubmit.bind(this);
  }

  handleChange({ target: { name, value } }) {
    this.setState({
      noteInfo: {
        ...this.state.noteInfo,
        [name]: value,
      }
    })
  }

  handleSubmit() {
    if (!this.state.isHitSave) {
      this.setState({
        isHitSave: true,
      });
    }
    if (this.isFieldError('note') || this.isFieldError('category')) {
      return;
    }
    const noteInfo = { ...this.state.noteInfo };
    const { dispatch } = this.context;
    const {onClose} = this.props;
    if (!noteInfo._id) {
      dispatch(ContactNoteActionCreator.createContactNotes(noteInfo));
    } else {
      dispatch(ContactNoteActionCreator.saveContactNotes(noteInfo));
    }
    onClose();
  }

  isFieldError(name) {
    if (!this.state.noteInfo[name]) {
      return true;
    }
    return false;
  }

  render() {
    const { classes, isOpen, onClose } = this.props;
    const { intl: { messages } } = this.context;
    const { noteInfo } = this.state;
    const contactNotes = Object.values(Enum.ContactNotes).map(item => ({
      key: item,
      value: item,
      text: messages[item],
    }));
    return (
      <Modal
        open={isOpen}
        onClose={onClose}
        size="tiny"
      >
        <Modal.Header className={classes.header}>
          {
            noteInfo._id ? messages.editNote : messages.addNote
          }
        </Modal.Header>
        <Modal.Content>
          <Form
            onSubmit={this.handleSubmit}
          >
            <Form.Field required error={this.state.isHitSave && this.isFieldError('note')}>
              <Form.TextArea
                rows={5}
                placeholder={messages.addNote}
                name='note'
                value={noteInfo.note}
                onChange={this.handleChange}
              />
            </Form.Field>
            <Form.Field required error={this.state.isHitSave && this.isFieldError('category')}>
              <label>{messages.category}</label>
              <Form.Select
                options={contactNotes}
                placeholder={messages.category}
                name='category'
                value={noteInfo.category}
                onChange={(e, target) => this.handleChange({ target: target })}
              />
            </Form.Field>
            <Form.Field className={classes.actionGroup}>
              <Button onClick={onClose}>
                {messages.cancel}
              </Button>
              <Button
                type='submit'
                color='green'
                disabled={isequal(this.props.noteInfo, noteInfo) && noteInfo._id}
              >
                {
                  noteInfo._id ? messages.update : messages.create
                }
              </Button>
            </Form.Field>
          </Form>
        </Modal.Content>
      </Modal>
    )
  }
}

NoteInfoModal.propTypes = {
  isOpen: PropTypes.bool.isRequired,
  onClose: PropTypes.func.isRequired,
  noteInfo: PropTypes.shape({}).isRequired,
  selectedContactId: PropTypes.string.isRequired,
};

NoteInfoModal.contextType = AppContext;

export default injectSheet(ModalStyleSheet)(NoteInfoModal);