import React from 'react';
import { Loader, List, Button, Icon, Pagination, Input } from 'semantic-ui-react';
import injectSheet from "react-jss";

import ReduxStatus from "../../../../Common/Constants/ReduxStatus";
import stylesheet from "./stylesheet";
import AppContext from "../../../../Common/Constants/AppContext";
import moment from "moment/moment";
import NoteInfoModal from './NoteInfoModal';
import ContactNoteActionCreator from "../../../Actions/ContactNoteActionCreator";
import Confirmation from '../../../../Common/Components/Modal/ConfirmModal';
import Utils from "../../../../Common/Utils/Utils";

class Notes extends React.Component {
  constructor() {
    super();
    this.state = {
      toggleEdit: false,
      noteInfo: {},

      selectedDeleteNoteId: '',
      toggleDelete: false,
    }
    this.handleDeleteNote = this.handleDeleteNote.bind(this);
    this.handlePaginationChange = this.handlePaginationChange.bind(this);
    this.onSearchFilterChange = this.onSearchFilterChange.bind(this);
  }

  componentDidMount() {
    const { dispatch } = this.context;
    const { selectedContact } = this.props;
    const filter = {
      contact: selectedContact._id,
    }
    dispatch(ContactNoteActionCreator.getContactNotes(1, filter));
  }

  handlePaginationChange(e, { activePage }) {
    const { dispatch } = this.context;
    const { contactNotes: { filter } } = this.props;
    dispatch(ContactNoteActionCreator.getContactNotes(activePage, filter))
  }

  onSearchFilterChange(e, { value }) {
    const { dispatch } = this.context;
    const { contactNotes } = this.props;
    const newFilter = { ...contactNotes.filter };
    if (value) {
      newFilter.note = { "$regex": value, "$options": "i" };
    } else {
      newFilter.note = null;
    }
    dispatch(ContactNoteActionCreator.getContactNotes(1, newFilter))
  }

  handleDeleteNote() {
    const { dispatch } = this.context;
    dispatch(ContactNoteActionCreator.deleteContactNotes(this.state.selectedDeleteNoteId));
    this.setState({
      selectedDeleteNoteId: '',
      toggleDelete: false,
    })
  }
  
  onTogglePin = (note) => {
    const { dispatch } = this.context;
    dispatch(ContactNoteActionCreator.saveContactNotes({...note, sticky: !note.sticky}));
  }

  render() {
    const { intl: { messages }, currentUser } = this.context;
    const { classes, selectedContact, contactNotes: { data, status, activePage, totalPage } } = this.props;
    return (
      <div className={classes.contactOverviewNote}>
        {
          this.state.toggleEdit &&
          <NoteInfoModal
            isOpen={this.state.toggleEdit}
            onClose={() => this.setState({ toggleEdit: false })}
            noteInfo={this.state.noteInfo}
          />
        }
        {
          this.state.toggleDelete &&
          <Confirmation
            isOpen={true}
            onClose={() => this.setState({ toggleDelete: false })}
            onConfirm={this.handleDeleteNote}
            content={{
              mainText: messages.deleteText.replace('{item}', 'this note'),
              description: messages.messageConfirm.replace('{name}',
                `${currentUser.first_name}`)
            }}
            title={messages.deleteNote}
            cancelText={messages.keepThisNote}
            confirmText={messages.delete}
          />
        }
        <div className='contact-note-header'>
          <Input
            icon='search'
            iconPosition='left'
            placeholder='Search note...'
            onChange={this.onSearchFilterChange}
          />
          <Button
            icon
            labelPosition='right'
            color='green'
            className='add-note'
            onClick={() => this.setState({
              toggleEdit: true,
              noteInfo: {
                contact: selectedContact._id,
                author: currentUser._id,
              }
            })}
          >
            {messages.addNote}
            <Icon name='right add' circular inverted />
          </Button>
        </div>
        <List selection celled>
          {
            data.map((note) => (
              <List.Item
                key={note._id}
              >
                <List.Content>
                  <div className='date-add'>
                    {moment(new Date(note.created_at)).format('DD MMM YYYY')}
                  </div>
                  <div className={`note-content ${note.sticky ? 'pinned' : ''}`}>
                    <Icon onClick={() => this.onTogglePin(note)} name="pin" className="pin" size="large" />
                    <div className='note'>{note.note}</div>
                    <div className='author'>Added by <span>{Utils.combinePersonName(note.author)}</span></div>
                    <div className='category'>{messages[note.category]}</div>
                    <div className='item-action'>
                      <div
                        onClick={(e) => {
                          e.stopPropagation();
                          this.setState({
                            selectedDeleteNoteId: note._id,
                            toggleDelete: true,
                          })
                        }}
                      >
                        {messages.delete}
                      </div>
                      <div
                        onClick={(e) => {
                          e.stopPropagation();

                          this.setState({
                            toggleEdit: true,
                            noteInfo: {
                              ...note,
                              contact: selectedContact._id,
                              author: currentUser._id,
                            }
                          })
                        }}
                      >
                        {messages.edit}
                      </div>
                    </div>
                  </div>
                </List.Content>
              </List.Item>
            ))
          }
        </List>
        {
          data.length > 0 && totalPage > 1 &&
          <Pagination
            activePage={activePage}
            totalPages={totalPage}
            onPageChange={this.handlePaginationChange}
          />
        }
        {
          status === ReduxStatus.loading &&
          <Loader active />
        }
      </div>
    )
  }
}

Notes.contextType = AppContext;

export default injectSheet(stylesheet)(Notes);