import React from "react";
import { connect } from "react-redux";
import { Route } from 'react-router-dom';

import PageTitle from '../Common/Components/PageTitle';
import PageNavigationMenu from '../Common/Components/PageNavigationMenu';
import AppContext from "../Common/Constants/AppContext";
import AllContact from "./Components/ContactList/AllContact";
import VolunteersContact from "./Components/ContactList/VolunteersContact";
import ContactAdvancedFilter from "./Components/ContactList/ContactAdvancedFilter/ContactAdvancedFilter";
import SettingsActionCreator from "../Settings/SettingsActionCreator";

class Contact extends React.Component {

  componentDidMount() {
    const {history, dispatch} = this.props;
    dispatch(SettingsActionCreator.getContactTitle())
    if (history.location.pathname === '/') {
      history.replace('/contacts/all');
    }
  }

  render() {
    const { intl: { messages } } = this.context;
    const {
      match,
      history,
      contacts: { contactList, contactVolunteerList, contactFilterSegmentList, uploadContactList },
      criteria: { criteriaList },
      account: { accountList }
    } = this.props;
    const menuItems = [
      {
        name: 'all',
        text: messages.all,
        url: '/contacts/all',
      },
      {
        name: 'donors',
        text: messages.donors,
        url: '/contacts/donors',
      },
      {
        name: 'members',
        text: messages.members,
        url: '/contacts/members',
      },
      {
        name: 'volunteers',
        text: messages.volunteers,
        url: '/contacts/volunteers',
      },
      {
        name: 'segment',
        text: 'Segment',
        url: '/contacts/advanced-filter',
      }
    ];

    return (
      <div>
        <PageTitle title={messages.contacts} />
        <PageNavigationMenu
          tabs={menuItems}
        />
        <Route exact path={`${match.path}`} render={() => <AllContact contacts={contactList} history={history} type='all' />} />
        <Route path={`${match.path}/all`} render={() => <AllContact uploadContactList={uploadContactList} contacts={contactList} history={history} type='all' />} />
        <Route path={`${match.path}/donors`} render={() => <AllContact contacts={contactList} history={history} type='donor' />} />
        <Route path={`${match.path}/members`} render={() => <AllContact contacts={contactList} history={history} type='membership' />} />
        <Route path={`${match.path}/volunteers`} render={() => <VolunteersContact contacts={contactVolunteerList} history={history} type='volunteer' />} />
        <Route path={`${match.path}/advanced-filter`}
          render={() => (
            <ContactAdvancedFilter
              contacts={contactFilterSegmentList}
              history={history}
              criteriaList={criteriaList}
              accountList={accountList}
            />
          )} />
      </div>
    );
  }
}

const mapStateToProps = ({ contacts, criteria, account }) => ({
  contacts,
  criteria,
  account
});

Contact.contextType = AppContext;

export default connect(mapStateToProps)(Contact);
