import React from "react";
import { connect } from "react-redux";
import { Route } from 'react-router-dom';

import PageTitle from '../Common/Components/PageTitle';
import PageNavigationMenu from '../Common/Components/PageNavigationMenu';
import AppContext from "../Common/Constants/AppContext";
import ContactActionCreator from "./Actions/ContactActionCreator";
import ContactDetailProfile from "./Components/ContactDetailProfile/ContactDetailProfile";
import ContactDetailVolunteer from "./Components/ContactDetailVolunteer/ContactDetailVolunteer";
import ContactOverview from "./Components/ContactOverview/ContactOverview";
import ContactMembership from "./Components/ContactMembership/ContactMembership";
import ContactDonations from "./Components/ContactDonations/ContactDonations";
import SettingsActionCreator from "../Settings/SettingsActionCreator";

class ContactDetail extends React.Component {
  componentDidMount() {
    const { dispatch } = this.context;
    const { match: { params: { id } } } = this.props;
    dispatch(SettingsActionCreator.getContactTitle())
    dispatch(ContactActionCreator.getContactById(id));
  }

  componentWillUnmount() {
    const { dispatch } = this.context;
    dispatch(ContactActionCreator.clearSelectedContact());
  }

  render() {
    const { intl: { messages } } = this.context;
    const { match, contacts, history } = this.props;
    const { selectedContactDetail, 
      contactNotes, 
      contactTasks, 
      contactActivities, 
      contactSchedule, 
      contactMembershipOrders, 
      contactMemberships, 
      contactOnceOffDonationOrders, 
      contactRecurringDonationOrders,
      donationSummaryDetail,
      contactMembershipPayments,
      contactDonationPayments,
      donationTabIndex
     } = contacts;
    const menuItems = [
      {
        name: 'overview',
        text: messages.overview,
        url: `${match.url}/overview`,
      },
      {
        name: 'detail',
        text: messages.detail,
        url: `${match.url}/detail`,
      },
      {
        name: 'volunteers',
        text: messages.volunteering,
        url: `${match.url}/volunteering`,
      },
      {
        name: 'membership',
        text: messages.memberships,
        url: `${match.url}/membership`,
      },
      {
        name: 'donations',
        text: messages.donations,
        url: `${match.url}/donations`,
      },
    ];

    const { selectedContact } = selectedContactDetail;

    return (
      <div>
        <PageTitle
          title={!selectedContact._id ? messages.contactProfile :
            `${selectedContact.first_name} ${selectedContact.last_name}`
          }
        />
        <PageNavigationMenu
          tabs={menuItems}
        />
        <Route exact path={`${match.path}`}
               render={
                 () => <ContactOverview
                   selectedContactDetail={selectedContactDetail}
                   contactNotes={contactNotes}
                   contactTasks={contactTasks}
                   contactActivities={contactActivities}
                   history={history}
                 />
               }
        />
        <Route exact path={`${match.path}/overview`}
               render={
                 () => <ContactOverview
                   selectedContactDetail={selectedContactDetail}
                   contactNotes={contactNotes}
                   contactTasks={contactTasks}
                   contactActivities={contactActivities}
                   history={history}
                 />
               } />
        <Route path={`${match.path}/detail`}
               render={
                 () => <ContactDetailProfile
                   selectedContactDetail={selectedContactDetail}
                   history={history}
                 />
               } />
        <Route path={`${match.path}/volunteering`}
               render={
                 () => <ContactDetailVolunteer
                   selectedContactDetail={selectedContactDetail}
                   contactSchedule={contactSchedule}
                   history={history} />
               } />
        <Route
          path={`${match.path}/membership`}
          render={() => (
            <ContactMembership
              selectedContactDetail={selectedContactDetail}
              contactMembershipOrders={contactMembershipOrders}
              contactMemberships={contactMemberships}
              contactMembershipPayments={contactMembershipPayments}
              history={history}
            />
          )}
        />
        <Route
          path={`${match.path}/donations`}
          render={() => (
            <ContactDonations
              selectedContactDetail={selectedContactDetail}
              contactOnceOffDonationOrders={contactOnceOffDonationOrders}
              contactRecurringDonationOrders={contactRecurringDonationOrders}
              donationSummaryDetail={donationSummaryDetail}
              contactDonationPayments={contactDonationPayments}
              history={history}
              donationTabIndex={donationTabIndex}
            />
          )}
        />
      </div>
    );
  }
}

const
  mapStateToProps = ({ contacts }) => ({
    contacts,
  });

ContactDetail.contextType = AppContext;

export default connect(mapStateToProps)(ContactDetail);
