import get from 'lodash/get'

const buildSearchContactQuery = (filter) => {
  const newFilter = {};
  if(filter.type) {
    newFilter.type = filter.type;
  }
  if(filter['volunteer.roles']) {
    newFilter['volunteer.roles'] = filter['volunteer.roles'];
  }
  if (filter.searchText) {
    const searchKey = get(filter, 'searchKey', '');
    const searchText = get(filter, 'searchText', '');

    if (searchKey === 'name')
      newFilter["$text"] = {"$search": searchText};
    else if (searchKey === 'phone')
      newFilter["$or"] = [
        {home_number: {$regex: searchText}},
        {mobile_number: {$regex: searchText}},
      ]
    else if (searchKey === 'email')
      newFilter["emails.email"] = { $regex: searchText, $options: 'i' }
    else
      newFilter[searchKey] = searchText;
  }
  if(filter.selectedState) {
    newFilter["$or"] = [{ "home_address.state": filter.selectedState }, { "work_address.state": filter.selectedState }, { "postal_address.state": filter.selectedState }];
  }
  if (filter.selectedVotingDistrict && filter.selectedVotingDistrict._id) {
    newFilter.voting_district = filter.selectedVotingDistrict._id;
  }
  if(filter.volunteer) {
    newFilter.volunteer = {
      "$exists": true
    };
    if(filter['volunteer.status']) {
      newFilter['volunteer.status'] = filter['volunteer.status']
    } else {
      newFilter['volunteer.status'] = { "$ne": "inactive" }
    }
  }
  if(filter['payments.payment_type']) {
    newFilter['payments.payment_type'] = filter['payments.payment_type'];
  }
  if(filter['payments.membership_class']) {
    newFilter['payments.membership_class'] = filter['payments.membership_class'];
  }
  console.log(newFilter)
  return newFilter;
};


export default {
  buildSearchContactQuery,
}
