import { put, call, takeLatest, delay } from "redux-saga/effects";
import { get } from '../../Common/Utils/AxiosClient';
import Enum from '../../Common/Constants/Enum';
import Utils from "../../Common/Utils/Utils";
import {
  GET_CONTACT_ACTIVITIES_SUCCESS,
  GET_CONTACT_ACTIVITIES_FAILED,
  GET_CONTACT_ACTIVITIES,
} from "../Actions/ContactActivitiesActionCreator";

function* watchGetContactActivities({ payload: { activePage, filter } }) {
  try {
    yield delay(300);
    const newFilter = Utils.cleanObject(filter);
    const skip = (activePage - 1) * Enum.ActivitiesPerPage;
    const url = `/audit-logs`;
    const params = {
      filter: newFilter,
      limit: Enum.ActivitiesPerPage,
      skip,
      sort: {'created_at': -1}
    };
    const res = yield call(get, url, params);
    const totalPage = Utils.getTotalPage(res.data.metadata);

    yield put({
      type: GET_CONTACT_ACTIVITIES_SUCCESS,
      payload: {
        activePage,
        filter: filter,
        totalPage,
        data: res.data.data,
      }
    });
  } catch (e) {
    yield put({
      type: GET_CONTACT_ACTIVITIES_FAILED,
      payload: {
        ...e
      },
    });
  }
}

function* ContactActivitiesSaga() {
  yield takeLatest(GET_CONTACT_ACTIVITIES, watchGetContactActivities);
}

export default ContactActivitiesSaga;
