import { takeEvery, put, call, select, takeLatest, delay } from "redux-saga/effects";
import { deleteClient, get, patch, post } from '../../Common/Utils/AxiosClient';
import Enum from '../../Common/Constants/Enum';
import Utils from "../../Common/Utils/Utils";
import {
  CREATE_CONTACT_NOTES,
  GET_CONTACT_NOTES_SUCCESS,
  GET_CONTACT_NOTES_FAILED,
  DELETE_CONTACT_NOTES, GET_CONTACT_NOTES,
  SAVE_CONTACT_NOTES
} from "../Actions/ContactNoteActionCreator";

function* watchGetContactNotes({ payload: { activePage, filter} }) {
  try {
    yield delay(300);
    const sort = {sticky: -1, modified_at: -1}
    const newFilter = Utils.cleanObject(filter);
    const skip = (activePage - 1) * Enum.NotePerPage;
    const url = `/notes`;
    const params = {
      filter: newFilter,
      limit: Enum.NotePerPage,
      skip,
      populate: { "path": "author" },
      sort
    };
    const res = yield call(get, url, params);
    const totalPage = Utils.getTotalPage(res.data.metadata);

    yield put({
      type: GET_CONTACT_NOTES_SUCCESS,
      payload: {
        activePage,
        filter: filter,
        totalPage,
        data: res.data.data,
      }
    });
  } catch (e) {
    yield put({
      type: GET_CONTACT_NOTES_FAILED,
      payload: {
        ...e
      },
    });
  }
}

function* watchCreateContactNotes({ payload: { note } }) {
  try {
    const url = '/notes';
    yield call(post, url, note);
    const contactNotesList = yield select(state => state.contacts.contactNotes);
    yield put({
      type: GET_CONTACT_NOTES,
      payload: {
        activePage: contactNotesList.activePage,
        filter: contactNotesList.filter,
      }
    });
  } catch (e) {
  }
}

function* watchSaveContactNotes({ payload: { note } }) {
  try {
    const url = `/notes/${note._id}`;
    yield call(patch, url, note);
    const contactNotesList = yield select(state => state.contacts.contactNotes);
    yield put({
      type: GET_CONTACT_NOTES,
      payload: {
        activePage: contactNotesList.activePage,
        filter: contactNotesList.filter,
      }
    });
  } catch (e) {
  }
}

function* watchDeleteContactNotes({ payload: { id } }) {
  try {
    const url = `/notes/${id}`;
    yield call(deleteClient, url);
    const contactNotesList = yield select(state => state.contacts.contactNotes);
    yield put({
      type: GET_CONTACT_NOTES,
      payload: {
        activePage: contactNotesList.activePage,
        filter: contactNotesList.filter,
      }
    });
  } catch (e) {
  }
}

function* ContactNoteSaga() {
  yield takeLatest(GET_CONTACT_NOTES, watchGetContactNotes);
  yield takeEvery(CREATE_CONTACT_NOTES, watchCreateContactNotes);
  yield takeEvery(SAVE_CONTACT_NOTES, watchSaveContactNotes);
  yield takeEvery(DELETE_CONTACT_NOTES, watchDeleteContactNotes);
}

export default ContactNoteSaga;
