import { takeEvery, put, call, select, takeLatest } from "redux-saga/effects"
import { toast } from "react-toastify"
import { get, patch, post } from '../../Common/Utils/AxiosClient'
import Enum from '../../Common/Constants/Enum'
import Utils from "../../Common/Utils/Utils"

import {
  GET_CONTACT_MEMBERSHIPS, GET_CONTACT_MEMBERSHIPS_SUCCESS, GET_CONTACT_MEMBERSHIPS_FAILURE,
  GET_CONTACT_MEMBERSHIP_ORDERS, GET_CONTACT_MEMBERSHIP_ORDERS_SUCCESS, GET_CONTACT_MEMBERSHIP_ORDERS_FAILURE,
  CREATE_CONTACT_MEMBERSHIP_ORDER,
  GET_CONTACT_ONCE_OFF_DONATION_ORDERS, GET_CONTACT_ONCE_OFF_DONATION_ORDERS_SUCCESS, GET_CONTACT_ONCE_OFF_DONATION_ORDERS_FAILURE,
  GET_CONTACT_RECURRING_DONATION_ORDERS, GET_CONTACT_RECURRING_DONATION_ORDERS_SUCCESS, GET_CONTACT_RECURRING_DONATION_ORDERS_FAILURE,
  CREATE_CONTACT_DONATION_ORDER,
  GET_CONTACT_DONATION_SUMMARY, GET_CONTACT_DONATION_SUMMARY_SUCCESS, GET_CONTACT_DONATION_SUMMARY_FAILURE,
  GET_CONTACT_MEMBERSHIP_PAYMENTS, GET_CONTACT_MEMBERSHIP_PAYMENTS_SUCCESS, GET_CONTACT_MEMBERSHIP_PAYMENTS_FAILURE,
  GET_CONTACT_DONATION_PAYMENTS, GET_CONTACT_DONATION_PAYMENTS_SUCCESS, GET_CONTACT_DONATION_PAYMENTS_FAILURE,
  CANCEL_ORDER,
  RENEW_ORDER,
  UPDATE_PAYMENT_SOURCE
} from "../Actions/ContactOrderActionCreator"

import { GET_CONTACT_BY_ID } from '../Actions/ContactActionCreator'

function* watchGetContactMembershipOrders({ payload: { activePage, filter } }) {
  try {
    const newFilter = Utils.cleanObject(filter);
    const skip = (activePage - 1) * Enum.PerPage;
    const url = `/orders`;
    const params = {
      filter: newFilter,
      limit: Enum.PerPage,
      skip,
      populate: { "path": "membership" },
      sort: {"created_at" : -1 }
    };
    const res = yield call(get, url, params);
    const totalPage = Utils.getTotalPage(res.data.metadata);

    yield put({
      type: GET_CONTACT_MEMBERSHIP_ORDERS_SUCCESS,
      payload: {
        activePage,
        filter: filter,
        totalPage,
        data: res.data.data,
      }
    });
  } catch (e) {
    yield put({
      type: GET_CONTACT_MEMBERSHIP_ORDERS_FAILURE,
      payload: {
        ...e
      },
    });
  }
}

function* watchCreateContactMembershipOrder({ payload: { order } }) {
  const { messages } = yield select(state => state.intl);
  try {
    const url = '/orders';
    yield call(post, url, order);
    const contactOrderList = yield select(state => state.contacts.contactMembershipOrders);
    yield put({
      type: GET_CONTACT_MEMBERSHIP_ORDERS,
      payload: {
        activePage: contactOrderList.activePage,
        filter: contactOrderList.filter,
      }
    });
    yield put({
      type: GET_CONTACT_BY_ID,
      payload: {
        id: order.contact,
        hideLoading: true
      }
    })
    toast.success(messages.createMembershipSuccess);
  } catch ({response: {data: {error}}}) {
    let message = messages.createMembershipFailure;
    if(error.type === Enum.ErrorTypes.duplicate) {
      message = messages.createMembershipDuplicate;
    }
    if(error.type === Enum.ErrorTypes.payment) {
      message = error.message;
    }
    toast.error(message);
  }
}

function* watchGetContactOnceOffDonationOrders({ payload: { activePage, filter } }) {
  try {
    const newFilter = Utils.cleanObject(filter);
    const skip = (activePage - 1) * Enum.PerPage;
    const url = `/orders`;
    const params = {
      filter: newFilter,
      limit: Enum.PerPage,
      skip,
      sort: {"created_at" : -1 }
    };
    const res = yield call(get, url, params);
    const totalPage = Utils.getTotalPage(res.data.metadata);

    yield put({
      type: GET_CONTACT_ONCE_OFF_DONATION_ORDERS_SUCCESS,
      payload: {
        activePage,
        filter: filter,
        totalPage,
        data: res.data.data,
      }
    });
  } catch (e) {
    yield put({
      type: GET_CONTACT_ONCE_OFF_DONATION_ORDERS_FAILURE,
      payload: {
        ...e
      },
    });
  }
}

function* watchGetContactRecurringDonationOrders({ payload: { activePage, filter } }) {
  try {
    const newFilter = Utils.cleanObject(filter);
    const skip = (activePage - 1) * Enum.PerPage;
    const url = `/orders`;
    const params = {
      filter: newFilter,
      limit: Enum.PerPage,
      skip,
      sort: {"created_at" : -1 }
    };
    const res = yield call(get, url, params);
    const totalPage = Utils.getTotalPage(res.data.metadata);

    yield put({
      type: GET_CONTACT_RECURRING_DONATION_ORDERS_SUCCESS,
      payload: {
        activePage,
        filter: filter,
        totalPage,
        data: res.data.data,
      }
    });
  } catch (e) {
    yield put({
      type: GET_CONTACT_RECURRING_DONATION_ORDERS_FAILURE,
      payload: {
        ...e
      },
    });
  }
}

function* watchCreateContactDonationOrder({ payload: { order } }) {
  const { messages } = yield select(state => state.intl);
  try {
    const url = '/orders';
    yield call(post, url, order);
    const contactOrderList = yield select(state => 
      order.donation.donation_type === 'once-off-donation' ? 
      state.contacts.contactOnceOffDonationOrders : 
      state.contacts.contactRecurringDonationOrders);
    yield put({
      type: order.donation.donation_type === 'once-off-donation' ? GET_CONTACT_ONCE_OFF_DONATION_ORDERS : GET_CONTACT_RECURRING_DONATION_ORDERS,
      payload: {
        activePage: contactOrderList.activePage,
        filter: contactOrderList.filter,
      }
    });
    yield put({
      type: GET_CONTACT_DONATION_SUMMARY,
      payload: {
        contactId: order.contact,
      }
    });
    yield put({
      type: GET_CONTACT_BY_ID,
      payload: {
        id: order.contact,
        hideLoading: true
      }
    })
    toast.success(messages.createDonationSuccess);
  } catch ({response: {data: {error}}}) {
    let message = messages.createDonationFailure;
    if(error.type === Enum.ErrorTypes.duplicate) {
      message = messages.createDonationDuplicate;
    }
    if(error.type === Enum.ErrorTypes.payment) {
      message = error.message;
    }
    toast.error(message);
  }
}

function* watchGetContactMemberships({ payload: { activePage, filter } }) {
  try {
    const newFilter = Utils.cleanObject(filter);
    const skip = (activePage - 1) * Enum.PerPage;
    const url = `/memberships`;
    const params = {
      filter: newFilter,
      limit: Enum.PerPage,
      skip
    };
    const res = yield call(get, url, params);
    const totalPage = Utils.getTotalPage(res.data.metadata);

    yield put({
      type: GET_CONTACT_MEMBERSHIPS_SUCCESS,
      payload: {
        activePage,
        filter: filter,
        totalPage,
        data: res.data.data,
      }
    });
  } catch (e) {
    yield put({
      type: GET_CONTACT_MEMBERSHIPS_FAILURE,
      payload: {
        ...e
      },
    });
  }
}

function* watchGetContactSummary({ payload: { contactId } }) {
  const { messages } = yield select(state => state.intl);
  try {
    const url = `/donations-summary?contact=${contactId}`;
    const res = yield call(get, url);
    yield put({ type: GET_CONTACT_DONATION_SUMMARY_SUCCESS, payload: res.data.data });
  } catch (e) {
    yield put({
      type: GET_CONTACT_DONATION_SUMMARY_FAILURE,
      payload: {
        ...e
      },
    });
    toast.error(messages['contact.donation.summary.get.error']);
  }
}

function* watchGetContactMembershipPayments({ payload: { activePage, filter } }) {
  try {
    const newFilter = Utils.cleanObject(filter);
    const skip = (activePage - 1) * Enum.PerPage;
    const url = `/payments`;
    const params = {
      filter: newFilter,
      limit: Enum.PerPage,
      skip,
      sort: {"created_at" : -1 }
    };
    const res = yield call(get, url, params);
    const totalPage = Utils.getTotalPage(res.data.metadata);

    yield put({
      type: GET_CONTACT_MEMBERSHIP_PAYMENTS_SUCCESS,
      payload: {
        activePage,
        filter: filter,
        totalPage,
        data: res.data.data,
      }
    });
  } catch (e) {
    yield put({
      type: GET_CONTACT_MEMBERSHIP_PAYMENTS_FAILURE,
      payload: {
        ...e
      },
    });
  }
}

function* watchGetContactDonationPayments({ payload: { activePage, filter } }) {
  try {
    const newFilter = Utils.cleanObject(filter);
    const skip = (activePage - 1) * Enum.PerPage;
    const url = `/payments`;
    const params = {
      filter: newFilter,
      limit: Enum.PerPage,
      skip,
      sort: {"created_at" : -1 }
    };
    const res = yield call(get, url, params);
    const totalPage = Utils.getTotalPage(res.data.metadata);

    yield put({
      type: GET_CONTACT_DONATION_PAYMENTS_SUCCESS,
      payload: {
        activePage,
        filter: filter,
        totalPage,
        data: res.data.data,
      }
    });
  } catch (e) {
    yield put({
      type: GET_CONTACT_DONATION_PAYMENTS_FAILURE,
      payload: {
        ...e
      },
    });
  }
}

function* watchCancelOrder({ payload: { orderId, type } }) {
  try {
    const url = `/cancel-order/${orderId}`;
    yield call(post, url);
    
    if(type === 'membership') {
      const contactOrderList = yield select(state => state.contacts.contactMembershipOrders);
      yield put({
        type: GET_CONTACT_MEMBERSHIP_ORDERS,
        payload: {
          activePage: contactOrderList.activePage,
          filter: contactOrderList.filter,
        }
      });
    }

    if(type === 'donation') {
      const contactOrderList = yield select(state => state.contacts.contactRecurringDonationOrders);
      yield put({
        type: GET_CONTACT_RECURRING_DONATION_ORDERS,
        payload: {
          activePage: contactOrderList.activePage,
          filter: contactOrderList.filter,
        }
      });
    }

  } catch (e) {
  }
}


function* watchRenewOrder({ payload: { orderId, startDate, expiryDate, type } }) {
  const { messages } = yield select(state => state.intl);
  try {
    const url = `/renew-order/${orderId}`;
    yield call(post, url, {order_id: orderId, start_date: startDate, expiry_date: expiryDate });
    if(type === 'membership') {
      const contactOrderList = yield select(state => state.contacts.contactMembershipOrders);
      yield put({
        type: GET_CONTACT_MEMBERSHIP_ORDERS,
        payload: {
          activePage: contactOrderList.activePage,
          filter: contactOrderList.filter,
        }
      });
    }

    if(type === 'donation') {
      const contactOrderList = yield select(state => state.contacts.contactRecurringDonationOrders);
      yield put({
        type: GET_CONTACT_RECURRING_DONATION_ORDERS,
        payload: {
          activePage: contactOrderList.activePage,
          filter: contactOrderList.filter,
        }
      });
    }
    toast.success(messages.renewMembershipSuccess);
  } catch (e) {
    toast.error(messages.renewMembershipError);
  }
}

function* watchUpdatePaymentSource({ payload: { order_id, source_id } }) {
  const { messages } = yield select(state => state.intl);
  try {
    const url = `/orders/${order_id}/stripe-sources`
    yield call(patch, url, { source_id });
    const contactOrderList = yield select(state => state.contacts.contactRecurringDonationOrders);
    yield put({
      type: GET_CONTACT_RECURRING_DONATION_ORDERS,
      payload: {
        activePage: contactOrderList.activePage,
        filter: contactOrderList.filter,
      }
    });

    const { selectedContact } = yield select(state => state.contacts.selectedContactDetail);
    yield put({
      type: GET_CONTACT_BY_ID,
      payload: {
        id: selectedContact._id,
        hideLoading: true
      }
    })
    toast.success(messages['contact.donations.update_source.success']);
  } catch (e) {
    toast.error(messages['contact.donations.update_source.failure']);
  }
}

function* ContactOrderSaga() {
  yield takeLatest(GET_CONTACT_MEMBERSHIPS, watchGetContactMemberships)

  yield takeLatest(GET_CONTACT_MEMBERSHIP_ORDERS, watchGetContactMembershipOrders)
  yield takeEvery(CREATE_CONTACT_MEMBERSHIP_ORDER, watchCreateContactMembershipOrder)

  yield takeLatest(GET_CONTACT_ONCE_OFF_DONATION_ORDERS, watchGetContactOnceOffDonationOrders)
  yield takeLatest(GET_CONTACT_RECURRING_DONATION_ORDERS, watchGetContactRecurringDonationOrders)

  yield takeEvery(CREATE_CONTACT_DONATION_ORDER, watchCreateContactDonationOrder)

  yield takeLatest(GET_CONTACT_DONATION_SUMMARY, watchGetContactSummary)

  yield takeLatest(GET_CONTACT_MEMBERSHIP_PAYMENTS, watchGetContactMembershipPayments)

  yield takeLatest(GET_CONTACT_DONATION_PAYMENTS, watchGetContactDonationPayments)

  yield takeEvery(CANCEL_ORDER, watchCancelOrder)

  yield takeEvery(RENEW_ORDER, watchRenewOrder)

  yield takeEvery(UPDATE_PAYMENT_SOURCE, watchUpdatePaymentSource)
}

export default ContactOrderSaga;
