import { put, call, takeLatest } from "redux-saga/effects";
import { get } from '../../Common/Utils/AxiosClient';
import Enum from '../../Common/Constants/Enum';
import Utils from "../../Common/Utils/Utils";
import {
  GET_CONTACT_SCHEDULE,
  GET_CONTACT_SCHEDULE_FAILED,
  GET_CONTACT_SCHEDULE_SUCCESS
} from "../Actions/ContactScheduleActionCreator";

function* watchGetContactSchedules({ payload: { activePage, filter } }) {
  try {
    const newFilter = Utils.cleanObject(filter);
    const skip = (activePage - 1) * Enum.SchedulePerPage;
    const url = `/schedules`;
    const params = {
      filter: newFilter,
      limit: Enum.SchedulePerPage,
      skip,
      populate: { "path": "location", "populate": [{ "path": "event" }, { "path": "voting_district" }] },
    };
    const res = yield call(get, url, params);
    const totalPage = Utils.getTotalPage(res.data.metadata);

    yield put({
      type: GET_CONTACT_SCHEDULE_SUCCESS,
      payload: {
        activePage,
        filter: filter,
        totalPage,
        data: res.data.data,
      }
    });
  } catch (e) {
    yield put({
      type: GET_CONTACT_SCHEDULE_FAILED,
      payload: {
        ...e
      },
    });
  }
}

function* ContactScheduleSaga() {
  yield takeLatest(GET_CONTACT_SCHEDULE, watchGetContactSchedules);
}

export default ContactScheduleSaga;
