import { takeEvery, put, call, select, takeLatest, delay } from "redux-saga/effects";
import { deleteClient, get, patch, post } from '../../Common/Utils/AxiosClient';
import Enum from '../../Common/Constants/Enum';
import Utils from "../../Common/Utils/Utils";
import {
  CREATE_CONTACT_TASKS,
  GET_CONTACT_TASKS_SUCCESS,
  GET_CONTACT_TASKS_FAILED,
  DELETE_CONTACT_TASKS, GET_CONTACT_TASKS,
  SAVE_CONTACT_TASKS
} from "../Actions/ContactTaskActionCreator";

function* watchGetContactTasks({ payload: { activePage, filter } }) {
  try {
    yield delay(300);
    const newFilter = Utils.cleanObject(filter);
    const skip = (activePage - 1) * Enum.TaskPerPage;
    const url = `/tasks`;
    const params = {
      filter: newFilter,
      limit: Enum.TaskPerPage,
      skip,
      populate: { "path": "author" }
    };
    const res = yield call(get, url, params);
    const totalPage = Utils.getTotalPage(res.data.metadata);

    yield put({
      type: GET_CONTACT_TASKS_SUCCESS,
      payload: {
        activePage,
        filter: filter,
        totalPage,
        data: res.data.data,
      }
    });
  } catch (e) {
    yield put({
      type: GET_CONTACT_TASKS_FAILED,
      payload: {
        ...e
      },
    });
  }
}

function* watchCreateContactTasks({ payload: { task } }) {
  try {
    const url = '/tasks';
    yield call(post, url, task);
    const contactTasksList = yield select(state => state.contacts.contactTasks);
    yield put({
      type: GET_CONTACT_TASKS,
      payload: {
        activePage: contactTasksList.activePage,
        filter: contactTasksList.filter,
      }
    });
  } catch (e) {
  }
}

function* watchSaveContactTasks({ payload: { task } }) {
  try {
    const url = `/tasks/${task._id}`;
    yield call(patch, url, task);
    const contactTasksList = yield select(state => state.contacts.contactTasks);
    yield put({
      type: GET_CONTACT_TASKS,
      payload: {
        activePage: contactTasksList.activePage,
        filter: contactTasksList.filter,
      }
    });
  } catch (e) {
  }
}

function* watchDeleteContactTasks({ payload: { id } }) {
  try {
    const url = `/tasks/${id}`;
    yield call(deleteClient, url);
    const contactTasksList = yield select(state => state.contacts.contactTasks);
    yield put({
      type: GET_CONTACT_TASKS,
      payload: {
        activePage: contactTasksList.activePage,
        filter: contactTasksList.filter,
      }
    });
  } catch (e) {
  }
}

function* ContactTaskSaga() {
  yield takeLatest(GET_CONTACT_TASKS, watchGetContactTasks);
  yield takeEvery(CREATE_CONTACT_TASKS, watchCreateContactTasks);
  yield takeEvery(SAVE_CONTACT_TASKS, watchSaveContactTasks);
  yield takeEvery(DELETE_CONTACT_TASKS, watchDeleteContactTasks);
}

export default ContactTaskSaga;
