import React from "react"
import { Accordion, Table, Icon, Pagination, Loader } from 'semantic-ui-react'
import AppContext from "../../../Common/Constants/AppContext"
import DashboardActionCreator from "../../DashboardActionCreator"
import ReduxStatus from "../../../Common/Constants/ReduxStatus"
import injectsheet from "react-jss"
import stylesheet from './stylesheet'
import _ from 'lodash'
import Utils from "../../../Common/Utils/Utils"

class AccumulatedDonationList extends React.Component {

  constructor() {
    super();
    this.state = {
      isShowAccumulatedDonation: true
    };
    this.handlePaginationChange = this.handlePaginationChange.bind(this);
  }

  componentDidMount() {
    const { dispatch } = this.context;
    dispatch(DashboardActionCreator.getAccumulatedDonations(1));
  }

  handlePaginationChange(e, { activePage }) {
    const { dispatch } = this.context;
    dispatch(DashboardActionCreator.getAccumulatedDonations(activePage));
  }

  render() {
    const { classes, accumulatedDonationList: { data, status, activePage, totalPage } } = this.props
    const { intl: { messages } } = this.context
    return (

      <Accordion fluid className={classes.accumulatedDonationList}>
        <Accordion.Title onClick={() => this.setState({ isShowAccumulatedDonation: !this.state.isShowAccumulatedDonation })}>ACCUMULATED DONATIONS LFY</Accordion.Title>
        <Accordion.Content active={this.state.isShowAccumulatedDonation}>

          {
            status === ReduxStatus.loading &&
            <Loader active />
          }

          <Table singleLine selectable basic='very'>
            <Table.Header>
              <Table.Row className="accumulatedDonation-list-header">
                <Table.HeaderCell>{messages.payee}</Table.HeaderCell>
              </Table.Row>
            </Table.Header>
            <Table.Body>
              {data.map(item => (
                <Table.Row key={item._id}>
                  <Table.Cell>
                    {
                      item ?
                        <a target="_blank" rel="noopener noreferrer"
                          href={`/contact-detail/${item._id}/overview`}>
                          {Utils.combineName(item)}
                        </a> :
                        Utils.combineName(item)
                    }
                  </Table.Cell>
                </Table.Row>
              ))}
            </Table.Body>
          </Table>

          {
            data.length > 0 && totalPage > 1 &&
            <Pagination
              activePage={activePage}
              totalPages={totalPage}
              onPageChange={this.handlePaginationChange}
            />
          }

        </Accordion.Content>
      </Accordion>

    );
  }
}

AccumulatedDonationList.contextType = AppContext
export default injectsheet(stylesheet)(AccumulatedDonationList)
