import React from "react"
import { Accordion, Table, Icon, Pagination, Loader } from 'semantic-ui-react'
import AppContext from "../../../Common/Constants/AppContext"
import DashboardActionCreator from "../../DashboardActionCreator"
import ReduxStatus from "../../../Common/Constants/ReduxStatus"
import injectsheet from "react-jss"
import stylesheet from './stylesheet'
import moment from 'moment'
import _ from 'lodash'
import Utils from "../../../Common/Utils/Utils"

class PaymentList extends React.Component {

  state = {
    isShowFailedPayments: true
  };

  componentDidMount() {
    const { dispatch } = this.context
    dispatch(DashboardActionCreator.getPayments(1, {status: {$in: ['pending', 'failed']}}))
  }

  handlePaginationChange = (e, { activePage }) => {
    const { dispatch } = this.context
    const { taskList: { filter } } = this.props;
    dispatch(DashboardActionCreator.getTasks(activePage, filter))
  }

  handleDeletePayment = (id) => {
    const {dispatch} = this.context
    dispatch(DashboardActionCreator.deletePayment(id))
  }

  render() {
    const { classes, paymentList: { data, status, activePage, totalPage } } = this.props
    const { intl: { messages } } = this.context
    return (
      <Accordion fluid className={classes.paymentList}>
        <Accordion.Title onClick={() => this.setState({isShowFailedPayments: !this.state.isShowFailedPayments})}>FAILED PAYMENTS</Accordion.Title>
        <Accordion.Content active={this.state.isShowFailedPayments}>
          {
            status === ReduxStatus.loading &&
            <Loader active />
          }
          <Table singleLine selectable basic='very'>
            <Table.Header>
              <Table.Row className="payment-list-header">
                {/* <Table.HeaderCell className="computer only">{messages.paymentId}</Table.HeaderCell> */}
                <Table.HeaderCell>{messages.payee}</Table.HeaderCell>
                <Table.HeaderCell>{messages['common.overdue']}</Table.HeaderCell>
                <Table.HeaderCell>{messages.amount}</Table.HeaderCell>
                <Table.HeaderCell>{messages.paymentType}</Table.HeaderCell>
                <Table.HeaderCell>{messages.reference}</Table.HeaderCell>
              </Table.Row>
            </Table.Header>
            <Table.Body>
              {data.map(item => (
                <Table.Row key={item._id}>
                  {/* <Table.Cell>
                    <Link to={`/finance-detail/${item._id}`} target="_blank">
                      {_.padStart(item.payment_id, 5, 0)}
                    </Link>
                  </Table.Cell> */}
                  <Table.Cell>
                    {
                      item.linked_profile ?
                        <a target="_blank" rel="noopener noreferrer"
                          href={`/contact-detail/${item.linked_profile._id}/overview`}>
                          {Utils.combineName(item.linked_profile, messages)}
                        </a> :
                        Utils.combineName(item.payee)
                    }
                  </Table.Cell>
                  <Table.Cell>{item.processed_date && moment(new Date(item.processed_date)).fromNow(true)}</Table.Cell>
                  <Table.Cell>${item.amount}</Table.Cell>
                  <Table.Cell>{messages[item.payment_type]}</Table.Cell>
                  <Table.Cell>{item.reference ? _.padStart(item.reference, 5, 0) : '-'}</Table.Cell>
                  <Table.Cell> <Icon name='delete' onClick={() => this.handleDeletePayment(item._id)}> </Icon> </Table.Cell>
                </Table.Row>
              ))}
            </Table.Body>
          </Table>
          {
            data.length > 0 && totalPage > 1 &&
            <Pagination
              activePage={activePage}
              totalPages={totalPage}
              onPageChange={this.handlePaginationChange}
            />
          }
        </Accordion.Content>
      </Accordion>
    );
  }
}

PaymentList.contextType = AppContext
export default injectsheet(stylesheet)(PaymentList)
