import React from "react"
import { Grid } from 'semantic-ui-react'
import { connect } from "react-redux"
import colors from "../Common/Constants/color"
import AppContext from "../Common/Constants/AppContext"
import PageTitle from '../Common/Components/PageTitle'
import PaymentList from '../Dashboard/Components/Payment/PaymentList'
import TaskList from '../Dashboard/Components/Task/TaskList'
import AccumulatedDonationList from "./Components/AccumulatedDonation/AccumulatedDonationList"

const styles = {
  dashboardContainer: {
    padding: '2em',
    backgroundColor: colors.primaryWhite2,
    height: '100%'
  }
}

class Dashboard extends React.Component {

  state = {
    isShowFailedPayments: true,
    isShowIncompleteTasks: true
  };

  render() {
    const { intl: { messages } } = this.context;
    const {
      dashboard: { taskList, paymentList, accumulatedDonationList },
      account: { accountList }
    } = this.props;

    return (
      <div style={{ height: '100%' }}>
        <PageTitle title={messages.dashboard} />
        <div style={styles.dashboardContainer}>
          <Grid stackable columns={2}>
            <Grid.Column stackable row={2}>
              <Grid.Row>
                <PaymentList paymentList={paymentList} accountList={accountList} />
              </Grid.Row>
              <Grid.Row>
                <AccumulatedDonationList accumulatedDonationList={accumulatedDonationList} accountList={accountList} />
              </Grid.Row>
            </Grid.Column>
            <Grid.Column>
              <TaskList taskList={taskList} accountList={accountList} />
            </Grid.Column>
          </Grid>
        </div>
      </div>
    );
  }
}

const mapStateToProps = ({ dashboard, account, fileUploads }) => ({
  dashboard,
  account,
  fileUploads
});

Dashboard.contextType = AppContext

export default connect(mapStateToProps)(Dashboard)
