import {
  GET_DASHBOARD_TASKS, GET_DASHBOARD_TASKS_SUCCESS, GET_DASHBOARD_TASKS_FAILURE,
  SAVE_DASHBOARD_TASK, SAVE_DASHBOARD_TASKS_SUCCESS, SAVE_DASHBOARD_TASKS_FAILURE,
  GET_DASHBOARD_PAYMENTS, GET_DASHBOARD_PAYMENTS_SUCCESS, GET_DASHBOARD_PAYMENTS_FAILURE,
  GET_ACCUMULATED_DONATIONS, GET_ACCUMULATED_DONATIONS_SUCCESS, GET_ACCUMULATED_DONATIONS_FAILURE,
} from "./DashboardActionCreator";

import ReduxStatus from '../Common/Constants/ReduxStatus';

const initialState = {
  taskList: {
    status: ReduxStatus.empty,
    activePage: 1,
    totalPage: 1,
    totalRecord: 0,
    data: [],
    message: "",
    filter: {},
  },
  paymentList: {
    status: ReduxStatus.empty,
    activePage: 1,
    totalPage: 1,
    totalRecord: 0,
    data: [],
    message: "",
    filter: {},
  },
  accumulatedDonationList: {
    status: ReduxStatus.empty,
    activePage: 1,
    totalPage: 1,
    totalRecord: 0,
    data: [],
    message: "",
  },
};

const actionsMap = {
  // Async action
  [GET_DASHBOARD_TASKS]: (state, payload) => {
    return {
      ...state,
      taskList: {
        ...state.taskList,
        status: ReduxStatus.loading,
        message: payload.message
      }
    };
  },
  [GET_DASHBOARD_TASKS_SUCCESS]: (state, { activePage, totalPage, totalRecord, data, filter }) => {
    return {
      ...state,
      taskList: {
        ...state.taskList,
        activePage,
        totalPage,
        totalRecord,
        data,
        status: ReduxStatus.loaded,
        message: "",
        filter,
      }
    };
  },
  [GET_DASHBOARD_TASKS_FAILURE]: (state, payload) => {
    return {
      ...state,
      taskList: {
        ...state.taskList,
        status: ReduxStatus.loadFailed,
        message: payload.message,
      }
    };
  },

  [SAVE_DASHBOARD_TASK]: (state) => {
    return {
      ...state,
      taskList: {
        ...state.taskList,
        status: ReduxStatus.loading
      }
    }
  },
  [SAVE_DASHBOARD_TASKS_SUCCESS]: (state) => {
    return {
      ...state,
      taskList: {
        ...state.taskList,
        status: ReduxStatus.loaded,
      }
    };
  },
  [SAVE_DASHBOARD_TASKS_FAILURE]: (state) => {
    return {
      ...state,
      taskList: {
        ...state.taskList,
        status: ReduxStatus.loadFailed
      }
    };
  },

  [GET_DASHBOARD_PAYMENTS]: (state, payload) => {
    return {
      ...state,
      paymentList: {
        ...state.paymentList,
        status: ReduxStatus.loading,
        message: payload.message
      }
    };
  },
  [GET_DASHBOARD_PAYMENTS_SUCCESS]: (state, { activePage, totalPage, totalRecord, data, filter }) => {
    return {
      ...state,
      paymentList: {
        ...state.paymentList,
        activePage,
        totalPage,
        totalRecord,
        data,
        status: ReduxStatus.loaded,
        message: "",
        filter,
      }
    };
  },
  [GET_DASHBOARD_PAYMENTS_FAILURE]: (state, payload) => {
    return {
      ...state,
      paymentList: {
        ...state.paymentList,
        status: ReduxStatus.loadFailed,
        message: payload.message,
      }
    };
  },
  [GET_ACCUMULATED_DONATIONS]: (state, payload) => {
    return {
      ...state,
      accumulatedDonationList: {
        ...state.accumulatedDonationList,
        status: ReduxStatus.loading,
        message: payload.message
      },
      type: payload.type
    };
  },
  [GET_ACCUMULATED_DONATIONS_SUCCESS]: (state, { activePage, totalPage, totalRecord, data }) => {
    return {
      ...state,
      accumulatedDonationList: {
        ...state.accumulatedDonationList,
        activePage,
        totalPage,
        totalRecord,
        data,
        status: ReduxStatus.loaded,
        message: "",
      }
    };
  },
  [GET_ACCUMULATED_DONATIONS_FAILURE]: (state, payload) => {
    return {
      ...state,
      accumulatedDonationList: {
        ...state.accumulatedDonationList,
        status: ReduxStatus.loadFailed,
        message: payload.message,
      }
    };
  },

};


export default function reducer(state = initialState, action = {}) {
  const fn = actionsMap[action.type];
  return fn ? fn(state, action.payload) : state;
}
