import { put, call, takeLatest, takeEvery, select } from "redux-saga/effects"
import { get, patch } from '../Common/Utils/AxiosClient'
import Enum from '../Common/Constants/Enum'
import Utils from "../Common/Utils/Utils"
import {
  GET_DASHBOARD_TASKS, GET_DASHBOARD_TASKS_SUCCESS, GET_DASHBOARD_TASKS_FAILURE,
  SAVE_DASHBOARD_TASK, SAVE_DASHBOARD_TASKS_FAILURE, SAVE_DASHBOARD_TASKS_SUCCESS,
  GET_DASHBOARD_PAYMENTS, GET_DASHBOARD_PAYMENTS_SUCCESS, GET_DASHBOARD_PAYMENTS_FAILURE, DELETE_PAYMENT,
  GET_ACCUMULATED_DONATIONS, GET_ACCUMULATED_DONATIONS_SUCCESS, GET_ACCUMULATED_DONATIONS_FAILURE, DELETE_DASHBOARD_TASK,
} from "./DashboardActionCreator"
import { toast } from "react-toastify"

function* watchGetTasks({ payload: { activePage, filter } }) {
  try {
    const newFilter = Utils.cleanObject(filter)
    const skip = (activePage - 1) * Enum.DashboardTaskPerPage
    const url = `/tasks`;
    const params = {
      filter: newFilter,
      limit: Enum.DashboardTaskPerPage,
      skip,
      populate: [{ "path": "author" }, { "path": "contact" }],
      sort: { created_at: -1 }
    };
    const res = yield call(get, url, params)
    const totalPage = Utils.getTotalPage(res.data.metadata)

    yield put({
      type: GET_DASHBOARD_TASKS_SUCCESS,
      payload: {
        activePage,
        filter: filter,
        totalPage,
        data: res.data.data,
      }
    })
  } catch (error) {
    yield put({
      type: GET_DASHBOARD_TASKS_FAILURE,
      payload: {
        ...error
      },
    })
  }
}

function* watchSaveTask({ payload: { task } }) {
  try {
    const url = `/tasks/${task._id}`
    yield call(patch, url, task)
    yield put({
      type: SAVE_DASHBOARD_TASKS_SUCCESS
    })
  } catch (e) {
    yield put({ type: SAVE_DASHBOARD_TASKS_FAILURE })
  }
}

function* watchDeleteTask({ payload: { id } }) {
  try {
    const url = `/tasks/delete/${id}`;
    yield call(patch, url);
    toast.success(`Delete task successful`);
  } catch (e) {
    toast.error(`Delete task failed`);
  }
}

function* watchGetPayments({ payload: { activePage, filter } }) {
  try {
    const newFilter = Utils.cleanObject(filter)
    const skip = (activePage - 1) * Enum.PaymentPerPage
    const url = `/payments`;
    const params = {
      filter: newFilter,
      limit: Enum.PaymentPerPage,
      skip,
      populate: { "path": "linked_profile" },
      sort: { "processed_date": -1 }
    };
    const res = yield call(get, url, params)
    const totalPage = Utils.getTotalPage(res.data.metadata)

    yield put({
      type: GET_DASHBOARD_PAYMENTS_SUCCESS,
      payload: {
        activePage,
        filter: filter,
        totalPage,
        data: res.data.data,
      }
    })
  } catch (error) {
    yield put({
      type: GET_DASHBOARD_PAYMENTS_FAILURE,
      payload: {
        ...error
      },
    })
  }
}

function* watchDeletePayment({ payload: { id } }) {
  try {
    const url = `/payments/delete/${id}`;
    yield call(patch, url);
    toast.success(`Delete payment successful`);
  } catch (e) {
    toast.error(`Delete payment failed`);
  }
}

function* watchGetAccumulatedDonations({ payload: { activePage } }) {
  try {
    const skip = (activePage - 1) * Enum.DashboardDonationPerPage;
    const params = {
      limit: Enum.DashboardDonationPerPage,
      skip,
    };
    const url = '/accumulated-donations';
    const res = yield call(get, url, params);
    const totalPage = Utils.getTotalPage(res.data.metadata);
    yield put({
      type: GET_ACCUMULATED_DONATIONS_SUCCESS,
      payload: {
        activePage,
        totalPage,
        totalRecord: res.data.metadata.total,
        data: res.data.data,
      }
    });
  } catch (e) {
    yield put({
      type: GET_ACCUMULATED_DONATIONS_FAILURE,
      payload: {
        ...e
      },
    });
    toast.error('GET ACCUMULATED DONATIONS FAILED');
  }
}

function* DashboadSaga() {
  yield takeLatest(GET_DASHBOARD_TASKS, watchGetTasks)
  yield takeEvery(SAVE_DASHBOARD_TASK, watchSaveTask)
  yield takeLatest(GET_DASHBOARD_PAYMENTS, watchGetPayments)
  yield takeEvery(DELETE_PAYMENT, watchDeletePayment)
  yield takeEvery(DELETE_DASHBOARD_TASK, watchDeleteTask)
  yield takeLatest(GET_ACCUMULATED_DONATIONS, watchGetAccumulatedDonations)
}

export default DashboadSaga;
