import React from 'react';
import PropTypes from 'prop-types';
import { Button, Form, Modal, Radio } from 'semantic-ui-react';
import injectSheet from "react-jss";
import AppContext from "../../../../Common/Constants/AppContext";
import SearchVolunteerInEvent from "../../../../Common/Components/Search/SearchVolunteerInEvent";
import Utils from "../../../../Common/Utils/Utils";
import Enum from "../../../../Common/Constants/Enum";
import { ModalStyleSheet } from "../../../../Common/GlobalStyle";

class SetDeliveryModal extends React.Component {
  constructor(props) {
    super(props);
    const { location } = this.props;
    let delivery = {};
    if (location.delivery) {
      delivery = {
        ...location.delivery,
        recipient: location.delivery.recipient ? location.delivery.recipient._id : '',
      }
    } else {
      delivery = {
        address: Utils.combineAddress(location.address),
      }
    }
    this.state = {
      delivery,
    };
    this.isFieldError = this.isFieldError.bind(this);
    this.handleChange = this.handleChange.bind(this);
    this.handleStatusChange = this.handleStatusChange.bind(this);
    this.handleSelectVolunteer = this.handleSelectVolunteer.bind(this);
    this.handleSubmit = this.handleSubmit.bind(this);
  }

  handleChange({ target: { name, value } }) {
    this.setState({
      delivery: {
        ...this.state.delivery,
        [name]: value,
      }
    })
  }

  handleStatusChange(e, { value }) {
    this.setState({
      delivery: {
        ...this.state.delivery,
        status: value,
      }
    })
  }

  isFieldError(name) {
    const { intl: { messages } } = this.context;
    if (!this.state.delivery[name]) {
      return `${messages.pleaseEnter} ${messages[name]}`;
    }
    return '';
  }

  handleSelectVolunteer(selectedVolunteer) {
    this.setState({
      delivery: {
        ...this.state.delivery,
        recipient: selectedVolunteer._id,
      }
    })
  }

  handleSubmit() {
    if (!this.state.isHitSave) {
      this.setState({
        isHitSave: true,
      });
    }
    if (this.isFieldError('recipient')) {
      return;
    }
    const { onOk } = this.props;
    onOk(this.state.delivery);
  }

  render() {
    const { classes, isOpen, onClose, eventId, location } = this.props;
    const { intl: { messages } } = this.context;
    const { delivery } = this.state;
    const initRecipient = (location.delivery && location.delivery.recipient) ? location.delivery.recipient : {};
    return (
      <Modal
        open={isOpen}
        onClose={onClose}
        size="mini"
      >
        <Modal.Header className={classes.header}>
          {
            messages.setDelivery
          }
        </Modal.Header>
        <Modal.Content>
          <Form
            onSubmit={this.handleSubmit}
          >
            <Form.Field required error={this.state.isHitSave && !delivery.recipient}>
              <label>{messages.recipient}</label>
              <SearchVolunteerInEvent
                onSelect={this.handleSelectVolunteer}
                eventId={eventId}
                value={Utils.combineName(initRecipient, messages)}
                initVolunteer={initRecipient}
              />
              {
                this.state.isHitSave && !delivery.recipient &&
                <div className={classes.helpText}>{this.isFieldError('recipient')}</div>
              }
            </Form.Field>
            <Form.Field>
              <label>{messages.deliverTo}</label>
              <input
                placeholder={messages.deliverTo}
                name='address'
                value={delivery.address}
                onChange={this.handleChange}
              />
            </Form.Field>
            <Form.Field>
              <label>{messages.tracking_number}</label>
              <input
                placeholder={messages.tracking_number}
                name='tracking_number'
                value={delivery.tracking_number}
                onChange={this.handleChange}
              />
            </Form.Field>
            {
              Object.values(Enum.DeliveryStatus).map(item => (
                <Form.Field key={item}>
                  <Radio
                    label={messages[item]}
                    name='status'
                    value={item}
                    checked={delivery.status === item}
                    onChange={this.handleStatusChange}
                  />
                </Form.Field>
              ))
            }
            <Form.Field className={classes.actionGroup}>
              <Button onClick={onClose}>
                {messages.cancel}
              </Button>
              <Button
                type='submit'
                color='green'
              >
                {
                  messages.setDelivery
                }
              </Button>
            </Form.Field>
          </Form>
        </Modal.Content>
      </Modal>
    )
  }
}

SetDeliveryModal.propTypes = {
  isOpen: PropTypes.bool.isRequired,
  onClose: PropTypes.func.isRequired,
  onOk: PropTypes.func.isRequired,
  location: PropTypes.shape({}).isRequired,
  eventId: PropTypes.string.isRequired,
};

SetDeliveryModal.contextType = AppContext;

export default injectSheet(ModalStyleSheet)(SetDeliveryModal);