import React from 'react';
import PropTypes from 'prop-types';
import isempty from "lodash.isempty";
import get from "lodash/get";

import Utils from "../../../../../../Common/Utils/Utils";
import { Image, List, Loader } from "semantic-ui-react";
import ReduxStatus from "../../../../../../Common/Constants/ReduxStatus";
import AppContext from "../../../../../../Common/Constants/AppContext";
import LocationSearchVolunteer from "./LocationSearchVolunteer/LocationSearchVolunteer";
import ConfirmModal from "../../../../../../Common/Components/Modal/ConfirmModal";
import LocationActionCreator from "../../../../../Actions/LocationActionCreator";

class LocationDetail extends React.Component {
  constructor() {
    super();
    this.state = {
      toggleRemoveVolunteer: false,
      selectedRemoveVolunteer: null,
    }
    this.renderVolunteerItem = this.renderVolunteerItem.bind(this);
    this.handleRemoveVolunteerFromLocation = this.handleRemoveVolunteerFromLocation.bind(this);
  }

  renderVolunteerItem(item) {
    const { intl: { messages } } = this.context;
    return (
      <List.Item key={item._id} className='volunteer-item'>
        <div className='item-action'>
          <div
            onClick={(e) => {
              e.stopPropagation();
              this.setState({
                toggleRemoveVolunteer: true,
                selectedRemoveVolunteer: item,
              })
            }}
          >
            {messages.remove}
          </div>
        </div>
        <List.Content className='volunteer-content'>
          {
            !isempty(item.profile_picture) ?
              <Image avatar src={item.profile_picture['thumb@64_64']} /> :
              <Image avatar src={require("../../../../../../Assets/avatar.png")} />
          }
          <div>
            <a target="_blank" rel="noopener noreferrer" href={`/contact-detail/${item._id}/overview`}>
              {Utils.combineName(item, messages)}
            </a>
            <div className='volunteer-city'> 
            {
              [
                get(item, 'home_address.city'),
                Utils.getContactInfo(item),
              ]
              .filter(item => item)
              .join(' - ')
            }
            </div>
          </div>
        </List.Content>
      </List.Item>
    )
  }

  handleRemoveVolunteerFromLocation() {
    const { dispatch } = this.context;
    const { selectedLocation } = this.props;
    dispatch(LocationActionCreator
      .removeVolunteerToLocation(selectedLocation._id, this.state.selectedRemoveVolunteer._id)
    );
    this.setState({
      toggleRemoveVolunteer: false,
      selectedRemoveVolunteer: null
    })
  }

  render() {
    const { intl: { messages }, currentUser } = this.context;
    const { locationVolunteers: { data, status: volunteerStatus }, selectedLocation, selectedEvent } = this.props;
    if (isempty(selectedLocation)) {
      return null;
    }
    return [
      <div className='location-info'>
        <div className='location-name'>{selectedLocation.name}</div>
        <div className='second-description'>
          {Utils.combineAddress(selectedLocation.address)}
        </div>
        <div className='second-description'>{selectedLocation.expected_votes} {messages.estimatedVotes}</div>
        <LocationSearchVolunteer
          selectedLocation={selectedLocation}
          selectedEvent={selectedEvent}
        />
      </div>,
      <div className='volunteer-list'>
        {
          this.state.toggleRemoveVolunteer &&
          <ConfirmModal
            isOpen={true}
            onClose={() => this.setState({ toggleRemoveVolunteer: false })}
            onConfirm={this.handleRemoveVolunteerFromLocation}
            content={{
              mainText: messages.deleteVolunteerFromLocationText.replace('{name}', Utils.combineName(this.state.selectedRemoveVolunteer, messages)),
              description: messages.messageConfirm.replace('{name}',
                `${currentUser.first_name}`)
            }}
            title={messages.removeVolunteer}
            cancelText={messages.keepThisVolunteer}
            confirmText={messages.remove}
          />
        }
        <List celled relaxed>
          {
            data.map(item => this.renderVolunteerItem(item))
          }
          {
            volunteerStatus === ReduxStatus.loading &&
            <Loader active />
          }
        </List>
      </div>,
      <div className='volunteer-count'>
        {data.length}/
        {selectedLocation.volunteers_required} {messages.volunteers}
      </div>
    ];
  }
}

LocationDetail.contextType = AppContext;

LocationDetail.propTypes = {
  selectedLocation: PropTypes.shape({}),
}

export default LocationDetail;