import React from 'react';
import PropTypes from 'prop-types';
import { Search } from "semantic-ui-react";
import Utils from "../../../../../../../Common/Utils/Utils";
import ContactActionCreator from "../../../../../../../Contact/Actions/ContactActionCreator";
import Enum from "../../../../../../../Common/Constants/Enum";
import AppContext from "../../../../../../../Common/Constants/AppContext";

class SearchAndAssignVolunteer extends React.Component {

  constructor(props) {
    super(props);
    this.state = {
      value: ' ',
      options: [],
      loading: false,
      selectedVolunteer: {},
    };
    this.status = [
      Enum.VolunteerStatus.active,
    ]
    this.handleChange = this.handleChange.bind(this);
    this.handleResultSelect = this.handleResultSelect.bind(this);
    this.handleBlur = this.handleBlur.bind(this);
    this.handleSearchResult = this.handleSearchResult.bind(this);
  }

  componentDidMount() {
    const { dispatch } = this.context;
    dispatch(ContactActionCreator.searchVolunteer('', this.handleSearchResult, this.status));
  }

  handleSearchResult(data) {
    this.setState({
      value: this.state.value || ' ',
      options: data,
      loading: false,
    })
  }

  handleResultSelect = (e, { result }) => {
    const { intl: { messages } } = this.context;
    this.setState({
      value: Utils.combineName(result, messages),
      selectedVolunteer: result,
    });
    const { onSelect } = this.props;
    if (onSelect) {
      onSelect(result);
    }
  }

  handleChange({ target: { name, value } }) {
    const { dispatch } = this.context;
    if (!value.trim()) {
      if (this.state.value !== ' ') {
        this.setState({
          value: ' ',
          loading: true,
          options: this.state.options,
        });
        dispatch(ContactActionCreator.searchVolunteer('', this.handleSearchResult, this.status));
      }
    } else {
      this.setState({
        value,
        loading: true,
      });
      dispatch(ContactActionCreator.searchVolunteer(value.trim(), this.handleSearchResult, this.status));
    }
  }

  handleBlur() {
    const { intl: { messages } } = this.context;
    this.setState({
      value: Utils.combineName(this.state.selectedVolunteer, messages),
    });
  }

  render() {
    const { intl: { messages } } = this.context;
    const { loading, options } = this.state;

    const results = options ? options.map(item => ({
      ...item,
      title: [
        Utils.combineName(item, messages),
        Utils.getContactInfo(item)
      ].filter(item => item)
      .join(' - '),
    })) : [];
    return (
      <Search
        value={this.state.value}
        input={{ icon: 'search', iconPosition: 'left' }}
        loading={loading}
        onBlur={this.handleBlur}
        onResultSelect={this.handleResultSelect}
        onSearchChange={this.handleChange}
        results={results}
        fluid
        placeholder='Select Volunteer'
      />
    )
  }
}

SearchAndAssignVolunteer.contextType = AppContext;

SearchAndAssignVolunteer.propTypes = {
  onSelect: PropTypes.func,
};

SearchAndAssignVolunteer.defaultProps = {
  onSelect: null,
}

export default SearchAndAssignVolunteer;