import React from 'react';
import { Loader, List, Button, Icon, Pagination, Input } from 'semantic-ui-react';
import injectSheet from "react-jss";
import moment from "moment/moment";

import AppContext from "../../../../../../Common/Constants/AppContext";
import stylesheet from "./stylesheet";
import NoteInfoModal from './NoteInfoModal';
import LocationNoteActionCreator from "../../../../../Actions/LocationNoteActionCreator";
import ReduxStatus from "../../../../../../Common/Constants/ReduxStatus";
import Utils from "../../../../../../Common/Utils/Utils";
import ConfirmModal from "../../../../../../Common/Components/Modal/ConfirmModal";
import Enum from "../../../../../../Common/Constants/Enum";

class LocationNotes extends React.Component {
  constructor() {
    super();
    this.state = {
      toggleEdit: false,
      noteInfo: {},

      selectedDeleteNoteId: '',
      toggleDelete: false,
    }
    this.handleDeleteNote = this.handleDeleteNote.bind(this);
    this.handlePaginationChange = this.handlePaginationChange.bind(this);
    this.onSearchFilterChange = this.onSearchFilterChange.bind(this);
  }

  handlePaginationChange(e, { activePage }) {
    const { dispatch } = this.context;
    const { locationNotes: { filter } } = this.props;
    dispatch(LocationNoteActionCreator.getLocationNotes(activePage, filter))
  }

  onSearchFilterChange(e, { value }) {
    const { dispatch } = this.context;
    const { locationNotes } = this.props;
    const newFilter = { ...locationNotes.filter };
    if (value) {
      newFilter.note = { "$regex": value, "$options": "i" };
    } else {
      newFilter.note = null;
    }
    dispatch(LocationNoteActionCreator.getLocationNotes(1, newFilter));
  }

  handleDeleteNote() {
    const { dispatch } = this.context;
    dispatch(LocationNoteActionCreator.deleteLocationNotes(this.state.selectedDeleteNoteId));
    this.setState({
      selectedDeleteNoteId: '',
      toggleDelete: false,
    })
  }

  render() {
    const { intl: { messages }, currentUser } = this.context;
    const { classes, selectedLocation, locationNotes: { data, status, activePage, totalPage } } = this.props;
    return (
      <div className={classes.locationNoteContainer}>
        {
          this.state.toggleEdit &&
          <NoteInfoModal
            isOpen={this.state.toggleEdit}
            onClose={() => this.setState({ toggleEdit: false })}
            noteInfo={this.state.noteInfo}
          />
        }
        {
          this.state.toggleDelete &&
          <ConfirmModal
            isOpen={true}
            onClose={() => this.setState({ toggleDelete: false })}
            onConfirm={this.handleDeleteNote}
            content={{
              mainText: messages.deleteText.replace('{item}', 'this note'),
              description: messages.messageConfirm.replace('{name}',
                `${currentUser.first_name}`)
            }}
            title={messages.deleteNote}
            cancelText={messages.keepThisNote}
            confirmText={messages.delete}
          />
        }
        <div className='location-note-header'>
          <Input
            icon='search'
            iconPosition='left'
            placeholder='Search note...'
            onChange={this.onSearchFilterChange}
          />
          <Button
            icon
            labelPosition='right'
            color='green'
            className='add-note'
            onClick={() => this.setState({
              toggleEdit: true,
              noteInfo: {
                location: selectedLocation._id,
                author: currentUser._id,
                category: Enum.ContactNotes.general,
              }
            })}
          >
            {messages.add}
            <Icon name='right add' circular inverted />
          </Button>
        </div>
        <List selection celled>
          {
            data.map((note) => (
              <List.Item
                key={note._id}
              >
                <List.Content>
                  <div className='note-content'>
                    <div className='note'>{note.note}</div>
                    <div className='author'>Added by {Utils.combineName(note.author)}</div>
                    <div>
                      {moment(new Date(note.created_at)).format('DD MMM YYYY')}
                    </div>
                    <div className='item-action'>
                      <div
                        onClick={(e) => {
                          e.stopPropagation();
                          this.setState({
                            selectedDeleteNoteId: note._id,
                            toggleDelete: true,
                          })
                        }}
                      >
                        {messages.delete}
                      </div>
                      <div
                        onClick={(e) => {
                          e.stopPropagation();

                          this.setState({
                            toggleEdit: true,
                            noteInfo: {
                              ...note,
                              location: selectedLocation._id,
                              author: currentUser._id,
                            }
                          })
                        }}
                      >
                        {messages.edit}
                      </div>
                    </div>
                  </div>
                </List.Content>
              </List.Item>
            ))
          }
        </List>
        {
          data.length > 0 && totalPage > 1 &&
          <Pagination
            activePage={activePage}
            totalPages={totalPage}
            onPageChange={this.handlePaginationChange}
          />
        }
        {
          status === ReduxStatus.loading &&
          <Loader active />
        }
      </div>
    )
  }
}

LocationNotes.contextType = AppContext;

export default injectSheet(stylesheet)(LocationNotes);