import React from 'react';
import PropTypes from 'prop-types';
import isequal from "lodash.isequal";
import { Button, Form, Modal } from 'semantic-ui-react';
import injectSheet from "react-jss";
import { ModalStyleSheet } from "../../../../../../Common/GlobalStyle";
import AppContext from "../../../../../../Common/Constants/AppContext";
import LocationNoteActionCreator from "../../../../../Actions/LocationNoteActionCreator";

class NoteInfoModal extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      noteInfo: {
        ...props.noteInfo,
      },
    };
    this.isFieldError = this.isFieldError.bind(this);
    this.handleChange = this.handleChange.bind(this);
    this.handleSubmit = this.handleSubmit.bind(this);
  }

  handleChange({ target: { name, value } }) {
    this.setState({
      noteInfo: {
        ...this.state.noteInfo,
        [name]: value,
      }
    })
  }

  handleSubmit() {
    if (!this.state.isHitSave) {
      this.setState({
        isHitSave: true,
      });
    }
    if (this.isFieldError('note')) {
      return;
    }
    const noteInfo = { ...this.state.noteInfo };
    const { dispatch } = this.context;
    const {onClose} = this.props;
    if (!noteInfo._id) {
      dispatch(LocationNoteActionCreator.createLocationNotes(noteInfo));
    } else {
      dispatch(LocationNoteActionCreator.saveLocationNotes(noteInfo));
    }
    onClose();
  }

  isFieldError(name) {
    const { intl: { messages } } = this.context;
    if (!this.state.noteInfo[name]) {
      return `${messages.pleaseEnter} ${messages[name]}`;
    }
    return '';
  }

  render() {
    const { classes, isOpen, onClose } = this.props;
    const { intl: { messages } } = this.context;
    const { noteInfo } = this.state;
    return (
      <Modal
        open={isOpen}
        onClose={onClose}
        size="tiny"
      >
        <Modal.Header className={classes.header}>
          {
            noteInfo._id ? messages.editNote : messages.addNote
          }
        </Modal.Header>
        <Modal.Content>
          <Form
            onSubmit={this.handleSubmit}
          >
            <Form.TextArea
              rows={5}
              placeholder={messages.addNote}
              name='note'
              value={noteInfo.note}
              onChange={this.handleChange}
            />
            <Form.Field className={classes.actionGroup}>
              <Button onClick={onClose}>
                {messages.cancel}
              </Button>
              <Button
                type='submit'
                color='green'
                disabled={isequal(this.props.noteInfo, noteInfo) && noteInfo._id}
              >
                {
                  noteInfo._id ? messages.update : messages.create
                }
              </Button>
            </Form.Field>
          </Form>
        </Modal.Content>
      </Modal>
    )
  }
}

NoteInfoModal.propTypes = {
  isOpen: PropTypes.bool.isRequired,
  onClose: PropTypes.func.isRequired,
  noteInfo: PropTypes.shape({}).isRequired,
};

NoteInfoModal.contextType = AppContext;

export default injectSheet(ModalStyleSheet)(NoteInfoModal);