import React from 'react';
import PropTypes from 'prop-types';
import injectSheet from "react-jss";
import stylesheet from "./stylesheet";
import AppContext from "../../../../Common/Constants/AppContext";
import AssignVolunteer from "./AssignVolunteer/AssignVolunteer";
import Enum from "../../../../Common/Constants/Enum";
import LocationList from "./LocationList/LocationList";
import EventMap from "./EventMap/EventMap";
import LocationActionCreator from "../../../Actions/LocationActionCreator";
import ContactActionCreator from "../../../../Contact/Actions/ContactActionCreator";
import LocationNoteActionCreator from "../../../Actions/LocationNoteActionCreator";
import Utils from "../../../../Common/Utils/Utils";
import { eventVotingDistrictLocation } from "../../../../Common/Constants/AppKey";


const radius100 = ['Barwon', 'Murray', 'Orange'];
const radius25 = ['Sydney', 'Newcastle', 'Wollongong'];

class EventLocationMap extends React.Component {

  constructor() {
    super();
    this.state = {
      toggleDeleteLocation: false,
      selectedDeleteLocation: null,
      toggleLocationModal: false,
      locationInfo: {},

      searchText: '',
      searchStatus: Object.values(Enum.EventLocationStatus),

      selectedLocation: {},
    };
    this.handleSelectLocation = this.handleSelectLocation.bind(this);
  }

  handleSelectLocation(location) {
    if (location._id) {
      if (location._id !== this.state.selectedLocation._id) {
        const { dispatch } = this.context;
        dispatch(LocationActionCreator.getLocationVolunteers(location._id, 1));
        //get location note
        const locationNoteFilter = {
          location: location._id,
        }
        dispatch(LocationNoteActionCreator.getLocationNotes(1, locationNoteFilter));
        const status = [
          Enum.VolunteerStatus.active,
        ];
        const lat = location.address.location.coordinates[1];
        const lng = location.address.location.coordinates[0];
        let radius = 50;
        if (location.voting_district) {
          if(radius100.includes(location.voting_district.name)) {
            radius = 100;
          }
          if(radius25.includes(location.voting_district.name)) {
            radius = 25;
          }
        }
        const geoInfo = [[lng, lat], radius / 111.12];
        // const geoInfo = [lng, lat];
        dispatch(ContactActionCreator.searchVolunteerOnMap(geoInfo, status));
        this.setState({
          selectedLocation: location,
        })
      }
    } else {
      if (location._id !== this.state.selectedLocation._id) {
        this.setState({
          selectedLocation: location,
        })
      }
    }
    const { selectedEvent } = this.props;
    const preSelectedData = Utils.getLocalStorage(eventVotingDistrictLocation) || {
      [selectedEvent._id]: {
        location: {},
        votingDistrict: {}
      }
    };

    if (preSelectedData[selectedEvent._id]) {
      preSelectedData[selectedEvent._id].location = location;
    } else {
      preSelectedData[selectedEvent._id] = {
        location: location,
      }
    }
    Utils.setLocalStorage(eventVotingDistrictLocation, preSelectedData);
  }

  render() {
    const { classes, locationList, locationVolunteers, locationNotes, volunteerOnMapList, selectedEvent } = this.props;

    return (
      <div className={classes.eventLocationPage}>
        <LocationList
          selectedEvent={selectedEvent}
          locationList={locationList}
          classes={classes}
          selectedLocation={this.state.selectedLocation}
          handleSelectLocation={this.handleSelectLocation}
        />
        <EventMap
          classes={classes}
          selectedEvent={selectedEvent}
          selectedLocation={this.state.selectedLocation}
          locationList={locationList}
          volunteerOnMapList={volunteerOnMapList}
          handleSelectLocation={this.handleSelectLocation}
        />
        {
          this.state.selectedLocation._id &&
          <AssignVolunteer
            selectedEvent={selectedEvent}
            selectedLocation={this.state.selectedLocation}
            locationVolunteers={locationVolunteers}
            locationNotes={locationNotes}
            handleSelectLocation={this.handleSelectLocation}
            classes={classes}
          />
        }
      </div>
    )
  }
}

EventLocationMap.propTypes = {
  selectedEvent: PropTypes.shape({}).isRequired,
  locationList: PropTypes.shape({}),
  volunteerOnMapList: PropTypes.shape({}),
  locationNotes: PropTypes.shape({}),
};

EventLocationMap.contextType = AppContext;

export default injectSheet(stylesheet)(EventLocationMap);