import React from 'react';
import isequal from 'lodash.isequal';
import debounce from 'lodash.debounce';

import Map from "../../../../../Common/Components/Map/Map";
import AppContext from "../../../../../Common/Constants/AppContext";
import PropTypes from "prop-types";
import LocationMarkerAndInfo from "./LocatioinMarkerAndInfo/LocationMarkerAndInfo";
import VolunteerMarkerAndInfo from "./VolunteerMarkerAndInfo/VolunteerMarkerAndInfo";

const CHANGE_TYPE = {
  location: 'location',
  list: 'list',
  init: 'init',
}

class EventMap extends React.Component {
  constructor() {
    super();
    this.state = {
      isBind: false,

      defaultZoom: 11,
      centerPosition: {
        lat: -34.9508296,
        lng: 138.5971553,
      },
    };
    this.handleMapLoad = this.handleMapLoad.bind(this);
    this.setCenterMap = this.setCenterMap.bind(this);
    this.onZoomChangeHandler = debounce(this.onZoomChangeHandler.bind(this), 300);
  }

  handleMapLoad(map) {
    this.map = map;
  }

  setCenterMap(centerPosition) {
    this.setState({
      centerPosition
    })
  }

  onZoomChangeHandler() {
    const defaultZoom = this.map.getZoom()
    this.setState({
      defaultZoom,
    });
  }

  getSnapshotBeforeUpdate(prevProps) {
    if (!isequal(prevProps.selectedLocation, this.props.selectedLocation) && this.props.selectedLocation._id) {
      return CHANGE_TYPE.location;
    }
    if (!isequal(prevProps.locationList.data, this.props.locationList.data) && this.props.locationList.data.length > 0) {
      return CHANGE_TYPE.list;
    }
    if (this.props.locationList.data.length > 0 && !this.state.isBind) {
      return CHANGE_TYPE.init;
    }
    return null;
  }

  componentDidUpdate(prevProps, prevState, snapshot) {
    if (snapshot === CHANGE_TYPE.location) {
      const centerPosition = {
        lat: this.props.selectedLocation.address.location.coordinates[1],
        lng: this.props.selectedLocation.address.location.coordinates[0],
      }
      this.setState({
        defaultZoom: 14,
        centerPosition,
      })
    }
    if (snapshot === CHANGE_TYPE.list || snapshot === CHANGE_TYPE.init) {
      const centerLocation = this.props.locationList.data[0];
      const centerPosition = {
        lat: centerLocation.address.location.coordinates[1],
        lng: centerLocation.address.location.coordinates[0],
      }
      this.setState({
        defaultZoom: 14,
        centerPosition,
        isBind: true,
      })
    }
  }

  render() {
    const { locationList, selectedLocation, selectedEvent, volunteerOnMapList, handleSelectLocation } = this.props;

    return (
      <div className="map-container" style={{ width: '100%' }}>
        <Map
          handleMapLoad={this.handleMapLoad}
          zoom={this.state.defaultZoom}
          center={this.state.centerPosition}
          onZoomChanged={this.onZoomChangeHandler}
        >
          <LocationMarkerAndInfo
            locationList={locationList}
            selectedLocation={selectedLocation}
            handleSelectLocation={handleSelectLocation}
          />
          {
            selectedLocation._id &&
            <VolunteerMarkerAndInfo
              volunteerOnMapList={volunteerOnMapList}
              selectedLocation={selectedLocation}
              selectedEvent={selectedEvent}
              setCenterMap={this.setCenterMap}
            />
          }
        </Map>
      </div>
    );
  }
}

EventMap.contextType = AppContext;

EventMap.propTypes = {
  classes: PropTypes.shape({}),
  selectedEvent: PropTypes.shape({}),
  locationList: PropTypes.shape({}),
  selectedLocation: PropTypes.shape({}),
  handleSelectLocation: PropTypes.func,
  volunteerOnMapList: PropTypes.shape({}),
}

export default EventMap;