import React from 'react';
import GoogleInfoBox from "react-google-maps/lib/components/addons/InfoBox";
import Utils from "../../../../../../Common/Utils/Utils";
import AppContext from "../../../../../../Common/Constants/AppContext";
import injectSheet from "react-jss";
import colors from "../../../../../../Common/Constants/color";

const google = window.google;

const stylesheet = {
  infoBox: {
    width: 180,
    display: 'flex',
    flexDirection: 'column',
    '& .header-status': {
      height: 5,
      minHeight: 5,
      backgroundColor: colors.primaryRed,
      '&.complete': {
        backgroundColor: colors.primaryGreen,
      },
      '&.in-progress': {
        backgroundColor: colors.primaryYellow,
      },
    },
    '& .info-content': {
      backgroundColor: colors.primaryBlack2,
      padding: [15, 10],
      color: colors.primaryWhite,
      textAlign: 'center',
      '& .location-name': {
        fontSize: '1rem',
        marginBottom: '0.5rem',
      }
    }
  },
}
class InfoBox extends React.Component {
  constructor() {
    super();
    this.state = {
      isShowInfo: false,
    }
    this.renderInfo = this.renderInfo.bind(this);
  }

  renderInfo() {
    const { classes, currentLocation } = this.props;
    const { intl: { messages } } = this.context;
    return (
      <div className={classes.infoBox}>
        <div className={`header-status ${currentLocation.status}`}></div>
        <div className='info-content'>
          <div className='location-name'>{currentLocation.name}</div>
          <div>{Utils.combineAddress(currentLocation.address)}</div>
          <div>
            {currentLocation.volunteers ? currentLocation.volunteers.length : 0}/
            {currentLocation.volunteers_required} {messages.volunteers}
          </div>
        </div>
      </div>
    )
  }

  render() {
    const { position } = this.props;
    return (
      <GoogleInfoBox
        options={{
          closeBoxURL: ``,
          enableEventPropagation: true,
          disableAutoPan: true,
          pixelOffset: new google.maps.Size(-90, 0)
        }}
        position={new google.maps.LatLng(position.lat, position.lng)}
      >
        {
          this.renderInfo()
        }
      </GoogleInfoBox>
    )
  }
}

InfoBox.contextType = AppContext;

export default injectSheet(stylesheet)(InfoBox);