import React from 'react';
import GoogleInfoBox from "react-google-maps/lib/components/addons/InfoBox";
import Utils from "../../../../../../Common/Utils/Utils";
import AppContext from "../../../../../../Common/Constants/AppContext";
import injectSheet from "react-jss";
import colors from "../../../../../../Common/Constants/color";
import LocationActionCreator from "../../../../../Actions/LocationActionCreator";

const google = window.google;

const stylesheet = {
  infoBox: {
    width: 250,
    display: 'flex',
    flexDirection: 'column',
    backgroundColor: colors.primaryWhite2,
    fontSize: '0.9rem',
    '& .header-status': {
      height: 5,
      minHeight: 5,
      backgroundColor: colors.primaryBlue,
      '&.selected': {
        backgroundColor: colors.primaryBlack2,
      },
      '&.assigned': {
        backgroundColor: colors.primaryGray7,
      },
    },
    '& .info-content': {
      padding: [15, 10],
      color: colors.primaryBlack2,
      textAlign: 'center',
      '& .location-name': {
        fontSize: '1rem',
        fontWeight: 900,
        marginBottom: '0.5rem',
      }
    },
    '& .volunteer-action-on-map': {
      padding: [10, 3],
      borderTop: '1px solid #EDEDED',
      textAlign: 'center',
      color: '#4183c4',
    }
  },
}

class InfoBox extends React.Component {
  constructor() {
    super();
    this.state = {
      isShowInfo: false,
    }
    this.renderInfo = this.renderInfo.bind(this);
    this.handleAssignOrUnAssign = this.handleAssignOrUnAssign.bind(this);
  }

  handleAssignOrUnAssign() {
    const { volunteerAssignedStatus, id, selectedLocation } = this.props;
    const { dispatch } = this.context;
    if (volunteerAssignedStatus === 'selected') {
      dispatch(LocationActionCreator.removeVolunteerToLocation(selectedLocation._id, id));
    } else if (volunteerAssignedStatus === 'available') {
      dispatch(LocationActionCreator.addVolunteerToLocation(selectedLocation._id, id));
    }
  }

  renderInfo() {
    const { classes, currentVolunteer, volunteerAssignedStatus } = this.props;
    const getAdditionalInfo = () => {
      if(!currentVolunteer) return ''

      if(currentVolunteer.mobile_number && currentVolunteer.mobile_number !== 'NA') return currentVolunteer.mobile_number
      if(currentVolunteer.home_number && currentVolunteer.home_number !== 'NA') return currentVolunteer.home_number

      if(Array.isArray(currentVolunteer.emails) && currentVolunteer.emails.length > 0) {
        const email = currentVolunteer.emails.find(item => item.primary) || currentVolunteer.emails[0]
        if(email) return email.email
      }

      return ""
    }
    const { intl: { messages } } = this.context;
    return (
      <div className={classes.infoBox}>
        <div className={`header-status ${volunteerAssignedStatus}`}></div>
        <div className='info-content'>
          <div className='location-name'>{Utils.combineName(currentVolunteer, messages)}</div>
          <div style={{ marginBottom: '10px', marginTop: '5px' }}>{getAdditionalInfo(currentVolunteer)}</div>
          <div>{Utils.combineAddress(currentVolunteer.home_address)}</div>
        </div>
        <div className='volunteer-action-on-map'>
          <a target="_blank" rel="noopener noreferrer" href={`/contact-detail/${currentVolunteer._id}/overview`}>
            View profile
          </a>
        </div>
        {
          volunteerAssignedStatus !== 'assigned' &&
          <div className='volunteer-action-on-map' onClick={this.handleAssignOrUnAssign}>
            {volunteerAssignedStatus === 'available' ? messages.assignTo : messages.unassignFrom} selected location
          </div>
        }
      </div>
    )
  }

  render() {
    const { position } = this.props;
    return (
      <GoogleInfoBox
        options={{
          closeBoxURL: ``,
          enableEventPropagation: true,
          disableAutoPan: true,
          pixelOffset: new google.maps.Size(-125, 0)
        }}
        position={new google.maps.LatLng(position.lat, position.lng)}
      >
        {
          this.renderInfo()
        }
      </GoogleInfoBox>
    )
  }
}

InfoBox.contextType = AppContext;

export default injectSheet(stylesheet)(InfoBox);