import React from 'react';
import injectSheet from "react-jss";
import isempty from "lodash.isempty";
import isequal from "lodash.isequal";

import GoogleInfoBox from "react-google-maps/lib/components/addons/InfoBox";
import AppContext from "../../../../../../Common/Constants/AppContext";
import colors from "../../../../../../Common/Constants/color";
import LocationActionCreator from "../../../../../Actions/LocationActionCreator";
import Utils from "../../../../../../Common/Utils/Utils";
import { Icon, Image } from "semantic-ui-react";

const google = window.google;

const stylesheet = {
  volunteerList: {
    width: 250,
    display: 'flex',
    flexDirection: 'column',
    backgroundColor: colors.primaryWhite2,
    fontSize: '0.9rem',
    '& .header-status': {
      height: 5,
      minHeight: 5,
      backgroundColor: colors.primaryBlue,
      '&.selected': {
        backgroundColor: colors.primaryBlack2,
      },
      '&.assigned': {
        backgroundColor: colors.primaryGray7,
      },
    },
    '& .volunteer-info-content': {
      display: 'flex',
      flexDirection: 'column',
      '& .volunteer-info': {
        padding: 10,
        display: 'flex',
        alignItems: 'center',
        borderBottom: '1px solid #CDD4D9',
        '&:last-child': {
          borderBottom: 'none',
        },
        '& img': {
          width: '3rem',
          height: '3rem',
          objectFit: 'cover',
        },
        '& .info': {
          paddingLeft: 10,
          '& .volunteer-name': {
            fontSize: '1rem',
            fontWeight: 900,
            marginBottom: '0.5rem',
          },
        },
        '& i': {
          marginLeft: 10,
        }
      }
    }
  },
  infoBox: {
    display: 'flex',
    flexDirection: 'column',
    backgroundColor: colors.primaryWhite2,
    fontSize: '0.9rem',
    '& .header-status': {
      height: 5,
      minHeight: 5,
      backgroundColor: colors.primaryBlue,
      '&.selected': {
        backgroundColor: colors.primaryBlack2,
      },
      '&.assigned': {
        backgroundColor: colors.primaryGray7,
      },
    },
    '& .info-content': {
      padding: [15, 10],
      color: colors.primaryBlack2,
      textAlign: 'center',
      '& .location-name': {
        fontSize: '1rem',
        fontWeight: 900,
        marginBottom: '0.5rem',
      }
    },
    '& .volunteer-action-on-map': {
      padding: [10, 3],
      borderTop: '1px solid #EDEDED',
      textAlign: 'center',
      color: '#4183c4',
    }
  },
}

class VolunteerClustererInfoBox extends React.Component {
  constructor() {
    super();
    this.state = {
      volunteerId: null,
    }
    this.handleAssignOrUnAssign = this.handleAssignOrUnAssign.bind(this);
  }

  handleAssignOrUnAssign(volunteer) {
    const { volunteerAssignedStatus, id } = volunteer;
    const { selectedLocation } = this.props;
    const { dispatch } = this.context;
    if (volunteerAssignedStatus === 'selected') {
      dispatch(LocationActionCreator.removeVolunteerToLocation(selectedLocation._id, id));
    } else if (volunteerAssignedStatus === 'available') {
      dispatch(LocationActionCreator.addVolunteerToLocation(selectedLocation._id, id));
    }
  }

  componentDidUpdate(prevProps) {
    const pre = prevProps.volunteers ? prevProps.volunteers.map(item => item.id) : [];
    const cur = this.props.volunteers ? this.props.volunteers.map(item => item.id) : [];
    if (!isequal(pre, cur)) {
      this.setState({
        volunteerId: null,
      })
    }
  }

  render() {
    const { position } = this.props;
    const { classes, volunteers } = this.props;
    const { intl: { messages } } = this.context;
    const { volunteerId } = this.state;
    let currentSelectedVolunteerOnMap = null;
    if (volunteerId) {
      currentSelectedVolunteerOnMap = volunteers.find(item => item.id === volunteerId);
    }
    return (
      <GoogleInfoBox
        options={{
          closeBoxURL: ``,
          enableEventPropagation: true,
          disableAutoPan: true,
          pixelOffset: new google.maps.Size(-125, 0)
        }}
        position={new google.maps.LatLng(position.lat, position.lng)}
      >
        {
          currentSelectedVolunteerOnMap ? (
              <div className={classes.infoBox}>
                <div className={`header-status ${currentSelectedVolunteerOnMap.volunteerAssignedStatus}`}></div>
                <div className='info-content'>
                  <div className='location-name'>{Utils.combineName(currentSelectedVolunteerOnMap.currentVolunteer, messages)}</div>
                  <div style={{ marginBottom: '10px', marginTop: '5px' }}>{currentSelectedVolunteerOnMap.currentVolunteer.mobile_number}</div>
                  <div>{Utils.combineAddress(currentSelectedVolunteerOnMap.currentVolunteer.home_address)}</div>
                </div>
                <div className='volunteer-action-on-map'>
                  <a target="_blank" rel="noopener noreferrer"
                     href={`/contact-detail/${currentSelectedVolunteerOnMap.currentVolunteer._id}/overview`}>
                    View profile
                  </a>
                </div>
                {
                  currentSelectedVolunteerOnMap.volunteerAssignedStatus !== 'assigned' &&
                  <div className='volunteer-action-on-map' onClick={() => this.handleAssignOrUnAssign(currentSelectedVolunteerOnMap)}>
                    {currentSelectedVolunteerOnMap.volunteerAssignedStatus === 'available' ? messages.assignTo : messages.unassignFrom} selected
                    location
                  </div>
                }
                <div className='volunteer-action-on-map' onClick={() => this.setState({ volunteerId: null })}>
                  Back
                </div>
              </div>
            ) :
            (
              <div className={classes.volunteerList}>
                <div className='volunteer-info-content'>
                  {
                    volunteers.map((item) => (
                      <div key={item.id} className='volunteer-info-status'
                           onClick={() => this.setState({ volunteerId: item.id })}>
                        <div className={`header-status ${item.volunteerAssignedStatus}`}></div>
                        <div className='volunteer-info'>
                          {
                            !isempty(item.currentVolunteer.profile_picture) ?
                              <Image avatar src={item.currentVolunteer.profile_picture['thumb@64_64']} /> :
                              <Image avatar src={require("../../../../../../Assets/avatar.png")} />
                          }
                          <div className='info'>
                            <div className='volunteer-name'>{Utils.combineName(item.currentVolunteer, messages)}</div>
                            <div>{Utils.combineAddress(item.currentVolunteer.home_address)}</div>
                          </div>
                          <Icon name='arrow right' />
                        </div>
                      </div>
                    ))
                  }
                </div>
              </div>
            )
        }
      </GoogleInfoBox>
    )
  }
}

VolunteerClustererInfoBox.contextType = AppContext;

export default injectSheet(stylesheet)(VolunteerClustererInfoBox);