import React from 'react';
import isequal from 'lodash.isequal';
import PropTypes from "prop-types";
import MarkerClusterer from 'react-google-maps/lib/components/addons/MarkerClusterer';

import VolunteerAndInfo from "./VolunteerAndInfo";
import InfoBox from "./InfoBox";
import VolunteerClustererInfoBox from './VolunteerClustererInfoBox';
import Utils from "../../../../../../Common/Utils/Utils";

const CHANGE_TYPE = {
  location: 'location',
}

class VolunteerMarkerAndInfo extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      selectedVolunteerId: '',
      selectedMarkerClusterer: null,
    }
    this.onMarkerClustererClick = this.onMarkerClustererClick.bind(this);
  }

  getVolunteerMarker = () => {
    const { selectedEvent, selectedLocation, volunteerOnMapList } = this.props;
    const volunteers = [];
    volunteerOnMapList.data.forEach(item => {
      if (item.home_address && item.home_address.location && item.home_address.location.coordinates) {
        let volunteerAssignedStatus = 'available';
        const existEvent = item.events
          .find(item => item.event === selectedEvent._id);
        if (existEvent) {
          if (existEvent.location !== selectedLocation._id) {
            if (existEvent.location) {
              // this volunteer is already assigned to another location
              volunteerAssignedStatus = 'assigned';
            }
          } else {
            // this volunteer is already assigned to this location
            volunteerAssignedStatus = 'selected';
          }
        }
        const vltLocation = {
          name: Utils.combineName(item),
          position: {
            lat: item.home_address.location.coordinates[1],
            lng: item.home_address.location.coordinates[0],
          },
          key: item._id,
          id: item._id,
          // defaultAnimation: 2,
          volunteerAssignedStatus: volunteerAssignedStatus,
          icon: require(`../../../../../../Assets/${volunteerAssignedStatus}Volunteer.png`),
          currentVolunteer: item,
        }
        volunteers.push(vltLocation);
      }
    });
    return volunteers;
  }

  handleSelectVolunteer = (selectedVolunteerId) => {
    if (selectedVolunteerId === this.state.selectedVolunteerId) {
      this.setState({ selectedVolunteerId: "", selectedMarkerClusterer: null });
    } else {
      this.setState({ selectedVolunteerId, selectedMarkerClusterer: null });
    }
  }

  onMarkerClustererClick(cluster) {
    const { setCenterMap } = this.props;
    const volunteers = cluster.getMarkers().map(item => item.volunteer);
    const position = {
      lat: cluster.getCenter().lat(),
      lng: cluster.getCenter().lng(),
    };
    const clusterId = volunteers.map(item => item.id).join('-');
    if (this.state.selectedMarkerClusterer && this.state.selectedMarkerClusterer.clusterId === clusterId) {
      this.setState({
        selectedVolunteerId: '',
        selectedMarkerClusterer: null,
      })
    } else {
      setCenterMap(position);
      const selectedMarkerClusterer = {
        clusterId,
        volunteers: volunteers.map(item => item.id),
        position,
      };
      this.setState({
        selectedVolunteerId: '',
        selectedMarkerClusterer,
      })
    }
  }

  getSnapshotBeforeUpdate(prevProps, prevState) {
    if (!isequal(prevProps.selectedLocation, this.props.selectedLocation)) {
      return CHANGE_TYPE.location;
    }
    return null;
  }

  componentDidUpdate(prevProps, prevState, snapshot) {
    if (snapshot === CHANGE_TYPE.location) {
      this.setState({
        selectedVolunteerId: '',
        selectedMarkerClusterer: null,
      })
    }
  }

  render() {
    const { selectedLocation } = this.props;
    const volunteers = this.getVolunteerMarker();
    let selectedVolunteer = {};
    if (this.state.selectedVolunteerId) {
      selectedVolunteer = volunteers.find(item => item.id === this.state.selectedVolunteerId);
    }

    let volunteersCluster = [];
    if (this.state.selectedMarkerClusterer && this.state.selectedMarkerClusterer.volunteers.length > 0) {
      volunteersCluster = volunteers.filter(item => this.state.selectedMarkerClusterer.volunteers.includes(item.id));
    }
    return (
      <React.Fragment>
        <MarkerClusterer
          onClick={this.onMarkerClustererClick}
          enableRetinaIcons
          // gridSize={60}
          zoomOnClick={false}
        >
          {
            volunteers && volunteers.map(volunteer => (
              <VolunteerAndInfo
                selectedLocation={selectedLocation}
                selectedVolunteerId={this.state.selectedVolunteerId}
                handleSelectVolunteer={this.handleSelectVolunteer}
                volunteer={volunteer}
              />
            ))
          }
        </MarkerClusterer>
        {
          this.state.selectedVolunteerId &&
          <InfoBox
            key={selectedLocation._id}
            selectedLocation={selectedLocation}
            {...selectedVolunteer}
          />
        }
        {
          this.state.selectedMarkerClusterer && this.state.selectedMarkerClusterer.volunteers.length > 0 &&
          <VolunteerClustererInfoBox
            key={this.state.selectedMarkerClusterer.clusterId}
            position={this.state.selectedMarkerClusterer.position}
            volunteers={volunteersCluster}
            selectedLocation={selectedLocation}
          />
        }

      </React.Fragment>
    )
  }
}

VolunteerMarkerAndInfo.propType = {
  volunteerOnMapList: PropTypes.shape({}),
  selectedEvent: PropTypes.shape({}).isRequired,
  selectedLocation: PropTypes.shape({}).isRequired,
}

export default VolunteerMarkerAndInfo;