import React from 'react';
import PropTypes from 'prop-types';
import isequal from "lodash.isequal";
import isempty from 'lodash.isempty';
import { Button, Form, Modal } from 'semantic-ui-react';
import injectSheet from "react-jss";
import AppContext from "../../../../../Common/Constants/AppContext";
import Enum from "../../../../../Common/Constants/Enum";
import SearchAddress from "../../../../../Common/Components/AutocompleteSearchAddress/SearchAddress";
import { ModalStyleSheet } from "../../../../../Common/GlobalStyle";
import ElectorateComponent from "../../../../../Common/Components/ElectorateComponent/ElectorateComponent";
import LocationActionCreator from "../../../../Actions/LocationActionCreator";

class LocationInfoModal extends React.Component {
  constructor(props) {
    super(props);
    const locationInfo = {
      ...props.locationInfo,
      voting_district: props.locationInfo.voting_district || {
        name: 'Select',
      }
    };
    delete locationInfo.delivery;
    this.state = {
      locationInfo,
    };
    this.isFieldError = this.isFieldError.bind(this);
    this.handleChange = this.handleChange.bind(this);
    this.handleSubmit = this.handleSubmit.bind(this);
    this.handleSelectElectorate = this.handleSelectElectorate.bind(this);
  }

  handleChange({ target: { name, value } }) {
    if (name === 'expected_votes') {
      let volunteers_required;
      if (value < 1000) {
        volunteers_required = 2;
      } else if (value < 2000) {
        volunteers_required = 4;
      } else {
        volunteers_required = 6;
      }
      this.setState({
        locationInfo: {
          ...this.state.locationInfo,
          [name]: value,
          volunteers_required,
        }
      })
    } else {
      this.setState({
        locationInfo: {
          ...this.state.locationInfo,
          [name]: value,
        }
      })
    }
  }

  handleSelectElectorate(selectedElectorate) {
    this.setState({
      locationInfo: {
        ...this.state.locationInfo,
        voting_district: selectedElectorate,
      }
    });
  }

  isFieldError(name) {
    const { intl: { messages } } = this.context;
    if (name === 'address') {
      if (isempty(this.state.locationInfo[name])) {
        return `${messages.pleaseEnter} ${messages[name]}`;
      }
    } else if (name === 'electorate') {
      if (!this.state.locationInfo.voting_district || !this.state.locationInfo.voting_district._id) {
        return `${messages.pleaseEnter} ${messages[name]}`;
      }
    } else if (this.state.locationInfo[name] === undefined ||
      this.state.locationInfo[name] === null ||
      this.state.locationInfo[name] === ''
    ) {
      let fieldText = messages[name];
      if (name === 'name') {
        fieldText = messages.locationName;
      }
      return `${messages.pleaseEnter} ${fieldText}`;
    }
    return '';
  }

  handleSubmit() {
    if (!this.state.isHitSave) {
      this.setState({
        isHitSave: true,
      });
    }
    if (this.isFieldError('name') ||
      this.isFieldError('electorate') ||
      this.isFieldError('expected_votes') ||
      this.isFieldError('volunteers_required') ||
      this.isFieldError('status')
    ) {
      return;
    }
    const { dispatch } = this.context;
    const { selectedEvent,onClose, onMap } = this.props;
    const voting_district = this.state.locationInfo.voting_district._id;
    const locationInfo = {
      ...this.state.locationInfo,
      voting_district,
    }
    if (locationInfo._id) {
      if(onMap) {
        dispatch(LocationActionCreator.saveLocationOnMap(selectedEvent._id, locationInfo));
      } else {
        dispatch(LocationActionCreator.saveLocation(selectedEvent._id, locationInfo));
      }
    } else {
      if(onMap) {
        dispatch(LocationActionCreator.createLocationOnMap(selectedEvent._id, locationInfo));
      } else {
        dispatch(LocationActionCreator.createLocation(selectedEvent._id, locationInfo));
      }
    }
    onClose();
  }

  render() {
    const { classes, isOpen, onClose } = this.props;
    const { intl: { messages } } = this.context;
    const { locationInfo } = this.state;
    const eventLocationStatus = Object.values(Enum.EventLocationStatus).map(item => ({
      key: item,
      value: item,
      text: messages[item],
    }));
    return (
      <Modal
        open={isOpen}
        onClose={onClose}
        size="tiny"
      >
        <Modal.Header className={classes.header}>
          {
            locationInfo._id ? messages.updateLocation : messages.addLocation
          }
        </Modal.Header>
        <Modal.Content>
          <Form
            onSubmit={this.handleSubmit}
          >
            <Form.Field required error={this.state.isHitSave && this.isFieldError('name')}>
              <label>{messages.locationName}</label>
              <input
                placeholder={messages.locationName}
                name='name'
                value={locationInfo.name}
                onChange={this.handleChange}
              />
              {
                this.state.isHitSave && this.isFieldError('name') &&
                <div className={classes.helpText}>{this.isFieldError('name')}</div>
              }
            </Form.Field>
            <Form.Field required error={this.state.isHitSave && this.isFieldError('address')}>
              <label>{messages.address}</label>
              <SearchAddress
                address={locationInfo.address}
                onSelect={(addressInfo) => this.handleChange({ target: { name: 'address', value: addressInfo } })}
              />
              {
                this.state.isHitSave && this.isFieldError('address') &&
                <div className={classes.helpText}>{this.isFieldError('address')}</div>
              }
            </Form.Field>
            <Form.Field required error={this.state.isHitSave && this.isFieldError('electorate')}>
              <label>{messages.electorate}</label>
              <ElectorateComponent
                onSelect={this.handleSelectElectorate}
                defaultSelected={locationInfo.voting_district}
              />
              {
                this.state.isHitSave && this.isFieldError('electorate') &&
                <div className={classes.helpText}>{this.isFieldError('electorate')}</div>
              }
            </Form.Field>
            <Form.Field required error={this.state.isHitSave && this.isFieldError('expected_votes')}>
              <label>{messages.expected_votes}</label>
              <input
                placeholder={messages.expected_votes}
                name='expected_votes'
                type='number'
                value={locationInfo.expected_votes}
                onChange={this.handleChange}
              />
              {
                this.state.isHitSave && this.isFieldError('expected_votes') &&
                <div className={classes.helpText}>{this.isFieldError('expected_votes')}</div>
              }
            </Form.Field>
            <Form.Field required error={this.state.isHitSave && this.isFieldError('status')}>
              <label>{messages.status}</label>
              <Form.Select
                options={eventLocationStatus}
                placeholder={messages.status}
                name='status'
                value={locationInfo.status}
                onChange={(e, target) => this.handleChange({ target: target })}
              />
              {
                this.state.isHitSave && this.isFieldError('status') &&
                <div className={classes.helpText}>{this.isFieldError('status')}</div>
              }
            </Form.Field>
            <Form.Field required error={this.state.isHitSave && this.isFieldError('volunteers_required')}>
              <label>{messages.volunteers_required}</label>
              <input
                placeholder={messages.volunteers_required}
                name='volunteers_required'
                type='number'
                value={locationInfo.volunteers_required}
                onChange={this.handleChange}
              />
              {
                this.state.isHitSave && this.isFieldError('volunteers_required') &&
                <div className={classes.helpText}>{this.isFieldError('volunteers_required')}</div>
              }
            </Form.Field>
            <Form.Field className={classes.actionGroup}>
              <Button onClick={onClose}>
                {messages.cancel}
              </Button>
              <Button
                type='submit'
                color='green'
                disabled={isequal(this.props.locationInfo, locationInfo) && locationInfo._id}
              >
                {
                  locationInfo._id ? messages.update : messages.create
                }
              </Button>
            </Form.Field>
          </Form>
        </Modal.Content>
      </Modal>
    )
  }
}

LocationInfoModal.propTypes = {
  isOpen: PropTypes.bool.isRequired,
  onClose: PropTypes.func.isRequired,
  locationInfo: PropTypes.shape({}).isRequired,
  selectedEvent: PropTypes.shape({}).isRequired,
  onMap: PropTypes.bool,
};

LocationInfoModal.defaultProps = {
  onMap: false,
}

LocationInfoModal.contextType = AppContext;

export default injectSheet(ModalStyleSheet)(LocationInfoModal);