import React from 'react';
import PropTypes from 'prop-types';
import debounce from "lodash.debounce";
import { Button, Input, List, Loader, Checkbox, Popup, Icon } from 'semantic-ui-react';

import Utils from "../../../../../Common/Utils/Utils";
import ReduxStatus from "../../../../../Common/Constants/ReduxStatus";
import Enum from "../../../../../Common/Constants/Enum";

import LocationInfoModal from './LocationInfoModal';
import ConfirmModal from "../../../../../Common/Components/Modal/ConfirmModal";
import AppContext from "../../../../../Common/Constants/AppContext";
import LocationActionCreator from "../../../../Actions/LocationActionCreator";
import ElectorateComponent from "../../../../../Common/Components/ElectorateComponent/ElectorateComponent";
import { eventVotingDistrictLocation } from "../../../../../Common/Constants/AppKey";

class LocationList extends React.Component {
  constructor(props) {
    super(props);
    let selectedVotingDistrict = {};
    const preSelectedData = Utils.getLocalStorage(eventVotingDistrictLocation);
    if (preSelectedData) {
      const { selectedEvent } = props;
      selectedVotingDistrict = preSelectedData[selectedEvent._id] ? (preSelectedData[selectedEvent._id].votingDistrict || {}) : {};
    }

    this.state = {
      toggleShowHide: true,

      toggleDeleteLocation: false,
      selectedDeleteLocation: null,

      toggleLocationModal: false,
      locationInfo: {},

      searchText: '',
      searchStatus: Object.values(Enum.EventLocationStatus),
      currentSelectedElectorate: selectedVotingDistrict,
    }

    this.onSearchFilterChange = debounce(this.onSearchFilterChange.bind(this), 300);
    this.handleDeleteLocation = this.handleDeleteLocation.bind(this);
    this.getSearchFilterQuery = this.getSearchFilterQuery.bind(this);
    this.toggleChange = this.toggleChange.bind(this);
    this.handleSelectElectorate = this.handleSelectElectorate.bind(this);
  }

  componentDidMount() {
    if (this.state.currentSelectedElectorate._id) {
      const { dispatch } = this.context;
      const { selectedEvent } = this.props;
      const filter = this.getSearchFilterQuery(this.state.searchText, this.state.searchStatus, this.state.currentSelectedElectorate);
      dispatch(LocationActionCreator.getLocationsOnMap(selectedEvent._id, 1, filter));
    }
  }

  getSearchFilterQuery(searchText, status, electorate) {
    const { handleSelectLocation } = this.props;
    handleSelectLocation({});
    const filter = {
      "$and": [],
    };
    if (searchText) {
      const search = [
        {
          "name": {
            "$regex": searchText,
            "$options": "i",
          },
        },
        {
          "address.line1": {
            "$regex": searchText,
            "$options": "i"
          }
        },
        {
          "address.line2": {
            "$regex": searchText,
            "$options": "i"
          }
        },
        {
          "address.line3": {
            "$regex": searchText,
            "$options": "i"
          }
        },
        {
          "address.city": {
            "$regex": searchText,
            "$options": "i"
          }
        },

        {
          "address.state": {
            "$regex": searchText,
            "$options": "i"
          }
        },
        {
          "address.country": {
            "$regex": searchText,
            "$options": "i"
          }
        },
      ];
      filter["$and"].push({
        "$or": search,
      });
    }
    filter["$and"].push({
      "status": { "$in": status }
    })
    if (electorate._id) {
      filter["$and"].push({
        "voting_district": electorate._id,
      })
    }
    return filter;
  }

  onSearchFilterChange(e, { value }) {
    const { dispatch } = this.context;
    const { selectedEvent } = this.props;
    const filter = this.getSearchFilterQuery(value, this.state.searchStatus, this.state.currentSelectedElectorate);
    this.setState({
      searchText: value,
    })
    dispatch(LocationActionCreator.getLocationsOnMap(selectedEvent._id, 1, filter));
  }

  handleDeleteLocation() {
    const { dispatch } = this.context;
    const { selectedEvent } = this.props;
    dispatch(LocationActionCreator.deleteLocation(selectedEvent._id, this.state.selectedDeleteLocation._id));
    this.setState({
      toggleDeleteLocation: false,
      selectedDeleteLocation: null,
    })
  }

  toggleChange(status) {
    const newSearchStatus = [...this.state.searchStatus];
    if (newSearchStatus.includes(status)) {
      const index = newSearchStatus.indexOf(status);
      newSearchStatus.splice(index, 1);
    } else {
      newSearchStatus.push(status);
    }
    this.setState({
      searchStatus: newSearchStatus,
    });

    const { dispatch } = this.context;
    const { selectedEvent } = this.props;
    const filter = this.getSearchFilterQuery(this.state.searchText, newSearchStatus);
    dispatch(LocationActionCreator.getLocationsOnMap(selectedEvent._id, 1, filter));
  }

  handleSelectElectorate(selectedElectorate) {
    this.setState({
      currentSelectedElectorate: selectedElectorate,
    });
    const { dispatch } = this.context;
    const { selectedEvent } = this.props;
    const filter = this.getSearchFilterQuery(this.state.searchText, this.state.searchStatus, selectedElectorate);
    dispatch(LocationActionCreator.getLocationsOnMap(selectedEvent._id, 1, filter));

    const preSelectedData = Utils.getLocalStorage(eventVotingDistrictLocation) || {
      [selectedEvent._id]: {
        location: {},
        votingDistrict: {}
      }
    };

    if (preSelectedData[selectedEvent._id]) {
      preSelectedData[selectedEvent._id].votingDistrict = selectedElectorate;
      preSelectedData[selectedEvent._id].location = {};
    } else {
      preSelectedData[selectedEvent._id] = {
        votingDistrict: selectedElectorate,
        location: {},
      }
    }
    Utils.setLocalStorage(eventVotingDistrictLocation, preSelectedData);
  }

  render() {
    const { intl: { messages }, currentUser } = this.context;
    const {
      classes,
      locationList: { data, status: locationStatus },
      selectedLocation,
      handleSelectLocation,
      selectedEvent,
    } = this.props;

    const style = {
      width: '1px',
      minWidth: '1px',
    }

    return (
      <div className='event-location-list' style={this.state.toggleShowHide ? {} : style}>
        <div className='toggle-show-hide-panel'
             onClick={() => this.setState({ toggleShowHide: !this.state.toggleShowHide })}>
          {
            this.state.toggleShowHide ?
              [
                <span key='close'>Close</span>,
                <Icon key='close-icon' name='close' />
              ] : [
                <span key='open'>Open</span>,
                <Icon key='open-icon' name='angle down' />
              ]
          }
        </div>
        {
          this.state.toggleLocationModal &&
          <LocationInfoModal
            isOpen={this.state.toggleLocationModal}
            onClose={() => this.setState({ toggleLocationModal: false })}
            locationInfo={this.state.locationInfo}
            selectedEvent={selectedEvent}
            onMap={true}
          />
        }
        {
          this.state.toggleDeleteLocation &&
          <ConfirmModal
            isOpen={true}
            onClose={() => this.setState({ toggleDeleteLocation: false })}
            onConfirm={this.handleDeleteLocation}
            content={{
              mainText: messages.deleteText.replace('{item}', this.state.selectedDeleteLocation.name),
              description: messages.messageConfirm.replace('{name}',
                `${currentUser.first_name}`)
            }}
            title={messages.deleteLocation}
            cancelText={messages.keepThisLocation}
            confirmText={messages.delete}
          />
        }
        <div className='event-location-search-electorate'>
          <ElectorateComponent
            getDefault
            onSelect={this.handleSelectElectorate}
            defaultSelected={this.state.currentSelectedElectorate}
          />
        </div>
        <div className='event-location-search'>
          <Input
            icon='search'
            iconPosition='left'
            placeholder='Search locations'
            onChange={this.onSearchFilterChange}
          />
          <Popup
            trigger={(
              <div className='filter-container'>
                <span>{messages.filter}</span>
                <Icon name='angle down' />
              </div>
            )}
            content={(
              <div className={classes.filterOptions}>
                {
                  Object.values(Enum.EventLocationStatus).map(item => (
                    <Checkbox key={item} label={messages[item]} onChange={() => this.toggleChange(item)}
                              checked={this.state.searchStatus.includes(item)} />
                  ))
                }
              </div>
            )}
            on='click'
            position='bottom center'
          />
        </div>
        <div className='event-location-content'>
          <List selection celled>
            {
              data.map((location) => (
                <List.Item
                  key={location._id}
                  className={selectedLocation._id === location._id ? 'select-location' : ''}
                  onClick={() => handleSelectLocation(location)}
                >
                  <List.Content>
                    <List.Header>
                      <span className='name'>{location.name}</span>
                      <div className='item-action'>
                        <div
                          onClick={(e) => {
                            e.stopPropagation();
                            this.setState({
                              toggleDeleteLocation: true,
                              selectedDeleteLocation: location,
                            })
                          }}
                        >
                          {messages.delete}
                        </div>
                        <div
                          onClick={(e) => {
                            e.stopPropagation();
                            this.setState({
                              toggleLocationModal: true,
                              locationInfo: location,
                            })
                          }}
                        >
                          {messages.edit}
                        </div>
                      </div>
                    </List.Header>
                    <List.Description className='second-description'>
                      {Utils.combineAddress(location.address)}
                    </List.Description>
                    <List.Description>{location.expected_votes} {messages.estimatedVotes}</List.Description>
                    <List.Description className='last-description'>
                        <span>
                          {location.volunteers ? location.volunteers.length : 0}/
                          {location.volunteers_required} {messages.volunteers}
                        </span>
                      <div className={`status ${location.status}`}>{messages[location.status]}</div>
                    </List.Description>
                  </List.Content>
                </List.Item>
              ))
            }
          </List>
          {
            locationStatus === ReduxStatus.loading &&
            <Loader active />
          }
        </div>
        {
          this.state.toggleShowHide &&
          <div className='event-location-action'>
            <Button
              color='green'
              labelPosition='right'
              fluid
              content='Add event location'
              icon='add'
              onClick={() => this.setState({
                toggleLocationModal: true,
                locationInfo: {},
              })}
            >
            </Button>
          </div>
        }
      </div>
    );
  }
}

LocationList.contextType = AppContext;

LocationList.propTypes = {
  classes: PropTypes.shape({}),
  selectedEvent: PropTypes.shape({}),
  locationList: PropTypes.shape({}),
  selectedLocation: PropTypes.shape({}),
  handleSelectLocation: PropTypes.func,
}

export default LocationList;