import React from 'react';
import { Loader, List, Pagination, Input } from 'semantic-ui-react';
import injectSheet from "react-jss";

import ReduxStatus from "../../../../Common/Constants/ReduxStatus";
import stylesheet from "./stylesheet";
import AppContext from "../../../../Common/Constants/AppContext";
import moment from "moment/moment";
import NoteInfoModal from './NoteInfoModal';
import EventNoteActionCreator from "../../../Actions/EventNoteActionCreator";
import Confirmation from '../../../../Common/Components/Modal/ConfirmModal';
import Utils from "../../../../Common/Utils/Utils";
import Enum from "../../../../Common/Constants/Enum";
import AddButton from "../../../../Common/Components/Base/AddButton";

class EventNotes extends React.Component {
  constructor() {
    super();
    this.state = {
      toggleEdit: false,
      noteInfo: {},

      selectedDeleteNoteId: '',
      toggleDelete: false,
    }
    this.handleDeleteNote = this.handleDeleteNote.bind(this);
    this.handlePaginationChange = this.handlePaginationChange.bind(this);
    this.onSearchFilterChange = this.onSearchFilterChange.bind(this);
  }

  componentDidMount() {
    const { dispatch } = this.context;
    const { selectedEvent } = this.props;
    const filter = {
      event: selectedEvent._id,
    }
    dispatch(EventNoteActionCreator.getEventNotes(1, filter));
  }

  handlePaginationChange(e, { activePage }) {
    const { dispatch } = this.context;
    const { eventNotes: { filter } } = this.props;
    dispatch(EventNoteActionCreator.getEventNotes(activePage, filter))
  }

  onSearchFilterChange(e, { value }) {
    const { dispatch } = this.context;
    const { eventNotes } = this.props;
    const newFilter = { ...eventNotes.filter };
    if (value) {
      newFilter.note = { "$regex": value, "$options": "i" };
    } else {
      newFilter.note = null;
    }
    dispatch(EventNoteActionCreator.getEventNotes(1, newFilter))
  }

  handleDeleteNote() {
    const { dispatch } = this.context;
    dispatch(EventNoteActionCreator.deleteEventNotes(this.state.selectedDeleteNoteId));
    this.setState({
      selectedDeleteNoteId: '',
      toggleDelete: false,
    })
  }

  render() {
    const { intl: { messages }, currentUser } = this.context;
    const { classes, selectedEvent, eventNotes: { data, status, activePage, totalPage } } = this.props;
    return (
      <div className={classes.eventOverviewNote}>
        {
          this.state.toggleEdit &&
          <NoteInfoModal
            isOpen={this.state.toggleEdit}
            onClose={() => this.setState({ toggleEdit: false })}
            noteInfo={this.state.noteInfo}
          />
        }
        {
          this.state.toggleDelete &&
          <Confirmation
            isOpen={true}
            onClose={() => this.setState({ toggleDelete: false })}
            onConfirm={this.handleDeleteNote}
            content={{
              mainText: messages.deleteText.replace('{item}', 'this note'),
              description: messages.messageConfirm.replace('{name}',
                `${currentUser.first_name}`)
            }}
            title={messages.deleteNote}
            cancelText={messages.keepThisNote}
            confirmText={messages.delete}
          />
        }
        <AddButton
          onClick={() => this.setState({
            toggleEdit: true,
            noteInfo: {
              event: selectedEvent._id,
              author: currentUser._id,
              category: Enum.ContactNotes.general,
            }
          })}
          content={messages.addNote}
        />
        <div className='event-note-header'>
          <Input
            icon='search'
            iconPosition='left'
            placeholder='Search note...'
            onChange={this.onSearchFilterChange}
          />
        </div>
        <List selection celled>
          {
            data.map((note) => (
              <List.Item
                key={note._id}
              >
                <List.Content>
                  <div className='note-content'>
                    <div className='note'>{note.note}</div>
                    <div className='author'>Added by {Utils.combineName(note.author)}</div>
                    <div>
                      {moment(new Date(note.created_at)).format('DD MMM YYYY')}
                    </div>
                    <div className='item-action'>
                      <div
                        onClick={(e) => {
                          e.stopPropagation();
                          this.setState({
                            selectedDeleteNoteId: note._id,
                            toggleDelete: true,
                          })
                        }}
                      >
                        {messages.delete}
                      </div>
                      <div
                        onClick={(e) => {
                          e.stopPropagation();

                          this.setState({
                            toggleEdit: true,
                            noteInfo: {
                              ...note,
                              event: selectedEvent._id,
                              author: currentUser._id,
                            }
                          })
                        }}
                      >
                        {messages.edit}
                      </div>
                    </div>
                  </div>
                </List.Content>
              </List.Item>
            ))
          }
        </List>
        {
          data.length > 0 && totalPage > 1 &&
          <Pagination
            activePage={activePage}
            totalPages={totalPage}
            onPageChange={this.handlePaginationChange}
          />
        }
        {
          status === ReduxStatus.loading &&
          <Loader active />
        }
      </div>
    )
  }
}

EventNotes.contextType = AppContext;

export default injectSheet(stylesheet)(EventNotes);