import React from 'react';
import PropTypes from "prop-types";
import injectSheet from "react-jss";
import { Form, Loader } from 'semantic-ui-react';
import isempty from "lodash.isempty";

import AppContext from "../../../../Common/Constants/AppContext";
import SearchLocation from "../../../../Common/Components/Search/SearchLocation";
import stylesheet from './stylesheet';
import ScheduleActionCreator from "../../../Actions/ScheduleActionCreator";
import Scheduler from "../../../../Common/Components/Scheduler/Scheduler";
import EventScheduleInfoModal from "./EventScheduleInfoModal";
import ConfirmModal from "../../../../Common/Components/Modal/ConfirmModal";
import Utils from "../../../../Common/Utils/Utils";
import ElectorateComponent from "../../../../Common/Components/ElectorateComponent/ElectorateComponent";
import ReduxStatus from "../../../../Common/Constants/ReduxStatus";
import { eventVotingDistrictLocation } from "../../../../Common/Constants/AppKey";

class EventSchedule extends React.Component {
  constructor(props) {
    super(props);
    let selectedLocation = {};
    let selectedVotingDistrict = {};
    const preSelectedData = Utils.getLocalStorage(eventVotingDistrictLocation);
    if (preSelectedData) {
      const { selectedEvent } = props;
      selectedLocation = preSelectedData[selectedEvent._id] ? (preSelectedData[selectedEvent._id].location || {}) : {};
      selectedVotingDistrict = preSelectedData[selectedEvent._id] ? (preSelectedData[selectedEvent._id].votingDistrict || {}) : {};
    }
    this.state = {
      selectedLocation: selectedLocation,
      selectedVotingDistrict: selectedVotingDistrict,

      toggleAddEventSchedule: false,
      selectedEventSchedule: {},

      toggleDeleteEventSchedule: false,
      selectedDeleteEventSchedule: {},
    }
    this.handleSelectLocation = this.handleSelectLocation.bind(this);
    this.handleSelectElectorate = this.handleSelectElectorate.bind(this);
    this.handleSaveEventSchedule = this.handleSaveEventSchedule.bind(this);
    this.handleRemoveTimeSlot = this.handleRemoveTimeSlot.bind(this);
  }

  componentDidMount() {
    const { dispatch } = this.context;
    const { selectedLocation } = this.state;
    if (!isempty(selectedLocation)) {
      dispatch(ScheduleActionCreator.getLocationSchedule(selectedLocation._id));
    }
  }

  handleSelectLocation(selectedLocation) {
    const { dispatch } = this.context;
    this.setState({
      selectedLocation,
    });

    const { selectedEvent } = this.props;
    const preSelectedData = Utils.getLocalStorage(eventVotingDistrictLocation) || {
      [selectedEvent._id]: {
        location: {},
        votingDistrict: {}
      }
    };
    if (preSelectedData[selectedEvent._id]) {
      preSelectedData[selectedEvent._id].location = selectedLocation;
    } else {
      preSelectedData[selectedEvent._id] = {
        location: selectedLocation,
      }
    }
    Utils.setLocalStorage(eventVotingDistrictLocation, preSelectedData);
    if (selectedLocation._id) {
      dispatch(ScheduleActionCreator.getLocationSchedule(selectedLocation._id))
    } else {
      dispatch(ScheduleActionCreator.resetLocationSchedule());
    }
  }

  handleSelectElectorate(selectedElectorate) {
    this.setState({
      selectedVotingDistrict: selectedElectorate,
      selectedLocation: {},
    });
    const { selectedEvent } = this.props;
    const preSelectedData = Utils.getLocalStorage(eventVotingDistrictLocation) || {
      [selectedEvent._id]: {
        location: {},
        votingDistrict: {}
      }
    };

    if (preSelectedData[selectedEvent._id]) {
      preSelectedData[selectedEvent._id].votingDistrict = selectedElectorate;
    } else {
      preSelectedData[selectedEvent._id] = {
        votingDistrict: selectedElectorate,
      }
    }
    Utils.setLocalStorage(eventVotingDistrictLocation, preSelectedData);

  }

  handleSaveEventSchedule(eventScheduleInfo) {
    const { dispatch } = this.context;
    const { selectedLocation } = this.state;
    if (!isempty(selectedLocation)) {
      if (eventScheduleInfo._id) {
        dispatch(ScheduleActionCreator.saveLocationSchedule(selectedLocation._id, eventScheduleInfo));

      } else {
        dispatch(ScheduleActionCreator.createLocationSchedule(selectedLocation._id, eventScheduleInfo));
      }
      this.setState({
        toggleAddEventSchedule: false,
        selectedEventSchedule: {}
      })
    }
  }

  handleRemoveTimeSlot() {
    const { selectedLocation } = this.state;
    if (!isempty(selectedLocation)) {
      const { dispatch } = this.context;
      dispatch(ScheduleActionCreator.deleteLocationSchedule(selectedLocation._id, this.state.selectedDeleteEventSchedule._id));
      this.setState({
        toggleDeleteEventSchedule: false,
        selectedDeleteEventSchedule: null,
      })
    }
  }

  render() {
    const { classes, selectedEvent, locationSchedule: { data, status } } = this.props;
    const { intl: { messages }, currentUser } = this.context;
    const { selectedLocation } = this.state;
    return (
      <div className={classes.eventSchedulePage}>
        <Form>
          <Form.Group className='filter-electorate-location'>
            <Form.Field>
              <label>Electorate</label>
              <ElectorateComponent
                getDefault
                onSelect={this.handleSelectElectorate}
                defaultSelected={this.state.selectedVotingDistrict}
              />
            </Form.Field>
            <Form.Field>
              <div style={{ marginTop: '32px' }}>and</div>
            </Form.Field>
            <Form.Field className='search-location-container'>
              <label>Select location</label>
              {
                <SearchLocation
                  eventId={selectedEvent._id}
                  onSelect={this.handleSelectLocation}
                  value={selectedLocation.name}
                  initLocation={selectedLocation}
                  getDefault
                  voting_district={this.state.selectedVotingDistrict._id}
                />
              }
            </Form.Field>
          </Form.Group>
        </Form>
        {
          selectedLocation._id && [
            this.state.toggleAddEventSchedule &&
            <EventScheduleInfoModal
              isOpen={this.state.toggleAddEventSchedule}
              onClose={() => this.setState({ toggleAddEventSchedule: false })}
              onOk={this.handleSaveEventSchedule}
              selectedEvent={selectedEvent}
              eventScheduleInfo={this.state.selectedEventSchedule}
            />,
            this.state.toggleDeleteEventSchedule &&
            <ConfirmModal
              isOpen={true}
              onClose={() => this.setState({ toggleDeleteEventSchedule: false })}
              onConfirm={this.handleRemoveTimeSlot}
              content={{
                mainText: messages.removeVolunteerFromLocationText.replace('{name}', Utils.combineName(this.state.selectedDeleteEventSchedule.volunteer, messages)),
                description: messages.messageConfirm.replace('{name}',
                  `${currentUser.first_name}`)
              }}
              title={messages.deleteTimeSlot}
              cancelText={messages.keepThisTimeSlot}
              confirmText={messages.delete}
            />,
            <Scheduler
              scheduleData={data}
              editResource={(item) => this.setState({
                toggleAddEventSchedule: true,
                selectedEventSchedule: item
              })}
              deleteResource={(item => this.setState({
                toggleDeleteEventSchedule: true,
                selectedDeleteEventSchedule: item
              }))}
            />,
            status === ReduxStatus.loading &&
            <Loader active />
          ]
        }
      </div>
    );
  }
}

EventSchedule.propTypes = {
  selectedEvent: PropTypes.shape({}).isRequired,
  locationSchedule: PropTypes.shape({}).isRequired,
};

EventSchedule.contextType = AppContext;

export default injectSheet(stylesheet)(EventSchedule);