import React from 'react';
import PropTypes from 'prop-types';
import isequal from "lodash.isequal";
import { Button, Form, Icon, Modal } from 'semantic-ui-react';
import injectSheet from "react-jss";
import AppContext from "../../../../Common/Constants/AppContext";
import DatePicker from "react-datepicker/es";
import { ModalStyleSheet } from "../../../../Common/GlobalStyle";
import colors from "../../../../Common/Constants/color";

const inlineStyle = {
  display: 'flex',
  alignItems: 'center',
  justifyContent: 'space-around',
}

class EventScheduleInfoModal extends React.Component {
  constructor(props) {
    super(props);
    const eventScheduleInfo = { ...props.eventScheduleInfo };
    if (eventScheduleInfo.time_slots && eventScheduleInfo.time_slots.length > 0) {
      eventScheduleInfo.time_slots.forEach(item => {
        item.start_time = new Date(item.start_time);
        item.end_time = new Date(item.end_time);
      });
    } else {
      eventScheduleInfo.time_slots = [];
    }
    this.state = {
      eventScheduleInfo: {
        ...eventScheduleInfo,
        volunteer: eventScheduleInfo.volunteer ? eventScheduleInfo.volunteer._id : '',
      },
    };
    this.isFieldError = this.isFieldError.bind(this);
    this.handleSubmit = this.handleSubmit.bind(this);
    this.handleSelectVolunteer = this.handleSelectVolunteer.bind(this);
    this.handleChangeTime = this.handleChangeTime.bind(this);
  }

  handleSelectVolunteer(selectedVolunteer) {
    this.setState({
      eventScheduleInfo: {
        ...this.state.eventScheduleInfo,
        volunteer: selectedVolunteer._id,
      }
    })
  }

  handleChangeTime(name, value, index) {
    const eventScheduleInfo = { ...this.state.eventScheduleInfo };
    const year = eventScheduleInfo.time_slots[index].start_time.getFullYear();
    const month = eventScheduleInfo.time_slots[index].start_time.getMonth();
    const date = eventScheduleInfo.time_slots[index].start_time.getDate();
    let hours = 0;
    let minutes = 0;
    if (value) {
      hours = value.getHours();
      minutes = value.getMinutes();
    }
    eventScheduleInfo.time_slots[index][name] = new Date(year, month, date, hours, minutes, 0);
    this.setState({
      eventScheduleInfo,
    });
  }

  handleAddTimeSlot = () => {
    const { selectedEvent } = this.props;
    const eventScheduleInfo = { ...this.state.eventScheduleInfo };
    eventScheduleInfo.time_slots = eventScheduleInfo.time_slots.slice(0);
    eventScheduleInfo.time_slots.push({
      start_time: new Date(selectedEvent.start_time),
      end_time: new Date(selectedEvent.end_time),
    });
    this.setState({
      eventScheduleInfo,
    });
  }

  handleRemoveTimeSlot = (index) => {
    const eventScheduleInfo = { ...this.state.eventScheduleInfo };
    eventScheduleInfo.time_slots = eventScheduleInfo.time_slots.slice(0);
    eventScheduleInfo.time_slots.splice(index, 1);
    this.setState({
      eventScheduleInfo,
    });
  }

  isFieldError(name, index) {
    if (!this.state.eventScheduleInfo.time_slots[index][name])
      if (!this.state.eventScheduleInfo[name]) {
        return true;
      }
    return false;
  }

  handleSubmit() {
    if (!this.state.isHitSave) {
      this.setState({
        isHitSave: true,
      });
    }
    let valid = true;
    this.state.eventScheduleInfo.time_slots.forEach(item => {
      if(!item.start_time || !item.end_time) {
        valid = false;
      }
    });
    if (!valid) {
      return;
    }
    const { onOk } = this.props;
    const eventScheduleInfo = { ...this.state.eventScheduleInfo };
    eventScheduleInfo.time_slots.forEach(item => {
      item.start_time = new Date(item.start_time).getTime();
      item.end_time = new Date(item.end_time).getTime();
    });
    onOk(eventScheduleInfo);
  }

  render() {
    const { classes, isOpen, onClose } = this.props;
    const { intl: { messages } } = this.context;
    const { eventScheduleInfo } = this.state;
    return (
      <Modal
        open={isOpen}
        onClose={onClose}
        size="tiny"
      >
        <Modal.Header className={classes.header}>
          {
            eventScheduleInfo._id ? messages.editTimeSlot : messages.addTimeSlot
          }
        </Modal.Header>
        <Modal.Content>
          <Form
            onSubmit={this.handleSubmit}
          >
            <h4>Time slot</h4>
            {
              eventScheduleInfo.time_slots.map((item, index) => (
                <Form.Group inline>
                  <Form.Field style={inlineStyle}
                              error={this.state.isHitSave && this.isFieldError('start_time', index)}>
                    <label>From</label>
                    <DatePicker
                      showTimeSelect
                      showTimeSelectOnly
                      timeIntervals={5}
                      selected={eventScheduleInfo.time_slots[index].start_time}
                      onChange={(value) => this.handleChangeTime('start_time', value, index)}
                      dateFormat="HH:mm"
                      timeFormat="HH:mm"
                      placeholderText='HH:MM'
                      minTime={new Date(new Date(new Date().setHours(0)).setMinutes(0))}
                      maxTime={new Date(new Date(new Date().setHours(eventScheduleInfo.time_slots[index].end_time.getHours())).setMinutes(eventScheduleInfo.time_slots[index].end_time.getMinutes()))}
                    />
                  </Form.Field>
                  <Form.Field style={inlineStyle} error={this.state.isHitSave && this.isFieldError('end_time', index)}>
                    <label>To</label>
                    <DatePicker
                      showTimeSelect
                      showTimeSelectOnly
                      timeIntervals={5}
                      selected={eventScheduleInfo.time_slots[index].end_time}
                      onChange={(value) => this.handleChangeTime('end_time', value, index)}
                      dateFormat="HH:mm"
                      timeFormat="HH:mm"
                      placeholderText='HH:MM'
                      minTime={new Date(new Date(new Date().setHours(eventScheduleInfo.time_slots[index].start_time.getHours())).setMinutes(eventScheduleInfo.time_slots[index].start_time.getMinutes()))}
                      maxTime={new Date(new Date(new Date().setHours(23)).setMinutes(59))}
                    />
                  </Form.Field>
                  {
                    eventScheduleInfo.time_slots.length > 1 &&
                    <Icon
                      name='remove'
                      style={{ cursor: 'pointer' }}
                      color='red'
                      onClick={() => this.handleRemoveTimeSlot(index)}
                    />
                  }
                </Form.Group>
              ))
            }
            <Form.Field>
              <Icon color='blue' name='add' />
              <span onClick={this.handleAddTimeSlot} style={{ color: colors.primaryBlue, cursor: 'pointer' }}>Add time slot</span>
            </Form.Field>
            <Form.Field className={classes.actionGroup}>
              <Button onClick={onClose}>
                {messages.cancel}
              </Button>
              <Button
                type='submit'
                color='green'
                disabled={isequal(this.props.eventScheduleInfo, eventScheduleInfo) && eventScheduleInfo._id}
              >
                {
                  eventScheduleInfo._id ? messages.update : messages.add
                }
              </Button>
            </Form.Field>
          </Form>
        </Modal.Content>
      </Modal>
    )
  }
}

EventScheduleInfoModal.propTypes = {
  isOpen: PropTypes.bool.isRequired,
  onClose: PropTypes.func.isRequired,
  onOk: PropTypes.func.isRequired,
  selectedEvent: PropTypes.shape({}).isRequired,
  eventScheduleInfo: PropTypes.shape({}).isRequired,
};

EventScheduleInfoModal.contextType = AppContext;

export default injectSheet(ModalStyleSheet)(EventScheduleInfoModal);