import React from 'react';
import PropTypes from 'prop-types';
import { Button, Form, Modal } from 'semantic-ui-react';
import injectSheet from "react-jss";
import AppContext from "../../../../Common/Constants/AppContext";
import SearchVolunteer from "../../../../Common/Components/Search/SearchVolunteer";
import { ModalStyleSheet } from "../../../../Common/GlobalStyle";

class AddVolunteerModal extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      selectedVolunteer: {},
    };
    this.handleSubmit = this.handleSubmit.bind(this);
    this.handleSelect = this.handleSelect.bind(this);
  }

  handleSelect = (selectedVolunteer) => {
    this.setState({
      selectedVolunteer,
    });
  }

  handleSubmit() {
    if (!this.state.isHitSave) {
      this.setState({
        isHitSave: true,
      });
    }
    if (!this.state.selectedVolunteer._id) {
      return;
    }
    const { onOk } = this.props;
    onOk(this.state.selectedVolunteer);
  }

  render() {
    const { classes, isOpen, onClose } = this.props;
    const { intl: { messages } } = this.context;
    const { selectedVolunteer } = this.state;

    return (
      <Modal
        open={isOpen}
        onClose={onClose}
        size="tiny"
      >
        <Modal.Header className={classes.header}>
          {messages.addVolunteer}
        </Modal.Header>
        <Modal.Content>
          <Form
            onSubmit={this.handleSubmit}
          >
            <Form.Field required error={this.state.isHitSave && !selectedVolunteer._id}>
              <SearchVolunteer onSelect={this.handleSelect} />
              {
                this.state.isHitSave && !selectedVolunteer._id &&
                <div className={classes.helpText}>{messages.pleaseSelectAVolunteer}</div>
              }
            </Form.Field>
            <Form.Field className={classes.actionGroup}>
              <Button onClick={onClose}>
                {messages.cancel}
              </Button>
              <Button
                type='submit'
                color='green'
                disabled={!selectedVolunteer._id}
              >
                {
                  messages.add
                }
              </Button>
            </Form.Field>
          </Form>
        </Modal.Content>
      </Modal>
    )
  }
}

AddVolunteerModal.propTypes = {
  isOpen: PropTypes.bool.isRequired,
  onClose: PropTypes.func.isRequired,
  onOk: PropTypes.func.isRequired,
};

AddVolunteerModal.contextType = AppContext;

export default injectSheet(ModalStyleSheet)(AddVolunteerModal);