import React from 'react';
import PropTypes from 'prop-types';
import { Button, Form, Modal } from 'semantic-ui-react';
import injectSheet from "react-jss";
import AppContext from "../../../../Common/Constants/AppContext";
import SearchLocation from "../../../../Common/Components/Search/SearchLocation";
import { ModalStyleSheet } from "../../../../Common/GlobalStyle";

class ChangeLocationModal extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      currentLocation: props.currentLocation,
      selectedLocation: props.currentLocation,
    };
    this.handleSubmit = this.handleSubmit.bind(this);
    this.handleSelect = this.handleSelect.bind(this);
  }

  handleSelect = (selectedLocation) => {
    this.setState({
      selectedLocation,
    });
  }

  handleSubmit() {
    const { onOk } = this.props;
    onOk(this.state.selectedLocation);
  }

  render() {
    const { classes, isOpen, onClose, eventId } = this.props;
    const { intl: { messages } } = this.context;
    const { selectedLocation, currentLocation } = this.state;

    return (
      <Modal
        open={isOpen}
        onClose={onClose}
        size="tiny"
      >
        <Modal.Header className={classes.header}>
          {
            currentLocation._id ? messages.changeLocation : messages.setLocation
          }
        </Modal.Header>
        <Modal.Content>
          <Form
            onSubmit={this.handleSubmit}
          >
            <Form.Field>
              <SearchLocation
                eventId={eventId}
                onSelect={this.handleSelect}
                value={currentLocation.name}
                initLocation={currentLocation}
                resetWhenClear={true}
              />
            </Form.Field>
            <Form.Field className={classes.actionGroup}>
              <Button onClick={onClose}>
                {messages.cancel}
              </Button>
              <Button
                type='submit'
                color='green'
                disabled={selectedLocation._id === currentLocation._id}
              >
                {
                  currentLocation._id ? messages.changeLocation : messages.setLocation
                }
              </Button>
            </Form.Field>
          </Form>
        </Modal.Content>
      </Modal>
    )
  }
}

ChangeLocationModal.propTypes = {
  isOpen: PropTypes.bool.isRequired,
  onClose: PropTypes.func.isRequired,
  onOk: PropTypes.func.isRequired,
  currentLocation: PropTypes.shape({}).isRequired,
  eventId: PropTypes.string.isRequired,
};

ChangeLocationModal.contextType = AppContext;

export default injectSheet(ModalStyleSheet)(ChangeLocationModal);