import React from 'react';
import PropTypes from 'prop-types';
import isequal from 'lodash.isequal';
import debounce from 'lodash.debounce';
import { Form, Input } from "semantic-ui-react";
import injectSheet from "react-jss";
import stylesheet from './stylesheet';
import AppContext from "../../../../../Common/Constants/AppContext";
import ElectorateComponent from "../../../../../Common/Components/ElectorateComponent/ElectorateComponent";
import SearchLocation from "../../../../../Common/Components/Search/SearchLocation";

class EventVolunteerFilter extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      selectedVotingDistrict: {name: 'All'},
      selectedLocation: {},
      assignmentStatus: '',
      '$text': '',
      ...props.initFilter,
    };
    this.handleChange = this.handleChange.bind(this);
    this.handleResetFilter = this.handleResetFilter.bind(this);
    this.handleSearch = debounce(this.handleSearch.bind(this), 300);
  }

  handleResetFilter() {
    const filter = {
      selectedVotingDistrict: {name: 'All'},
      selectedLocation: {},
      assignmentStatus: '',
      '$text': '',
    };
    this.setState({
      ...filter,
    });
    const { onSearchFilterChange } = this.props;
    onSearchFilterChange(filter);
  }

  handleChange(e, { name, value }) {
    const filter = {
      ...this.state,
      [name]: value,
    };
    if (isequal(filter, this.state)) {
      return;
    }
    this.setState({
      ...filter,
    });
    this.handleSearch(filter);
  }

  handleSearch(filter) {
    const { onSearchFilterChange } = this.props;
    onSearchFilterChange(filter);
  }

  handleSelectElectorate = (selectedElectorate) => {
    const filter = {
      ...this.state,
      selectedVotingDistrict: selectedElectorate,
      selectedLocation: {},
    };
    if (isequal(filter, this.state)) {
      return;
    }
    this.setState({
      ...filter,
    });

    const { onSearchFilterChange } = this.props;
    onSearchFilterChange(filter);

  }

  handleSelectLocation = (selectedLocation) => {
    const filter = {
      ...this.state,
      selectedLocation: selectedLocation,
    };
    if (isequal(filter, this.state)) {
      return;
    }
    this.setState({
      ...filter,
    });

    const { onSearchFilterChange } = this.props;
    onSearchFilterChange(filter);
  }

  render() {
    const { classes, selectedEvent, showNumber, total } = this.props;
    const { intl: { messages } } = this.context;
    const emptyFilter = {
      key: 'all',
      text: messages.all,
      value: '',
    };
    const assignmentStatus = [
      emptyFilter,
      {
        key: 'assigned',
        text: 'Assigned',
        value: 'assigned',
      },
      {
        key: 'unassigned',
        text: 'Unassigned',
        value: 'unassigned',
      },
    ];
    return (
      <div className={classes.searchFilter}>
        <div className='reset-filter'>
          <span onClick={this.handleResetFilter}>Reset filters</span>
          <img src={require('../../../../../Assets/reset.png')} alt='' onClick={this.handleResetFilter} />
        </div>
        <div className='search-container'>
          <div className='search-box'>
            <Input
              icon='search'
              iconPosition='left'
              placeholder='Search volunteers...'
              name={"$text"}
              value={this.state["$text"]}
              onChange={this.handleChange}
            />
          </div>
          <div className='filter-box'>
            <div className='block-item'>
              <div className='text-title'>{messages.electorate}</div>
              <div className='control'>
                <ElectorateComponent
                  onSelect={this.handleSelectElectorate}
                  defaultSelected={this.state.selectedVotingDistrict}
                  allowAll
                />
              </div>
            </div>
            <div className='block-item'>
              <div className='text-title'>{messages.location}</div>
              <div className='control'>
                <Form.Field className='search-location-container'>
                  <SearchLocation
                    eventId={selectedEvent._id}
                    onSelect={this.handleSelectLocation}
                    value={this.state.selectedLocation.name}
                    initLocation={this.state.selectedLocation}
                    voting_district={this.state.selectedVotingDistrict._id}
                  />
                </Form.Field>
              </div>
            </div>
            <div className='block-item assignment-status'>
              <div className='text-title'>Assignment Status</div>
              <div className='control'>
                <Form.Select
                  options={assignmentStatus}
                  placeholder={messages.all}
                  name='assignmentStatus'
                  value={this.state.assignmentStatus}
                  onChange={this.handleChange}
                />
              </div>
            </div>
          </div>
        </div>
        <div className='display-contact-number'>
          Showing <b>{showNumber}</b> of <b>{total}</b> contacts
        </div>
      </div>
    )
  }
}

EventVolunteerFilter.contextType = AppContext;

EventVolunteerFilter.propTypes = {
  onSearchFilterChange: PropTypes.func.isRequired,
  initFilter: PropTypes.shape({}),
  showNumber: PropTypes.number,
  total: PropTypes.number,
};

EventVolunteerFilter.defaultProps = {
  initFilter: {},
  showNumber: 0,
  total: 0,
};

export default injectSheet(stylesheet)(EventVolunteerFilter);