import React from 'react';
import { Loader, Popup, Table, Pagination, Checkbox, Icon } from "semantic-ui-react";
import { Link } from 'react-router-dom';
import isempty from "lodash.isempty";
import injectSheet from "react-jss";
import PropTypes from "prop-types";
import AppContext from "../../../../Common/Constants/AppContext";
import Utils from "../../../../Common/Utils/Utils";
import EventActionCreator from "../../../Actions/EventActionCreator";
import stylesheet from './stylesheet';
import ReduxStatus from "../../../../Common/Constants/ReduxStatus";
import AddVolunteerModal from "./AddVolunteerModal";
import ConfirmModal from "../../../../Common/Components/Modal/ConfirmModal";
import ChangeLocationModal from "./ChangeLocationModal";
import LocationActionCreator from "../../../Actions/LocationActionCreator";
import AddButton from '../../../../Common/Components/Base/AddButton';
import SendSmsModal from "./SendSmsModal";
import ContactActionCreator from "../../../../Contact/Actions/ContactActionCreator";
import EventVolunteerFilter from "./EventVolunteerFilter/EventVolunteerFilter";

class EventVolunteers extends React.Component {
  constructor() {
    super();
    this.state = {
      currentCheckList: [],
      sendSMSInfoToggle: false,

      toggleRemoveVolunteer: false,
      selectedRemoveVolunteer: null,

      toggleChangeLocation: false,
      selectedVolunteerChangeLocation: null,
    };
    this.getLocation = this.getLocation.bind(this);
    this.handlePaginationChange = this.handlePaginationChange.bind(this);
    this.handleAddVolunteerToEvent = this.handleAddVolunteerToEvent.bind(this);
    this.handleRemoveVolunteerFromEvent = this.handleRemoveVolunteerFromEvent.bind(this);
    this.onSearchFilterChange = this.onSearchFilterChange.bind(this);
    this.handleChangeLocation = this.handleChangeLocation.bind(this);
    this.handleCheckAll = this.handleCheckAll.bind(this);
    this.handleExportToCSV = this.handleExportToCSV.bind(this);
  }

  componentDidMount() {
    const { dispatch } = this.context;
    const { selectedEvent, eventVolunteers: { activePage, filter } } = this.props;
    dispatch(EventActionCreator.getEventVolunteers(selectedEvent._id, activePage, filter));
  }

  handleCheckAll() {
    const { eventVolunteers: { data } } = this.props;
    if (this.state.currentCheckList.length !== data.length) {
      const currentCheckList = data.map(item => item._id);
      this.setState({
        currentCheckList,
      })
    } else {
      this.setState({
        currentCheckList: [],
      })
    }
  }

  addOrRemoveCheck(item) {
    const currentCheckList = [...this.state.currentCheckList];
    if (currentCheckList.includes(item._id)) {
      const index = currentCheckList.indexOf(item._id);
      currentCheckList.splice(index, 1);
    } else {
      currentCheckList.push(item._id);
    }
    this.setState({
      currentCheckList,
    });
  }

  onSearchFilterChange(filter) {
    const { dispatch } = this.context;
    const { selectedEvent } = this.props;
    dispatch(EventActionCreator.getEventVolunteers(selectedEvent._id, 1, filter));
  }

  handlePaginationChange(e, { activePage }) {
    const { dispatch } = this.context;
    const { eventVolunteers: { filter }, selectedEvent } = this.props;
    dispatch(EventActionCreator.getEventVolunteers(selectedEvent._id, activePage, filter));
  }

  getLocation(events) {
    if (!events || events.length === 0) {
      return {};
    }
    const { selectedEvent: { _id } } = this.props;
    const event = events.find(item => item.event === _id);
    if (event && event.location) {
      return event.location;
    }
    return {};
  }

  handleAddVolunteerToEvent(volunteer) {
    const { dispatch } = this.context;
    const { selectedEvent } = this.props;
    dispatch(EventActionCreator.addVolunteerToEvent(selectedEvent._id, [volunteer._id]));
    this.setState({
      toggleLAddVolunteerModal: false,
    })
  }

  handleRemoveVolunteerFromEvent() {
    const { dispatch } = this.context;
    const { selectedEvent } = this.props;
    dispatch(EventActionCreator.removeVolunteerFromEvent(selectedEvent._id, this.state.selectedRemoveVolunteer._id));
    this.setState({
      toggleRemoveVolunteer: false,
      selectedRemoveVolunteer: null
    })
  }

  handleChangeLocation(newLocation) {
    const { dispatch } = this.context;
    const { selectedEvent } = this.props;
    const { selectedVolunteerChangeLocation } = this.state;
    const oldLocation = this.getLocation(selectedVolunteerChangeLocation.events);
    dispatch(LocationActionCreator.changeLocationFromVolunteer(selectedEvent._id, oldLocation._id, newLocation._id, selectedVolunteerChangeLocation._id));
    this.setState({ toggleChangeLocation: false });
  }

  handleExportToCSV() {
    const { dispatch } = this.context;
    const { selectedEvent } = this.props;
    if (this.state.currentCheckList.length > 0) {
      const filter = {
        "_id": { "$in": this.state.currentCheckList },
        "events.event": selectedEvent._id,
      };
      dispatch(ContactActionCreator.exportContactsToCSV(
        filter,
        {
          populate: { "path": "events.location", "populate": { "path": "voting_district" } },
          exported_fields: "prefix_name,first_name,middle_name,last_name,mobile_number,home_number,location,sms_date",
        }
      ));
    } else {
      const { eventVolunteers: { filter } } = this.props;
      const newFilter = {};
      if (filter["$text"]) {
        newFilter["$text"] = { "$search": filter["$text"] };
      }
      if (filter.assignmentStatus) {
        newFilter["events.event"] = selectedEvent._id;
        newFilter["events.location"] = { "$exists": filter.assignmentStatus === 'assigned' ? "true" : "false" };
      } else {
        if (filter.selectedVotingDistrict && filter.selectedVotingDistrict._id) {
          newFilter.voting_district = filter.selectedVotingDistrict._id;
        }
        if (filter.selectedLocation && filter.selectedLocation._id) {
          newFilter["events.location"] = filter.selectedLocation._id;
        }
      }

      dispatch(ContactActionCreator.exportContactsToCSV({
        ...newFilter,
        "events.event": selectedEvent._id,
      }, {
        populate: { "path": "events.location", "populate": { "path": "voting_district" } },
        exported_fields: "prefix_name,first_name,middle_name,last_name,mobile_number,home_number,location,sms_date",
      }));
    }
  }

  render() {
    const { classes, selectedEvent, eventVolunteers: { data, status, activePage, filter, totalRecord, totalPage } } = this.props;
    const { intl: { messages }, currentUser } = this.context;

    const currentSelectedVolunteer = data.filter(item => this.state.currentCheckList.includes(item._id));
    return (
      <div className={classes.eventVolunteerPage}>
        {
          status === ReduxStatus.loading && <Loader active />
        }
        {
          this.state.toggleLAddVolunteerModal &&
          <AddVolunteerModal
            isOpen={this.state.toggleLAddVolunteerModal}
            onClose={() => this.setState({ toggleLAddVolunteerModal: false })}
            onOk={this.handleAddVolunteerToEvent}
          />
        }
        {
          this.state.toggleRemoveVolunteer &&
          <ConfirmModal
            isOpen={true}
            onClose={() => this.setState({ toggleRemoveVolunteer: false })}
            onConfirm={this.handleRemoveVolunteerFromEvent}
            content={{
              mainText: messages.deleteVolunteerText.replace('{name}', Utils.combineName(this.state.selectedRemoveVolunteer, messages)),
              description: messages.messageConfirm.replace('{name}',
                `${currentUser.first_name}`)
            }}
            title={messages.removeVolunteer}
            cancelText={messages.keepThisVolunteer}
            confirmText={messages.delete}
          />
        }
        {
          this.state.toggleChangeLocation &&
          <ChangeLocationModal
            isOpen={this.state.toggleChangeLocation}
            onClose={() => this.setState({ toggleChangeLocation: false })}
            onOk={this.handleChangeLocation}
            eventId={selectedEvent._id}
            currentLocation={this.getLocation(this.state.selectedVolunteerChangeLocation.events)}
          />
        }
        {
          this.state.sendSMSInfoToggle &&
          <SendSmsModal
            isOpen={this.state.sendSMSInfoToggle}
            onClose={() => this.setState({ sendSMSInfoToggle: false })}
            volunteers={currentSelectedVolunteer}
            eventId={selectedEvent._id}
          />
        }
        <EventVolunteerFilter
          initFilter={filter}
          onSearchFilterChange={this.onSearchFilterChange}
          selectedEvent={selectedEvent}
          showNumber={data.length}
          total={totalRecord}
        />
        <AddButton
          onClick={() => this.setState({
            toggleLAddVolunteerModal: true,
          })}
          content={messages.addVolunteer}
        />
        <Table selectable basic>
          <Table.Header>
            <Table.Row>
              <Table.HeaderCell>
                <Checkbox checked={this.state.currentCheckList.length === data.length} onChange={this.handleCheckAll} />
              </Table.HeaderCell>
              <Table.HeaderCell></Table.HeaderCell>
              <Table.HeaderCell width={4}>{messages.name}</Table.HeaderCell>
              <Table.HeaderCell>{messages.mobile}</Table.HeaderCell>
              <Table.HeaderCell>{messages.email}</Table.HeaderCell>
              <Table.HeaderCell width={4}>{messages.location}</Table.HeaderCell>
              <Table.HeaderCell>
                <div className={classes.volunteerSearch}>
                  <Popup
                    trigger={(
                      <div className='action-container'>
                        <span>{messages.actions}</span> <Icon name='ellipsis horizontal' />
                      </div>
                    )}
                    content={(
                      <div className={classes.headerAction}>
                        <div
                          className={'action ' + (this.state.currentCheckList.length === 0 ? 'disabled' : '')}
                          onClick={(e) => {
                            e.stopPropagation();
                            if (this.state.currentCheckList.length === 0) {
                              return;
                            }
                            this.setState({
                              sendSMSInfoToggle: true,
                            })
                            document.getElementsByTagName('body')[0].click();
                          }}
                        >
                          Send volunteering info
                        </div>
                        <div
                          className='action'
                          onClick={(e) => {
                            e.stopPropagation()
                            this.handleExportToCSV()
                            document.getElementsByTagName('body')[0].click()
                          }}
                        >
                          {messages.exportToCSV}
                        </div>
                      </div>
                    )}
                    position='bottom right'
                    on='click'
                  />
                </div>
              </Table.HeaderCell>
            </Table.Row>
          </Table.Header>
          <Table.Body>
            {data.map(item => (
              <Table.Row key={item._id} className="contact-row">
                <Table.Cell collapsing>
                  <Checkbox
                    onChange={() => this.addOrRemoveCheck(item)}
                    checked={this.state.currentCheckList.includes(item._id)}
                  />
                </Table.Cell>
                <Table.Cell collapsing>
                  {
                    !isempty(item.profile_picture) ?
                      <img className={classes.profileImage} src={item.profile_picture['thumb@64_64']} alt='' /> :
                      <img className={classes.profileImage} src={require("../../../../Assets/avatar.png")} alt='' />
                  }
                </Table.Cell>
                <Table.Cell>
                  <Link to={`/contact-detail/${item._id}/overview`}>
                    {Utils.combineName(item, messages)}
                  </Link>
                  <div className='volunteer-city'>
                    {item.home_address && item.home_address.city}
                  </div>
                </Table.Cell>
                <Table.Cell>{item.mobile_number}</Table.Cell>
                <Table.Cell>
                  <a href={`mailto: ${Utils.getContactEmail(item.emails)}`}
                     target="_top">{Utils.getContactEmail(item.emails)}</a>
                </Table.Cell>
                <Table.Cell>
                  {
                    this.getLocation(item.events)._id ? <Popup
                        trigger={
                          (
                            <div
                              className='change-location'
                              onClick={() => this.setState({
                                toggleChangeLocation: true,
                                selectedVolunteerChangeLocation: item,
                              })}
                            >
                              <div>
                                {this.getLocation(item.events).name}
                              </div>
                              <div
                                className='location-address'>{Utils.combineAddress(this.getLocation(item.events).address)}</div>
                            </div>
                          )
                        }
                        inverted
                        position='top center'
                        content={messages.changeLocation}
                      />
                      : <div
                        className='set-location'
                        onClick={() => this.setState({
                          toggleChangeLocation: true,
                          selectedVolunteerChangeLocation: item,
                        })}
                      >
                        {messages.setLocation}
                      </div>
                  }
                </Table.Cell>
                <Table.Cell>
                  <div className='sms-info-and-action'>
                    <div>
                      {Utils.getLastContacted(item.sms_logs) ? `SMS - ${Utils.getLastContacted(item.sms_logs)}` : 'SMS - Not yet'}
                    </div>
                    <div className="user-action">
                      <div
                        onClick={() => {
                          this.setState({
                            toggleRemoveVolunteer: true,
                            selectedRemoveVolunteer: item,
                          })
                        }}
                      >
                        {messages.remove}
                      </div>
                    </div>
                  </div>
                </Table.Cell>
              </Table.Row>
            ))}
          </Table.Body>
        </Table>
        {
          data.length > 0 && totalPage > 1 &&
          <Pagination
            activePage={activePage}
            totalPages={totalPage}
            onPageChange={this.handlePaginationChange}
          />
        }
      </div>
    )
  }
}

EventVolunteers.propTypes = {
  selectedEvent: PropTypes.shape({}).isRequired,
  eventVolunteers: PropTypes.shape({}).isRequired,
};

EventVolunteers.contextType = AppContext;

export default injectSheet(stylesheet)(EventVolunteers);
