import React from 'react';
import PropTypes from 'prop-types';
import { Button, Form, Modal } from 'semantic-ui-react';
import injectSheet from "react-jss";
import { ModalStyleSheet } from "../../../../Common/GlobalStyle";
import AppContext from "../../../../Common/Constants/AppContext";
import SMSActionCreator from "../../../../Common/SMS/SMSActionCreator";
import Utils from "../../../../Common/Utils/Utils";

class SendSmsModal extends React.Component {
  constructor() {
    super();
    const message = "Hi <First Name>, " +
      "thanks for supporting SFFP in our campaign for <Elecorate>! " +
      "You will be volunteering <Time> at: <LocationName> (<Line 1> <Line 2>, <City>, <PostalCode>). " +
      "For important info visit: https://sffpapp.com.au/volfaq";
    this.state = {
      message,
    };
    this.handleChange = this.handleChange.bind(this);
    this.handleSubmit = this.handleSubmit.bind(this);
  }

  handleChange({ target: { name, value } }) {
    this.setState({
      message: value
    })
  }

  handleSubmit() {
    if (!this.state.isHitSave) {
      this.setState({
        isHitSave: true,
      });
    }
    if (!this.state.message) {
      return;
    }
    const { onClose, eventId, volunteers } = this.props;
    const { dispatch, intl: { messages } } = this.context;
    const sendToVolunteers = volunteers.map(item => ({
      contact_id: item._id,
      mobile_number: item.mobile_number,
      name: item.first_name,
      fullName: Utils.combineName(item, messages),
      location: Utils.getLocationFromEvent(item.events, eventId),
    }))
    dispatch(SMSActionCreator.sendSMS(eventId, sendToVolunteers, this.state.message));
    onClose();
  }

  render() {
    const { classes, isOpen, onClose } = this.props;
    const { intl: { messages } } = this.context;
    return (
      <Modal
        open={isOpen}
        onClose={onClose}
        size="tiny"
      >
        <Modal.Header className={classes.header}>
          Send Volunteering Info
        </Modal.Header>
        <Modal.Content>
          <Form
            onSubmit={this.handleSubmit}
          >
            <Form.TextArea
              rows={5}
              placeholder={this.state.message}
              name='message'
              value={this.state.message}
              onChange={this.handleChange}
            />
            <Form.Field className={classes.actionGroup}>
              <Button onClick={onClose}>
                {messages.cancel}
              </Button>
              <Button
                type='submit'
                color='green'
                disabled={!this.state.message}
              >
                Send
              </Button>
            </Form.Field>
          </Form>
        </Modal.Content>
      </Modal>
    )
  }
}

SendSmsModal.propTypes = {
  isOpen: PropTypes.bool.isRequired,
  onClose: PropTypes.func.isRequired,
  eventId: PropTypes.string.isRequired,
  volunteers: PropTypes.shape([]).isRequired,
};

SendSmsModal.contextType = AppContext;

export default injectSheet(ModalStyleSheet)(SendSmsModal);