import React from 'react';
import PropTypes from 'prop-types';
import TextTruncate from 'react-text-truncate';
import { Card, Icon } from 'semantic-ui-react';
import moment from "moment";
import { Link } from "react-router-dom";
import injectSheet from "react-jss";
import stylesheet from "../stylesheet";
import AppContext from "../../../Common/Constants/AppContext";

class EventCard extends React.Component {

  constructor() {
    super();
    this.handleEdit = this.handleEdit.bind(this);
  }

  handleEdit(e) {
    e.preventDefault();
    const { onEdit } = this.props;
    onEdit();
  }

  render() {
    const { intl: { messages } } = this.context;
    const { classes } = this.props;
    const { event, onEdit, onDuplicate, onDelete } = this.props;
    return (
      <Card className={classes.eventCard}>
        <Card.Content className='event-header'>
          <div className='event-action'>
            <div onClick={onDelete}>
              {messages.delete}
            </div>
            <div onClick={onDuplicate}>
              {messages.duplicate}
            </div>
            <div onClick={this.handleEdit}>
              {messages.edit}
            </div>
          </div>
        </Card.Content>
        <Card.Content className='event-body'>
          <div className='event-content'>
            <div className='event-name'>
              <Link to={`/event-detail/${event._id}/locations`}>
                {event.name}
              </Link>
            </div>
            <div className='event-time'>
              {moment(new Date(event.start_time)).format('ddd, D MMM YYYY')} - &nbsp;
              {moment(new Date(event.start_time)).format('LT')} to &nbsp;
              {moment(new Date(event.end_time)).format('LT')}
            </div>
            <div className='event-description'>
              <TextTruncate
                line={3}
                truncateText="…"
                text={event.description}
                textTruncateChild={(
                  <a href='/' onClick={onEdit}>Read more</a>
                )}
              />
            </div>
          </div>
        </Card.Content>
        <Card.Content className='event-footer'>
          <div className='event-stat'>
            <div className='location-stat'>
              <Icon name='map marker alternate' color='grey' size='large' />
              <span>{event.total_locations} Locations</span>
            </div>
            <div className='volunteer-stat'>
              <Icon name='user' color='grey' size='large' />
              <span>{event.total_volunteers} Volunteers</span>
            </div>
          </div>
        </Card.Content>
      </Card>
    );
  }
}

EventCard.contextType = AppContext;

EventCard.propTypes = {
  event: PropTypes.shape({}).isRequired,
  onEdit: PropTypes.func.isRequired,
  onDuplicate: PropTypes.func.isRequired,
  onDelete: PropTypes.func.isRequired,
};

export default injectSheet(stylesheet)(EventCard);