import React from 'react';
import PropTypes from 'prop-types';
import isequal from "lodash.isequal";
import { Button, Form, Modal } from 'semantic-ui-react';
import injectSheet from "react-jss";
import AppContext from "../../../Common/Constants/AppContext";
import DatePicker from "react-datepicker/es";
import { ModalStyleSheet } from "../../../Common/GlobalStyle";
import { config } from '../../../configuration';

class EventInfoModal extends React.Component {
  constructor(props) {
    super(props);
    var currentDate = new Date();
    const year = currentDate.getFullYear();
    const month = currentDate.getMonth();
    const date = currentDate.getDate();
    const eventInfo = { ...props.eventInfo };
    if (eventInfo.start_time) {
      eventInfo.start_time = new Date(eventInfo.start_time);
    }
    if (eventInfo.end_time) {
      eventInfo.end_time = new Date(eventInfo.end_time);
    }
    this.state = {
      eventInfo: {
        start_time: new Date(year, month, date, 7, 0),
        end_time: new Date(year, month, date, 20, 0),
        ...eventInfo,
      },
    };
    this.isFieldError = this.isFieldError.bind(this);
    this.handleChange = this.handleChange.bind(this);
    this.handleChangeDate = this.handleChangeDate.bind(this);
    this.handleSubmit = this.handleSubmit.bind(this);
  }

  handleChange({ target: { name, value } }) {
    this.setState({
      eventInfo: {
        ...this.state.eventInfo,
        [name]: value,
      }
    })
  }

  handleChangeDate(value) {
    const eventInfo = { ...this.state.eventInfo };
    const date = value || new Date();
    if (eventInfo.start_time) {
      eventInfo.start_time = new Date(date.getFullYear(), date.getMonth(), date.getDate(), eventInfo.start_time.getHours(), eventInfo.start_time.getMinutes(), 0);
    }
    if (eventInfo.end_time) {
      eventInfo.end_time = new Date(date.getFullYear(), date.getMonth(), date.getDate(), eventInfo.end_time.getHours(), eventInfo.end_time.getMinutes(), 0);
    }
    this.setState({
      eventInfo,
    });
  }

  hanldeChangeTime(name, value) {
    const eventInfo = { ...this.state.eventInfo };
    if (!eventInfo.start_time) {
      eventInfo.start_time = new Date();
    }
    const year = eventInfo.start_time.getFullYear();
    const month = eventInfo.start_time.getMonth();
    const date = eventInfo.start_time.getDate();
    let hours = 0;
    let minutes = 0;
    if (value) {
      hours = value.getHours();
      minutes = value.getMinutes();
    }
    eventInfo[name] = new Date(year, month, date, hours, minutes, 0);
    this.setState({
      eventInfo,
    });
  }

  handleSubmit() {
    if (!this.state.isHitSave) {
      this.setState({
        isHitSave: true,
      });
    }
    if (this.isFieldError('name') ||
      this.isFieldError('start_time') ||
      this.isFieldError('end_time')
    ) {
      return;
    }
    const { onOk } = this.props;
    const eventInfo = { ...this.state.eventInfo };
    onOk({
      ...this.state.eventInfo,
      start_time: eventInfo.start_time.getTime(),
      end_time: eventInfo.end_time.getTime(),
    });
  }

  isFieldError(name) {
    const { intl: { messages } } = this.context;
    if (!this.state.eventInfo[name]) {
      let fieldText = messages[name];
      if (name === 'name') {
        fieldText = messages.eventName;
      }
      return `${messages.pleaseEnter} ${fieldText}`;
    }
    return '';
  }

  render() {
    const { classes, isOpen, onClose } = this.props;
    const { intl: { messages } } = this.context;
    const { eventInfo } = this.state;
    return (
      <Modal
        open={isOpen}
        onClose={onClose}
        size="tiny"
      >
        <Modal.Header className={classes.header}>
          {
            eventInfo._id ? messages.updateEvent : messages.createEvent
          }
        </Modal.Header>
        <Modal.Content>
          <Form
            onSubmit={this.handleSubmit}
          >
            <Form.Field required error={this.state.isHitSave && this.isFieldError('name')}>
              <label>{messages.eventName}</label>
              <input
                placeholder={messages.eventName}
                name='name'
                value={eventInfo.name}
                onChange={this.handleChange}
              />
              {
                this.state.isHitSave && this.isFieldError('name') &&
                <div className={classes.helpText}>{this.isFieldError('name')}</div>
              }
            </Form.Field>
            <Form.Group widths='equal'>
              <Form.Field required error={this.state.isHitSave && this.isFieldError('start_time')}>
                <label>Date</label>
                <DatePicker
                  selected={eventInfo.start_time}
                  onChange={this.handleChangeDate}
                  dateFormat='dd/MM/yyyy'
                  placeholderText={config.DATE_FORMAT}
                  todayButton={'Today'}
                />
              </Form.Field>
              <Form.Field required error={this.state.isHitSave && this.isFieldError('start_time')}>
                <label>Start time</label>
                <DatePicker
                  showTimeSelect
                  showTimeSelectOnly
                  timeIntervals={5}

                  selected={eventInfo.start_time}
                  onChange={(value) => this.hanldeChangeTime('start_time', value)}
                  dateFormat="HH:mm"
                  timeFormat="HH:mm"
                  placeholderText='HH:MM'
                  minTime={new Date(new Date(new Date().setHours(0)).setMinutes(0))}
                  maxTime={new Date(new Date(new Date().setHours(eventInfo.end_time.getHours())).setMinutes(eventInfo.end_time.getMinutes()))}
                />
              </Form.Field>
              <Form.Field required error={this.state.isHitSave && this.isFieldError('end_time')}>
                <label>End time</label>
                <DatePicker
                  showTimeSelect
                  showTimeSelectOnly
                  timeIntervals={5}
                  selected={eventInfo.end_time}
                  onChange={(value) => this.hanldeChangeTime('end_time', value)}
                  dateFormat="HH:mm"
                  timeFormat="HH:mm"
                  placeholderText='HH:MM'
                  minTime={new Date(new Date(new Date().setHours(eventInfo.start_time.getHours())).setMinutes(eventInfo.start_time.getMinutes()))}
                  maxTime={new Date(new Date(new Date().setHours(23)).setMinutes(59))}
                />
              </Form.Field>
            </Form.Group>
            <Form.TextArea
              rows={5}
              label='Description'
              placeholder='Description...'
              name='description'
              value={eventInfo.description}
              onChange={this.handleChange}
            />
            <Form.Field className={classes.actionGroup}>
              <Button onClick={onClose}>
                {messages.cancel}
              </Button>
              <Button
                type='submit'
                color='green'
                disabled={isequal(this.props.eventInfo, eventInfo) && eventInfo._id}
              >
                {
                  eventInfo._id ? messages.update : messages.create
                }
              </Button>
            </Form.Field>
          </Form>
        </Modal.Content>
      </Modal>
    )
  }
}

EventInfoModal.propTypes = {
  isOpen: PropTypes.bool.isRequired,
  onClose: PropTypes.func.isRequired,
  onOk: PropTypes.func.isRequired,
  contactInfo: PropTypes.shape({}).isRequired,
};

EventInfoModal.contextType = AppContext;

export default injectSheet(ModalStyleSheet)(EventInfoModal);