import React from "react";
import { connect } from "react-redux";
import { Route, Switch } from 'react-router-dom';

import PageTitle from '../Common/Components/PageTitle';
import PageNavigationMenu from '../Common/Components/PageNavigationMenu';
import AppContext from "../Common/Constants/AppContext";
import EventActionCreator from "./Actions/EventActionCreator";
import EventLocationMap from "./Components/EventDetails/EventLocationMap/EventLocationMap";
import ReduxStatus from "../Common/Constants/ReduxStatus";
import { Loader } from "semantic-ui-react";
import EventVolunteers from "./Components/EventDetails/EventVolunteers/EventVolunteers";
import EventInventory from "./Components/EventDetails/EventInventory/EventInventory";
import LocationSchedule from "./Components/EventDetails/EventSchedule/EventSchedule";
import EventNotes from "./Components/EventDetails/EventNotes/EventNotes";
import EventLocations from "./Components/EventDetails/EventLocations/EventLocations";

const pageStyle = {
  display: 'flex',
  flexDirection: 'column',
  height: '100%',
}

class EventDetail extends React.Component {
  componentDidMount() {
    const { dispatch } = this.context;
    const { match: { params: { id } }, selectEventDetail: { selectedEvent } } = this.props;
    if(!selectedEvent._id || (selectedEvent._id !== id)) {
      dispatch(EventActionCreator.getEventById(id));
    }
  }

  componentWillUnmount(safely) {
    const { dispatch } = this.context;
    const { match: { params: { id } }, history: { location: { pathname } } } = this.props;
    if (!pathname.includes(`/event-detail/${id}`)) {
      dispatch(EventActionCreator.clearSelectedEvent());
    }
  }

  render() {
    const { intl: { messages } } = this.context;
    const { match, selectEventDetail, eventVolunteers, eventNotes, eventInventories, locationList, locationListOnMap, locationVolunteers, locationNotes, volunteerOnMapList, locationSchedule } = this.props;
    const menuItems = [
      {
        name: 'locations',
        text: messages.locations,
        url: `${match.url}/locations`,
      },
      {
        name: 'volunteers',
        text: messages.volunteers,
        url: `${match.url}/volunteers`,
      },
      {
        name: 'map',
        text: messages.map,
        url: `${match.url}/map`,
      },
      {
        name: 'inventory',
        text: messages.inventory,
        url: `${match.url}/inventory`,
      },
      {
        name: 'schedule',
        text: messages.schedule,
        url: `${match.url}/schedule`,
      },
      {
        name: 'notes',
        text: messages.notes,
        url: `${match.url}/notes`,
      },
    ];

    const { selectedEvent, status } = selectEventDetail;

    return (
      <div style={pageStyle}>
        <PageTitle
          title={selectedEvent.name || ''}
        />
        <PageNavigationMenu
          tabs={menuItems}
        />
        {
          status === ReduxStatus.loading && <Loader active />
        }
        {
          selectedEvent._id &&
          <Switch>
            <Route exact path={`${match.path}`} key='default'
                   render={() => (
                     <EventLocations
                       selectedEvent={selectEventDetail.selectedEvent}
                       locationList={locationList}
                     />)}
            />
            <Route exact path={`${match.path}/locations`} key='locations'
                   render={() => (
                     <EventLocations
                       selectedEvent={selectEventDetail.selectedEvent}
                       locationList={locationList}
                     />)}
            />
            <Route path={`${match.path}/map`} key='map'
                   render={() => (
                     <EventLocationMap
                       selectedEvent={selectEventDetail.selectedEvent}
                       locationList={locationListOnMap}
                       locationVolunteers={locationVolunteers}
                       locationNotes={locationNotes}
                       volunteerOnMapList={volunteerOnMapList}
                     />)}
            />
            <Route path={`${match.path}/volunteers`} key='volunteers'
                   render={() => (
                     <EventVolunteers
                       selectedEvent={selectEventDetail.selectedEvent}
                       eventVolunteers={eventVolunteers}
                     />)}
            />
            <Route path={`${match.path}/inventory`} key='inventory'
                   render={() => (
                     <EventInventory
                       selectedEvent={selectEventDetail.selectedEvent}
                       eventInventories={eventInventories}
                       locationList={locationList}
                     />)}
            />
            <Route path={`${match.path}/schedule`} key='schedule'
                   render={() => (
                     <LocationSchedule
                       selectedEvent={selectEventDetail.selectedEvent}
                       locationSchedule={locationSchedule}
                     />)}
            />
            <Route path={`${match.path}/notes`} key='notes'
                   render={() => (
                     <EventNotes
                       selectedEvent={selectEventDetail.selectedEvent}
                       eventNotes={eventNotes}
                     />)}
            />
          </Switch>
        }


      </div>
    );
  }
}

const
  mapStateToProps = ({
                       events: { selectEventDetail, eventVolunteers, eventNotes },
                       locations: { locationList, locationListOnMap, locationVolunteers, locationNotes },
                       contacts: { volunteerOnMapList },
                       inventories: { eventInventories },
                       schedule: { locationSchedule },
                     }) => ({
    selectEventDetail,
    eventVolunteers,
    eventNotes,

    locationList,
    locationListOnMap,
    locationVolunteers,
    locationNotes,
    volunteerOnMapList,

    eventInventories,
    locationSchedule,
  });

EventDetail
  .contextType = AppContext;

export default connect(mapStateToProps)(EventDetail);

