import React from "react";
import { connect } from "react-redux";
import { Route } from 'react-router-dom';

import PageTitle from '../Common/Components/PageTitle';
import PageNavigationMenu from '../Common/Components/PageNavigationMenu';
import AppContext from "../Common/Constants/AppContext";
import UpcomingEvents from './Components/EventList/UpcomingEvents';
import PastEvents from './Components/EventList/PastEvents';

const pageStyle = {
  display: 'flex',
  flexDirection: 'column',
  height: '100%',
}
class Events extends React.Component {

  render() {
    const { intl: { messages } } = this.context;
    const { match, events: { upcomingEvents, pastEvents } } = this.props;
    const menuItems = [
      {
        name: 'upcoming',
        text: messages.upcoming,
        url: '/events/upcoming',
      },
      {
        name: 'past',
        text: messages.past,
        url: '/events/past',
      },
    ];

    return (
      <div style={pageStyle}>
        <PageTitle title={messages.events} />
        <PageNavigationMenu
          tabs={menuItems}
        />
        <Route exact path={`${match.path}`} render={() => <UpcomingEvents events={upcomingEvents} />} />
        <Route path={`${match.path}/upcoming`} render={() => <UpcomingEvents events={upcomingEvents} />} />
        <Route path={`${match.path}/past`} render={() => <PastEvents events={pastEvents} />} />
      </div>
    );
  }
}

const mapStateToProps = ({ events }) => ({
  events,
});

Events.contextType = AppContext;

export default connect(mapStateToProps)(Events);
