import ReduxStatus from '../../Common/Constants/ReduxStatus';
import {
  GET_UPCOMING_EVENTS,
  GET_UPCOMING_EVENTS_FAILED,
  GET_UPCOMING_EVENTS_SUCCESS,
  GET_PAST_EVENTS,
  GET_PAST_EVENTS_SUCCESS,
  GET_PAST_EVENTS_FAILED,
  GET_EVENT_BY_ID,
  GET_EVENT_BY_ID_SUCCESS,
  GET_EVENT_BY_ID_FAILED,
  CLEAR_SELECTED_EVENT, GET_EVENT_VOLUNTEERS, GET_EVENT_VOLUNTEERS_SUCCESS, GET_EVENT_VOLUNTEERS_FAILED,
} from "../Actions/EventActionCreator";

import {
  GET_EVENT_NOTES,
  GET_EVENT_NOTES_SUCCESS,
  GET_EVENT_NOTES_FAILED,
} from "../Actions/EventNoteActionCreator";


const initialState = {
  upcomingEvents: {
    status: ReduxStatus.empty,
    activePage: 1,
    totalPage: 1,
    data: [],
    message: "",
    filter: {},
  },
  pastEvents: {
    status: ReduxStatus.empty,
    activePage: 1,
    totalPage: 1,
    data: [],
    message: "",
    filter: {},
  },
  selectEventDetail: {
    status: ReduxStatus.empty,
    message: "",
    selectedEvent: {},
  },
  eventVolunteers: {
    status: ReduxStatus.empty,
    activePage: 1,
    totalPage: 1,
    totalRecord: 0,
    data: [],
    message: "",
    filter: {},
  },
  eventInventories: {
    status: ReduxStatus.empty,
    activePage: 1,
    totalPage: 1,
    data: [],
    message: "",
    filter: {},
  },
  eventNotes: {
    status: ReduxStatus.empty,
    activePage: 1,
    totalPage: 1,
    data: [],
    message: "",
    filter: {},
  },
};

const actionsMap = {
  // Async action
  [GET_UPCOMING_EVENTS]: state => {
    return {
      ...state,
      upcomingEvents: {
        ...state.upcomingEvents,
        status: ReduxStatus.loading,
        message: "",
      }
    };
  },
  [GET_UPCOMING_EVENTS_SUCCESS]: (state, { activePage, totalPage, data, filter }) => {
    return {
      ...state,
      upcomingEvents: {
        ...state.upcomingEvents,
        activePage,
        totalPage,
        data,
        status: ReduxStatus.loaded,
        message: "",
        filter,
      }
    };
  },
  [GET_UPCOMING_EVENTS_FAILED]: (state, payload) => {
    return {
      ...state,
      upcomingEvents: {
        ...state.upcomingEvents,
        status: ReduxStatus.loadFailed,
        message: payload.message,
      }
    };
  },

  [GET_PAST_EVENTS]: state => {
    return {
      ...state,
      pastEvents: {
        ...state.pastEvents,
        status: ReduxStatus.loading,
        message: "",
      }
    };
  },
  [GET_PAST_EVENTS_SUCCESS]: (state, { activePage, totalPage, data, filter }) => {
    return {
      ...state,
      pastEvents: {
        ...state.pastEvents,
        activePage,
        totalPage,
        data,
        status: ReduxStatus.loaded,
        message: "",
        filter,
      }
    };
  },
  [GET_PAST_EVENTS_FAILED]: (state, payload) => {
    return {
      ...state,
      pastEvents: {
        ...state.pastEvents,
        status: ReduxStatus.loadFailed,
        message: payload.message,
      }
    };
  },

  [GET_EVENT_BY_ID]: (state) => {
    return {
      ...state,
      selectEventDetail: {
        selectedEvent: {},
        status: ReduxStatus.loading,
        message: "",
      }
    };
  },
  [GET_EVENT_BY_ID_SUCCESS]: (state, payload) => {
    return {
      ...state,
      selectEventDetail: {
        selectedEvent: payload,
        status: ReduxStatus.loaded,
        message: "",
      }
    };
  },
  [GET_EVENT_BY_ID_FAILED]: (state, payload) => {
    return {
      ...state,
      selectEventDetail: {
        ...state.selectEventDetail,
        selectedEvent: {},
        status: ReduxStatus.loadFailed,
        message: payload.message,
      }
    };
  },
  [CLEAR_SELECTED_EVENT]: (state) => {
    return {
      ...state,
      selectEventDetail: {
        selectedEvent: {},
        status: ReduxStatus.loading,
        message: "",
      },
      eventVolunteers: {
        status: ReduxStatus.empty,
        activePage: 1,
        totalPage: 1,
        data: [],
        message: "",
        filter: {},
      },
      eventNotes: {
        status: ReduxStatus.empty,
        activePage: 1,
        totalPage: 1,
        data: [],
        message: "",
        filter: {},
      },
    };
  },

  [GET_EVENT_VOLUNTEERS]: state => {
    return {
      ...state,
      eventVolunteers: {
        ...state.eventVolunteers,
        status: ReduxStatus.loading,
        message: "",
      }
    };
  },
  [GET_EVENT_VOLUNTEERS_SUCCESS]: (state, { activePage, totalPage, totalRecord, data, filter }) => {
    return {
      ...state,
      eventVolunteers: {
        ...state.eventVolunteers,
        activePage,
        totalPage,
        totalRecord,
        data,
        status: ReduxStatus.loaded,
        message: "",
        filter,
      }
    };
  },
  [GET_EVENT_VOLUNTEERS_FAILED]: (state, payload) => {
    return {
      ...state,
      eventVolunteers: {
        ...state.eventVolunteers,
        status: ReduxStatus.loadFailed,
        message: payload.message,
      }
    };
  },

  [GET_EVENT_NOTES]: state => {
    return {
      ...state,
      eventNotes: {
        ...state.eventNotes,
        status: ReduxStatus.loading,
        message: "",
      }
    };
  },
  [GET_EVENT_NOTES_SUCCESS]: (state, { activePage, totalPage, data, filter }) => {
    return {
      ...state,
      eventNotes: {
        ...state.eventNotes,
        activePage,
        totalPage,
        data,
        status: ReduxStatus.loaded,
        message: "",
        filter,
      }
    };
  },
  [GET_EVENT_NOTES_FAILED]: (state, payload) => {
    return {
      ...state,
      eventNotes: {
        ...state.eventNotes,
        status: ReduxStatus.loadFailed,
        message: payload.message,
      }
    };
  },
};

export default function reducer(state = initialState, action = {}) {
  const fn = actionsMap[action.type];
  return fn ? fn(state, action.payload) : state;
}
