import ReduxStatus from '../../Common/Constants/ReduxStatus';
import {
  GET_INVENTORIES,
  GET_INVENTORIES_SUCCESS,
  GET_INVENTORIES_FAILED,
  UPDATE_INVENTORY_LOCATION_QUANTITY,
} from "../Actions/InventoryActionCreator";
import { CLEAR_SELECTED_EVENT } from "../Actions/EventActionCreator";


const initialState = {
  eventInventories: {
    status: ReduxStatus.empty,
    activePage: 1,
    totalPage: 1,
    data: [],
    message: "",
    filter: {},
  },
};

const actionsMap = {
  // Async action
  [GET_INVENTORIES]: state => {
    return {
      ...state,
      eventInventories: {
        ...state.eventInventories,
        status: ReduxStatus.loading,
        message: "",
      }
    };
  },
  [GET_INVENTORIES_SUCCESS]: (state, { activePage, totalPage, data, filter }) => {
    return {
      ...state,
      eventInventories: {
        ...state.eventInventories,
        activePage,
        totalPage,
        data,
        status: ReduxStatus.loaded,
        message: "",
        filter,
      }
    };
  },
  [GET_INVENTORIES_FAILED]: (state, payload) => {
    return {
      ...state,
      eventInventories: {
        ...state.eventInventories,
        status: ReduxStatus.loadFailed,
        message: payload.message,
      }
    };
  },
  [UPDATE_INVENTORY_LOCATION_QUANTITY]: (state, payload) => {
    const { inventoryId, locationId, quantity } = payload;
    const newData = [...state.eventInventories.data];
    newData.forEach(item => {
      if(item._id === inventoryId) {
        if(item.locations && item.locations.length > 0) {
          item.locations.forEach(loc => {
            if(loc.location === locationId) {
              loc.quantity = quantity;
            }
          })
          item.usedQuantity = item.locations.map(loc => loc.quantity).reduce((sum, value) => sum + value, 0);
        }
      }
    });
    return {
      ...state,
      eventInventories: {
        ...state.eventInventories,
        data: newData,
      }
    };
  },
  [CLEAR_SELECTED_EVENT]: () => {
    return {
      ...initialState,
    }
  }
};

export default function reducer(state = initialState, action = {}) {
  const fn = actionsMap[action.type];
  return fn ? fn(state, action.payload) : state;
}
