import ReduxStatus from '../../Common/Constants/ReduxStatus';
import {
  GET_LOCATIONS,
  GET_LOCATIONS_SUCCESS,
  GET_LOCATIONS_FAILED,

  GET_LOCATION_VOLUNTEERS,
  GET_LOCATION_VOLUNTEERS_SUCCESS,
  GET_LOCATION_VOLUNTEERS_FAILED,

  CLEAR_LOCATION_VOLUNTEERS, GET_LOCATIONS_ON_MAP, GET_LOCATIONS_ON_MAP_SUCCESS, GET_LOCATIONS_ON_MAP_FAILED,

} from "../Actions/LocationActionCreator";

import {
  GET_LOCATION_NOTES,
  GET_LOCATION_NOTES_SUCCESS,
  GET_LOCATION_NOTES_FAILED,
} from "../Actions/LocationNoteActionCreator";
import { CLEAR_SELECTED_EVENT } from "../Actions/EventActionCreator";


const initialState = {
  locationList: {
    status: ReduxStatus.empty,
    activePage: 1,
    totalPage: 1,
    totalRecord: 0,
    data: [],
    message: "",
    filter: {},
    sort: {},
  },
  locationListOnMap: {
    status: ReduxStatus.empty,
    activePage: 1,
    totalPage: 1,
    totalRecord: 0,
    data: [],
    message: "",
    filter: {},
    sort: {},
  },
  locationVolunteers: {
    status: ReduxStatus.empty,
    activePage: 1,
    totalPage: 1,
    data: [],
    message: "",
    filter: {},
  },
  locationNotes: {
    status: ReduxStatus.empty,
    activePage: 1,
    totalPage: 1,
    data: [],
    message: "",
    filter: {},
  },
};

const actionsMap = {
  // Async action
  [GET_LOCATIONS]: state => {
    return {
      ...state,
      locationList: {
        ...state.locationList,
        status: ReduxStatus.loading,
        message: "",
      }
    };
  },
  [GET_LOCATIONS_SUCCESS]: (state, { activePage, totalPage, totalRecord, data, filter, sort }) => {
    return {
      ...state,
      locationList: {
        ...state.locationList,
        activePage,
        totalPage,
        totalRecord,
        data,
        status: ReduxStatus.loaded,
        message: "",
        filter,
        sort,
      }
    };
  },
  [GET_LOCATIONS_FAILED]: (state, payload) => {
    return {
      ...state,
      locationList: {
        ...state.locationList,
        status: ReduxStatus.loadFailed,
        message: payload.message,
      }
    };
  },

  [GET_LOCATIONS_ON_MAP]: state => {
    return {
      ...state,
      locationListOnMap: {
        ...state.locationListOnMap,
        status: ReduxStatus.loading,
        message: "",
      }
    };
  },
  [GET_LOCATIONS_ON_MAP_SUCCESS]: (state, { activePage, totalPage, totalRecord, data, filter }) => {
    return {
      ...state,
      locationListOnMap: {
        ...state.locationListOnMap,
        activePage,
        totalPage,
        totalRecord,
        data,
        status: ReduxStatus.loaded,
        message: "",
        filter,
      }
    };
  },
  [GET_LOCATIONS_ON_MAP_FAILED]: (state, payload) => {
    return {
      ...state,
      locationListOnMap: {
        ...state.locationListOnMap,
        status: ReduxStatus.loadFailed,
        message: payload.message,
      }
    };
  },

  [GET_LOCATION_VOLUNTEERS]: state => {
    return {
      ...state,
      locationVolunteers: {
        ...state.locationVolunteers,
        data: [],
        status: ReduxStatus.loading,
        message: "",
      }
    };
  },
  [GET_LOCATION_VOLUNTEERS_SUCCESS]: (state, { activePage, totalPage, data, filter }) => {
    return {
      ...state,
      locationVolunteers: {
        ...state.locationVolunteers,
        activePage,
        totalPage,
        data,
        status: ReduxStatus.loaded,
        message: "",
        filter,
      }
    };
  },
  [GET_LOCATION_VOLUNTEERS_FAILED]: (state, payload) => {
    return {
      ...state,
      locationVolunteers: {
        ...state.locationVolunteers,
        status: ReduxStatus.loadFailed,
        message: payload.message,
      }
    };
  },
  [CLEAR_LOCATION_VOLUNTEERS]: (state) => {
    return {
      ...state,
      locationVolunteers: {
        ...initialState.locationVolunteers,
      }
    };
  },

  [CLEAR_SELECTED_EVENT]: () => {
    return {
      ...initialState,
    }
  },
  [GET_LOCATION_NOTES]: state => {
    return {
      ...state,
      locationNotes: {
        ...state.locationNotes,
        status: ReduxStatus.loading,
        message: "",
      }
    };
  },
  [GET_LOCATION_NOTES_SUCCESS]: (state, { activePage, totalPage, data, filter }) => {
    return {
      ...state,
      locationNotes: {
        ...state.locationNotes,
        activePage,
        totalPage,
        data,
        status: ReduxStatus.loaded,
        message: "",
        filter,
      }
    };
  },
  [GET_LOCATION_NOTES_FAILED]: (state, payload) => {
    return {
      ...state,
      locationNotes: {
        ...state.locationNotes,
        status: ReduxStatus.loadFailed,
        message: payload.message,
      }
    };
  },
};

export default function reducer(state = initialState, action = {}) {
  const fn = actionsMap[action.type];
  return fn ? fn(state, action.payload) : state;
}
