import ReduxStatus from '../../Common/Constants/ReduxStatus';
import {
  GET_LOCATION_SCHEDULE,
  GET_LOCATION_SCHEDULE_SUCCESS,
  GET_LOCATION_SCHEDULE_FAILED,
  RESET_LOCATION_SCHEDULE,
} from "../Actions/ScheduleActionCreator";
import { CLEAR_SELECTED_EVENT } from "../Actions/EventActionCreator";

const initialState = {
  locationSchedule: {
    status: ReduxStatus.empty,
    activePage: 1,
    totalPage: 1,
    data: [],
    message: "",
    filter: {},
  },
};

const actionsMap = {
  // Async action
  [GET_LOCATION_SCHEDULE]: state => {
    return {
      ...state,
      locationSchedule: {
        ...state.locationSchedule,
        status: ReduxStatus.loading,
        message: "",
      }
    };
  },
  [GET_LOCATION_SCHEDULE_SUCCESS]: (state, { activePage, totalPage, data, filter }) => {
    return {
      ...state,
      locationSchedule: {
        ...state.locationSchedule,
        activePage,
        totalPage,
        data,
        status: ReduxStatus.loaded,
        message: "",
        filter,
      }
    };
  },
  [GET_LOCATION_SCHEDULE_FAILED]: (state, payload) => {
    return {
      ...state,
      locationSchedule: {
        ...state.locationSchedule,
        status: ReduxStatus.loadFailed,
        message: payload.message,
      }
    };
  },
  [RESET_LOCATION_SCHEDULE]: () => {
    return {
      ...initialState,
    }
  },
  [CLEAR_SELECTED_EVENT]: () => {
    return {
      ...initialState,
    }
  }
};

export default function reducer(state = initialState, action = {}) {
  const fn = actionsMap[action.type];
  return fn ? fn(state, action.payload) : state;
}
