import { takeEvery, put, call, select, takeLatest, delay } from "redux-saga/effects";
import { deleteClient, get, patch, post } from '../../Common/Utils/AxiosClient';
import Enum from '../../Common/Constants/Enum';
import Utils from "../../Common/Utils/Utils";
import {
  CREATE_EVENT_NOTES,
  GET_EVENT_NOTES_SUCCESS,
  GET_EVENT_NOTES_FAILED,
  DELETE_EVENT_NOTES, GET_EVENT_NOTES,
  SAVE_EVENT_NOTES
} from "../Actions/EventNoteActionCreator";

function* watchGetEventNotes({ payload: { activePage, filter } }) {
  try {
    yield delay(300);
    const newFilter = Utils.cleanObject(filter);
    const skip = (activePage - 1) * Enum.NotePerPage;
    const url = `/notes`;
    const params = {
      filter: newFilter,
      limit: Enum.NotePerPage,
      skip,
      populate: { "path": "author" }
    };
    const res = yield call(get, url, params);
    const totalPage = Utils.getTotalPage(res.data.metadata);

    yield put({
      type: GET_EVENT_NOTES_SUCCESS,
      payload: {
        activePage,
        filter: filter,
        totalPage,
        data: res.data.data,
      }
    });
  } catch (e) {
    yield put({
      type: GET_EVENT_NOTES_FAILED,
      payload: {
        ...e
      },
    });
  }
}

function* watchCreateEventNotes({ payload: { note } }) {
  try {
    const url = '/notes';
    yield call(post, url, note);
    const eventNotesList = yield select(state => state.events.eventNotes);
    yield put({
      type: GET_EVENT_NOTES,
      payload: {
        activePage: eventNotesList.activePage,
        filter: eventNotesList.filter,
      }
    });
  } catch (e) {
  }
}

function* watchSaveEventNotes({ payload: { note } }) {
  try {
    const url = `/notes/${note._id}`;
    yield call(patch, url, note);
    const eventNotesList = yield select(state => state.events.eventNotes);
    yield put({
      type: GET_EVENT_NOTES,
      payload: {
        activePage: eventNotesList.activePage,
        filter: eventNotesList.filter,
      }
    });
  } catch (e) {
  }
}

function* watchDeleteEventNotes({ payload: { id } }) {
  try {
    const url = `/notes/${id}`;
    yield call(deleteClient, url);
    const eventNotesList = yield select(state => state.events.eventNotes);
    yield put({
      type: GET_EVENT_NOTES,
      payload: {
        activePage: eventNotesList.activePage,
        filter: eventNotesList.filter,
      }
    });
  } catch (e) {
  }
}

function* EventNoteSaga() {
  yield takeLatest(GET_EVENT_NOTES, watchGetEventNotes);
  yield takeEvery(CREATE_EVENT_NOTES, watchCreateEventNotes);
  yield takeEvery(SAVE_EVENT_NOTES, watchSaveEventNotes);
  yield takeEvery(DELETE_EVENT_NOTES, watchDeleteEventNotes);
}

export default EventNoteSaga;
