import { takeEvery, put, call, select, takeLatest, delay } from "redux-saga/effects";
import { deleteClient, get, patch, post } from '../../Common/Utils/AxiosClient';
import Enum from '../../Common/Constants/Enum';
import {
  GET_INVENTORIES,
  GET_INVENTORIES_SUCCESS,
  GET_INVENTORIES_FAILED,
  CREATE_INVENTORY,
  SAVE_INVENTORY,
  SAVE_INVENTORY_FAILED,
  DELETE_INVENTORY, UPDATE_INVENTORY_LOCATION_QUANTITY,
} from "../Actions/InventoryActionCreator";
import Utils from "../../Common/Utils/Utils";
import InventoryActionCreator from "../Actions/InventoryActionCreator";

function* watchGetInventories({ payload: { eventId, activePage, filter } }) {
  try {
    const skip = (activePage - 1) * Enum.VolunteerPerPage;
    const url = `/events/${eventId}/inventories`;
    const params = {
      filter,
      limit: Enum.VolunteerPerPage,
      skip,
    };
    const res = yield call(get, url, params);
    const totalPage = Utils.getTotalPage(res.data.metadata);
    const data = res.data.data.map(item => {
      return {
        ...item,
        usedQuantity: item.locations ? item.locations.map(loc => loc.quantity).reduce((sum, value) => sum + value, 0) : 0,
      }
    })
    yield put({
      type: GET_INVENTORIES_SUCCESS,
      payload: {
        activePage,
        filter: filter,
        totalPage,
        data,
      }
    });
  } catch (e) {
    yield put({
      type: GET_INVENTORIES_FAILED,
      payload: {
        ...e
      },
    });
  }
}

function* watchCreateInventory({ payload: { eventId, inventory } }) {
  try {
    const url = `/events/${eventId}/inventories`;
    yield call(post, url, inventory);
    let eventInventories = yield select(state => state.inventories.eventInventories);
    yield put(InventoryActionCreator.getInventories(eventId, eventInventories.activePage, eventInventories.filter))
  } catch (e) {
  }
}

function* watchSaveInventory({ payload: { eventId, inventory } }) {
  try {
    const url = `/events/${eventId}/inventories/${inventory._id}`;
    yield call(patch, url, inventory);
    let eventInventories = yield select(state => state.inventories.eventInventories);
    yield put(InventoryActionCreator.getInventories(eventId, eventInventories.activePage, eventInventories.filter))
  } catch (e) {
    yield put({
      type: SAVE_INVENTORY_FAILED,
      payload: {
        ...e
      },
    });
  }
}

function* watchDeleteInventory({ payload: { eventId, id } }) {
  try {
    const url = `/events/${eventId}/inventories/${id}`;
    yield call(deleteClient, url);
    let eventInventories = yield select(state => state.inventories.eventInventories);
    yield put(InventoryActionCreator.getInventories(eventId, eventInventories.activePage, eventInventories.filter))
  } catch (e) {
  }
}

function* watchUpdateInventoryLocationQuantity({ payload: { eventId, inventoryId, locationId, quantity } }) {
  try {
    yield delay(300);
    const url = `/events/${eventId}/inventories/${inventoryId}/update-quantity/${locationId}`;
    yield call(patch, url, { quantity });
    let eventInventories = yield select(state => state.inventories.eventInventories);
    yield put(InventoryActionCreator.getInventories(eventId, eventInventories.activePage, eventInventories.filter))
  } catch (e) {
  }
}

function* InventorySaga() {
  yield takeEvery(GET_INVENTORIES, watchGetInventories);
  yield takeEvery(CREATE_INVENTORY, watchCreateInventory);
  yield takeEvery(SAVE_INVENTORY, watchSaveInventory);
  yield takeEvery(DELETE_INVENTORY, watchDeleteInventory);
  yield takeLatest(UPDATE_INVENTORY_LOCATION_QUANTITY, watchUpdateInventoryLocationQuantity);
}

export default InventorySaga;
