import { takeEvery, put, call, select, takeLatest, delay } from "redux-saga/effects";
import { deleteClient, get, patch, post } from '../../Common/Utils/AxiosClient';
import Enum from '../../Common/Constants/Enum';
import Utils from "../../Common/Utils/Utils";
import {
  CREATE_LOCATION_NOTES,
  GET_LOCATION_NOTES_SUCCESS,
  GET_LOCATION_NOTES_FAILED,
  DELETE_LOCATION_NOTES, GET_LOCATION_NOTES,
  SAVE_LOCATION_NOTES
} from "../Actions/LocationNoteActionCreator";

function* watchGetLocationNotes({ payload: { activePage, filter } }) {
  try {
    yield delay(300);
    const newFilter = Utils.cleanObject(filter);
    const skip = (activePage - 1) * Enum.NotePerPage;
    const url = `/notes`;
    const params = {
      filter: newFilter,
      limit: Enum.NotePerPage,
      skip,
      populate: { "path": "author" }
    };
    const res = yield call(get, url, params);
    const totalPage = Utils.getTotalPage(res.data.metadata);

    yield put({
      type: GET_LOCATION_NOTES_SUCCESS,
      payload: {
        activePage,
        filter: filter,
        totalPage,
        data: res.data.data,
      }
    });
  } catch (e) {
    yield put({
      type: GET_LOCATION_NOTES_FAILED,
      payload: {
        ...e
      },
    });
  }
}

function* watchCreateLocationNotes({ payload: { note } }) {
  try {
    const url = '/notes';
    yield call(post, url, note);
    const locationNotesList = yield select(state => state.locations.locationNotes);
    yield put({
      type: GET_LOCATION_NOTES,
      payload: {
        activePage: locationNotesList.activePage,
        filter: locationNotesList.filter,
      }
    });
  } catch (e) {
  }
}

function* watchSaveLocationNotes({ payload: { note } }) {
  try {
    const url = `/notes/${note._id}`;
    yield call(patch, url, note);
    const locationNotesList = yield select(state => state.locations.locationNotes);
    yield put({
      type: GET_LOCATION_NOTES,
      payload: {
        activePage: locationNotesList.activePage,
        filter: locationNotesList.filter,
      }
    });
  } catch (e) {
  }
}

function* watchDeleteLocationNotes({ payload: { id } }) {
  try {
    const url = `/notes/${id}`;
    yield call(deleteClient, url);
    const locationNotesList = yield select(state => state.locations.locationNotes);
    yield put({
      type: GET_LOCATION_NOTES,
      payload: {
        activePage: locationNotesList.activePage,
        filter: locationNotesList.filter,
      }
    });
  } catch (e) {
  }
}

function* LocationNoteSaga() {
  yield takeLatest(GET_LOCATION_NOTES, watchGetLocationNotes);
  yield takeEvery(CREATE_LOCATION_NOTES, watchCreateLocationNotes);
  yield takeEvery(SAVE_LOCATION_NOTES, watchSaveLocationNotes);
  yield takeEvery(DELETE_LOCATION_NOTES, watchDeleteLocationNotes);
}

export default LocationNoteSaga;
