import { takeEvery, put, call, select, takeLatest, delay } from "redux-saga/effects";
import isempty from 'lodash.isempty';
import { toast } from 'react-toastify';
import { deleteClient, get, patch, post, put as clientPut } from '../../Common/Utils/AxiosClient';
import Enum from '../../Common/Constants/Enum';
import {
  GET_LOCATIONS,
  GET_LOCATIONS_SUCCESS,
  GET_LOCATIONS_FAILED,
  CREATE_LOCATION,
  SAVE_LOCATION,
  DELETE_LOCATION,

  GET_LOCATIONS_ON_MAP,
  GET_LOCATIONS_ON_MAP_SUCCESS,
  GET_LOCATIONS_ON_MAP_FAILED,
  CREATE_LOCATION_ON_MAP,
  SAVE_LOCATION_ON_MAP,
  DELETE_LOCATION_ON_MAP,

  GET_LOCATION_VOLUNTEERS,
  GET_LOCATION_VOLUNTEERS_SUCCESS,
  GET_LOCATION_VOLUNTEERS_FAILED,
  SAVE_LOCATION_VOLUNTEER,
  SAVE_LOCATION_VOLUNTEER_FAILED,
  SEARCH_LOCATION,
  CHANGE_LOCATION_FROM_VOLUNTEER,
  ADD_VOLUNTEER_TO_LOCATION, REMOVE_VOLUNTEER_TO_LOCATION,
} from "../Actions/LocationActionCreator";
import Utils from "../../Common/Utils/Utils";
import LocationActionCreator from "../Actions/LocationActionCreator";
import EventActionCreator from "../Actions/EventActionCreator";
import ContactActionCreator from "../../Contact/Actions/ContactActionCreator";

function* watchGetLocations({ payload: { eventId, activePage, filter, sort } }) {
  try {
    const skip = (activePage - 1) * Enum.VolunteerPerPage;
    const newFilter = Utils.cleanObject(filter);
    const url = `/events/${eventId}/locations`;
    const params = {
      filter: newFilter,
      limit: Enum.VolunteerPerPage,
      skip,
      sort: isempty(sort) ? { name: 1 } : sort,
      populate: { "path": "voting_district" }
    };
    const res = yield call(get, url, params);
    const totalPage = Utils.getTotalPage(res.data.metadata)
    yield put({
      type: GET_LOCATIONS_SUCCESS,
      payload: {
        activePage,
        filter: filter,
        sort: params.sort,
        totalPage,
        totalRecord: res.data.metadata.total,
        data: res.data.data,
      }
    });
  } catch (e) {
    yield put({
      type: GET_LOCATIONS_FAILED,
      payload: {
        ...e
      },
    });
  }
}

function* watchCreateLocation({ payload: { eventId, location } }) {
  try {
    const url = `/events/${eventId}/locations`;
    yield call(post, url, location);
    let locationList = yield select(state => state.locations.locationList);
    yield put(LocationActionCreator.getLocations(eventId, locationList.activePage, locationList.filter, locationList.sort));
    toast.success(`Create location ${location.name} successful`);
  } catch (e) {
    toast.error(`Create location failed`);
  }
}

function* watchSaveLocation({ payload: { eventId, location } }) {
  try {
    const url = `/events/${eventId}/locations/${location._id}`;
    yield call(patch, url, location);
    let locationList = yield select(state => state.locations.locationList);
    yield put(LocationActionCreator.getLocations(eventId, locationList.activePage, locationList.filter, locationList.sort));
    toast.success(`Update location ${location.name} successful`);
  } catch (e) {
    toast.error(`Update location failed`);
  }
}

function* watchDeleteLocation({ payload: { eventId, id } }) {
  try {
    const url = `/events/${eventId}/locations/${id}`;
    yield call(deleteClient, url);
    let locationList = yield select(state => state.locations.locationList);
    yield put(LocationActionCreator.getLocations(eventId, locationList.activePage, locationList.filter, locationList.sort));
    toast.success(`Delete location successful`);
  } catch (e) {
    toast.error(`Delete location failed`);
  }
}

function* watchGetLocationsOnMap({ payload: { eventId, activePage, filter, sort } }) {
  try {
    const skip = (activePage - 1) * Enum.VolunteerPerPage;
    const url = `/events/${eventId}/locations`;
    const params = {
      filter,
      limit: Enum.VolunteerPerPage,
      skip,
      sort: isempty(sort) ? { name: 1 } : sort,
      populate: { "path": "voting_district" }
    };
    const res = yield call(get, url, params);
    const totalPage = Utils.getTotalPage(res.data.metadata)
    yield put({
      type: GET_LOCATIONS_ON_MAP_SUCCESS,
      payload: {
        activePage,
        filter: filter,
        totalPage,
        totalRecord: res.data.metadata.total,
        data: res.data.data,
      }
    });
  } catch (e) {
    yield put({
      type: GET_LOCATIONS_ON_MAP_FAILED,
      payload: {
        ...e
      },
    });
  }
}

function* watchCreateLocationOnMap({ payload: { eventId, location } }) {
  try {
    const url = `/events/${eventId}/locations`;
    yield call(post, url, location);
    let locationList = yield select(state => state.locations.locationListOnMap);
    yield put(LocationActionCreator.getLocationsOnMap(eventId, locationList.activePage, locationList.filter, locationList.sort));
    toast.success(`Create location ${location.name} successful`);
  } catch (e) {
    toast.error(`Create location failed`);
  }
}

function* watchSaveLocationOnMap({ payload: { eventId, location } }) {
  try {
    const url = `/events/${eventId}/locations/${location._id}`;
    yield call(patch, url, location);
    let locationList = yield select(state => state.locations.locationListOnMap);
    yield put(LocationActionCreator.getLocationsOnMap(eventId, locationList.activePage, locationList.filter, locationList.sort));
    toast.success(`Update location ${location.name} successful`);
  } catch (e) {
    toast.error(`Update location failed`);
  }
}

function* watchDeleteLocationOnMap({ payload: { eventId, id } }) {
  try {
    const url = `/events/${eventId}/locations/${id}`;
    yield call(deleteClient, url);
    let locationList = yield select(state => state.locations.locationListOnMap);
    yield put(LocationActionCreator.getLocationsOnMap(eventId, locationList.activePage, locationList.filter, locationList.sort));
    toast.success(`Delete location successful`);
  } catch (e) {
    toast.error(`Delete location failed`);
  }
}

function* watchGetLocationVolunteers({ payload: { locationId, activePage, filter } }) {
  try {
    const skip = (activePage - 1) * Enum.VolunteerPerPage;
    const url = `/locations/${locationId}/volunteers`;
    const params = {
      filter,
      limit: Enum.VolunteerPerPage,
      skip,
    };
    const res = yield call(get, url, params);
    const totalPage = Utils.getTotalPage(res.data.metadata)
    yield put({
      type: GET_LOCATION_VOLUNTEERS_SUCCESS,
      payload: {
        activePage,
        filter: filter,
        totalPage,
        data: res.data.data,
      }
    });
  } catch (e) {
    yield put({
      type: GET_LOCATION_VOLUNTEERS_FAILED,
      payload: {
        ...e
      },
    });
  }
}

function* watchAddVolunteerToLocation({ payload: { locationId, volunteerId } }) {
  try {
    const addLocationUrl = `/locations/${locationId}/volunteers`;
    yield call(post, addLocationUrl, [volunteerId]);
    const volunteerOnMapList = yield select(state => state.contacts.volunteerOnMapList);
    const { filter: { geoInfo, status } } = volunteerOnMapList;
    yield put(ContactActionCreator.searchVolunteerOnMap(geoInfo, status));
    yield put(LocationActionCreator.getLocationVolunteers(locationId));
  } catch (e) {

  }
}

function* watchRemoveVolunteerFromLocation({ payload: { locationId, volunteerId } }) {
  try {
    const removeLocationUrl = `/locations/${locationId}/volunteers/${volunteerId}`;
    yield call(deleteClient, removeLocationUrl);
    const volunteerOnMapList = yield select(state => state.contacts.volunteerOnMapList);
    const { filter: { geoInfo, status } } = volunteerOnMapList;
    yield put(ContactActionCreator.searchVolunteerOnMap(geoInfo, status));
    yield put(LocationActionCreator.getLocationVolunteers(locationId));
  } catch (e) {

  }
}

function* watchSaveLocationVolunteer({ payload: { eventId, locationId, volunteerIds } }) {
  try {
    const url = `/locations/${locationId}/volunteers`;
    yield call(clientPut, url, volunteerIds);

    yield put(EventActionCreator.getEventVolunteers(eventId));
    let locationList = yield select(state => state.locations.locationList);
    yield put(LocationActionCreator.getLocations(eventId, locationList.activePage, locationList.filter, locationList.sort));
  } catch (e) {
    yield put({
      type: SAVE_LOCATION_VOLUNTEER_FAILED,
      payload: {
        ...e
      },
    });
  }
}

function* watchSearchLocation({ payload: { eventId, searchText, voting_district, handleSearchResult } }) {
  try {
    yield delay(300);
    const filter = {};
    if (searchText) {
      const search = [
        {
          "name": {
            "$regex": searchText,
            "$options": "i",
          },
        },
        {
          "address.line1": {
            "$regex": searchText,
            "$options": "i"
          }
        },
        {
          "address.line2": {
            "$regex": searchText,
            "$options": "i"
          }
        },
        {
          "address.line3": {
            "$regex": searchText,
            "$options": "i"
          }
        },
        {
          "address.city": {
            "$regex": searchText,
            "$options": "i"
          }
        },

        {
          "address.state": {
            "$regex": searchText,
            "$options": "i"
          }
        },
        {
          "address.country": {
            "$regex": searchText,
            "$options": "i"
          }
        },
      ];
      filter["$or"] = search;
    }
    if (voting_district) {
      filter.voting_district = voting_district;
    }
    const url = `/events/${eventId}/locations`;
    const params = {
      filter,
      limit: 20,
      skip: 0,
    };
    const res = yield call(get, url, params);
    handleSearchResult(res.data.data);
  } catch (e) {
  }
}

function* watchChangeLocationFromVolunteer({ payload: { eventId, oldLocationId, newLocationId, volunteerId } }) {
  try {
    if (oldLocationId) {
      const removeLocationUrl = `/locations/${oldLocationId}/volunteers/${volunteerId}`;
      yield call(deleteClient, removeLocationUrl);
    }

    if (newLocationId) {
      const addLocationUrl = `/locations/${newLocationId}/volunteers`;
      yield call(post, addLocationUrl, [volunteerId]);
    }
    let eventVolunteersList = yield select(state => state.events.eventVolunteers);
    yield put(EventActionCreator.getEventVolunteers(eventId, eventVolunteersList.activePage, eventVolunteersList.filter))
    toast.success(`Change location successful`);

  } catch (e) {
    toast.error(`Something went wrong`);
  }
}

function* LocationSaga() {
  yield takeEvery(GET_LOCATIONS, watchGetLocations);
  yield takeEvery(CREATE_LOCATION, watchCreateLocation);
  yield takeEvery(SAVE_LOCATION, watchSaveLocation);
  yield takeEvery(DELETE_LOCATION, watchDeleteLocation);

  yield takeEvery(GET_LOCATIONS_ON_MAP, watchGetLocationsOnMap);
  yield takeEvery(CREATE_LOCATION_ON_MAP, watchCreateLocationOnMap);
  yield takeEvery(SAVE_LOCATION_ON_MAP, watchSaveLocationOnMap);
  yield takeEvery(DELETE_LOCATION_ON_MAP, watchDeleteLocationOnMap);

  yield takeEvery(GET_LOCATION_VOLUNTEERS, watchGetLocationVolunteers);
  yield takeEvery(ADD_VOLUNTEER_TO_LOCATION, watchAddVolunteerToLocation);
  yield takeEvery(REMOVE_VOLUNTEER_TO_LOCATION, watchRemoveVolunteerFromLocation);
  yield takeEvery(SAVE_LOCATION_VOLUNTEER, watchSaveLocationVolunteer);
  yield takeLatest(SEARCH_LOCATION, watchSearchLocation);
  yield takeEvery(CHANGE_LOCATION_FROM_VOLUNTEER, watchChangeLocationFromVolunteer);
}

export default LocationSaga;
