import { takeEvery, put, call, select } from "redux-saga/effects";
import { toast } from 'react-toastify';
import { deleteClient, get, patch, post } from '../../Common/Utils/AxiosClient';
import Enum from '../../Common/Constants/Enum';
import ScheduleActionCreator, {
  GET_LOCATION_SCHEDULE,
  GET_LOCATION_SCHEDULE_SUCCESS,
  GET_LOCATION_SCHEDULE_FAILED,
  CREATE_LOCATION_SCHEDULE,
  SAVE_LOCATION_SCHEDULE,
  DELETE_LOCATION_SCHEDULE,
} from "../Actions/ScheduleActionCreator";
import Utils from "../../Common/Utils/Utils";

function* watchGetLocationSchedule({ payload: { locationId, activePage, filter = {} } }) {
  try {
    const skip = (activePage - 1) * Enum.VolunteerPerPage;
    const url = `/locations/${locationId}/schedules`;
    const params = {
      filter,
      limit: Enum.VolunteerPerPage,
      skip,
      populate: { "path": "volunteer" }
    };
    const res = yield call(get, url, params);
    const totalPage = Utils.getTotalPage(res.data.metadata);
    yield put({
      type: GET_LOCATION_SCHEDULE_SUCCESS,
      payload: {
        activePage,
        filter: filter,
        totalPage,
        data: res.data.data,
      }
    });
  } catch (e) {
    yield put({
      type: GET_LOCATION_SCHEDULE_FAILED,
      payload: {
        ...e
      },
    });
  }
}

function* watchCreateLocationSchedule({ payload: { locationId, schedule } }) {
  try {
    const url = `/locations/${locationId}/schedules`;
    yield call(post, url, schedule);
    let locationSchedule = yield select(state => state.schedule.locationSchedule);
    yield put(ScheduleActionCreator.getLocationSchedule(locationId, locationSchedule.activePage, locationSchedule.filter));
    toast.success(`Create schedule successful`);
  } catch (e) {
    toast.error(`Create schedule failed`);
  }
}

function* watchSaveLocationSchedule({ payload: { locationId, schedule } }) {
  try {
    const url = `/locations/${locationId}/schedules/${schedule._id}`;
    yield call(patch, url, schedule);
    let locationSchedule = yield select(state => state.schedule.locationSchedule);
    yield put(ScheduleActionCreator.getLocationSchedule(locationId, locationSchedule.activePage, locationSchedule.filter))
    toast.success(`Update schedule successful`);
  } catch (e) {
    const { response: { data: { error } } } = e;
    toast.error(error.message);
    let locationSchedule = yield select(state => state.schedule.locationSchedule);
    yield put(ScheduleActionCreator.getLocationSchedule(locationId, locationSchedule.activePage, locationSchedule.filter));
  }
}

function* watchDeleteLocationSchedule({ payload: { locationId, id } }) {
  try {
    const url = `/locations/${locationId}/schedules/${id}`;
    yield call(deleteClient, url);
    let locationSchedule = yield select(state => state.schedule.locationSchedule);
    yield put(ScheduleActionCreator.getLocationSchedule(locationId, locationSchedule.activePage, locationSchedule.filter))
  } catch (e) {
  }
}


function* LocationScheduleSaga() {
  yield takeEvery(GET_LOCATION_SCHEDULE, watchGetLocationSchedule);
  yield takeEvery(CREATE_LOCATION_SCHEDULE, watchCreateLocationSchedule);
  yield takeEvery(SAVE_LOCATION_SCHEDULE, watchSaveLocationSchedule);
  yield takeEvery(DELETE_LOCATION_SCHEDULE, watchDeleteLocationSchedule);
}

export default LocationScheduleSaga;
