import React from "react";
import Enum from '../../../Common/Constants/Enum'
import FinanceFilter from "./FinanceFilter/FinanceFilter";
import moment from 'moment'
import injectsheet from 'react-jss'
import PropTypes from "prop-types"
import PaymentActionCreator from "../../Actions/PaymentActionCreator"
import AppContext from "../../../Common/Constants/AppContext"
import { Table, Pagination, Loader, Tab } from "semantic-ui-react"
import Utils from "../../../Common/Utils/Utils"
import ReduxStatus from "../../../Common/Constants/ReduxStatus"
import stylesheet from './stylesheet'
import { Link } from "react-router-dom"
import _ from 'lodash'

class Campaigns extends React.Component {

    constructor() {
        super();
        this.handlePaginationChange = this.handlePaginationChange.bind(this);
    }

    componentDidMount() {
        const { dispatch } = this.context;
        dispatch(PaymentActionCreator.getPayments(1, { campaign_code: { $gt: 0 } }));
    }

    handlePaginationChange(e, { activePage }) {
        const { dispatch } = this.context;
        dispatch(PaymentActionCreator.getPayments(activePage, { campaign_code: { $gt: 0 } }));
    }

    render() {
        const { intl: { messages } } = this.context;
        const { classes, payments: { data, status, activePage, totalPage } } = this.props;
        return (
            <div className={classes.paymentListPage}>
                {
                    status === ReduxStatus.loading && <Loader active />
                }
                &nbsp;
                <Table singleLine selectable basic>
                    <Table.Header>
                        <Table.Row>
                            <Table.HeaderCell>{messages.paymentId}</Table.HeaderCell>
                            <Table.HeaderCell>{messages.campaignId}</Table.HeaderCell>
                            <Table.HeaderCell>{messages.date}</Table.HeaderCell>
                            <Table.HeaderCell>{messages.amount}</Table.HeaderCell>
                            <Table.HeaderCell>{messages.actual_amount}</Table.HeaderCell>
                            <Table.HeaderCell>{messages.paymentType}</Table.HeaderCell>
                            <Table.HeaderCell>{messages.reference}</Table.HeaderCell>
                            <Table.HeaderCell>{messages.paymentMethod}</Table.HeaderCell>
                            <Table.HeaderCell>{messages.payee}</Table.HeaderCell>
                            <Table.HeaderCell>{messages.status}</Table.HeaderCell>
                        </Table.Row>
                    </Table.Header>
                    <Table.Body>
                        {data.sort((a, b) => b.campaign_code - a.campaign_code).map(item => (
                            <Table.Row key={item._id}>
                                <Table.Cell>
                                    <Link to={`/finance-detail/${item._id}`}>
                                        {_.padStart(item.payment_id, 5, 0)}
                                    </Link>
                                </Table.Cell>
                                <Table.Cell>{item.campaign_code}</Table.Cell>
                                <Table.Cell>{item.processed_date && moment(new Date(item.processed_date)).format('D MMM YYYY')}</Table.Cell>
                                <Table.Cell>${item.amount}</Table.Cell>
                                <Table.Cell>${item.actual_amount || item.amount}</Table.Cell>
                                <Table.Cell>{messages[item.payment_type]}</Table.Cell>
                                <Table.Cell>{item.reference ? _.padStart(item.reference, 5, 0) : '-'}</Table.Cell>
                                <Table.Cell>{messages[item.payment_method]}</Table.Cell>
                                <Table.Cell>
                                    {
                                        item.linked_profile ?
                                            <a target="_blank" rel="noopener noreferrer"
                                                href={`/contact-detail/${item.linked_profile._id}/overview`}>
                                                {Utils.combineName(item.linked_profile, messages)}
                                            </a> :
                                            Utils.combinePersonName(item.payee)
                                    }
                                </Table.Cell>
                                <Table.Cell>
                                    {
                                        item.status === 'failed' ?
                                            <div className='failed-status'>{messages[item.status]}</div> :
                                            messages[item.status]
                                    }
                                </Table.Cell>
                            </Table.Row>
                        ))}
                    </Table.Body>
                </Table>

                {
                    data.length > 0 && totalPage > 1 &&
                    <Pagination
                        activePage={activePage}
                        totalPages={totalPage}
                        onPageChange={this.handlePaginationChange}
                    />
                }

            </div>
        )
    }
}

Campaigns.propTypes = {
    payments: PropTypes.shape({}).isRequired,
};

Campaigns.contextType = AppContext;

export default injectsheet(stylesheet)(Campaigns);