import React from 'react'
import FinanceFilter from "./FinanceFilter/FinanceFilter"
import Enum from '../../../Common/Constants/Enum'
import moment from 'moment'
import injectsheet from 'react-jss'
import PropTypes from "prop-types"
import AppContext from "../../../Common/Constants/AppContext"
import PaymentActionCreator from "../../Actions/PaymentActionCreator"
import { Table, Pagination, Loader, Icon, Button } from "semantic-ui-react"
import Utils from "../../../Common/Utils/Utils"
import ReduxStatus from "../../../Common/Constants/ReduxStatus"
import stylesheet from './stylesheet'
import { Link } from "react-router-dom"
import _ from 'lodash'

class DonationPayment extends React.Component {
  constructor() {
    super();
    this.handlePaginationChange = this.handlePaginationChange.bind(this);
    this.onSearchFilterChange = this.onSearchFilterChange.bind(this);
  }

  componentDidMount() {
    const { dispatch } = this.context;
    const { payments: { activePage, filter } } = this.props;
    dispatch(PaymentActionCreator.getDonationPayments(activePage, filter));
  }

  handlePaginationChange(e, { activePage }) {
    const { dispatch } = this.context;
    const { payments: { filter } } = this.props;
    dispatch(PaymentActionCreator.getDonationPayments(activePage, filter));
  }

  onSearchFilterChange(filter) {
    const { dispatch } = this.context;
    dispatch(PaymentActionCreator.getDonationPayments(1, filter));
  }

  handleExportToCSV = () => {
    const { dispatch } = this.context
    const { payments: { filter } } = this.props
    const donationFilter = filter.payment_type ? {} : {
      payment_type: {"$in": Object.values(Enum.DonationTypeEnum) }
    }
    dispatch(PaymentActionCreator.exportPaymentsToCSV({...filter,...donationFilter}))
  }

  render() {
    const { intl: { messages } } = this.context;
    const { classes, payments: { data, status, activePage, totalPage, totalRecord, filter } } = this.props;
    return (
      <div className={classes.paymentListPage}>
        {
          status === ReduxStatus.loading && <Loader active />
        }
        <FinanceFilter
          initFilter={filter}
          onSearchFilterChange={this.onSearchFilterChange}
          showNumber={data.length}
          total={totalRecord}
          filterType='donation'
        />

        <Table singleLine selectable basic>
          <Table.Header>
            <Table.Row className="contact-header">
              <Table.HeaderCell>{messages.paymentId}</Table.HeaderCell>
              <Table.HeaderCell>{messages.date}</Table.HeaderCell>
              <Table.HeaderCell>{messages.amount}</Table.HeaderCell>
              <Table.HeaderCell>{messages.actual_amount}</Table.HeaderCell>
              <Table.HeaderCell>{messages.paymentType}</Table.HeaderCell>
              <Table.HeaderCell>{messages.reference}</Table.HeaderCell>
              <Table.HeaderCell>{messages.paymentMethod}</Table.HeaderCell>
              <Table.HeaderCell>{messages.payee}</Table.HeaderCell>
              <Table.HeaderCell>{messages.status}</Table.HeaderCell>
              <Table.HeaderCell>
                <Button basic icon onClick={this.handleExportToCSV}>{messages.exportToCSV} <Icon name='download' /></Button>
              </Table.HeaderCell>
            </Table.Row>
          </Table.Header>
          <Table.Body>
            {data.map(item => (
              <Table.Row key={item._id}>
                <Table.Cell>
                  <Link to={`/finance-detail/${item._id}`}>
                    {_.padStart(item.payment_id, 5, 0)}
                  </Link>
                </Table.Cell>
                <Table.Cell>{item.processed_date && moment(new Date(item.processed_date)).format('D MMM YYYY')}</Table.Cell>
                <Table.Cell>${item.amount}</Table.Cell>
                <Table.Cell>${item.actual || item.amount}</Table.Cell>
                <Table.Cell>{messages[item.payment_type]}</Table.Cell>
                <Table.Cell>{item.reference ? _.padStart(item.reference, 5, 0) : '-'}</Table.Cell>
                <Table.Cell>{messages[item.payment_method]}</Table.Cell>
                <Table.Cell>
                  {
                    item.linked_profile ?
                    <a target="_blank" rel="noopener noreferrer"
                       href={`/contact-detail/${item.linked_profile._id}/overview`}>
                      {Utils.combineName(item.linked_profile, messages)}
                    </a> :
                    Utils.combinePersonName(item.payee)
                  }
                </Table.Cell>
                <Table.Cell>
                  {
                    item.status === 'failed' ?
                      <div className='failed-status'>{messages[item.status]}</div> :
                      messages[item.status]
                  }
                </Table.Cell>
                <Table.Cell></Table.Cell>
              </Table.Row>
            ))}
          </Table.Body>
        </Table>
        {
          data.length > 0 && totalPage > 1 &&
          <Pagination
            activePage={activePage}
            totalPages={totalPage}
            onPageChange={this.handlePaginationChange}
          />
        }
      </div>
    );
  }
}

DonationPayment.propTypes = {
  payments: PropTypes.shape({}).isRequired,
};

DonationPayment.contextType = AppContext;

export default injectsheet(stylesheet)(DonationPayment);
