import React from 'react'
import FinanceFilter from "./FinanceFilter/FinanceFilter"
import Enum from '../../../Common/Constants/Enum'
import moment from 'moment'
import injectsheet from 'react-jss'
import PropTypes from "prop-types"
import AppContext from "../../../Common/Constants/AppContext"
import PaymentActionCreator from "../../Actions/PaymentActionCreator"
import { Table, Pagination, Loader, Button, Icon } from "semantic-ui-react"
import Utils from "../../../Common/Utils/Utils"
import ReduxStatus from "../../../Common/Constants/ReduxStatus"
import stylesheet from './stylesheet'
import { Link } from "react-router-dom"
import _ from 'lodash'

class MembershipPayment extends React.Component {
  constructor() {
    super();
    this.state = {
      isEdit: false,
      selectedPayment: null,
      value: null,
      isHitSave: false,
    }
    this.handlePaginationChange = this.handlePaginationChange.bind(this);
    this.onSearchFilterChange = this.onSearchFilterChange.bind(this);
    this.handleSaveInfo = this.handleSaveInfo.bind(this);
    this.handleChange = this.handleChange.bind(this);
    this.onCancel = this.onCancel.bind(this);
  }

  componentDidMount() {
    const { dispatch } = this.context;
    const { payments: { activePage, filter } } = this.props;
    dispatch(PaymentActionCreator.getMembershipPayments(activePage, filter));
  }

  handlePaginationChange(e, { activePage }) {
    const { dispatch } = this.context;
    const { payments: { filter } } = this.props;
    dispatch(PaymentActionCreator.getMembershipPayments(activePage, filter));
  }

  onSearchFilterChange(filter) {
    const { dispatch } = this.context;
    dispatch(PaymentActionCreator.getMembershipPayments(1, filter));
  }

  handleExportToCSV = () => {
    const { dispatch } = this.context
    const { payments: { filter } } = this.props
    const membershipFilter = {payment_type: Enum.PaymentTypeEnum.membership}
    dispatch(PaymentActionCreator.exportPaymentsToCSV({...filter,...membershipFilter}))
  }

  handleChange({ target: { value } }) {
    this.setState({
      value,
    })
  }

  handleSaveInfo(payment) {
      if (!this.state.isHitSave) {
        this.setState({
          isHitSave: true,
        });
      }
      if(this.state.value === payment.campaign_code) {
        this.onCancel();
        return;
      }
      const { dispatch } = this.context
      dispatch(PaymentActionCreator.savePayment(payment._id, this.state.value));
      this.setState({
        isEdit: false,
      })
  }

  onCancel() {
    this.setState({
      isEdit: false,
      selectedPayment: null,
    })
  }


  render() {
    const { intl: { messages } } = this.context;
    const { classes, payments: { data, status, activePage, totalPage, totalRecord, filter } } = this.props;
    return (
      <div className={classes.paymentListPage}>
        {
          status === ReduxStatus.loading && <Loader active />
        }

        <FinanceFilter
          initFilter={filter}
          onSearchFilterChange={this.onSearchFilterChange}
          showNumber={data.length}
          total={totalRecord}
          filterType=''
        />

        <Table singleLine selectable basic>
          <Table.Header>
            <Table.Row className="contact-header">
              <Table.HeaderCell>{messages.paymentId}</Table.HeaderCell>
              <Table.HeaderCell>{messages.campaignId}</Table.HeaderCell>
              <Table.HeaderCell>{messages.date}</Table.HeaderCell>
              <Table.HeaderCell>{messages.amount}</Table.HeaderCell>
              <Table.HeaderCell>{messages.actual_amount}</Table.HeaderCell>
              <Table.HeaderCell>{messages.reference}</Table.HeaderCell>
              <Table.HeaderCell>{messages.paymentMethod}</Table.HeaderCell>
              <Table.HeaderCell>{messages.payee}</Table.HeaderCell>
              <Table.HeaderCell>{messages.status}</Table.HeaderCell>
              <Table.HeaderCell>
                <Button basic icon onClick={this.handleExportToCSV}>{messages.exportToCSV} <Icon name='download' /></Button>
              </Table.HeaderCell>
            </Table.Row>
          </Table.Header>
          <Table.Body>
            {data.map(item => (
              <Table.Row key={item._id}>
                <Table.Cell>
                  <Link to={`/finance-detail/${item._id}`}>
                    {_.padStart(item.payment_id, 5, 0)}
                  </Link>
                </Table.Cell>
                <Table.Cell>
                  {item.campaign_code}&nbsp;
                  {
                    !this.state.isEdit &&
                    <Icon name='edit' color='blue' onClick={() => this.setState({ isEdit: true, selectedPayment: item.payment_id })} />
                  }
                  {
                    this.state.isEdit && this.state.selectedPayment === item.payment_id &&
                    <div className={classes.editInput}>
                      <input
                        type="text"
                        placeholder={messages.campaignId}
                        name='campaign_code'
                        onChange={this.handleChange}
                      />
                      <Icon name='check' color='blue' onClick={() => this.handleSaveInfo(item)} />
                      <Icon name='close' color='blue' onClick={() => this.onCancel()} />
                    </div>
                  }
                </Table.Cell>
                <Table.Cell>{item.processed_date && moment(new Date(item.processed_date)).format('D MMM YYYY')}</Table.Cell>
                <Table.Cell>${item.amount}</Table.Cell>
                <Table.Cell>${item.actual_amount || item.amount}</Table.Cell>
                <Table.Cell>{item.reference ? _.padStart(item.reference, 5, 0) : '-'}</Table.Cell>
                <Table.Cell>{messages[item.payment_method]}</Table.Cell>
                <Table.Cell>
                  {
                    item.linked_profile ?
                      <a target="_blank" rel="noopener noreferrer"
                        href={`/contact-detail/${item.linked_profile._id}/overview`}>
                        {Utils.combineName(item.linked_profile, messages)}
                      </a> :
                      Utils.combinePersonName(item.payee)
                  }
                </Table.Cell>
                <Table.Cell>
                  {
                    item.status === 'failed' ?
                    <div className='failed-status'>{messages[item.status]}</div> :
                    messages[item.status]
                  }
                </Table.Cell>
              </Table.Row>
            ))}
          </Table.Body>
        </Table>
        {
          data.length > 0 && totalPage > 1 &&
          <Pagination
            activePage={activePage}
            totalPages={totalPage}
            onPageChange={this.handlePaginationChange}
          />
        }
      </div>
    );
  }
}

MembershipPayment.propTypes = {
  payments: PropTypes.shape({}).isRequired,
};

MembershipPayment.contextType = AppContext;

export default injectsheet(stylesheet)(MembershipPayment);
