import React from 'react';
import PropTypes from 'prop-types';
import isequal from "lodash.isequal";
import { Button, Form, Modal } from 'semantic-ui-react';
import injectSheet from "react-jss";
import { ModalStyleSheet } from "../../../../../../Common/GlobalStyle";
import AppContext from "../../../../../../Common/Constants/AppContext";

class CriteriaNameModal extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      criteriaInfo: {
        ...props.criteriaInfo,
      },
    };
    this.handleChange = this.handleChange.bind(this);
    this.handleSubmit = this.handleSubmit.bind(this);
  }

  handleChange({ target: { name, value } }) {
    this.setState({
      criteriaInfo: {
        ...this.state.criteriaInfo,
        [name]: value,
      }
    })
  }

  handleSubmit() {
    if (!this.state.isHitSave) {
      this.setState({
        isHitSave: true,
      });
    }
    if (!this.state.criteriaInfo.name) {
      return;
    }
    const { onSave } = this.props;
    onSave(this.state.criteriaInfo);
  }

  render() {
    const { classes, isOpen, onClose } = this.props;
    const { intl: { messages } } = this.context;
    const { criteriaInfo } = this.state;
    return (
      <Modal
        open={isOpen}
        onClose={onClose}
        size="tiny"
        closeOnDimmerClick={false}
      >
        <Modal.Header className={classes.header}>
          {
            criteriaInfo._id ? messages.updateName : messages.saveAs
          }
        </Modal.Header>
        <Modal.Content>
          <Form
            onSubmit={this.handleSubmit}
          >
            <Form.Field required error={this.state.isHitSave && !criteriaInfo.name}>
              <label>Name</label>
              <Form.Input
                name='name'
                value={criteriaInfo.name}
                onChange={this.handleChange}
              />
            </Form.Field>

            <Form.Field className={classes.actionGroup}>
              <Button onClick={onClose}>
                {messages.cancel}
              </Button>
              <Button
                type='submit'
                color='green'
                disabled={isequal(this.props.criteriaInfo, criteriaInfo) && criteriaInfo._id}
              >
                {
                  criteriaInfo._id ? messages.update : messages.create
                }
              </Button>
            </Form.Field>
          </Form>
        </Modal.Content>
      </Modal>
    )
  }
}

CriteriaNameModal.propTypes = {
  isOpen: PropTypes.bool.isRequired,
  isSaveAs: PropTypes.bool.isRequired,
  onSave: PropTypes.func.isRequired,
  onClose: PropTypes.func.isRequired,
  criteriaInfo: PropTypes.shape({}).isRequired,
};

CriteriaNameModal.contextType = AppContext;

export default injectSheet(ModalStyleSheet)(CriteriaNameModal);
