import React from 'react';
import injectSheet from 'react-jss';
import uuid from 'uuid/v4';
import { Select, Button, Icon } from 'semantic-ui-react';

import stylesheet from './stylesheet';
import Segment from "../Segment/Segment";
import AppContext from "../../../../../../../Common/Constants/AppContext";

const operatorOptions = {
  and: 'and',
  or: 'or',
};

class SegmentGroup extends React.Component {

  handleChange = (e, { name, value }) => {
    const { segmentGroup, handleChange } = this.props;
    const { segmentFilter } = segmentGroup;
    handleChange({
      id: segmentGroup.id,
      operator: value,
      segmentFilter,
    });
  }

  handleAddRow = () => {
    const { segmentGroup, handleChange } = this.props;
    const { operator, segmentFilter } = segmentGroup;

    const id = uuid();
    segmentFilter[id] = {
      id,
      field: '',
      operator: '',
      value: '',
    };
    handleChange({
      id: segmentGroup.id,
      operator,
      segmentFilter,
    });
  }

  handleRemoveSegment = (id) => {
    const { segmentGroup, handleChange } = this.props;
    const { operator, segmentFilter } = segmentGroup;

    delete segmentFilter[id];
    handleChange({
      id: segmentGroup.id,
      operator,
      segmentFilter,
    });
  }


  handleFilterChange = (item) => {
    const { segmentGroup, handleChange } = this.props;
    const { segmentFilter, operator } = segmentGroup;
    segmentFilter[item.id] = item;
    handleChange({
      id: segmentGroup.id,
      operator,
      segmentFilter,
    });
  }

  render() {
    const { classes, parentOperator, index, segmentGroup: { id, operator, segmentFilter }, handleRemoveSegmentGroup, isHitSave } = this.props;
    const { intl: { messages } } = this.context;
    const matches = Object.keys(operatorOptions).map(key => ({
      key,
      text: messages[`common.advanced_search.${key}`],
      value: operatorOptions[key],
    }));

    return (
      <div className={classes.segmentGroup}>
        <div className='remove-segment-group'>
          <Icon
            name='remove'
            style={{ cursor: 'pointer' }}
            color='red'
            circular
            onClick={() => handleRemoveSegmentGroup(id)}
          />
        </div>
        <div>
          <span>{index > 0 && <span>{parentOperator}</span>} matching</span>
          <Select
            className='match-operator'
            options={matches}
            value={operator}
            onChange={this.handleChange}
          />
          <span>of the following</span>
        </div>
        {
          Object.values(segmentFilter).map((item, index) => (
            <Segment
              index={index}
              length={Object.values(segmentFilter).length}
              key={item.id}
              segment={item}
              parentOperator={operator}
              handleChange={this.handleFilterChange}
              handleRemoveSegment={this.handleRemoveSegment}
              isHitSave={isHitSave}
            />
          ))
        }
        <div>
          <Button color='blue' onClick={this.handleAddRow}>
            Add Row
          </Button>
        </div>
      </div>
    );
  }
}

SegmentGroup.propTypes = {}
SegmentGroup.contextType = AppContext
export default injectSheet(stylesheet)(SegmentGroup)

