import React from 'react'
import ReduxStatus from '../../../../Common/Constants/ReduxStatus'
import { Loader, Table, Pagination, Button, Icon } from 'semantic-ui-react'
import { Link } from 'react-router-dom'
import injectSheet from 'react-jss'
import PropTypes from 'prop-types'
import AppContext from '../../../../Common/Constants/AppContext'
import PaymentActionCreator from '../../../Actions/PaymentActionCreator'
import stylesheet from './stylesheet'
import Utils from '../../../../Common/Utils/Utils'
import AdvanceFilterSegment from './AdvanceFilterSegment/AdvanceFilterSegment'
import _ from 'lodash'
import moment from 'moment'

class PaymentSegment extends React.Component {
  constructor() {
    super();
    this.state = {
      filter: {}
    };
  }

  componentDidMount() {
    const { dispatch } = this.context;
    const { payments: { activePage, filter } } = this.props;
    dispatch(PaymentActionCreator.getPaymentsByFilterSegment(activePage, filter));
  }

  handlePaginationChange(e, { activePage }) {
    const { dispatch } = this.context;
    const { payments: { filter } } = this.props;
    dispatch(PaymentActionCreator.getPaymentsByFilterSegment(activePage, filter));
  }

  handleExportToCSV = () => {
    const { dispatch } = this.context;
    const { payments: { filter } } = this.props;
    dispatch(PaymentActionCreator.exportPaymentsToCSV(filter, true));
  }

  handleExportToCSV() {
    // const { dispatch } = this.context;
    // if (this.state.currentCheckList.length > 0) {
    //   const filter = { "_id": { "$in": this.state.currentCheckList } };
    //   dispatch(ContactActionCreator.exportContactsToCSV(filter));
    // } else {
    //   const { contacts: { filter } } = this.props;
    //   dispatch(ContactActionCreator.exportContactsToCSV(Utils.buildAdvancedQueryString(filter)));
    // }
  }

  render() {
    const { classes, payments: { data, status, activePage, totalPage, totalRecord }, criteriaList, accountList } = this.props;
    const { intl: { messages } } = this.context;
    return (
      <div className={classes.paymentAdvancedFilterSegment}>
        {
          status === ReduxStatus.loading && <Loader active />
        }
        <div className='payment-advanced-list'>
          <div className='payment-information'>
            <div className='display-payment-number'>
              Showing <b>{data.length}</b> of <b>{totalRecord}</b> payments
            </div>
            <Button basic icon onClick={this.handleExportToCSV}>{messages.exportToCSV} <Icon name='download' /></Button>
          </div>
          <Table singleLine selectable basic>
          <Table.Header>
            <Table.Row className="payment-header">
              <Table.HeaderCell>{messages.paymentId}</Table.HeaderCell>
              <Table.HeaderCell>{messages.date}</Table.HeaderCell>
              <Table.HeaderCell>{messages.amount}</Table.HeaderCell>
              <Table.HeaderCell>{messages.paymentType}</Table.HeaderCell>
              <Table.HeaderCell>{messages.reference}</Table.HeaderCell>
              <Table.HeaderCell>{messages.paymentMethod}</Table.HeaderCell>
              <Table.HeaderCell>{messages.payee}</Table.HeaderCell>
              <Table.HeaderCell>{messages.status}</Table.HeaderCell>
            </Table.Row>
          </Table.Header>
          <Table.Body>
            {data.map(item => (
              <Table.Row key={item._id}>
                <Table.Cell>
                  <Link to={`/finance-detail/${item._id}`}>
                    {_.padStart(item.payment_id, 5, 0)}
                  </Link>
                </Table.Cell>
                <Table.Cell>{item.processed_date && moment(new Date(item.processed_date)).format('D MMM YYYY')}</Table.Cell>
                <Table.Cell>${item.amount}</Table.Cell>
                <Table.Cell>{messages[item.payment_type]}</Table.Cell>
                <Table.Cell>{item.reference ? _.padStart(item.reference, 5, 0) : '-'}</Table.Cell>
                <Table.Cell>{messages[item.payment_method]}</Table.Cell>
                <Table.Cell>
                  {
                    item.linked_profile ?
                    <a target="_blank" rel="noopener noreferrer"
                       href={`/contact-detail/${item.linked_profile._id}/overview`}>
                      {Utils.combineName(item.linked_profile, messages)}
                    </a> :
                    Utils.combinePersonName(item.payee)
                  }  
                </Table.Cell>
                <Table.Cell>
                  {
                    item.status === 'failed' ?
                    <div className='failed-status'>{messages[item.status]}</div> :
                    messages[item.status]
                  }
                </Table.Cell>
              </Table.Row>
            ))}
          </Table.Body>
          </Table>
          {
            data.length > 0 && totalPage > 1 &&
            <Pagination
              activePage={activePage}
              totalPages={totalPage}
              onPageChange={this.handlePaginationChange}
            />
          }
        </div>

        <div className='advanced-filter-segment'>
          <AdvanceFilterSegment criteriaList={criteriaList} accountList={accountList} />
        </div>
      </div>
    )
  }
}

PaymentSegment.propTypes = {
  payments: PropTypes.shape({}).isRequired,
  criteriaList: PropTypes.shape({}).isRequired,
};

PaymentSegment.contextType = AppContext;

export default injectSheet(stylesheet)(PaymentSegment);
