import React from 'react';
import PropTypes from 'prop-types';
import { Button, Form, Modal } from 'semantic-ui-react';
import injectSheet from "react-jss";
import Utils from "../../../Common/Utils/Utils";
import AppContext from "../../../Common/Constants/AppContext";
import { ModalStyleSheet } from "../../../Common/GlobalStyle";
import colors from "../../../Common/Constants/color";
import CheckMark from "../../../Common/Components/Base/CheckMark";
import ToolsActionCreator from "../../../Tools/ToolsActionCreator";

const stylesheet = {
  ...ModalStyleSheet,
  content: {
    padding: '15px 0 !important',
    '& .email-item': {
      display: 'flex',
      padding: [15, 10],
      borderTop: `1px ${colors.primaryGray7} solid`,
      '&:last-child': {
        borderBottom: `1px ${colors.primaryGray7} solid`,
      },
      '& .select-email': {
        width: 60,
        cursor: 'pointer',
        display: 'flex',
        alignItems: 'center',
        '& .check-mark': {
          margin: 'auto',
        }
      },
      '& .email-item-content': {
        flexGrow: 1,
        paddingRight: 10,
        '& .email-number': {
          opacity: 0.6,
          fontSize: '0.8rem',
        }
      }
    }
  },
  actionGroup: {
    display: 'flex',
    justifyContent: 'flex-end',
    alignItems: 'center',
    paddingRight: 15,
  },
}

class EmailReceiptModal extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      alternateEmail: '',
      selectedEmailIndex: 0,
    };
    this.handleChange = this.handleChange.bind(this);
    this.handleSubmit = this.handleSubmit.bind(this);
  }

  handleChange({ target: { name, value } }) {
    const { selectedPayment: { linked_profile } } = this.props;
    if(this.state.selectedEmailIndex !== linked_profile.emails.length) {
      this.setState({
        alternateEmail: value,
        selectedEmailIndex: linked_profile.emails.length,
      })
    } else {
      this.setState({
        alternateEmail: value,
      })
    }
  }

  handleSubmit() {
    if (!this.state.isHitSave) {
      this.setState({
        isHitSave: true,
      });
    }
    const { selectedPayment: { linked_profile } } = this.props;
    if (
      linked_profile &&
      this.state.selectedEmailIndex === linked_profile.emails.length &&
      !Utils.validateEmail(this.state.alternateEmail)) {
      return;
    }
    let sendEmail = '';
    if (this.state.selectedEmailIndex === linked_profile.emails.length) {
      sendEmail = this.state.alternateEmail;
    } else {
      sendEmail = linked_profile[this.state.selectedEmailIndex];
    }
    const { dispatch } = this.context;
    const { onClose, selectedPayment: { _id } } = this.props;
    dispatch(ToolsActionCreator.sendEmailLetter({
      payment_id: _id,
      email: sendEmail,
    }));
    onClose();
  }

  render() {
    const { classes, isOpen, onClose, selectedPayment } = this.props;
    const { intl: { messages } } = this.context;
    const { linked_profile } = selectedPayment;
    return (
      <Modal
        open={isOpen}
        onClose={onClose}
        size="tiny"
      >
        <Modal.Header className={classes.header}>
          Email Letter
        </Modal.Header>
        <Modal.Content className={classes.content}>
          <Form
            onSubmit={this.handleSubmit}
          >
            {
              linked_profile && linked_profile.emails.map((item, index) => (
                <div key={item._id} className='email-item'>
                  <div
                    className='select-email'
                    onClick={() => this.setState({ selectedEmailIndex: index })}
                  >
                    {
                      index === this.state.selectedEmailIndex &&
                      <CheckMark className='check-mark' />
                    }
                  </div>
                  <div className='email-item-content'>
                    <div className='email-number'>
                      {
                        item.primary ? messages.email1Primary : (messages.email + (index + 1))
                      }
                    </div>
                    <div>{item.email}</div>
                  </div>
                </div>
              ))
            }
            <div key="alternative-email" className='email-item'>
              <div
                className='select-email'
                onClick={() => this.setState({ selectedEmailIndex: linked_profile.emails.length })}
              >
                {
                  linked_profile && this.state.selectedEmailIndex === linked_profile.emails.length &&
                  <CheckMark className='check-mark' />
                }
              </div>
              <div className='email-item-content'>
                <Form.Input
                  name='name'
                  fluid
                  placeholder="Alternate Email"
                  value={this.state.alternateEmail}
                  onChange={this.handleChange}
                  required={
                    linked_profile &&
                    this.state.selectedEmailIndex === linked_profile.emails.length
                  }
                  error={
                    this.state.isHitSave &&
                    linked_profile &&
                    this.state.selectedEmailIndex === linked_profile.emails.length &&
                    !Utils.validateEmail(this.state.alternateEmail)
                  }
                />
              </div>
            </div>

            <Form.Field className={classes.actionGroup}>
              <Button onClick={onClose}>
                {messages.cancel}
              </Button>
              <Button
                type='submit'
                color='green'
              >
                Send
              </Button>
            </Form.Field>
          </Form>
        </Modal.Content>
      </Modal>
    )
  }
}

EmailReceiptModal.propTypes = {
  isOpen: PropTypes.bool.isRequired,
  onClose: PropTypes.func.isRequired,
  selectedPayment: PropTypes.shape({}).isRequired,
};

EmailReceiptModal.contextType = AppContext;

export default injectSheet(stylesheet)(EmailReceiptModal);