import React from 'react'
import injectSheet from 'react-jss'
import { Loader, Icon } from 'semantic-ui-react'
import AppContext from "../../../Common/Constants/AppContext"
import Utils from "../../../Common/Utils/Utils"
import ReduxStatus from "../../../Common/Constants/ReduxStatus"
import moment from "moment"

import stylesheet from './stylesheet'
import EmailReceiptModal from "./EmailReceiptModal"
import ToolsActionCreator from "../../../Tools/ToolsActionCreator"

class FinanceDetail extends React.Component {
  state = {
    toggleEmailReceipt: false,
  };

  handleDownloadLetter = () => {
    const { dispatch } = this.context;
    const { selectedPaymentDetail: { selectedPayment } } = this.props;
    if(selectedPayment.payment_type === 'membership') {
      dispatch(ToolsActionCreator.downloadLetter(selectedPayment._id, 'membership_confirmation_letter'));
    } else {
      dispatch(ToolsActionCreator.downloadLetter(selectedPayment._id, 'donation_thank_you_letter'));
    }
  };

  render() {
    const { intl: { messages } } = this.context;
    const { classes, selectedPaymentDetail } = this.props;
    const { selectedPayment, status } = selectedPaymentDetail;
    const { linked_profile } = selectedPayment;
    return (
      <div className={classes.financeDetailPage}>
        {
          this.state.toggleEmailReceipt &&
          <EmailReceiptModal
            onClose={() => this.setState({ toggleEmailReceipt: false })}
            isOpen={this.state.toggleEmailReceipt}
            selectedPayment={selectedPayment}
          />
        }
        
        <div className='payment-receipt' id='div-contents'>
        <div className='receipt-action no-print'>
          <div className='btn' onClick={this.handleDownloadLetter}>
            <Icon name='download' />
            Download Letter
          </div>
          {/* <div className='btn' onClick={() => this.setState({ toggleEmailReceipt: true })}>
            <Icon name='mail' />
            Email Letter
          </div> */}
        </div>
          <div className='receipt-header'>PAYMENT DETAILS</div>
          <div className='receipt-content'>
            {
              status === ReduxStatus.loading && <Loader active />
            }
            <div className='field-content extra-section'>
              <div className='field-label'>{messages.payee}</div>
              <div className='field-value'>
                {
                  linked_profile ?
                  <a target="_blank" rel="noopener noreferrer"
                     href={`/contact-detail/${linked_profile._id}/overview`}>
                    {Utils.combineName(linked_profile, messages)}
                  </a> :
                  Utils.combinePersonName(selectedPayment.payee)
                }
              </div>
            </div>
            {
              linked_profile && linked_profile.type === 'organisation' &&
              <div className='field-content'>
                <div className='field-label'>{messages.abn}</div>
                <div className='field-value'>
                  linked_profile.abn
                </div>
              </div>
            }
            <div className='field-content'>
              <div className='field-label'>{messages.address}</div>
              {
                linked_profile && <div className='field-value'>
                  {
                    linked_profile.type === 'organisation' ?
                      (Utils.combineAddress(linked_profile.postal_address) || '-') :
                      (Utils.combineAddress(linked_profile.home_address) || '-')
                  }
                </div>
              }
            </div>
            <div className='field-content extra-section'>
              <div className='field-label'>{messages.paymentType}</div>
              <div className='field-value'>{messages[selectedPayment.payment_type]}</div>
            </div>
            <div className='field-content'>
              <div className='field-label'>{messages.status}</div>
              <div className='field-value'>{messages[selectedPayment.status]}</div>
            </div>
            <div className='field-content'>
              <div className='field-label'>{messages.paymentId}</div>
              <div className='field-value'>{selectedPayment.payment_id}</div>
            </div>
            <div className='field-content'>
              <div className='field-label'>{messages.nationBuilderId}</div>
              <div className='field-value'>{selectedPayment.nb_donation_id || '-'}</div>
            </div>
            <div className='field-content'>
              <div className='field-label'>{messages.reference}</div>
              <div className='field-value'>{selectedPayment.reference || '-'}</div>
            </div>
            <div className='field-content'>
              <div className='field-label'>{messages.dateOfPayment}</div>
              <div className='field-value'>
                {selectedPayment.processed_date && moment(new Date(selectedPayment.processed_date)).format('D MMM YYYY')}
              </div>
            </div>
            <div className='field-content'>
              <div className='field-label'>{messages.paymentMethod}</div>
              <div className='field-value'>{messages[selectedPayment.payment_method]}</div>
            </div>
            <div className='divided dashed' />
            <div className='field-content'>
              <div className='field-label'>Amount</div>
              <div className='field-value'>${selectedPayment.amount}</div>
            </div>
            <div className='field-content'>
              <div className='field-label'>Actual Amount</div>
              <div className='field-value'>${selectedPayment.actual_amount || selectedPayment.amount}</div>
            </div>
            <div className='field-content extra-section'>
              <div className='field-label'>{messages.subTotal}</div>
              <div className='field-value'>${selectedPayment.amount && selectedPayment.payment_type === 'membership' ? parseFloat((selectedPayment.actual_amount || selectedPayment.amount) - ((selectedPayment.actual_amount || selectedPayment.amount) / 11)).toFixed(2) : 0}</div>
            </div>
            <div className='field-content'>
              <div className='field-label'>{messages.gst}</div>
              <div className='field-value'>${selectedPayment.amount && selectedPayment.payment_type === 'membership' ? parseFloat((selectedPayment.actual_amount || selectedPayment.amount) / 11).toFixed(2): 0}</div>
            </div>
            <div className='field-content'>
              <div className='field-label'>{messages.total}</div>
              <div className='field-value'>${selectedPayment.actual_amount || selectedPayment.amount}</div>
            </div>
            <div className='divided' />
          </div>
        </div>
      
      </div>
    );
  }
}

FinanceDetail.contextType = AppContext;

export default injectSheet(stylesheet)(FinanceDetail);
