import React from "react";
import { connect } from "react-redux";
import { Route } from 'react-router-dom';

import PageTitle from '../Common/Components/PageTitle';
import PageNavigationMenu from '../Common/Components/PageNavigationMenu';
import AppContext from "../Common/Constants/AppContext";
import AllPayment from "./Components/Finance/AllPayment";
import DonationPayment from "./Components/Finance/DonationPayment";
import MembershipPayment from "./Components/Finance/MembershipPayment";
import Campaigns from "./Components/Finance/Campaigns";
import PaymentSegment from "./Components/Finance/PaymentSegment/PaymentSegment"

class Finance extends React.Component {

  render() {
    const { intl: { messages } } = this.context;
    const {
      match,
      history,
      payments: { paymentList, donationPaymentList, membershipPaymentList, paymentFilterSegmentList, paymentCriteria},
      account: { accountList }
    } = this.props;
    const menuItems = [
      {
        name: 'all',
        text: messages.allPayment,
        url: '/finance/allPayments',
      },
      {
        name: 'donations',
        text: messages.donations,
        url: '/finance/donations',
      },
      {
        name: 'memberships',
        text: messages.memberships,
        url: '/finance/memberships',
      },
      {
        name: 'campaigns',
        text: messages.campaigns,
        url: '/finance/campaigns'
      },
      {
        name: 'segments',
        text: messages.segments,
        url: '/finance/advanced-filter',
      }
    ];

    return (
      <div>
        <PageTitle title={messages.finance} />
        <PageNavigationMenu
          tabs={menuItems}
        />
        <Route exact path={`${match.path}`} render={() => <AllPayment finances={paymentList} history={history} />} />
        <Route path={`${match.path}/allPayments`} render={() => <AllPayment payments={paymentList} history={history} />} />
        <Route path={`${match.path}/donations`} render={() => <DonationPayment payments={donationPaymentList} history={history} />} />
        <Route path={`${match.path}/memberships`} render={() => <MembershipPayment payments={membershipPaymentList} history={history} />} />
        <Route path={`${match.path}/campaigns`} render={() => <Campaigns payments={paymentList} history={history} />} />
        <Route path={`${match.path}/advanced-filter`}
          render={() => (
            <PaymentSegment
              payments={paymentFilterSegmentList}
              history={history}
              criteriaList={paymentCriteria}
              accountList={accountList}
            />
          )} />
      </div>
    );
  }
}

const mapStateToProps = ({ payments, account }) => ({
  payments,
  account
});

Finance.contextType = AppContext;

export default connect(mapStateToProps)(Finance);
