import Enum from '../Common/Constants/Enum'

const buildSearchAllPaymentQuery = (filter) => {
  const newFilter = {};
  if(filter.payment_type) {
    newFilter.payment_type = filter.payment_type;
  }
  if(filter.payment_method) {
    newFilter.payment_method = filter.payment_method;
  }
  if(filter.status) {
    newFilter.status = filter.status;
  }
  if(filter.state) {
    newFilter['payee.address.state'] = filter.state;
  }
  // if(filter.partyBranch) {
  //   if(filter.partyBranch === 'NSW') {
  //     newFilter['party_branch'] = {$in:['NSW', 'FEDERAL']}
  //   } else if(filter.partyBranch === 'FEDERAL') {
  //     newFilter['payment_type'] = {$ne: 'membership'}
  //     newFilter['party_branch'] = 'FEDERAL'
  //   } else {
  //     newFilter.party_branch = filter.partyBranch
  //   }
  // }
  if(filter.searchText) {
    newFilter["$text"] = { "$search": filter.searchText };
  }
  if (filter.selectedVotingDistrict && filter.selectedVotingDistrict._id) {
    newFilter.voting_district = filter.selectedVotingDistrict._id;
  }
  if(filter.receivedAfter && !filter.receivedBefore) {
    newFilter.processed_date = { "$gte": filter.receivedAfter }
  }
  if(filter.receivedBefore && !filter.receivedAfter) {
    newFilter.processed_date = { "$lte": filter.receivedBefore }
  }
  if(filter.receivedAfter && filter.receivedBefore) {
    newFilter["$and"] = [{"processed_date": { "$lte": filter.receivedBefore }}, {"processed_date":{ "$gte": filter.receivedAfter }}]
  }
  if(filter.linked_profile) {
    newFilter.linked_profile = filter.linked_profile;
  }
  if(filter.campaign_code){
    newFilter.campaign_code = filter.campaign_code;
  }
  return newFilter;
}

const buildSearchDonationPaymentQuery = (filter) => {
  const newFilter = {};

  if(filter.payment_type) {
    newFilter.payment_type = filter.payment_type;
  } else {
    newFilter.payment_type = { "$in": Object.values(Enum.DonationTypeEnum), }
  }
  // if(filter.partyBranch) {
  //   newFilter.party_branch = filter.partyBranch;
  // }
  if(filter.payment_method) {
    newFilter.payment_method = filter.payment_method;
  }
  if(filter.status) {
    newFilter.status = filter.status;
  }
  if(filter.searchText) {
    newFilter["$text"] = { "$search": filter.searchText };
  }
  if (filter.selectedVotingDistrict && filter.selectedVotingDistrict._id) {
    newFilter.voting_district = filter.selectedVotingDistrict._id;
  }
  if(filter.receivedAfter && filter.receivedBefore) {
    newFilter["$and"] = [{"processed_date": { "$lte": filter.receivedBefore }}, {"processed_date":{ "$gte": filter.receivedAfter }}]
  }
  return newFilter;
}

const buildSearchMembershipPaymentQuery = (filter) => {
  const newFilter = {};
  newFilter.payment_type = Enum.PaymentTypeEnum.membership;
  if(filter.payment_method) {
    newFilter.payment_method = filter.payment_method;
  }
  // if(filter.partyBranch) {
  //   newFilter.party_branch = filter.partyBranch;
  // }
  if(filter.status) {
    newFilter.status = filter.status;
  }
  if(filter.searchText) {
    newFilter["$text"] = { "$search": filter.searchText };
  }
  if (filter.selectedVotingDistrict && filter.selectedVotingDistrict._id) {
    newFilter.voting_district = filter.selectedVotingDistrict._id;
  }
  if(filter.receivedAfter && filter.receivedBefore) {
    newFilter["$and"] = [{"processed_date": { "$lte": filter.receivedBefore }}, {"processed_date":{ "$gte": filter.receivedAfter }}]
  }
  return newFilter;
}

export default {
  buildSearchPaymentQuery: buildSearchAllPaymentQuery,
  buildSearchDonationPaymentQuery: buildSearchDonationPaymentQuery,
  buildSearchMembershipPaymentQuery: buildSearchMembershipPaymentQuery,
}
