import ReduxStatus from "../../Common/Constants/ReduxStatus";
import {
  GET_DONATION_PAYMENTS, GET_DONATION_PAYMENTS_FAILED, GET_DONATION_PAYMENTS_SUCCESS,
  GET_PAYMENTS, GET_PAYMENTS_FAILED, GET_PAYMENTS_SUCCESS,
  GET_MEMBERSHIP_PAYMENTS, GET_MEMBERSHIP_PAYMENTS_SUCCESS, GET_MEMBERSHIP_PAYMENTS_FAILED,
  CLEAR_SELECTED_PAYMENT,
  GET_PAYMENT_BY_ID, GET_PAYMENT_BY_ID_FAILED, GET_PAYMENT_BY_ID_SUCCESS,
  GET_PAYMENTS_FILTER_SEGMENT, GET_PAYMENTS_FILTER_SEGMENT_SUCCESS, GET_PAYMENTS_FILTER_SEGMENT_FAILURE,
  GET_PAYMENT_CRITERIA, GET_PAYMENT_CRITERIA_SUCCESS, GET_PAYMENT_CRITERIA_FAILURE
} from "../../Finance/Actions/PaymentActionCreator";

const initialState = {
  paymentList: {
    status: ReduxStatus.empty,
    activePage: 1,
    totalPage: 1,
    totalRecord: 0,
    data: [],
    message: "",
    filter: {},
  },

  donationPaymentList: {
    status: ReduxStatus.empty,
    activePage: 1,
    totalPage: 1,
    totalRecord: 0,
    data: [],
    message: "",
    filter: {},
  },

  membershipPaymentList: {
    status: ReduxStatus.empty,
    activePage: 1,
    totalPage: 1,
    totalRecord: 0,
    data: [],
    message: "",
    filter: {},
  },

  selectedPaymentDetail: {
    status: ReduxStatus.empty,
    message: "",
    selectedPayment: {},
  },

  paymentFilterSegmentList: {
    status: ReduxStatus.empty,
    activePage: 1,
    totalPage: 1,
    totalRecord: 0,
    data: [],
    message: "",
    filter: {},
  },

  paymentCriteria: {
    status: ReduxStatus.empty,
    activePage: 1,
    totalPage: 1,
    totalRecord: 0,
    data: [],
    message: "",
    filter: {},
  },
};

const actionsMap = {
  // Async action
  [GET_PAYMENTS]: state => {
    return {
      ...state,
      paymentList: {
        ...state.paymentList,
        status: ReduxStatus.loading,
        message: "",
      }
    };
  },
  [GET_PAYMENTS_SUCCESS]: (state, { activePage, totalPage, totalRecord, data, filter }) => {
    return {
      ...state,
      paymentList: {
        ...state.paymentList,
        activePage,
        totalPage,
        totalRecord,
        data,
        status: ReduxStatus.loaded,
        message: "",
        filter,
      }
    };
  },
  [GET_PAYMENTS_FAILED]: (state, payload) => {
    return {
      ...state,
      paymentList: {
        ...state.paymentList,
        status: ReduxStatus.loadFailed,
        message: payload.message,
      }
    };
  },

  [GET_DONATION_PAYMENTS]: state => {
    return {
      ...state,
      donationPaymentList: {
        ...state.donationPaymentList,
        status: ReduxStatus.loading,
        message: "",
      }
    };
  },
  [GET_DONATION_PAYMENTS_SUCCESS]: (state, { activePage, totalPage, totalRecord, data, filter }) => {
    return {
      ...state,
      donationPaymentList: {
        ...state.donationPaymentList,
        activePage,
        totalPage,
        totalRecord,
        data,
        status: ReduxStatus.loaded,
        message: "",
        filter,
      }
    };
  },
  [GET_DONATION_PAYMENTS_FAILED]: (state, payload) => {
    return {
      ...state,
      donationPaymentList: {
        ...state.donationPaymentList,
        status: ReduxStatus.loadFailed,
        message: payload.message,
      }
    };
  },

  [GET_MEMBERSHIP_PAYMENTS]: state => {
    return {
      ...state,
      membershipPaymentList: {
        ...state.membershipPaymentList,
        status: ReduxStatus.loading,
        message: "",
      }
    };
  },
  [GET_MEMBERSHIP_PAYMENTS_SUCCESS]: (state, { activePage, totalPage, totalRecord, data, filter }) => {
    return {
      ...state,
      membershipPaymentList: {
        ...state.membershipPaymentList,
        activePage,
        totalPage,
        totalRecord,
        data,
        status: ReduxStatus.loaded,
        message: "",
        filter,
      }
    };
  },
  [GET_MEMBERSHIP_PAYMENTS_FAILED]: (state, payload) => {
    return {
      ...state,
      membershipPaymentList: {
        ...state.membershipPaymentList,
        status: ReduxStatus.loadFailed,
        message: payload.message,
      }
    };
  },

  [GET_PAYMENT_BY_ID]: (state) => {
    return {
      ...state,
      selectedPaymentDetail: {
        selectedPayment: {},
        status: ReduxStatus.loading,
        message: "",
      }
    };
  },
  [GET_PAYMENT_BY_ID_SUCCESS]: (state, payload) => {
    return {
      ...state,
      selectedPaymentDetail: {
        selectedPayment: payload,
        status: ReduxStatus.loaded,
        message: "",
      }
    };
  },
  [GET_PAYMENT_BY_ID_FAILED]: (state, payload) => {
    return {
      ...state,
      selectedPaymentDetail: {
        ...state.selectedPaymentDetail,
        selectedPayment: {},
        status: ReduxStatus.loadFailed,
        message: payload.message,
      }
    };
  },

  [CLEAR_SELECTED_PAYMENT]: (state) => {
    return {
      ...state,
      selectedPaymentDetail: {
        selectedPayment: {},
        status: ReduxStatus.loading,
        message: "",
      },
    };
  },

  [GET_PAYMENTS_FILTER_SEGMENT]: state => {
    return {
      ...state,
      paymentFilterSegmentList: {
        ...state.paymentFilterSegmentList,
        status: ReduxStatus.loading,
        message: "",
      }
    };
  },
  [GET_PAYMENTS_FILTER_SEGMENT_SUCCESS]: (state, { activePage, totalPage, totalRecord, data, filter }) => {
    return {
      ...state,
      paymentFilterSegmentList: {
        ...state.paymentFilterSegmentList,
        activePage,
        totalPage,
        totalRecord,
        data,
        status: ReduxStatus.loaded,
        message: "",
        filter,
      }
    };
  },
  [GET_PAYMENTS_FILTER_SEGMENT_FAILURE]: (state, payload) => {
    return {
      ...state,
      paymentFilterSegmentList: {
        ...state.paymentFilterSegmentList,
        status: ReduxStatus.loadFailed,
        message: payload.message,
      }
    };
  },

  [GET_PAYMENT_CRITERIA]: state => {
    return {
      ...state,
      paymentCriteria: {
        ...state.paymentCriteria,
        status: ReduxStatus.loading,
        message: "",
      }
    };
  },
  [GET_PAYMENT_CRITERIA_SUCCESS]: (state, { activePage, totalPage, totalRecord, data, filter }) => {
    return {
      ...state,
      paymentCriteria: {
        ...state.paymentCriteria,
        activePage,
        totalPage,
        totalRecord,
        data,
        status: ReduxStatus.loaded,
        message: "",
        filter,
      }
    };
  },
  [GET_PAYMENT_CRITERIA_FAILURE]: (state, payload) => {
    return {
      ...state,
      paymentCriteria: {
        ...state.paymentCriteria,
        status: ReduxStatus.loadFailed,
        message: payload.message,
      }
    };
  },
}

export default function reducer(state = initialState, action = {}) {
  const fn = actionsMap[action.type];
  return fn ? fn(state, action.payload) : state;
}