import { put, call, select, takeLatest, takeEvery } from "redux-saga/effects";
import { get, post, patch, deleteClient } from '../../Common/Utils/AxiosClient';
import Enum from '../../Common/Constants/Enum';
import Utils from "../../Common/Utils/Utils";
import {
  GET_PAYMENTS, GET_PAYMENTS_SUCCESS, GET_PAYMENTS_FAILED,
  GET_DONATION_PAYMENTS, GET_DONATION_PAYMENTS_SUCCESS, GET_DONATION_PAYMENTS_FAILED,
  GET_MEMBERSHIP_PAYMENTS, GET_MEMBERSHIP_PAYMENTS_SUCCESS, GET_MEMBERSHIP_PAYMENTS_FAILED,
  GET_PAYMENT_BY_ID, GET_PAYMENT_BY_ID_FAILED, GET_PAYMENT_BY_ID_SUCCESS,
  GET_PAYMENTS_FILTER_SEGMENT, GET_PAYMENTS_FILTER_SEGMENT_SUCCESS, GET_PAYMENTS_FILTER_SEGMENT_FAILURE,
  GET_PAYMENT_CRITERIA, GET_PAYMENT_CRITERIA_SUCCESS, GET_PAYMENT_CRITERIA_FAILURE,
  CREATE_PAYMENT_CRITERIA, DELETE_PAYMENT_CRITERIA, SAVE_PAYMENT_CRITERIA,
  EXPORT_PAYMENTS, SAVE_PAYMENT
} from "../Actions/PaymentActionCreator";
import { toast } from "react-toastify";
import FinanceUtils from "../FinanceUtils";

function* watchGetPayments({ payload: { activePage, filter } }) {
  const { messages } = yield select(state => state.intl);
  try {
    const newFilter = FinanceUtils.buildSearchPaymentQuery(filter);
    const skip = (activePage - 1) * Enum.PaymentPerPage;
    const params = {
      filter: newFilter,
      limit: Enum.PaymentPerPage,
      skip,
      populate: { "path": "linked_profile" },
      sort: { "processed_date": -1}
    };

    const url = '/payments';
    const res = yield call(get, url, params);
    const totalPage = Utils.getTotalPage(res.data.metadata);
    yield put({
      type: GET_PAYMENTS_SUCCESS,
      payload: {
        activePage,
        filter: filter,
        totalPage,
        totalRecord: res.data.metadata.total,
        data: res.data.data,
      }
    });
  } catch (e) {
    console.log('e', e.message)
    yield put({
      type: GET_PAYMENTS_FAILED,
      payload: {
        ...e
      },
    });
    toast.error(messages['payment.list.get.error']);
  }
}

function* watchGetDonationPayments({ payload: { activePage, filter } }) {
  const { messages } = yield select(state => state.intl);
  try {
    const newFilter = FinanceUtils.buildSearchDonationPaymentQuery(filter);
    const skip = (activePage - 1) * Enum.PaymentPerPage;
    const params = {
      filter: newFilter,
      limit: Enum.PaymentPerPage,
      skip,
      populate: { "path": "linked_profile" }
    };

    const url = '/payments';
    const res = yield call(get, url, params);
    const totalPage = Utils.getTotalPage(res.data.metadata);
    yield put({
      type: GET_DONATION_PAYMENTS_SUCCESS,
      payload: {
        activePage,
        filter: filter,
        totalPage,
        totalRecord: res.data.metadata.total,
        data: res.data.data,
      }
    });
  } catch (e) {
    yield put({
      type: GET_DONATION_PAYMENTS_FAILED,
      payload: {
        ...e
      },
    });
    toast.error(messages['payment.list.get.error']);
  }
}

function* watchGetMembershipPayments({ payload: { activePage, filter } }) {
  const { messages } = yield select(state => state.intl);
  try {
    const newFilter = FinanceUtils.buildSearchMembershipPaymentQuery(filter);
    const skip = (activePage - 1) * Enum.PaymentPerPage;
    const params = {
      filter: newFilter,
      limit: Enum.PaymentPerPage,
      skip,
      populate: { "path": "linked_profile" }
    };

    const url = '/payments';
    const res = yield call(get, url, params);
    const totalPage = Utils.getTotalPage(res.data.metadata);
    yield put({
      type: GET_MEMBERSHIP_PAYMENTS_SUCCESS,
      payload: {
        activePage,
        filter: filter,
        totalPage,
        totalRecord: res.data.metadata.total,
        data: res.data.data,
      }
    });
  } catch (e) {
    yield put({
      type: GET_MEMBERSHIP_PAYMENTS_FAILED,
      payload: {
        ...e
      },
    });
    toast.error(messages['payment.list.get.error']);
  }
}

function* watchGetPayment({ payload: { id } }) {
  const { messages } = yield select(state => state.intl);
  try {
    const url = `/payments/${id}`;
    const params = {
      populate: { "path": "linked_profile" }
    };
    const res = yield call(get, url, params);
    yield put({ type: GET_PAYMENT_BY_ID_SUCCESS, payload: res.data.data });
  } catch (e) {
    yield put({
      type: GET_PAYMENT_BY_ID_FAILED,
      payload: {
        ...e
      },
    });
    toast.error(messages['payment.list.get.error']);
  }
}

function* watchSavePayment({ payload: { id, campaign_code } }) {
  try {
    const url = `/payments/${id}`
    yield call(patch, url, { campaign_code });
    toast.success(`Update campaignID successful`);
  } catch (e) {
  toast.error(`Update campaignID failed`);
  }
}

function* watchGetPaymentsFilterSegment({ payload: { activePage, filter } }) {
  const { messages } = yield select(state => state.intl);
  try {
    const newFilter = Utils.buildAdvancedQueryString(filter);
    const skip = (activePage - 1) * Enum.PaymentPerPage;
    const params = {
      filter: newFilter,
      limit: Enum.PaymentPerPage,
      skip,
      populate: { path: "linked_profile" },
      sort: { processed_date: -1}
    };

    const url = '/payments';
    const res = yield call(get, url, params);
    const totalPage = Utils.getTotalPage(res.data.metadata);
    yield put({
      type: GET_PAYMENTS_FILTER_SEGMENT_SUCCESS,
      payload: {
        activePage,
        filter: filter,
        totalPage,
        totalRecord: res.data.metadata.total,
        data: res.data.data,
      }
    });
  } catch (e) {
    yield put({
      type: GET_PAYMENTS_FILTER_SEGMENT_FAILURE,
      payload: {
        ...e
      },
    });
    toast.error(messages['payment.list.get.error']);
  }
}

function* watchGetPaymentCriteria({ payload: { activePage, accountId, filter } }) {
  try {
    const newFilter = Utils.cleanObject(filter);
    const skip = (activePage - 1) * Enum.SegmentFilterPerPage;
    const url = `/accounts/${accountId}/search-criteria`;
    const params = {
      filter: {...newFilter, ...{ type: 'payment' } },
      limit: Enum.SegmentFilterPerPage,
      skip,
      populate: { "path": "author" },
      sort: { "name": 1 },
    };
    const res = yield call(get, url, params);
    const totalPage = Utils.getTotalPage(res.data.metadata);
    const data = res.data.data.map(item => ({
      ...item,
      criteria: JSON.parse(item.criteria),
    }));
    yield put({
      type: GET_PAYMENT_CRITERIA_SUCCESS,
      payload: {
        activePage,
        filter: filter,
        totalPage,
        data,
      }
    });
  } catch (e) {
    yield put({
      type: GET_PAYMENT_CRITERIA_FAILURE,
      payload: {
        ...e
      },
    });
  }
}

function* watchCreatePaymentCriteria({ payload: { accountId, criteria, opts } }) {
  try {
    const url = `/accounts/${accountId}/search-criteria`;
    const res = yield call(post, url, {...criteria, ...{ type: 'payment' } });
    const { callback } = opts;
    if (callback) {
      callback(res.data.data);
    }
    const criteriaList = yield select(state => state.criteria.criteriaList);
    yield put({
      type: GET_PAYMENT_CRITERIA,
      payload: {
        accountId,
        activePage: criteriaList.activePage,
        filter: criteriaList.filter,
      }
    });
    toast.success(`Create criteria successful`);
  } catch (e) {
    const { response: { data: { error } } } = e;
    toast.error(error.message);
  }
}

function* watchSavePaymentCriteria({ payload: { accountId, criteria, opts } }) {
  try {
    const url = `/accounts/${accountId}/search-criteria/${criteria._id}`;
    yield call(patch, url, criteria);
    const { callback } = opts;
    if (callback) {
      callback();
    }
    const criteriaList = yield select(state => state.criteria.criteriaList);
    yield put({
      type: GET_PAYMENT_CRITERIA,
      payload: {
        accountId,
        activePage: criteriaList.activePage,
        filter: criteriaList.filter,
      }
    });
    toast.success(`Save criteria successful`);
  } catch (e) {
    const { response: { data: { error } } } = e;
    toast.error(error.message);
  }
}

function* watchDeletePaymentCriteria({ payload: { accountId, id } }) {
  try {
    const url = `/accounts/${accountId}/search-criteria/${id}`;
    yield call(deleteClient, url);
    const criteriaList = yield select(state => state.criteria.criteriaList);
    yield put({
      type: GET_PAYMENT_CRITERIA,
      payload: {
        accountId,
        activePage: criteriaList.activePage,
        filter: criteriaList.filter,
      }
    });
    toast.success(`Delete criteria successful`);
  } catch (e) {
    const { response: { data: { error } } } = e;
    toast.error(error.message);
  }
}

function* watchExportPaymentsToCSV({ payload: { activePage, isFromSegment, filter, opts } }) {
  const { messages } = yield select(state => state.intl);
  try {
    toast.info(messages['payment.list.generate_csv.processing'], { toastId: 'generatePaymentCsvNotification', autoClose: false });
    let newFilter = {}
    if(isFromSegment) {
      newFilter = Utils.buildAdvancedQueryString(filter);
    } else {
      newFilter = FinanceUtils.buildSearchPaymentQuery(filter);
    }
    const cleanObject = Utils.cleanObject(newFilter);
    const paymentFilter = encodeURIComponent(JSON.stringify(cleanObject));
    const url = `/export-payments-to-csv?filter=${paymentFilter}`;
    const params = {
      ...opts,
    };
    const config = {
      responseType: 'blob',
    };
    const res = yield call(get, url, params, config);

    Utils.downloadFile(res.data, `payments_${(new Date()).toLocaleDateString("en-AU")}.csv`);
    toast.dismiss('generatePaymentCsvNotification');
  } catch (e) {
    toast.dismiss('generatePaymentCsvNotification');
    toast.error(messages['payment.list.generate_csv.failure']);
  }
}

function* PaymentSaga() {
  yield takeLatest(GET_PAYMENTS, watchGetPayments)
  yield takeLatest(GET_DONATION_PAYMENTS, watchGetDonationPayments)
  yield takeLatest(GET_MEMBERSHIP_PAYMENTS, watchGetMembershipPayments)
  yield takeEvery(GET_PAYMENT_BY_ID, watchGetPayment)
  yield takeEvery(SAVE_PAYMENT, watchSavePayment)
  yield takeLatest(GET_PAYMENTS_FILTER_SEGMENT, watchGetPaymentsFilterSegment)
  yield takeLatest(GET_PAYMENT_CRITERIA, watchGetPaymentCriteria)
  yield takeLatest(EXPORT_PAYMENTS, watchExportPaymentsToCSV)
  yield takeEvery(CREATE_PAYMENT_CRITERIA, watchCreatePaymentCriteria)
  yield takeEvery(SAVE_PAYMENT_CRITERIA, watchSavePaymentCriteria)
  yield takeEvery(DELETE_PAYMENT_CRITERIA, watchDeletePaymentCriteria)
}

export default PaymentSaga;
