import React, { useEffect } from "react";
import injectSheet from "react-jss";
import { connect, useDispatch } from "react-redux";
import { compose } from "redux";
import { List } from "semantic-ui-react";
import colors from "../../../Common/Constants/color";
import SettingsActionCreator from "../../SettingsActionCreator";
import FieldInput from "./FieldInput";
import ModalDelete from "./ModalDelete";

const style = {
  wrapper: {
    padding: 24,
  },
  title: {
    fontSize: 16,
    fontWeight: 600,
    color: colors.primaryBlack,
  },
  list: {
    "& .item": {
      maxWidth: 300,
      borderRadius: 4,
    },
    "& .item:hover": {
      backgroundColor: colors.primaryGray10,
      "& .archive": {
        display: "block",
      },
    },
    "& .content": {
      display: "flex",
      justifyContent: "space-between",
      padding: "8px 10px",
    },
    "& .archive": {
      cursor: "pointer",
      display: "none",
      color: colors.primaryBlue,
    },
  },
};

const messages = {
  title: "Title Options",
  archive: "Archive",
};

const FieldSettings = (props) => {
  const dispatch = useDispatch();

  const { classes, settings } = props;
  const { contactTitles = [] } = settings || {};

  useEffect(() => {
    dispatch(SettingsActionCreator.getContactTitle());
  }, []);

  const onSubmit = (title) => {
    dispatch(SettingsActionCreator.createContactTitle({ title }));
  };

  const onDelete = (id) => {
    const result = dispatch(SettingsActionCreator.deleteContactTitle(id));
    return result;
  };

  return (
    <div className={classes.wrapper}>
      <div className={classes.title}>{messages.title}</div>
      <List className={classes.list}>
        {contactTitles.map((item) => (
          <List.Item key={item._id}>
            <List.Content>
              <div>{item.title}</div>
              <ModalDelete
                onDelete={() => onDelete(item._id)}
                trigger={<div className="archive">{messages.archive}</div>}
              />
            </List.Content>
          </List.Item>
        ))}
      </List>

      <FieldInput onSubmit={onSubmit} />
    </div>
  );
};

const mapStateToProps = ({ settings }) => ({
  settings,
});

export default compose(
  injectSheet(style),
  connect(mapStateToProps)
)(FieldSettings);
