import React from 'react';
import { List, Button, Search, Checkbox } from 'semantic-ui-react';
import AppContext from '../../Common/Constants/AppContext';
import ReduxStatus from "../../Common/Constants/ReduxStatus";
import SettingsActionCreator from "../SettingsActionCreator";
import injectSheet from "react-jss";
import _ from 'lodash'

const style = {
  generalSettingPage: {
    paddingTop: 40,
    '& .item': {
      padding: '20px !important',
      display: 'flex !important',
      flexDirection: 'column',
      alignItems: 'flex-start',
      '& .header': {
        marginBottom: '10px !important',
      },
      '& .description': {
        marginBottom: '10px !important',
      }
    }
  },
  searchInput: {
    '& .prompt': {
      borderRadius: '0.3em !important'
    }
  }
};

class GeneralSettings extends React.Component {
  constructor() {
    super()
    this.state = {
      selectedAccount: '',
      searchText: null
    }
  }

  handleResetContactedForNextElection() {
    const { dispatch } = this.context;
    dispatch(SettingsActionCreator.resetContactedForNextElection());
  }

  handleSearchChange = (e, { value }) => {
    this.setState({searchText: value})
    const { dispatch } = this.context;
    dispatch(SettingsActionCreator.getAccount(1, { "$text": { "$search": value } }));
  }

  handleResultSelect = (e, { result }) => {
    this.setState({searchText: result.title})
    const { dispatch } = this.context;
    dispatch(SettingsActionCreator.setDefaultAdmin(result._id))
  }

  handleChangeAutoEmails = (e, target) => {
    console.log('target', target.checked)
    const { dispatch } = this.context
    dispatch(SettingsActionCreator.setAutoEmailsStatus(target.checked))
  }

  componentDidMount() {
    const { dispatch } = this.context;
    dispatch(SettingsActionCreator.getDefaultAdmin())
    dispatch(SettingsActionCreator.getAutoEmailsStatus())
  }

  render() {
    const { classes } = this.props;
    const {team: { data, status }, defaultAdmin, autoEmailsStatus: { autoEmailsStatus }}= this.props.settings
    const { intl: { messages } } = this.context;
    const results = data.map(c => {
      return {
        _id: c._id,
        title: c.first_name + ' ' + c.last_name
      }
    })
    console.log('autoEmailsStatus', autoEmailsStatus)
    return (
      <div className={classes.generalSettingPage}>
        <List celled="true">
          <List.Item>
            <List.Content>
              <List.Header>
                {messages.resetContactedForNextElectionTitle}
              </List.Header>
              <List.Description>
                {messages.resetContactedForNextElectionDescription}
              </List.Description>
            </List.Content>
            <Button onClick={() => this.handleResetContactedForNextElection()}>{messages.reset}</Button>
          </List.Item>
          <List.Item>
            <List.Content>
              <List.Header>
                {messages['setting.autoEmailsTitle']}
              </List.Header>
              <List.Description>
                {messages['setting.autoEmailsDescription']}
              </List.Description>
            </List.Content>
            <Checkbox toggle checked={autoEmailsStatus} onChange={this.handleChangeAutoEmails} />
          </List.Item>
          <List.Item>
            <List.Content>
              <List.Header>
                {messages['setting.membershipPointPersonTitle']}
              </List.Header>
              <List.Description>
                {messages['setting.membershipPointPersonDescription']}
              </List.Description>
            </List.Content>
            <Search
              className={classes.searchInput}
              loading={status === ReduxStatus.loading}
              onResultSelect={this.handleResultSelect}
              onSearchChange={_.debounce(this.handleSearchChange, 500, {
                leading: true,
              })}
              results={results}
              value={this.state.searchText === null ? (defaultAdmin.data ? defaultAdmin.data.first_name + ' ' + defaultAdmin.data.last_name : '') : this.state.searchText}
              {...this.props}
            />
          </List.Item>
        </List>
      </div>
    );
  }
}

GeneralSettings.contextType = AppContext;

export default injectSheet(style)(GeneralSettings);