import React from 'react';
import { Input, Loader, Pagination, Card, Icon } from 'semantic-ui-react';
import AppContext from '../../../Common/Constants/AppContext';
import SettingsActionCreator from "../../SettingsActionCreator";
import ReduxStatus from "../../../Common/Constants/ReduxStatus";
import injectSheet from "react-jss";
import colors from "../../../Common/Constants/color";
import _ from 'lodash'

const style = {
  membershipSettingPage: {
    display: 'flex',
    flexDirection: 'column',
    flexGrow: 1,
  },
  membershipSearch: {
    height: 78,
    minHeight: 78,
    width: '100%',
    padding: 20,
    display: 'flex',
    justifyContent: 'center',
    position: 'relative',
    '& .input': {
      width: 490,
      maxWidth: '100%',
    }
  },
  membershipListPage: {
    flexGrow: 1,
    minHeight: 'fit-content',
    display: 'flex',
    flexWrap: 'wrap',
    alignItems: 'flex-start',
    backgroundColor: colors.primaryGray4,
    position: 'relative',
    padding: '1em',
    '& .ui.card': {
      margin: 14,
      height: 'auto',
      padding: '1em'
    },
    '& .ui.card:first-child': {
      marginTop: 14,
    },
    '& .ui.pagination.menu': {
      marginLeft: '50%',
      transform: 'translateX(-50%)',
      maxWidth: '100%',
    },
    '& .membership-card-body': {
      '& h4': {
        fontSize: '1.1em',
        '& label': {
          color: colors.primaryRed
        }
      },
      '& .price': {
        fontSize: '1.5em',
        fontWeight: 'lighter',
        color: colors.primaryGray6
      },
      '& .period': {
        fontSize: '1em',
        fontWeight: 'lighter',
        textTransform: 'capitalize',
        color: colors.primaryGray6
      },
      '& .member': {
        paddingTop: '0.3em',
        fontSize: '1em',
      }
    }
  }
}

class MembershipSettings extends React.Component {
  constructor() {
    super();
    this.state = {
      toggleDeleteAccount: false,
      selectedDeleteAccount: null,
      toggleResetPassword: false,
      selectedResetPasswordAccount: null,
      toggleTeamMemberModal: false,
      accountInfo: {},
    };
  }

  componentDidMount() {
    const { dispatch } = this.context;
    dispatch(SettingsActionCreator.getMemberships(1));
  }

  handlePaginationChange = (e, { activePage }) => {
    const { dispatch } = this.context;
    dispatch(SettingsActionCreator.getMemberships(activePage));
  }

  onSearchFilterChange = (e, { value }) => {
    const { dispatch } = this.context
    const { membershipList: { filter } } = this.props.settings
    const newFilter = {
      ...filter,
    }
    if (value) {
      newFilter['$text'] = { "$search": value }
    } else {
      delete newFilter['$text']
    }
    dispatch(SettingsActionCreator.getMemberships(1, newFilter))
  }

  render() {
    const { classes, settings } = this.props
    const { membershipList: { data, status, activePage, totalPage } } = settings
    return (
      <div className={classes.membershipSettingPage}>
        {
          status === ReduxStatus.loading && <Loader active />
        }
        <div className={classes.membershipSearch}>
          <Input
            icon='search'
            iconPosition='left'
            placeholder='Search keywords...'
            onChange={_.debounce(this.onSearchFilterChange, 300)}
          />
        </div>
        <div className={classes.membershipListPage}>
          {
            data.map((item, idx) => (
              <Card key={idx}>
                <Card.Content className='membership-card-body'>
                  <h4>{item.state} - {item.membership_class} <label>{item.archived && ' (Archived)'}</label></h4>
                  <p><span className='price'>${parseFloat(item.price).toFixed(2)}</span> <span className='period'>({item.period})</span></p>
                  <p className='member'><Icon name='address card' size='large'/> {item.total_members} Members</p>
                </Card.Content>
              </Card>
            ))
          }
          {
            data.length > 0 && totalPage > 1 &&
            <Pagination
              activePage={activePage}
              totalPages={totalPage}
              onPageChange={this.handlePaginationChange}
            />
          }
        </div>
      </div>
    )
  }
}

MembershipSettings.contextType = AppContext

export default injectSheet(style)(MembershipSettings)
