import React from "react"
import { connect } from "react-redux"
import { Route } from 'react-router-dom'

import PageTitle from '../Common/Components/PageTitle'
import PageNavigationMenu from '../Common/Components/PageNavigationMenu'
import TeamSettings from "./Components/TeamSettings/TeamSettings"
import GeneralSettings from "./Components/GeneralSettings"
import MembershipSettings from "./Components/MembershipSettings/MembershipSettings"
import AppContext from "../Common/Constants/AppContext"
import FieldSettings from "./Components/FieldSettings/FieldSettings"

class Settings extends React.Component {
  render() {
    const { intl: { messages } } = this.context;
    const { match, settings } = this.props;
    const menuItems = [
      {
        name: 'general',
        text: messages.general,
        url: '/settings/general',
      },
      {
        name: 'memberships',
        text: messages.memberships,
        url: '/settings/memberships',
      },
      {
        name: 'team',
        text: messages.team,
        url: '/settings/team',
      },
      {
        name: 'fields',
        text: messages.fields,
        url: '/settings/contact-title',
      },
    ];

    return (
      <div>
        <PageTitle title={messages.settings} />
        <PageNavigationMenu
          tabs={menuItems}
        />
        <Route exact path={`${match.path}`} render={() => <TeamSettings team={settings.team} />} />
        <Route path={`${match.path}/general`} render={() => <GeneralSettings settings={settings} />} />
        <Route path={`${match.path}/memberships`} render={() => <MembershipSettings settings={settings} />} />
        <Route path={`${match.path}/team`} render={() => <TeamSettings team={settings.team} />} />
        <Route path={`${match.path}/contact-title`} render={() => <FieldSettings settings={settings} />} />
      </div>
    );
  }
}

const mapStateToProps = ({ settings }) => ({
  settings,
});

Settings.contextType = AppContext;

export default connect(mapStateToProps)(Settings);
