import {
  GET_ACCOUNT, GET_ACCOUNT_SUCCESS, GET_ACCOUNT_FAILED,
  CREATE_ACCOUNT, CREATE_ACCOUNT_SUCCESS, CREATE_ACCOUNT_FAILED,
  GET_DEFAULT_ACCOUNT_SUCCESS,
  GET_MEMBERSHIPS, GET_MEMBERSHIPS_SUCCESS, GET_MEMBERSHIPS_FAILURE,
  GET_AUTO_EMAILS_STATUS_SUCCESS, GET_CONTACT_TITLE_SUCCESS, CREATE_CONTACT_TITLE_SUCCESS, DELETE_CONTACT_TITLE_SUCCESS
} from "./SettingsActionCreator";
import ReduxStatus from '../Common/Constants/ReduxStatus';

const initialState = {
  team: {
    status: ReduxStatus.empty,
    activePage: 1,
    totalPage: 1,
    totalRecord: 0,
    data: [],
    message: "",
    filter: {},
  },
  defaultAdmin: {},
  membershipList: {
    status: ReduxStatus.empty,
    activePage: 1,
    totalPage: 1,
    totalRecord: 0,
    data: [],
    message: "",
    filter: {},
  },
  autoEmailsStatus: {},
  contactTitles: []
};

const actionsMap = {
  // Async action
  [GET_ACCOUNT]: state => {
    return {
      ...state,
      team: {
        ...state.team,
        status: ReduxStatus.loading,
        message: "",
      }
    };
  },
  [GET_ACCOUNT_SUCCESS]: (state, { activePage, totalPage, totalRecord, data, filter }) => {
    return {
      ...state,
      team: {
        ...state.team,
        activePage,
        totalPage,
        totalRecord,
        data,
        status: ReduxStatus.loaded,
        message: "",
        filter,
      }
    };
  },
  [GET_ACCOUNT_FAILED]: (state, payload) => {
    return {
      ...state,
      team: {
        ...state.team,
        status: ReduxStatus.loadFailed,
        message: payload.message,
      }
    };
  },

  [CREATE_ACCOUNT]: state => {
    return {
      ...state,
      team: {
        ...state.team,
        status: ReduxStatus.saving,
        message: "",
      }
    };
  },
  [CREATE_ACCOUNT_SUCCESS]: (state) => {
    return {
      ...state,
      team: {
        ...state.team,
        status: ReduxStatus.saved,
      }
    };
  },
  [CREATE_ACCOUNT_FAILED]: (state) => {
    return {
      ...state,
      team: {
        ...state.team,
        status: ReduxStatus.saveFailed,
      }
    };
  },

  [GET_DEFAULT_ACCOUNT_SUCCESS]: (state, { data }) => {
    return {
      ...state,
      defaultAdmin: {
        data
      }
    };
  },

  [GET_MEMBERSHIPS]: state => {
    return {
      ...state,
      membershipList: {
        ...state.membershipList,
        status: ReduxStatus.loading,
        message: "",
      }
    };
  },
  [GET_MEMBERSHIPS_SUCCESS]: (state, { activePage, totalPage, totalRecord, data, filter }) => {
    return {
      ...state,
      membershipList: {
        ...state.membershipList,
        activePage,
        totalPage,
        totalRecord,
        data,
        status: ReduxStatus.loaded,
        message: "",
        filter,
      }
    };
  },
  [GET_MEMBERSHIPS_FAILURE]: (state, payload) => {
    return {
      ...state,
      membershipList: {
        ...state.membershipList,
        status: ReduxStatus.loadFailed,
        message: payload.message,
      }
    };
  },

  [GET_AUTO_EMAILS_STATUS_SUCCESS]: (state, { data }) => {
    return {
      ...state,
      autoEmailsStatus: {
        autoEmailsStatus: data
      }
    };
  },
  [GET_CONTACT_TITLE_SUCCESS]: (state, { data }) => {
    return {
      ...state,
      contactTitles: data
    };
  },
  [CREATE_CONTACT_TITLE_SUCCESS]: (state, { data }) => {
    return {
      ...state,
      contactTitles: [
        ...state.contactTitles,
        data
      ]
    };
  },
  [DELETE_CONTACT_TITLE_SUCCESS]: (state, { id }) => {
    return {
      ...state,
      contactTitles: state.contactTitles.filter(item => item._id !== id)
    };
  },
};

export default function reducer(state = initialState, action = {}) {
  const fn = actionsMap[action.type];
  return fn ? fn(state, action.payload) : state;
}
