import React from 'react'
import PropTypes from 'prop-types'
import isequal from 'lodash.isequal'
import { Input } from "semantic-ui-react"
import injectSheet from "react-jss"
import Enum from "../../../../Common/Constants/Enum"
import AppContext from "../../../../Common/Constants/AppContext"
import stylesheet from './stylesheet'

const defaultFilter = {
  searchText: ''
};

class ElectoralRollFilter extends React.Component {
  constructor(props) {
    super(props);

    this.state = {
      ...defaultFilter,
    }
    this.handleChange = this.handleChange.bind(this);
    this.handleResetFilter = this.handleResetFilter.bind(this);
  }

  handleResetFilter() {
    this.setState({
      ...defaultFilter,
    });
  }

  handleChange(e, { name, value }) {
    const filter = {
      ...this.state,
      [name]: value,
    };
    if (isequal(filter, this.state)) {
      return
    }
    this.setState({
      ...filter,
    })
    this.handleSearch(filter)
  }

  handleSearch(filter) {
    const { onSearchFilterChange } = this.props;
    onSearchFilterChange(filter);
  }

  handleSelectElectorate = (selectedElectorate) => {
    const filter = {
      ...this.state,
      selectedVotingDistrict: selectedElectorate,
    };
    if (isequal(filter, this.state)) {
      return;
    }
    this.setState({
      ...filter,
    });
  };

  render() {
    const { classes, showNumber, total } = this.props;
    const { intl: { messages } } = this.context;
    const emptyFilter = {
      key: 'all',
      text: messages.all,
      value: '',
    };

    const stateList = Object.keys(Enum.StateAustralia).map(item => ({
      key: item,
      value: item,
      text: Enum.StateAustralia[item],
    }));
    stateList.unshift(emptyFilter);

    const { searchText } = this.state;
    return (
      <div className={classes.searchFilter}>
        <div className='search-container'>
          <div className='search-box'>
            <Input
              icon='search'
              iconPosition='left'
              placeholder='Search...'
              name='searchText'
              value={searchText}
              onChange={this.handleChange}
            />
          </div>
          <div className='filter-box'>
            
            {/* <div className='block-item'>
              <div className='text-title'>{messages.state}</div>
              <div className='control'>
                <Form.Select
                  options={stateList}
                  placeholder={messages.all}
                  className='state-dropdown'
                  name='selectedState'
                  value={selectedState}
                  onChange={this.handleChange}
                />
              </div>
            </div> */}

            {/* <div className='block-item'>
              <div className='text-title'>{messages.electorate}</div>
              <div className='control'>
                <ElectorateComponent
                  onSelect={this.handleSelectElectorate}
                  defaultSelected={selectedVotingDistrict}
                  allowAll
                />
              </div>
            </div> */}
            
            {/* <div className='reset-filter'>
              <span onClick={this.handleResetFilter}>Reset filters</span>
              <img src={require('../../../../Assets/reset.png')} alt='' onClick={this.handleResetFilter} />
            </div> */}
            {/* <div className='action-container'>
              <span>Import</span> <Icon name='sign in' />
            </div> */}
          </div>
        </div>
        <div className='display-contact-number'>
          Showing <b>{showNumber}</b> of <b>{total}</b> Electorate rolls
        </div>
      </div>
    )
  }
}

ElectoralRollFilter.contextType = AppContext;

ElectoralRollFilter.propTypes = {
  showNumber: PropTypes.number,
  total: PropTypes.number,
};

ElectoralRollFilter.defaultProps = {
  showNumber: 0,
  total: 0,
}

export default injectSheet(stylesheet)(ElectoralRollFilter);