import React from "react";
import PropTypes from "prop-types";
import {
  Button,
  Form,
  Modal,
  Checkbox,
  List,
} from "semantic-ui-react";
import injectSheet from "react-jss";
import Dropzone from "react-dropzone";

import { ModalStyleSheet } from "../../../../Common/GlobalStyle";
import AppContext from "../../../../Common/Constants/AppContext";
import colors from "../../../../Common/Constants/color";

const style = {
  groupOfType: {
    justifyContent: "center",
  },
  toggleContactType: {
    display: "flex",
    alignItems: "center",
    "& .ui.toggle.checkbox .box:before, .ui.toggle.checkbox label:before": {
      backgroundColor: "#0d71bb!important",
    },
  },
  helpText: {
    extend: ModalStyleSheet.helpText,
  },
  actionGroup: {
    extend: ModalStyleSheet.actionGroup,
    justifyContent: "space-bettwen",
  },
  header: {
    extend: ModalStyleSheet.header,
  },
  warning: {
    color: colors.primaryRed1,
    marginLeft: 25,
    marginTop: 5,
  },
  dropzoneContainer: {
    "& .dropzone": {
      margin: "1em 0 1em 0",
      padding: "4em 0em",
      borderRadius: ".3em",
      backgroundColor: `${colors.primaryGray4} !important`,
      color: `${colors.primaryBlue} !important`,
      fontWeight: "bold",
      fontSize: "9pt",
      textAlign: "center",
      cursor: "pointer",
    },
  },
};

class ImportModal extends React.Component {
  state = {
    isVisible: false,
    files: [],
    isRemoveAllVoter: false,
  };

  openModal = () => this.setState({ isVisible: true });

  hideModal = () => this.setState({ isVisible: false, files: [] });

  onDrop = (files) => this.setState({ files });

  onChnageCheckboxRemoveAllVoter = () => {
    this.setState({ isRemoveAllVoter: !this.state.isRemoveAllVoter });
  };

  onImportData = async () => {
    const { files, isRemoveAllVoter } = this.state;
    const { onUpload, removeAllVoters } = this.props;
    if (isRemoveAllVoter) await removeAllVoters();

    onUpload(files);
    this.hideModal();
  };

  render() {
    const { classes, loading } = this.props;
    const {
      intl: { messages },
    } = this.context;
    const { isVisible, isRemoveAllVoter, files } = this.state;

    return (
      <Modal open={isVisible} onClose={this.hideModal} size="tiny">
        <Modal.Header className={classes.header}>Upload File</Modal.Header>
        <Modal.Content>
          <Dropzone accept=".txt" multiple onDrop={this.onDrop}>
            {({ getRootProps, getInputProps }) => (
              <section className={classes.dropzoneContainer}>
                <div {...getRootProps({ className: "dropzone" })}>
                  <input {...getInputProps()} />
                  <p>Drag & drop some files here, or click to select files</p>
                </div>
              </section>
            )}
          </Dropzone>
          <List>
            {files.map((file) => (
              <List.Item>
                <List.Icon name="file alternate" />
                <List.Content>{file.name}</List.Content>
              </List.Item>
            ))}
          </List>
          <Form.Field className={classes.actionGroup}>
            <Checkbox
              checked={isRemoveAllVoter}
              label={<label>Remove all voters before importing</label>}
              onChange={this.onChnageCheckboxRemoveAllVoter}
            />
          </Form.Field>
          {isRemoveAllVoter && (
            <i className={classes.warning}>
              Are you sure to remove all voters before importing?
            </i>
          )}
        </Modal.Content>
        <Modal.Actions>
          <Button onClick={this.hideModal}>{messages.close}</Button>
          <Button
            positive
            loading={loading}
            content="Import Data"
            disabled={files.length === 0}
            onClick={this.onImportData}
          />
        </Modal.Actions>
      </Modal>
    );
  }
}

ImportModal.propTypes = {
  onUpload: PropTypes.func.isRequired,
};

ImportModal.contextType = AppContext;

export default injectSheet(style)(ImportModal);
