import React from 'react'
import injectSheet from "react-jss"

import stylesheet from "./stylesheet"
import ElectoralRollFilter from "./ImportHistoryFilter/ImportHistoryFilter"
import { Table, Pagination, Loader } from "semantic-ui-react"
import moment from 'moment'

import ToolsActionCreator from '../../ToolsActionCreator'
import { connect } from "react-redux"
import ReduxStatus from "../../../Common/Constants/ReduxStatus"
import AppContext from "../../../Common/Constants/AppContext"

class ImportHistory extends React.Component {

  componentDidMount() {
    const { dispatch } = this.context
    const { tools: {importHistory: { activePage, filter } } } = this.props
    dispatch(ToolsActionCreator.getImportHistories(activePage, filter))
  }

  handlePaginationChange = (e, { activePage }) => {
    const { dispatch } = this.context
    const { tools: {importHistory: { filter } } } = this.props
    dispatch(ToolsActionCreator.getImportHistories(activePage, filter))
  }

  onSearchFilterChange = (filter) => {
    const { dispatch } = this.context;
    dispatch(ToolsActionCreator.getImportHistories(1, filter));
  }

  render() {
    const { classes } = this.props
    const { tools } = this.props
    const { importHistory: { data, status, activePage, totalPage, totalRecord, filter } } = tools
    const { intl: { messages } } = this.context
    return (
      <div className={classes.toolImportHistory}>
        {
          status === ReduxStatus.loading && <Loader active />
        }
        <ElectoralRollFilter
          initFilter={filter}
          onSearchFilterChange={this.onSearchFilterChange}
          showNumber={data.length}
          total={totalRecord} 
        />
        <div className='tool-electoral-content'>
          <Table singleLine basic>
            <Table.Header>
              <Table.Row>
                <Table.HeaderCell>File Name</Table.HeaderCell>
                <Table.HeaderCell>Import Time</Table.HeaderCell>
                <Table.HeaderCell>Type</Table.HeaderCell>
                <Table.HeaderCell>Imported</Table.HeaderCell>
                <Table.HeaderCell>Errors (Not imported)</Table.HeaderCell>
                <Table.HeaderCell>Status</Table.HeaderCell>
              </Table.Row>
            </Table.Header>
            <Table.Body>
              {data.map(item => (
                <Table.Row key={item._id} className="contact-row">
                  <Table.Cell>{item.import_file}</Table.Cell>
                  <Table.Cell>{moment(new Date(item.created_at)).format('D MMM YYYY HH:mm')}</Table.Cell>
                  <Table.Cell>{item.type}</Table.Cell>
                  <Table.Cell>
                    <Table.Row>
                      <Table.Cell>
                        {item.success.toString()}
                      </Table.Cell>
                    </Table.Row>
                  </Table.Cell>
                  <Table.Cell>
                    <Table.Row>
                      <Table.Cell>
                        {item.failure.toString()}
                      </Table.Cell>
                      <Table.Cell>
                        {(item.failure !== 0 && item.error_file && item.error_file.url) &&
                          <a href={item.error_file.url} download={item.error_file.file_name} target="_blank">Download Errors</a>}
                      </Table.Cell>
                    </Table.Row>
                  </Table.Cell>
                  <Table.Cell className={item.status === "completed" ? classes.success : classes.processing}>{item.status}</Table.Cell>
                </Table.Row>
              ))}
            </Table.Body>
          </Table>
          {
          data.length > 0 && totalPage > 1 &&
          <Pagination
            activePage={activePage}
            totalPages={totalPage}
            onPageChange={this.handlePaginationChange}
          />
        }
        </div>
      </div>
    )
  }
}

const mapStateToProps = ({ tools }) => ({
  tools,
})

ImportHistory.contextType = AppContext
export default connect(mapStateToProps)(injectSheet(stylesheet)(ImportHistory))
