import React from 'react'
import PropTypes from 'prop-types'
import isequal from 'lodash.isequal'
import { Form } from "semantic-ui-react"
import injectSheet from "react-jss"
import Enum from "../../../../Common/Constants/Enum"
import AppContext from "../../../../Common/Constants/AppContext"
import stylesheet from './stylesheet'

const defaultFilter = {
  searchText: ''
};

class ImportHistoryFilter extends React.Component {
  constructor(props) {
    super(props);

    this.state = {
      ...defaultFilter,
    }
    this.handleChange = this.handleChange.bind(this);
  }

  handleChange(e, { name, value }) {
    const filter = {
      ...this.state,
      [name]: value,
    };
    if (isequal(filter, this.state)) {
      return
    }
    this.setState({
      ...filter,
    })
    this.handleSearch(filter)
  }

  handleSearch(filter) {
    const { onSearchFilterChange } = this.props;
    onSearchFilterChange(filter);
  }


  render() {
    const { classes, showNumber, total, selectedType } = this.props;
    const { intl: { messages } } = this.context;
    const emptyFilter = {
      key: 'all',
      text: messages.all,
      value: '',
    };

    const typeList = Object.keys(Enum.ImportHistoryTypes).map(item => ({
      key: item,
      value: item,
      text: Enum.ImportHistoryTypes[item],
    }));
    typeList.unshift(emptyFilter);

    return (
      <div className={classes.searchFilter}>
        <div className='search-container'>
          <div className='filter-box'>
             <div className='block-item'>
              <div className='text-title'>{messages.type}</div>
              <div className='control'>
                <Form.Select
                  options={typeList}
                  placeholder={messages.all}
                  className='state-dropdown'
                  name='type'
                  value={selectedType}
                  onChange={this.handleChange}
                />
              </div>
            </div> 
          </div>
        </div>
        <div className='display-contact-number'>
          Showing <b>{showNumber}</b> of <b>{total}</b> Electorate rolls
        </div>
      </div>
    )
  }
}

ImportHistoryFilter.contextType = AppContext;

ImportHistoryFilter.propTypes = {
  showNumber: PropTypes.number,
  total: PropTypes.number,
};

ImportHistoryFilter.defaultProps = {
  showNumber: 0,
  total: 0,
}

export default injectSheet(stylesheet)(ImportHistoryFilter);
