import React from 'react';
import injectSheet from 'react-jss';
import PrintingCreatedFilter from "./PrintingCreatedFilter/PrintingCreatedFilter";
import AppContext from "../../../../Common/Constants/AppContext";
import ReduxStatus from "../../../../Common/Constants/ReduxStatus";
import ToolsActionCreator from '../../../ToolsActionCreator';
import { Pagination, Icon, Table, Loader } from "semantic-ui-react";
import ConfirmModal from "../../../../Common/Components/Modal/ConfirmModal";
import stylesheet from './stylesheet';
import moment from "moment";
import colors from "../../../../Common/Constants/color";
import { config } from '../../../../configuration';

class PrintingCreated extends React.Component {

  constructor() {
    super();
    this.state = {
      toggleDeletePrinting: false,
      selectedDeletePrinting: null
    }
  }

  componentDidMount = () => {
    const { dispatch } = this.context;
    const { printings: { activePage, filter } } = this.props;
    dispatch(ToolsActionCreator.getPrintings(activePage, filter));
  }

  handlePaginationChange = (e, { activePage }) => {
    const { dispatch } = this.context;
    const { printings: { filter } } = this.props;
    dispatch(ToolsActionCreator.getPrintings(activePage, filter));
  }

  onSearchFilterChange = (filter) => {
    const { dispatch } = this.context;
    dispatch(ToolsActionCreator.getPrintings(1, filter));
  }

  handleDeletePrinting = () => {
    const { dispatch } = this.context;
    this.state.selectedDeletePrinting && dispatch(ToolsActionCreator.deletePrinting(this.state.selectedDeletePrinting._id));
    this.setState({
      toggleDeletePrinting: false,
      selectedDeletePrinting: null
    })
  }

  render() {
    const { intl: { messages } } = this.context;
    const { classes, printings: { data, activePage, totalPage, status }} = this.props;
    return (
      <div className={classes.printingCreatedPage}>
        {
          status === ReduxStatus.loading && <Loader active />
        }
        {
          this.state.toggleDeletePrinting &&
          <ConfirmModal
            isOpen={true}
            onClose={() => this.setState({ toggleDeletePrinting: false })}
            onConfirm={this.handleDeletePrinting}
            content={{
              mainText: 'You are about to permanently delete...',
              description: this.state.selectedDeletePrinting && this.state.selectedDeletePrinting.generated_pdf && this.state.selectedDeletePrinting.generated_pdf.file_name
            }}
            title='Delete Printing'
            cancelText={messages.keepThisContact}
            confirmText={messages.delete}
          />
        }
        <PrintingCreatedFilter onSearchFilterChange={this.onSearchFilterChange} />
        <div className='printing-created-content'>
          <Table singleLine selectable basic>
            <Table.Header>
              <Table.Row>
                <Table.HeaderCell>Message Type</Table.HeaderCell>
                <Table.HeaderCell>Contacts</Table.HeaderCell>
                <Table.HeaderCell>Created On</Table.HeaderCell>
                <Table.HeaderCell>PDF</Table.HeaderCell>
                <Table.HeaderCell>
                </Table.HeaderCell>
              </Table.Row>
            </Table.Header>
            <Table.Body>
              {data.map(item => (
                <Table.Row key={item._id} className="contact-row">
                  {/* <Table.Cell collapsing>
                    <Checkbox
                      // onChange={() => this.addOrRemoveCheck(item)}
                      // checked={this.state.currentCheckList.includes(item._id)}
                    />
                  </Table.Cell> */}
                  <Table.Cell>
                    {messages[item.type]}
                  </Table.Cell>
                  <Table.Cell>{item.pages}</Table.Cell>
                  <Table.Cell>
                    {item.created_at && moment(new Date(item.created_at)).format(config.DATE_FORMAT)}
                  </Table.Cell>
                  <Table.Cell>
                  {item.generated_pdf && 
                    <div style={{ color: colors.primaryBlue }}>
                      <Icon name='file pdf'/>
                      <a href={item.generated_pdf.url} download={item.generated_pdf.url} target="_blank" rel="noopener noreferrer">{item.generated_pdf.file_name}</a>
                    </div>
                  }
                  </Table.Cell>
                  <Table.Cell>
                    <div className="user-action">
                      <div>
                        <a onClick={() => this.setState({
                          toggleDeletePrinting: true,
                          selectedDeletePrinting: item,
                        })}>{messages.delete}</a>
                      </div>
                      <div>
                        <a href={item.generated_pdf.url} download target="_blank">Download</a>
                      </div>
                    </div>
                  </Table.Cell>
                </Table.Row>
              ))}
            </Table.Body>
          </Table>
          {
            data.length > 0 && totalPage > 1 &&
            <Pagination
              activePage={activePage}
              totalPages={totalPage}
              onPageChange={this.handlePaginationChange}
            />
          }
        </div>
      </div>
    );
  }
}

PrintingCreated.contextType = AppContext;

export default injectSheet(stylesheet)(PrintingCreated);