import React from 'react';
import isequal from 'lodash.isequal';
import injectSheet from 'react-jss';
import { Select, Form } from "semantic-ui-react";
import stylesheet from './stylesheet';
import AppContext from '../../../../../Common/Constants/AppContext';
import DatePicker from 'react-datepicker/es';
import Enum from '../../../../../Common/Constants/Enum';

class PrintingCreatedFilter extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      letter_type: null,
      created_month: null,
      created_year: null,
    };
  }

  handleChangeDate({name, value}) {
    let filter = null;
    if(name === 'created_month') {
      filter = {
        ...this.state,
        [name]: value,
        created_year: value.getFullYear()
      }
    } else {
      filter = {
        ...this.state,
        [name]: value
      }
    }
    if (isequal(filter, this.state)) {
      return;
    }
    this.setState({
      ...filter,
    });
    this.handleSearch(filter);
  }

  handleChangeDropdown = (e, {name, value}) => {
    let filter = null
    if(name === 'created_year') {
      filter = {
        ...this.state,
        [name]: value,
        created_month: null
      };
    } else {
      filter = {
        ...this.state,
        [name]: value,
      };
    }
    if (isequal(filter, this.state)) {
      return;
    }
    this.setState({
      ...filter,
    });
    this.handleSearch(filter);
  }

  handleResetFilters = () => {
    const filter = {
      letter_type: null,
      created_month: null,
      created_year: null
    }
    this.setState({
      ...filter,
    });
    this.handleSearch(filter);
  }

  handleSearch = (filter) => {
    const { onSearchFilterChange } = this.props;
    if (filter.created_month) {
      filter['$expr'] = {
        $and: [
          {$eq: [{$month: "$created_at"}, filter.created_month.getMonth() + 1]},
          {$eq: [{$year: "$created_at"}, filter.created_year]}
        ]
      }
    } else {
      if (filter.created_year) {
        filter['$expr'] = {
          $eq: [{$year: "$created_at"}, filter.created_year]
        }
      }
    }
    delete filter.created_year;
    delete filter.created_month;
    filter['type'] = filter.letter_type
    delete filter.letter_type;
    onSearchFilterChange(filter);
  }
  
  render() {
    const { intl: { messages } } = this.context;
    const { classes } = this.props;

    const emptyOption = {
      key: 'all',
      text: messages.all,
      value: '',
    };

    const lettersTypes = Object.values(Enum.LetterTypes).map(item => ({
      key: item,
      text: messages[item],
      value: item
    }));
    lettersTypes.unshift(emptyOption);

    const year = (new Date()).getFullYear();
    const futureYears = Array.from(new Array(5),( val, index) => index + year);
    const pastYears = Array.from(new Array(5),( val, index) => year - (index + 1)).reverse();
    const years = [...pastYears, ...futureYears].map(item => {
      return {key: item, text: item, value: item}
    })
    years.unshift(emptyOption);

    return (
      <div className={classes.printingCreatedFilter}>
        <div className='block-item'>
          <div className='text-title'>Message type</div>
          <div className='control'>
            <Select
              options={lettersTypes}
              placeholder={messages.all}
              name='letter_type'
              value={this.state.letter_type}
              onChange={this.handleChangeDropdown}
            />
          </div>
        </div>
        <div className='block-item date-picker'>
          <div className='text-title'>Month created</div>
            <Form>
              <Form.Field>
                <DatePicker
                  selected={this.state.created_month && new Date(this.state.created_month)}
                  onChange={value => this.handleChangeDate({name: 'created_month', value})}
                  name='created_month'
                  dateFormat='MM/YYYY'
                  placeholderText='MM/YYYY'
                  showMonthYearPicker
                />
              </Form.Field>
            </Form>
        </div>
        <div className='block-item'>
          <div className='text-title'>Year created</div>
          <div className='control'>
            <Select
              options={years}
              placeholder={messages.all}
              name='created_year'
              value={this.state.created_year}
              onChange={this.handleChangeDropdown}
            />
          </div>
        </div>
        <div className='reset-filter'>
          <a href="javascript:void(0)" onClick={this.handleResetFilters}>Reset filters</a>
          <img src={require('../../../../../Assets/reset.png')} alt='' />
        </div>
      </div>
    );
  }
}

PrintingCreatedFilter.contextType = AppContext;

export default injectSheet(stylesheet)(PrintingCreatedFilter);