import React from 'react';
import injectSheet from 'react-jss';
import stylesheet from './stylesheet';
import { FiArrowUp } from 'react-icons/all';
import Enum from "../../../../Common/Constants/Enum";
import ReduxStatus from "../../../../Common/Constants/ReduxStatus";
import { Select, Button, Loader } from "semantic-ui-react";
import ToolsActionCreator from '../../../ToolsActionCreator';
import AppContext from "../../../../Common/Constants/AppContext";

class PrintingPending extends React.Component {
  constructor() {
    super();
    this.state = {
      selectedState: '',
    }
  }

  handleChange = (e, { name, value }) => {
    this.setState({ selectedState: value });
    const { dispatch } = this.context;
    if(value) {
      dispatch(ToolsActionCreator.getLetters({state: value}));
    }
  }

  handleDownloadPDF(type, state){
    const { dispatch } = this.context;
    if(type && state) {
      dispatch(ToolsActionCreator.generateLetters({type, state}));
    }
  }

  render() {
    const { classes, letters: { data, status } } = this.props;
    const { intl: { messages } } = this.context;
    const emptyFilter = {
      key: 'select',
      text: 'Select',
      value: '',
    };
    const stateList = Object.keys(Enum.StateAustralia).map(item => ({
      key: item,
      value: item,
      text: Enum.StateAustralia[item],
    }))
    stateList.unshift(emptyFilter);
    return (
      <div className={classes.printingPendingPage}>
        <div className='state-container'>
          <div className='block-item'>
            <div className='text-title'>{messages.state}</div>
            <div className='control'>
              <Select
                options={stateList}
                placeholder={messages.all}
                className='state-dropdown'
                name='selectedState'
                value={this.state.selectedState}
                onChange={this.handleChange}
              />
            </div>
          </div>
        </div>
        {
          status === ReduxStatus.loading && <Loader active />
        }
        {
          status !== ReduxStatus.loading  && 
          <div className='printing-pending-content'>
            {
              !this.state.selectedState &&
              <div className='empty-state'>
                <FiArrowUp />
                <div className='empty-text'>
                  {messages.selectBranchGuidance}
                </div>
              </div>
            }
            {
              this.state.selectedState &&
              <div className='printing-pending-list'>
                {
                  data.map((item, idx) => 
                    <div className='printing-item' key={idx}>
                      <div className='info'>
                        <div className='name'>{this.state.selectedState} - {messages[item.letter]}</div>
                        <div className='number-contact'>
                          <span className='number'>{item.contact}</span> contacts
                        </div>
                      </div>
                      <Button disabled={item.contact === 0} color='green' onClick={() => this.handleDownloadPDF(item.letter, this.state.selectedState)}>
                          Create PDF
                      </Button>
                    </div>
                    )
                }
              </div>
            }
          </div>
        }
      </div>
    );
  }
}

PrintingPending.contextType = AppContext;

export default injectSheet(stylesheet)(PrintingPending);
