import ReduxStatus from "../Common/Constants/ReduxStatus";
import {
  GET_LETTERS, GET_LETTERS_SUCCESS, GET_LETTERS_FAILURE,
  GET_PRINTINGS, GET_PRINTINGS_SUCCESS, GET_PRINTINGS_FAILURE,
  GET_ELECTORAL_ROLLS, GET_ELECTORAL_ROLLS_SUCCESS, GET_ELECTORAL_ROLLS_FAILURE, 
  GET_IMPORT_HISTORY, GET_IMPORT_HISTORY_SUCCESS, GET_IMPORT_HISTORY_FAILURE,
  UPLOAD_ELECTORAL_LIST, UPLOAD_ELECTORAL_LIST_SUCCESS, UPLOAD_ELECTORAL_LIST_FAILED, RESET_UPLOAD_ELECTORAL_LIST, REMOVE_ALL_ELECTORAL_ROLLS_SUCCESS, REMOVE_ALL_ELECTORAL_ROLLS
} from "../Tools/ToolsActionCreator";

const initialState = {
  letters: {
    status: ReduxStatus.empty,
    data: [],
    message: "",
    filter: {},
  },
  printings: {
    status: ReduxStatus.empty,
    data: [],
    message: "",
    filter: {},
    activePage: 1,
    totalPage: 1,
    totalRecord: 0
  },
  electoralRolls: {
    status: ReduxStatus.empty,
    data: [],
    message: "",
    filter: {},
    activePage: 1,
    totalPage: 1,
    totalRecord: 0
  },
  importHistory: {
    status: ReduxStatus.empty,
    data: [],
    message: "",
    filter: {},
    activePage: 1,
    totalPage: 1,
    totalRecord: 0
  },
  uploadElectoralList: {
    status: ReduxStatus.empty,
    message: ""
  }
};

const actionsMap = {
  // Async action
  [GET_LETTERS]: state => {
    return {
      ...state,
      letters: {
        ...state.letters,
        status: ReduxStatus.loading,
        message: "",
      }
    };
  },
  [GET_LETTERS_SUCCESS]: (state, { activePage, totalPage, totalRecord, data, filter }) => {
    return {
      ...state,
      letters: {
        ...state.letters,
        data,
        status: ReduxStatus.loaded,
        message: "",
        filter,
        activePage, 
        totalPage, 
        totalRecord
      }
    };
  },
  [GET_LETTERS_FAILURE]: (state, { message }) => {
    return {
      ...state,
      letters: {
        ...state.letters,
        status: ReduxStatus.loadFailed,
        message
      }
    };
  },

  [GET_PRINTINGS]: state => {
    console.log('state', state.printings)
    return {
      ...state,
      printings: {
        ...state.printings,
        status: ReduxStatus.loading,
        message: "",
      }
    };
  },
  [GET_PRINTINGS_SUCCESS]: (state, { activePage, totalPage, totalRecord, data, filter }) => {
    return {
      ...state,
      printings: {
        ...state.printings,
        data,
        status: ReduxStatus.loaded,
        message: "",
        filter,
        activePage, 
        totalPage, 
        totalRecord
      }
    };
  },
  [GET_PRINTINGS_FAILURE]: (state, { message }) => {
    return {
      ...state,
      printings: {
        ...state.printings,
        status: ReduxStatus.loadFailed,
        message
      }
    };
  },

  [GET_ELECTORAL_ROLLS]: state => {
    return {
      ...state,
      electoralRolls: {
        ...state.electoralRolls,
        status: ReduxStatus.loading,
        message: "",
      }
    };
  },

  [GET_ELECTORAL_ROLLS_SUCCESS]: (state, { activePage, totalPage, totalRecord, data, filter }) => {
    return {
      ...state,
      electoralRolls: {
        ...state.electoralRolls,
        data,
        status: ReduxStatus.loaded,
        message: "",
        filter,
        activePage, 
        totalPage, 
        totalRecord
      }
    };
  },
  [GET_ELECTORAL_ROLLS_FAILURE]: (state, { message }) => {
    return {
      ...state,
      electoralRolls: {
        ...state.electoralRolls,
        status: ReduxStatus.loadFailed,
        message
      }
    };
  },

  [REMOVE_ALL_ELECTORAL_ROLLS]: state => {
    return {
      ...state,
      electoralRolls: {
        ...state.electoralRolls,
        status: ReduxStatus.loading,
        message: "",
      }
    };
  },

  [REMOVE_ALL_ELECTORAL_ROLLS_SUCCESS]: (state) => {
    return {
      ...state,
      electoralRolls: initialState.electoralRolls
    };
  },

  [GET_IMPORT_HISTORY]: state => {
    return {
      ...state,
      importHistory: {
        ...state.importHistory,
        status: ReduxStatus.loading,
        message: "",
      }
    };
  },
  [GET_IMPORT_HISTORY_SUCCESS]: (state, { activePage, totalPage, totalRecord, data, filter }) => {
    return {
      ...state,
      importHistory: {
        ...state.importHistory,
        data,
        status: ReduxStatus.loaded,
        message: "",
        filter,
        activePage, 
        totalPage, 
        totalRecord
      }
    };
  },
  [GET_IMPORT_HISTORY_FAILURE]: (state, { message }) => {
    return {
      ...state,
      importHistory: {
        ...state.importHistory,
        status: ReduxStatus.loadFailed,
        message
      }
    };
  },

  [UPLOAD_ELECTORAL_LIST]: (state) => {
    return {
      ...state,
      uploadElectoralList:{
        ...state.uploadElectoralList,
        status: ReduxStatus.loading
      }
    }
  },
  [UPLOAD_ELECTORAL_LIST_SUCCESS]: (state, payload) => {
    return {
      ...state,
      uploadElectoralList:{
        ...state.uploadElectoralList,
        filename: payload.filename,
        status: ReduxStatus.loaded
      }
    }
  },
  [UPLOAD_ELECTORAL_LIST_FAILED]: (state) => {
    return {
      ...state,
      uploadElectoralList:{
        ...state.uploadElectoralList,
        status: ReduxStatus.loadFailed
      }
    }
  },
  [RESET_UPLOAD_ELECTORAL_LIST]: (state) => {
    return {
      ...state,
      uploadElectoralList:{
        status: ReduxStatus.empty,
        message: ""
      }
    }
  },
}

export default function reducer(state = initialState, action = {}) {
  const fn = actionsMap[action.type];
  return fn ? fn(state, action.payload) : state;
}
